/**************
 * GtkInfoBar *
 **************/
infobar {
  border-style: none;

  &.info { background-color: $info_bg_color; }

  &.question { background-color: $question_bg_color; }

  &.warning { background-color: $warning_bg_color; }

  &.error { background-color: $error_bg_color; }

  &.info,
  &.question,
  &.warning,
  &.error {
    > label, & { color: $black; }

    button {
      @extend %button_selected;

      color: $fg_color;
      background-color: $bg_color;
      
      > label,
      > image { color: $fg_color; }
      
    }

    selection {}

    *:link { @extend %link_selected; }
  }
}
