stage {
  font-family: Futura Bk bt, sans, Sans-Serif;
  font-size: 9pt;
  color: #D3DAE3;
}

.label-shadow {
  color: rgba(0, 0, 0, 0);
}

.sound-button, .menu #notification .notification-button, .menu #notification .notification-icon-button, .popup-menu #notification .notification-button, .popup-menu #notification .notification-icon-button {
  min-height: 20px;
  padding: 5px 32px;
  transition-duration: 0;
  text-shadow: none;
  color: #D3DAE3;
  background-color: #2c2f39;
  border: 1px solid rgba(255, 255, 255, 0.12);
  box-shadow: inset 0 2px 4px rgba(44, 47, 57, 0.05);
}

.sound-button, .menu #notification .notification-button, .menu #notification .notification-icon-button, .popup-menu #notification .notification-button, .popup-menu #notification .notification-icon-button {
  border-radius: 2px;
}

.sound-button:focus, .menu #notification .notification-button:focus, .menu #notification .notification-icon-button:focus, .popup-menu #notification .notification-button:focus, .popup-menu #notification .notification-icon-button:focus {
  text-shadow: none;
  color: #D3DAE3;
  background-color: #2c2f39;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px rgba(44, 47, 57, 0.05);
}

.sound-button:hover, .menu #notification .notification-button:hover, .menu #notification .notification-icon-button:hover, .popup-menu #notification .notification-button:hover, .popup-menu #notification .notification-icon-button:hover {
  text-shadow: none;
  color: #D3DAE3;
  background-color: #383a47;
  border: 1px solid rgba(255, 255, 255, 0.12);
  box-shadow: inset 0 2px 4px rgba(56, 58, 71, 0.05);
}

.sound-button:hover:focus, .menu #notification .notification-button:hover:focus, .menu #notification .notification-icon-button:hover:focus, .popup-menu #notification .notification-button:hover:focus, .popup-menu #notification .notification-icon-button:hover:focus {
  text-shadow: none;
  color: #D3DAE3;
  background-color: #2c2f39;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px rgba(44, 47, 57, 0.05);
}

.sound-button:active, .menu #notification .notification-button:active, .menu #notification .notification-icon-button:active, .popup-menu #notification .notification-button:active, .popup-menu #notification .notification-icon-button:active {
  text-shadow: none;
  color: #ffffff;
  background-color: #fb8441;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px #fb8441;
}

.sound-button:insensitive, .menu #notification .notification-button:insensitive, .menu #notification .notification-icon-button:insensitive, .popup-menu #notification .notification-button:insensitive, .popup-menu #notification .notification-icon-button:insensitive {
  text-shadow: none;
  color: rgba(211, 218, 227, 0.45);
  border: 1px solid rgba(255, 255, 255, 0);
  background-color: rgba(44, 47, 57, 0.55);
  box-shadow: inset 0 2px 4px rgba(44, 47, 57, 0.05);
}

.modal-dialog-button-box .modal-dialog-button, .notification-button, .notification-icon-button {
  min-height: 20px;
  padding: 5px 32px;
  transition-duration: 0;
  border-radius: 2px;
  text-shadow: none;
  color: #D3DAE3;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.4);
}

.modal-dialog-button-box .modal-dialog-button:hover, .notification-button:hover, .notification-icon-button:hover {
  text-shadow: none;
  color: #D3DAE3;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

.modal-dialog-button-box .modal-dialog-button:focus, .notification-button:focus, .notification-icon-button:focus {
  color: #fb8441;
}

.modal-dialog-button-box .modal-dialog-button:active, .notification-button:active, .notification-icon-button:active {
  text-shadow: none;
  color: #ffffff;
  border: 1px solid #fb8441;
  background-color: #fb8441;
}

.modal-dialog-button-box .modal-dialog-button:insensitive, .notification-button:insensitive, .notification-icon-button:insensitive {
  text-shadow: none;
  color: #5b5f68;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

#menu-search-entry, .menu #notification StEntry, .popup-menu #notification StEntry {
  padding: 7px;
  caret-size: 1px;
  selection-background-color: #fb8441;
  selected-color: #ffffff;
  transition-duration: 300ms;
  border-radius: 3px;
  color: #D3DAE3;
  background-color: #282a33;
  border: 1px solid rgba(255, 255, 255, 0.12);
  box-shadow: inset 0 2px 4px rgba(40, 42, 51, 0.05);
}

#menu-search-entry:focus, .menu #notification StEntry:focus, .popup-menu #notification StEntry:focus, #menu-search-entry:hover, .menu #notification StEntry:hover, .popup-menu #notification StEntry:hover {
  color: #D3DAE3;
  background-color: #282a33;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px rgba(40, 42, 51, 0.05);
}

#menu-search-entry:insensitive, .menu #notification StEntry:insensitive, .popup-menu #notification StEntry:insensitive {
  color: rgba(211, 218, 227, 0.45);
  background-color: #2d2f38;
  border-color: 1px solid rgba(65, 67, 75, 0.516);
  box-shadow: inset 0 2px 4px rgba(45, 47, 56, 0.05);
}

#menu-search-entry StIcon.capslock-warning, .menu #notification StEntry StIcon.capslock-warning, .popup-menu #notification StEntry StIcon.capslock-warning {
  icon-size: 16px;
  warning-color: #F27835;
  padding: 0 4px;
}

.notification StEntry {
  padding: 7px;
  caret-size: 1px;
  caret-color: #D3DAE3;
  selection-background-color: #fb8441;
  selected-color: #ffffff;
  transition-duration: 300ms;
  border-radius: 3px;
  color: #D3DAE3;
  background-color: rgba(89, 94, 114, 0.4);
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
}

.notification StEntry:focus {
  color: #ffffff;
  background-color: #fb8441;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
}

.notification StEntry:insensitive {
  color: rgba(211, 218, 227, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
}

StScrollView.vfade {
  -st-vfade-offset: 0px;
}

StScrollView.hfade {
  -st-hfade-offset: 0px;
}

StScrollBar {
  padding: 8px;
}

StScrollView StScrollBar {
  min-width: 5px;
  min-height: 5px;
}

StScrollBar StBin#trough {
  background-color: rgba(40, 42, 51, 0.1);
  border-radius: 8px;
}

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle {
  border-radius: 2px;
  background-color: #72767f;
  border: 0px solid;
  margin: 0px;
}

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover {
  background-color: #62666f;
}

StScrollBar StButton#vhandle:active, StScrollBar StButton#hhandle:active {
  background-color: #fb8441;
}

.separator {
  -gradient-height: 1px;
  -gradient-start: rgba(0, 0, 0, 0);
  -gradient-end: rgba(0, 0, 0, 0);
  -margin-horizontal: 1.5em;
  height: 1em;
}

.popup-slider-menu-item,
.slider {
  -slider-height: 4px;
  -slider-background-color: rgba(255, 255, 255, 0.12);
  -slider-border-color: rgba(0, 0, 0, 0);
  -slider-active-background-color: #fb8441;
  -slider-active-border-color: rgba(0, 0, 0, 0);
  -slider-border-width: 0;
  -slider-handle-radius: 4px;
  height: 18px;
  min-width: 15em;
  border: 0 solid transparent;
  border-right-width: 1px;
  border-left-width: 5px;
  color: transparent;
}

.popup-menu-item:active .popup-slider-menu-item, .popup-menu-item:active .slider {
  -slider-background-color: rgba(0, 0, 0, 0.2);
  -slider-active-background-color: #ffffff;
}

.check-box CinnamonGenericContainer {
  spacing: .2em;
  min-height: 30px;
  padding-top: 2px;
}

.check-box StLabel {
  font-weight: normal;
}

.check-box StBin {
  width: 16px;
  height: 16px;
  background-image: url("assets/checkbox/checkbox-unchecked.svg");
}

.check-box:focus StBin {
  background-image: url("assets/checkbox/checkbox-unchecked-focused.svg");
}

.check-box:checked StBin {
  background-image: url("assets/checkbox/checkbox-checked.svg");
}

.check-box:focus:checked StBin {
  background-image: url("assets/checkbox/checkbox-checked-focused.svg");
}

.radiobutton CinnamonGenericContainer {
  spacing: .2em;
  height: 26px;
  padding-top: 2px;
}

.radiobutton StLabel {
  padding-top: 4px;
  font-size: 0.9em;
  box-shadow: none;
}

.radiobutton StBin {
  width: 16px;
  height: 16px;
  background-image: url("assets/checkbox/checkbox-unchecked.svg");
}

.radiobutton:focus StBin {
  background-image: url("assets/checkbox/checkbox-unchecked-focused.svg");
}

.radiobutton:checked StBin {
  background-image: url("assets/checkbox/checkbox-checked.svg");
}

.radiobutton:focus:checked StBin {
  background-image: url("assets/checkbox/checkbox-checked-focused.svg");
}

.toggle-switch {
  width: 50px;
  height: 20px;
  background-size: contain;
  background-image: url("assets/switch/switch-off.svg");
}

.toggle-switch:checked {
  background-image: url("assets/switch/switch-on.svg");
}

.popup-menu-item:active .toggle-switch {
  background-image: url("common-assets/switch/switch-off-selected.svg");
}

.popup-menu-item:active .toggle-switch:checked {
  background-image: url("common-assets/switch/switch-on-selected.svg");
}

.cinnamon-link {
  color: #fdc5a5;
  text-decoration: underline;
}

.cinnamon-link:hover {
  color: #fee5d7;
}

#Tooltip {
  border-radius: 3px;
  padding: 5px 12px;
  background-color: #282A33;
  color: #D3DAE3;
  font-size: 1em;
  font-weight: normal;
  text-align: center;
}

.menu,
.popup-menu,
.popup-combo-menu {
  color: #D3DAE3;
  border-image: url("assets/menu/menu.svg") 9 9 9 9;
}

.menu-arrow,
.popup-menu-arrow {
  icon-size: 16px;
}

.menu .popup-sub-menu,
.popup-menu .popup-sub-menu,
.popup-combo-menu .popup-sub-menu {
  background-gradient-direction: none;
  box-shadow: none;
  border-image: url("assets/menu/submenu.svg") 9 9 9 9;
}

.menu .popup-sub-menu .popup-menu-item:ltr,
.popup-menu .popup-sub-menu .popup-menu-item:ltr,
.popup-combo-menu .popup-sub-menu .popup-menu-item:ltr {
  padding-right: 1em;
}

.menu .popup-sub-menu .popup-menu-item:rtl,
.popup-menu .popup-sub-menu .popup-menu-item:rtl,
.popup-combo-menu .popup-sub-menu .popup-menu-item:rtl {
  padding-left: 1em;
}

.menu .popup-sub-menu StScrollBar,
.popup-menu .popup-sub-menu StScrollBar,
.popup-combo-menu .popup-sub-menu StScrollBar {
  padding: 8px;
}

.menu .popup-sub-menu StScrollBar StBin#trough, .menu .popup-sub-menu StScrollBar StBin#vhandle,
.popup-menu .popup-sub-menu StScrollBar StBin#trough,
.popup-menu .popup-sub-menu StScrollBar StBin#vhandle,
.popup-combo-menu .popup-sub-menu StScrollBar StBin#trough,
.popup-combo-menu .popup-sub-menu StScrollBar StBin#vhandle {
  border-width: 0;
}

.menu .popup-menu-content,
.popup-menu .popup-menu-content,
.popup-combo-menu .popup-menu-content {
  padding: 1em 0em 1em 0em;
}

.menu .popup-menu-item,
.popup-menu .popup-menu-item,
.popup-combo-menu .popup-menu-item {
  padding: .4em 1.75em;
  spacing: 1em;
}

.menu .popup-menu-item:active,
.popup-menu .popup-menu-item:active,
.popup-combo-menu .popup-menu-item:active {
  color: #ffffff;
  background-color: transparent;
  border-image: url("common-assets/menu/menu-hover.svg") 9 9 1 1;
}

.menu .popup-menu-item:insensitive,
.popup-menu .popup-menu-item:insensitive,
.popup-combo-menu .popup-menu-item:insensitive {
  color: rgba(211, 218, 227, 0.5);
  background: none;
}

.menu .popup-inactive-menu-item,
.popup-menu .popup-inactive-menu-item,
.popup-combo-menu .popup-inactive-menu-item {
  color: #D3DAE3;
}

.menu .popup-inactive-menu-item:insensitive,
.popup-menu .popup-inactive-menu-item:insensitive,
.popup-combo-menu .popup-inactive-menu-item:insensitive {
  color: rgba(211, 218, 227, 0.45);
}

.menu .popup-menu-item:active .popup-inactive-menu-item,
.popup-menu .popup-menu-item:active .popup-inactive-menu-item,
.popup-combo-menu .popup-menu-item:active .popup-inactive-menu-item {
  color: #ffffff;
}

.menu-icon,
.popup-menu-icon {
  icon-size: 16px;
}

.popup-menu-boxpointer {
  -arrow-border-radius: 3px;
  -arrow-background-color: rgba(0, 0, 0, 0);
  -arrow-border-width: 1px;
  -arrow-border-color: rgba(0, 0, 0, 0);
  -arrow-base: 0;
  -arrow-rise: 0;
}

.popup-combo-menu {
  padding: 10px 1px;
}

.popup-combobox-item {
  spacing: 1em;
}

.popup-separator-menu-item {
  -gradient-height: 2px;
  -gradient-start: transparent;
  -gradient-end: transparent;
  -margin-horizontal: 1.5em;
  height: 1em;
}

.popup-alternating-menu-item:alternate {
  font-weight: normal;
}

.popup-device-menu-item {
  spacing: .5em;
}

.popup-subtitle-menu-item {
  font-weight: normal;
}

.nm-menu-item-icons {
  spacing: .5em;
}

#panel {
  font-weight: bold;
  height: 27px;
  width: 32px;
}

#panel:highlight {
  border-image: none;
  background-color: rgba(252, 65, 56, 0.5);
}

#panelLeft {
  spacing: 4px;
}

#panelLeft:dnd {
  background-gradient-direction: vertical;
  background-gradient-start: rgba(255, 0, 0, 0.05);
  background-gradient-end: rgba(255, 0, 0, 0.2);
}

#panelLeft:ltr {
  padding-right: 4px;
}

#panelLeft:rtl {
  padding-left: 4px;
}

#panelLeft.vertical {
  padding: 0;
}

#panelLeft.vertical:ltr {
  padding-right: 0px;
}

#panelLeft.vertical:rtl {
  padding-left: 0px;
}

#panelRight:dnd {
  background-gradient-direction: vertical;
  background-gradient-start: rgba(0, 0, 255, 0.05);
  background-gradient-end: rgba(0, 0, 255, 0.2);
}

#panelRight:ltr {
  padding-left: 4px;
  spacing: 0px;
}

#panelRight:rtl {
  padding-right: 4px;
  spacing: 0px;
}

#panelRight.vertical {
  padding: 0;
}

#panelRight.vertical:ltr {
  padding-right: 0px;
}

#panelRight.vertical:rtl {
  padding-left: 0px;
}

#panelCenter {
  spacing: 4px;
}

#panelCenter:dnd {
  background-gradient-direction: vertical;
  background-gradient-start: rgba(0, 255, 0, 0.05);
  background-gradient-end: rgba(0, 255, 0, 0.2);
}

.panel-top, .panel-bottom, .panel-left, .panel-right {
  color: #D3DAE3;
  font-size: 1em;
  padding: 0px;
}

.panel-top {
  border-image: url("common-assets/panel/panel-top.svg") 1 1 1 1;
}

.panel-bottom {
  border-image: url("common-assets/panel/panel-bottom.svg") 1 1 1 1;
}

.panel-left {
  border-image: url("common-assets/panel/panel-left.svg") 1 1 1 1;
}

.panel-right {
  border-image: url("common-assets/panel/panel-right.svg") 1 1 1 1;
}

.panel-dummy {
  background-color: rgba(252, 65, 56, 0.5);
}

.panel-dummy:entered {
  background-color: rgba(252, 65, 56, 0.6);
}

.panel-status-button {
  border-width: 0;
  -natural-hpadding: 3px;
  -minimum-hpadding: 3px;
  font-weight: bold;
  color: white;
  height: 22px;
}

.panel-button {
  -natural-hpadding: 6px;
  -minimum-hpadding: 2px;
  font-weight: bold;
  color: white;
  transition-duration: 100;
}

.system-status-icon {
  icon-size: 16px;
  padding: 0 1px;
}

#overview {
  spacing: 12px;
}

.window-caption {
  background-color: #282A33;
  border: 1px solid #282A33;
  color: #D3DAE3;
  spacing: 25px;
  border-radius: 2px;
  font-size: 9pt;
  padding: 5px 8px;
  -cinnamon-caption-spacing: 4px;
}

#selected.window-caption {
  background-color: #fb8441;
  color: #ffffff;
  border: 1px solid #fb8441;
  spacing: 25px;
}

.expo-workspaces-name-entry,
#selected.expo-workspaces-name-entry {
  height: 15px;
  border-radius: 2px;
  font-size: 9pt;
  padding: 5px 8px;
  -cinnamon-caption-spacing: 4px;
  color: #D3DAE3;
  background-color: rgba(89, 94, 114, 0.4);
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
}

.expo-workspaces-name-entry:focus,
#selected.expo-workspaces-name-entry:focus {
  border: 1px solid #fb8441;
  background-color: #fb8441;
  color: #ffffff;
  font-style: italic;
  transition-duration: 300;
  selection-background-color: #ffffff;
  selected-color: #fb8441;
}

.expo-workspace-thumbnail-frame {
  border: 4px solid rgba(255, 255, 255, 0);
  background-color: rgba(255, 255, 255, 0);
  border-radius: 2px;
}

#active.expo-workspace-thumbnail-frame {
  border: 4px solid #fb8441;
  background-color: black;
  border-radius: 2px;
}

.expo-background {
  background-color: #282a33;
}

.workspace-thumbnails {
  spacing: 26px;
}

.workspace-thumbnails-background, .workspace-thumbnails-background:rtl {
  padding: 8px;
}

.workspace-add-button {
  background-image: url("common-assets/misc/add-workspace.svg");
  height: 200px;
  width: 35px;
  transition-duration: 100;
}

.workspace-add-button:hover {
  background-image: url("common-assets/misc/add-workspace-hover.svg");
  transition-duration: 100;
}

.workspace-add-button:active {
  background-image: url("common-assets/misc/add-workspace-active.svg");
  transition-duration: 100;
}

.workspace-overview-background-shade {
  background-color: rgba(0, 0, 0, 0.5);
}

.workspace-close-button,
.window-close {
  background-image: url("common-assets/misc/close.svg");
  background-size: 26px;
  height: 26px;
  width: 26px;
  -cinnamon-close-overlap: 10px;
}

.workspace-close-button:hover,
.window-close:hover {
  background-image: url("common-assets/misc/close-hover.svg");
  background-size: 26px;
  height: 26px;
  width: 26px;
}

.workspace-close-button:active,
.window-close:active {
  background-image: url("common-assets/misc/close-active.svg");
  background-size: 26px;
  height: 26px;
  width: 26px;
}

.window-close-area {
  background-image: url("common-assets/misc/trash-icon.svg");
  height: 120px;
  width: 400px;
}

.about-content {
  width: 550px;
  height: 250px;
  spacing: 8px;
  padding-bottom: 10px;
}

.about-title {
  font-size: 2em;
  font-weight: bold;
}

.about-uuid {
  font-size: 10px;
  color: #888;
}

.about-icon {
  padding-right: 20px;
  padding-bottom: 14px;
}

.about-scrollBox {
  border: 1px solid rgba(255, 255, 255, 0.12);
  border-radius: 2px;
  background-color: #282A33;
  padding: 4px;
  padding-right: 0;
  border-radius: 0;
}

.about-scrollBox-innerBox {
  padding: 1.2em;
  spacing: 1.2em;
}

.about-description {
  padding-top: 4px;
  padding-bottom: 16px;
}

.about-version {
  padding-left: 7px;
  font-size: 10px;
  color: #888;
}

.calendar {
  padding: .4em 1.75em;
  spacing-rows: 0px;
  spacing-columns: 0px;
}

.calendar-month-label {
  color: #D3DAE3;
  font-weight: bold;
  padding: 8px 0;
}

.calendar-change-month-back,
.calendar-change-month-forward {
  width: 16px;
  height: 16px;
}

.calendar-change-month-back {
  background-image: url("common-assets/misc/calendar-arrow-left.svg");
}

.calendar-change-month-back:focus, .calendar-change-month-back:hover {
  background-image: url("common-assets/misc/calendar-arrow-left-hover.svg");
}

.calendar-change-month-back:active {
  background-image: url("common-assets/misc/calendar-arrow-left.svg");
}

.calendar-change-month-back:rtl {
  background-image: url("common-assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-back:rtl:focus, .calendar-change-month-back:rtl:hover {
  background-image: url("common-assets/misc/calendar-arrow-right-hover.svg");
}

.calendar-change-month-back:rtl:active {
  background-image: url("common-assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-forward {
  background-image: url("common-assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-forward:focus, .calendar-change-month-forward:hover {
  background-image: url("common-assets/misc/calendar-arrow-right-hover.svg");
}

.calendar-change-month-forward:active {
  background-image: url("common-assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-forward:rtl {
  background-image: url("common-assets/misc/calendar-arrow-left.svg");
}

.calendar-change-month-forward:rtl:focus, .calendar-change-month-forward:rtl:hover {
  background-image: url("common-assets/misc/calendar-arrow-left-hover.svg");
}

.calendar-change-month-forward:rtl:active {
  background-image: url("common-assets/misc/calendar-arrow-left.svg");
}

.datemenu-date-label {
  padding: .4em 1.75em;
  font-weight: bold;
  text-align: center;
  color: #D3DAE3;
  border-radius: 2px;
}

.calendar-day-base {
  font-size: 80%;
  text-align: center;
  width: 25px;
  height: 25px;
  padding: 0.1em;
  margin: 2px;
  border-radius: 12.5px;
}

.calendar-day-heading {
  color: rgba(211, 218, 227, 0.85);
  margin-top: 1em;
  font-size: 70%;
}

.calendar-day {
  border-width: 0;
  color: rgba(211, 218, 227, 0.8);
}

.calendar-day-top {
  border-top-width: 0;
}

.calendar-day-left {
  border-left-width: 0;
}

.calendar-nonwork-day {
  color: #D3DAE3;
  background-color: transparent;
  font-weight: bold;
}

.calendar-today,
.calendar-today:active,
.calendar-today:focus,
.calendar-today:hover {
  font-weight: bold;
  color: #ffffff;
  background-color: #fb8441;
  border-width: 0;
}

.calendar-other-month-day {
  color: rgba(211, 218, 227, 0.3);
  opacity: 1;
}

.calendar-week-number {
  color: rgba(211, 218, 227, 0.7);
  font-size: 80%;
}

#notification {
  border-radius: 3px;
  border-image: url("common-assets/misc/bg.svg") 9 9 9 9;
  padding: 13px;
  spacing-rows: 10px;
  spacing-columns: 10px;
  margin-from-right-edge-of-screen: 20px;
  width: 34em;
  color: #D3DAE3;
}

.menu #notification, .popup-menu #notification {
  border-image: url("assets/misc/message.svg") 9 9 9 9;
}

.menu #notification, .menu #notification.multi-line-notification, .popup-menu #notification, .popup-menu #notification.multi-line-notification {
  color: #D3DAE3;
}

.menu #notification .notification-button, .menu #notification .notification-icon-button, .popup-menu #notification .notification-button, .popup-menu #notification .notification-icon-button {
  padding: 5px;
}

#notification.multi-line-notification {
  padding-bottom: 13px;
  color: #D3DAE3;
}

#notification-scrollview {
  max-height: 10em;
}

#notification-scrollview > .top-shadow, #notification-scrollview > .bottom-shadow {
  height: 1em;
}

#notification-scrollview:ltr > StScrollBar {
  padding-left: 6px;
}

#notification-scrollview:rtl > StScrollBar {
  padding-right: 6px;
}

#notification-body {
  spacing: 5px;
}

#notification-actions {
  spacing: 10px;
}

.notification-with-image {
  min-height: 159px;
  color: #D3DAE3;
}

.notification-button, .notification-icon-button {
  padding: 5px;
}

.notification-icon-button > StIcon {
  icon-size: 36px;
}

#altTabPopup {
  padding: 8px;
  spacing: 16px;
}

.switcher-list {
  color: #D3DAE3;
  background: none;
  border: none;
  border-image: url("common-assets/misc/bg.svg") 9 9 9 9;
  border-radius: 3px;
  padding: 20px;
}

.switcher-list > StBoxLayout {
  padding: 4px;
}

.switcher-list-item-container {
  spacing: 8px;
}

.switcher-list .item-box {
  padding: 8px;
  border-radius: 2px;
}

.switcher-list .item-box:outlined {
  padding: 8px;
  border: 1px solid #fb8441;
}

.switcher-list .item-box:selected {
  color: #ffffff;
  background-color: #fb8441;
  border: 0px solid #fb8441;
}

.switcher-list .thumbnail {
  width: 256px;
}

.switcher-list .thumbnail-box {
  padding: 2px;
  spacing: 4px;
}

.switcher-list .separator {
  width: 1px;
  background: rgba(255, 255, 255, 0.2);
}

.switcher-arrow {
  border-color: rgba(0, 0, 0, 0);
  color: #D3DAE3;
}

.switcher-arrow:highlighted {
  border-color: rgba(0, 0, 0, 0);
  color: #D3DAE3;
}

.thumbnail-scroll-gradient-left {
  background-color: rgba(0, 0, 0, 0);
  border-radius: 24px;
  border-radius-topright: 0px;
  border-radius-bottomright: 0px;
  width: 60px;
}

.thumbnail-scroll-gradient-right {
  background-color: rgba(0, 0, 0, 0);
  border-radius: 24px;
  border-radius-topleft: 0px;
  border-radius-bottomleft: 0px;
  width: 60px;
}

.ripple-box {
  width: 104px;
  height: 104px;
  background-image: url("common-assets/misc/corner-ripple.svg");
  background-size: contain;
}

.lightbox {
  background-color: rgba(0, 0, 0, 0.4);
}

.flashspot {
  background-color: white;
}

.modal-dialog {
  color: #D3DAE3;
  background-color: rgba(50, 52, 61, 0);
  border: none;
  border-image: url("assets/misc/modal.svg") 9 9 9 67;
  padding: 0 5px 6px 5px;
}

.modal-dialog > StBoxLayout:first-child {
  padding: 20px 10px 10px 10px;
}

.modal-dialog-button-box {
  spacing: 0;
  margin: 0px;
  padding: 14px 10px;
  background: none;
  border: none;
  border-image: url("assets/misc/button-box.svg") 9 9 9 9;
}

.modal-dialog-button-box .modal-dialog-button {
  padding-top: 0;
  padding-bottom: 0;
  height: 30px;
}

.run-dialog {
  padding: 0px 15px 10px 15px;
  border-image: url("common-assets/misc/bg.svg") 9 9 9 9;
}

.run-dialog > * {
  padding: 0;
}

.run-dialog-label {
  font-weight: 400;
  color: #D3DAE3;
  padding-bottom: 6px;
}

.run-dialog-error-label {
  color: #FC4138;
}

.run-dialog-error-box {
  padding-top: 15px;
  spacing: 5px;
}

.run-dialog-completion-box {
  padding-left: 15px;
  font-size: 10px;
}

.run-dialog-entry {
  width: 21em;
  padding: 7px;
  border-radius: 3px;
  caret-color: #D3DAE3;
  selected-color: #ffffff;
  selection-background-color: #fb8441;
  color: #D3DAE3;
  background-color: rgba(89, 94, 114, 0.4);
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
}

.run-dialog-entry:focus {
  color: #D3DAE3;
  background-color: rgba(89, 94, 114, 0.4);
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
  background-color: #282A33;
  border-color: #fb8441;
}

.run-dialog .modal-dialog-button-box {
  border: none;
  border-image: none;
  box-shadow: none;
  background: none;
  background-gradient-direction: none;
}

/* CinnamonMountOperation Dialogs */
.cinnamon-mount-operation-icon {
  icon-size: 48px;
}

.mount-password-reask {
  color: #F27835;
}

.show-processes-dialog,
.mount-question-dialog {
  spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
  padding-left: 17px;
  width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
  padding-right: 17px;
}

.show-processes-dialog-app-list {
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.show-processes-dialog-app-list-item {
  color: #ccc;
}

.show-processes-dialog-app-list-item:hover {
  color: white;
}

.show-processes-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
  font-size: 1.1em;
}

.magnifier-zoom-region {
  border: 2px solid maroon;
}

.magnifier-zoom-region .full-screen {
  border-width: 0px;
}

#keyboard {
  background-color: #282A33;
  border-width: 0;
  border-top-width: 1px;
  border-color: rgba(0, 0, 0, 0.4);
}

.keyboard-layout {
  spacing: 10px;
  padding: 10px;
}

.keyboard-row {
  spacing: 15px;
}

.keyboard-key {
  min-height: 2em;
  min-width: 2em;
  font-size: 14pt;
  font-weight: bold;
  border-radius: 3px;
  box-shadow: none;
  text-shadow: none;
  color: #D3DAE3;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.4);
}

.keyboard-key:hover {
  text-shadow: none;
  color: #D3DAE3;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

.keyboard-key:active, .keyboard-key:checked {
  text-shadow: none;
  color: #ffffff;
  border: 1px solid #fb8441;
  background-color: #fb8441;
}

.keyboard-key:grayed {
  text-shadow: none;
  color: #5b5f68;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

.keyboard-subkeys {
  color: #D3DAE3;
  padding: 5px;
  -arrow-border-radius: 2px;
  -arrow-background-color: #282A33;
  -arrow-border-width: 1px;
  -arrow-border-color: rgba(0, 0, 0, 0.4);
  -arrow-base: 20px;
  -arrow-rise: 10px;
  -boxpointer-gap: 5px;
}

.menu-favorites-box {
  margin: auto;
  padding: 10px;
  transition-duration: 300;
  background-color: #32343D;
  border: 1px solid rgba(255, 255, 255, 0.12);
}

.menu-favorites-button {
  padding: 10px;
  border: 1px solid rgba(0, 0, 0, 0);
}

.menu-favorites-button:hover {
  text-shadow: none;
  color: #D3DAE3;
  background-color: #383a47;
  border: 1px solid rgba(255, 255, 255, 0.12);
  box-shadow: inset 0 2px 4px rgba(56, 58, 71, 0.05);
}

.menu-places-box {
  margin: auto;
  padding: 10px;
  border: 0px solid red;
}

.menu-places-button {
  padding: 10px;
}

.menu-categories-box {
  padding: 10px 30px 10px 30px;
}

.menu-applications-inner-box, .menu-applications-outer-box {
  padding: 10px 10px 0 10px;
}

.menu-application-button {
  padding: 6px;
  border: none;
}

.menu-application-button:highlighted {
  font-weight: bold;
}

.menu-application-button-selected {
  padding: 6px;
  border: none;
  text-shadow: none;
  color: #ffffff;
  background-color: #fb8441;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px #fb8441;
}

.menu-application-button-selected:highlighted {
  font-weight: bold;
}

.menu-application-button-label:ltr {
  padding-left: 6px;
}

.menu-application-button-label:rtl {
  padding-right: 6px;
}

.menu StScrollView.menu-application-button {
  padding: 0;
  border-radius: 2px;
  border: 1px solid rgba(255, 255, 255, 0.12);
  background-color: rgba(211, 218, 227, 0.1);
}

.menu StScrollView.menu-application-button .popup-menu-item {
  padding: 0;
  spacing: 0;
}

.menu StScrollView.menu-application-button .popup-menu-item:ltr {
  padding-left: 8px;
}

.menu StScrollView.menu-application-button .popup-menu-item:rtl {
  padding-right: 8px;
}

.menu StScrollView.menu-application-button .popup-menu-item:active {
  border-image: none;
  background-color: rgba(211, 218, 227, 0.15);
  color: #D3DAE3;
}

.menu StScrollView.menu-application-button .popup-menu-item StIcon {
  min-width: 22px;
}

.menu StScrollView.menu-application-button .popup-menu-item StLabel:ltr {
  padding: 6px 0 7px 5px;
}

.menu StScrollView.menu-application-button .popup-menu-item StLabel:rtl {
  padding: 6px 5px 7px 0;
}

.menu-category-button {
  padding: 6px;
  border: 1px solid rgba(0, 0, 0, 0);
  border-radius: 3px;
}

.menu-category-button-hover, .menu-category-button-selected {
  padding: 6px;
  background-color: #fb8441;
  color: #ffffff;
  border: 1px solid #fc945a;
  border-radius: 3px;
}

.menu-category-button-greyed {
  padding: 6px;
  color: rgba(211, 218, 227, 0.45);
  border: 1px solid rgba(0, 0, 0, 0);
}

.menu-category-button-label:ltr {
  padding-left: 6px;
}

.menu-category-button-label:rtl {
  padding-right: 6px;
}

.menu-selected-app-box {
  padding-right: 30px;
  padding-left: 28px;
  text-align: right;
  height: 30px;
}

.menu-selected-app-box:rtl {
  padding-top: 10px;
  height: 30px;
}

.menu-selected-app-title {
  font-weight: bold;
}

.menu-selected-app-description {
  max-width: 150px;
}

.menu-search-box:ltr {
  padding-left: 30px;
}

.menu-search-box-rtl {
  padding-right: 30px;
}

#menu-search-entry {
  width: 250px;
  height: 15px;
  font-weight: normal;
  caret-color: #D3DAE3;
}

.menu-search-entry-icon {
  icon-size: 1em;
  color: #D3DAE3;
}

/* Context menu (at the moment only for favorites) */
.info-osd {
  text-align: center;
  font-weight: bold;
  spacing: 1em;
  padding: 16px;
  color: #D3DAE3;
  border-image: url("common-assets/misc/osd.svg") 9 9 9 9;
}

.osd-window {
  text-align: center;
  font-weight: bold;
  spacing: 1em;
  padding: 20px;
  min-width: 64px;
  min-height: 64px;
  color: #D3DAE3;
  background: none;
  border: none;
  border-radius: 5px;
  border-image: url("common-assets/misc/osd.svg") 9 9 9 9;
}

.osd-window .osd-monitor-label {
  font-size: 3em;
}

.osd-window .level {
  padding: 0;
  height: 4px;
  background-color: rgba(0, 0, 0, 0.65);
  border-radius: 2px;
  color: #fb8441;
}

.osd-window .level-bar {
  border-radius: 2px;
  background-color: #fb8441;
}

.window-list-box {
  spacing: 2px;
  padding-left: 10px;
}

.panel-bottom .window-list-box, .panel-top .window-list-box {
  padding-top: 2px;
  padding-bottom: 2px;
}

.window-list-box.vertical {
  spacing: 2px;
  padding: 10px 0;
}

.window-list-box.vertical #appMenuIcon {
  padding-top: 0;
}

.window-list-box:highlight {
  background-color: rgba(252, 65, 56, 0.5);
}

.window-list-item-label {
  font-weight: normal;
  width: 15em;
  min-width: 5px;
}

.window-list-item-label StIcon, .window-list-item-label StBin, .window-list-item-label #appMenuIcon {
  padding: 0;
}

.window-list-item-box {
  font-weight: normal;
  background-image: none;
  spacing: 8px;
  transition-duration: 100;
  color: #D3DAE3;
  border: 0 solid transparent;
}

.panel-bottom .window-list-item-box StLabel {
  padding-left: 6px;
}

.panel-top .window-list-item-box StLabel {
  padding-left: 6px;
}

.panel-left .window-list-item-box StLabel {
  padding-top: 6px;
}

.panel-right .window-list-item-box StLabel {
  padding-top: 6px;
}

.panel-top .window-list-item-box {
  border-top-width: 2px;
}

.panel-top .window-list-item-box StIcon, .panel-top .window-list-item-box StBin, .panel-top .window-list-item-box #appMenuIcon {
  padding: 0;
  padding-top: 0;
}

.panel-bottom .window-list-item-box {
  border-bottom-width: 2px;
}

.panel-bottom .window-list-item-box StIcon, .panel-bottom .window-list-item-box StBin, .panel-bottom .window-list-item-box #appMenuIcon {
  padding: 0;
  padding-bottom: 0;
}

.panel-left .window-list-item-box {
  border-left-width: 2px;
}

.panel-left .window-list-item-box StIcon, .panel-left .window-list-item-box StBin, .panel-left .window-list-item-box #appMenuIcon {
  padding: 0;
  padding-left: 0;
}

.panel-right .window-list-item-box {
  border-right-width: 2px;
}

.panel-right .window-list-item-box StIcon, .panel-right .window-list-item-box StBin, .panel-right .window-list-item-box #appMenuIcon {
  padding: 0;
  padding-right: 0;
}

.window-list-item-box:hover {
  color: #ffffff;
  border: 0 solid rgba(211, 218, 227, 0.5);
  background-gradient-direction: none;
}

.panel-top .window-list-item-box:hover {
  border-top-width: 2px;
}

.panel-bottom .window-list-item-box:hover {
  border-bottom-width: 2px;
}

.panel-left .window-list-item-box:hover {
  border-left-width: 2px;
}

.panel-right .window-list-item-box:hover {
  border-right-width: 2px;
}

.window-list-item-box:active, .window-list-item-box:checked, .window-list-item-box:running {
  color: #ffffff;
  border: 0 solid rgba(251, 132, 65, 0.35);
  background-gradient-direction: none;
}

.panel-top .window-list-item-box:active, .panel-top .window-list-item-box:checked, .panel-top .window-list-item-box:running {
  border-top-width: 2px;
}

.panel-bottom .window-list-item-box:active, .panel-bottom .window-list-item-box:checked, .panel-bottom .window-list-item-box:running {
  border-bottom-width: 2px;
}

.panel-left .window-list-item-box:active, .panel-left .window-list-item-box:checked, .panel-left .window-list-item-box:running {
  border-left-width: 2px;
}

.panel-right .window-list-item-box:active, .panel-right .window-list-item-box:checked, .panel-right .window-list-item-box:running {
  border-right-width: 2px;
}

.window-list-item-box:active:hover, .window-list-item-box:checked:hover, .window-list-item-box:running:hover {
  border-color: rgba(251, 132, 65, 0.5);
}

.window-list-item-box:focus {
  color: #ffffff;
  border: 0 solid #fb8441;
  background-gradient-direction: none;
}

.panel-top .window-list-item-box:focus {
  border-top-width: 2px;
}

.panel-bottom .window-list-item-box:focus {
  border-bottom-width: 2px;
}

.panel-left .window-list-item-box:focus {
  border-left-width: 2px;
}

.panel-right .window-list-item-box:focus {
  border-right-width: 2px;
}

.window-list-item-box.right, .window-list-item-box.left {
  padding-left: 0px;
  padding-right: 0px;
}

.window-list-item-box .progress {
  background-gradient-direction: vertical;
  background-gradient-start: #fb8441;
  background-gradient-end: #fb8441;
  border-radius: 2px;
  box-shadow: none;
}

.window-list-item-demands-attention {
  background-gradient-start: #F27835;
  background-gradient-end: #F27835;
}

.window-list-preview {
  padding: 12px;
  spacing: 8px;
  border: none;
  border-image: url("assets/menu/menu.svg") 9 9 9 9;
  color: #D3DAE3;
  background: none;
}

.grouped-window-list-thumbnail-label {
  padding-left: 4px;
}

.grouped-window-list-thumbnail-alert {
  background-color: rgba(252, 65, 56, 0.5);
}

.grouped-window-list-thumbnail-menu .item-box {
  padding: 6px;
  border-radius: 2px;
  spacing: 4px;
}

.grouped-window-list-thumbnail-menu .item-box:outlined {
  padding: 2px;
  border: 2px solid #fb8441;
}

.grouped-window-list-thumbnail-menu .item-box:selected {
  background-color: rgba(255, 255, 255, 0.33);
}

.grouped-window-list-thumbnail-menu .thumbnail {
  width: 256px;
}

.grouped-window-list-thumbnail-menu .separator {
  width: 1px;
  background-color: rgba(211, 218, 227, 0.33);
}

.grouped-window-list-number-label {
  z-index: 99;
  text-shadow: none;
  font-size: 10px;
  color: #ffffff;
  padding: 0;
}

.grouped-window-list-button-label {
  padding-left: 4px;
}

.grouped-window-list-badge {
  border-radius: 256px;
  background-color: #fb8441;
}

.grouped-window-list-item-box {
  font-weight: normal;
  background-image: none;
  transition-duration: 100;
  color: #D3DAE3;
  border: 0 solid transparent;
}

.grouped-window-list-item-box.top {
  border-top-width: 2px;
}

.grouped-window-list-item-box.top StIcon, .grouped-window-list-item-box.top StBin, .grouped-window-list-item-box.top #appMenuIcon {
  padding: 0;
  padding-top: 0;
}

.grouped-window-list-item-box.bottom {
  border-bottom-width: 2px;
}

.grouped-window-list-item-box.bottom StIcon, .grouped-window-list-item-box.bottom StBin, .grouped-window-list-item-box.bottom #appMenuIcon {
  padding: 0;
  padding-bottom: 0;
}

.grouped-window-list-item-box.left {
  border-left-width: 2px;
}

.grouped-window-list-item-box.left StIcon, .grouped-window-list-item-box.left StBin, .grouped-window-list-item-box.left #appMenuIcon {
  padding: 0;
  padding-left: 0;
}

.grouped-window-list-item-box.right {
  border-right-width: 2px;
}

.grouped-window-list-item-box.right StIcon, .grouped-window-list-item-box.right StBin, .grouped-window-list-item-box.right #appMenuIcon {
  padding: 0;
  padding-right: 0;
}

.grouped-window-list-item-box:hover {
  color: #ffffff;
  border: 0 solid rgba(211, 218, 227, 0.5);
  background-gradient-direction: none;
}

.panel-top .grouped-window-list-item-box:hover {
  border-top-width: 2px;
}

.panel-bottom .grouped-window-list-item-box:hover {
  border-bottom-width: 2px;
}

.panel-left .grouped-window-list-item-box:hover {
  border-left-width: 2px;
}

.panel-right .grouped-window-list-item-box:hover {
  border-right-width: 2px;
}

.grouped-window-list-item-box:active, .grouped-window-list-item-box:checked, .grouped-window-list-item-box:running {
  color: #ffffff;
  border: 0 solid rgba(251, 132, 65, 0.35);
  background-gradient-direction: none;
}

.panel-top .grouped-window-list-item-box:active, .panel-top .grouped-window-list-item-box:checked, .panel-top .grouped-window-list-item-box:running {
  border-top-width: 2px;
}

.panel-bottom .grouped-window-list-item-box:active, .panel-bottom .grouped-window-list-item-box:checked, .panel-bottom .grouped-window-list-item-box:running {
  border-bottom-width: 2px;
}

.panel-left .grouped-window-list-item-box:active, .panel-left .grouped-window-list-item-box:checked, .panel-left .grouped-window-list-item-box:running {
  border-left-width: 2px;
}

.panel-right .grouped-window-list-item-box:active, .panel-right .grouped-window-list-item-box:checked, .panel-right .grouped-window-list-item-box:running {
  border-right-width: 2px;
}

.grouped-window-list-item-box:active:hover, .grouped-window-list-item-box:checked:hover, .grouped-window-list-item-box:running:hover {
  border-color: rgba(251, 132, 65, 0.5);
}

.grouped-window-list-item-box:focus {
  color: #ffffff;
  border: 0 solid #fb8441;
  background-gradient-direction: none;
}

.panel-top .grouped-window-list-item-box:focus {
  border-top-width: 2px;
}

.panel-bottom .grouped-window-list-item-box:focus {
  border-bottom-width: 2px;
}

.panel-left .grouped-window-list-item-box:focus {
  border-left-width: 2px;
}

.panel-right .grouped-window-list-item-box:focus {
  border-right-width: 2px;
}

.grouped-window-list-item-box .progress {
  background-gradient-direction: vertical;
  background-gradient-start: #fb8441;
  background-gradient-end: #fb8441;
  border-radius: 2px;
  box-shadow: none;
}

.grouped-window-list-item-demands-attention {
  background-gradient-start: #F27835;
  background-gradient-end: #F27835;
}

.sound-button {
  width: 22px;
  height: 13px;
  padding: 8px;
}

.sound-button-container {
  padding-right: 3px;
  padding-left: 3px;
}

.sound-button StIcon {
  icon-size: 1.4em;
}

.sound-track-infos {
  padding: 5px;
}

.sound-track-info {
  padding-top: 2px;
  padding-bottom: 2px;
}

.sound-track-info StIcon {
  icon-size: 16px;
}

.sound-track-info StLabel {
  padding-left: 5px;
  padding-right: 5px;
}

.sound-track-box {
  padding-left: 15px;
  padding-right: 15px;
  max-width: 220px;
}

.sound-seek-box {
  padding-left: 15px;
}

.sound-seek-box StLabel {
  padding-top: 2px;
}

.sound-seek-box StIcon {
  icon-size: 16px;
}

.sound-seek-slider {
  width: 140px;
}

.sound-volume-menu-item {
  padding: .4em 1.75em;
}

.sound-volume-menu-item StIcon {
  icon-size: 1.14em;
  padding-left: 8px;
  padding-right: 8px;
}

.sound-playback-control {
  padding: 5px 10px 10px 10px;
}

.sound-player {
  padding: 0 5px;
}

.sound-player > StBoxLayout:first-child {
  padding: 5px 10px 10px 10px;
  spacing: 0.5em;
}

.sound-player > StBoxLayout:first-child StButton:small {
  width: 24px;
  height: 24px;
  border-radius: 100px;
}

.sound-player > StBoxLayout:first-child StButton:small:hover {
  background-color: rgba(211, 218, 227, 0.1);
}

.sound-player > StBoxLayout:first-child StButton:small:active {
  background-color: rgba(211, 218, 227, 0.25);
}

.sound-player > StBoxLayout:first-child StButton:small StIcon {
  icon-size: 12px;
}

.sound-player-generic-coverart {
  background: rgba(0, 0, 0, 0.2);
}

.sound-player-overlay {
  width: 290px;
  height: 70px;
  padding: 15px;
  spacing: 0.5em;
  background: rgba(29, 30, 37, 0.9);
  border: 0px solid #121216;
  border-bottom: 1px;
  color: #D3DAE3;
}

.sound-player-overlay StButton {
  width: 22px;
  height: 13px;
  padding: 5px;
  color: #D3DAE3;
  border-radius: 2px;
  border: 1px solid rgba(40, 42, 51, 0);
}

.sound-player-overlay StButton StIcon {
  icon-size: 16px;
}

.sound-player-overlay StButton:hover {
  text-shadow: none;
  color: #D3DAE3;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

.sound-player-overlay StButton:active {
  text-shadow: none;
  color: #ffffff;
  background-color: #fb8441;
  border: 1px solid #fb8441;
  box-shadow: inset 0 2px 4px #fb8441;
}

.sound-player-overlay StBoxLayout {
  padding-top: 2px;
}

.sound-player .slider {
  height: 0.5em;
  padding: 0;
  border: none;
  -slider-height: 0.5em;
  -slider-background-color: #27282f;
  -slider-border-color: rgba(0, 0, 0, 0);
  -slider-active-background-color: #fb8441;
  -slider-active-border-color: rgba(0, 0, 0, 0);
  -slider-border-width: 0px;
  -slider-handle-radius: 0px;
}

#workspaceSwitcher {
  spacing: 0px;
  padding: 3px;
}

/* Controls the styling when using the "Simple buttons" option */
.workspace-switcher {
  padding-left: 3px;
  padding-right: 3px;
}

.workspace-button {
  width: 20px;
  height: 10px;
  color: #ffffff;
  padding: 3px;
  padding-top: 4px;
  transition-duration: 300;
}

.workspace-button:outlined, .workspace-button:outlined:hover {
  color: #fb8441;
}

.workspace-button:hover {
  color: rgba(251, 132, 65, 0.5);
}

/* Controls the style when using the "Visual representation" option */
.workspace-graph {
  padding: 3px;
  spacing: 3px;
}

.workspace-graph .workspace {
  border: 1px solid rgba(0, 0, 0, 0.4);
  background-gradient-direction: none;
  background-color: rgba(0, 0, 0, 0.2);
}

.workspace-graph .workspace:active {
  border: 1px solid #fb8441;
  background-gradient-direction: none;
}

.workspace-graph .workspace .windows {
  -active-window-background: #424656;
  -active-window-border: rgba(0, 0, 0, 0.8);
  -inactive-window-background: #424656;
  -inactive-window-border: rgba(0, 0, 0, 0.8);
}

.workspace-graph .workspace:active .windows {
  -active-window-background: #4d5265;
  -active-window-border: rgba(0, 0, 0, 0.8);
  -inactive-window-background: #2c2f39;
  -inactive-window-border: rgba(0, 0, 0, 0.8);
}

#panel-launchers-box {
  padding-left: 7px;
}

#panel-launchers-box.vertical {
  padding: 2px 0;
}

.panel-launcher {
  padding: 2px;
  transition-duration: 200ms;
}

.panel-launcher:hover {
  background-gradient-direction: none;
  border: 0px solid #fb8441;
}

.panel-bottom .panel-launcher:hover {
  border-bottom-width: 2px;
  padding-bottom: 0;
}

.panel-top .panel-launcher:hover {
  border-top-width: 2px;
  padding-top: 0;
}

.panel-left .panel-launcher:hover {
  border-left-width: 2px;
  padding-left: 0;
}

.panel-right .panel-launcher:hover {
  border-right-width: 2px;
  padding-right: 0;
}

.launcher {
  padding: 2px;
  spacing: 2px;
  transition-duration: 0.2s;
}

.launcher:hover {
  border: 0 solid #fb8441;
  background-gradient-direction: none;
}

.panel-top .launcher:hover {
  padding-top: 0;
  border-top-width: 2px;
}

.panel-bottom .launcher:hover {
  padding-bottom: 0;
  border-bottom-width: 2px;
}

.panel-left .launcher:hover {
  padding-left: 0;
  border-left-width: 2px;
}

.panel-right .launcher:hover {
  padding-right: 0;
  border-right-width: 2px;
}

.launcher .icon-box {
  padding: 0 2px;
}

.launcher .icon-box.vertical {
  padding: 2px 0;
}

#overview-corner {
  background-image: url("common-assets/misc/overview.png");
}

#overview-corner:hover {
  background-image: url("common-assets/misc/overview-hover.png");
}

.applet-separator {
  padding: 1px 4px;
}

.applet-separator-line {
  width: 1px;
  background: rgba(255, 255, 255, 0.12);
}

.applet-box {
  padding-left: 3px;
  padding-right: 3px;
  color: #D3DAE3;
  text-shadow: none;
  transition-duration: 100;
}

.applet-box.vertical {
  padding: 3px 0;
}

.applet-box:hover {
  color: #D3DAE3;
  background-color: rgba(211, 218, 227, 0.15);
}

.applet-box:checked, .applet-box:checked:hover {
  color: #ffffff;
  background-color: #fb8441;
}

.applet-box:highlight {
  background-image: none;
  border-image: none;
  background-color: rgba(252, 65, 56, 0.5);
}

.applet-label {
  font-weight: bold;
  color: #D3DAE3;
}

.applet-box:checked .applet-label {
  color: #ffffff;
  text-shadow: none;
}

.applet-icon {
  color: #D3DAE3;
  icon-size: 22px;
}

.applet-box:checked .applet-icon {
  color: #ffffff;
  text-shadow: none;
}

.user-icon {
  width: 32px;
  height: 32px;
  background-color: transparent;
  border: none;
  border-radius: 0;
}

.user-label {
  color: #D3DAE3;
  font-size: 1em;
  font-weight: bold;
  margin: 0px;
}

.desklet {
  color: #D3DAE3;
}

.desklet:highlight {
  background-color: rgba(252, 65, 56, 0.5);
}

.desklet-with-borders {
  border-image: url("common-assets/misc/bg.svg") 9 9 9 9;
  color: #D3DAE3;
  padding: 12px;
  padding-bottom: 16px;
}

.desklet-with-borders:highlight {
  background-color: rgba(252, 65, 56, 0.5);
}

.desklet-with-borders-and-header {
  border-image: url("common-assets/misc/desklet.svg") 9 9 9 9;
  color: #D3DAE3;
  border-radius: 0;
  border-radius-topleft: 0;
  border-radius-topright: 0;
  padding: 12px;
  padding-bottom: 17px;
}

.desklet-with-borders-and-header:highlight {
  background-color: rgba(252, 65, 56, 0.5);
}

.desklet-header {
  border-image: url("common-assets/misc/desklet-header.svg") 9 9 9 9;
  color: #D3DAE3;
  font-size: 1em;
  padding: 12px;
  padding-bottom: 6px;
}

.desklet-drag-placeholder {
  border: 2px solid #fb8441;
  background-color: rgba(251, 132, 65, 0.3);
}

.photoframe-box {
  border-image: url("common-assets/misc/bg.svg") 9 9 9 9;
  color: #D3DAE3;
  padding: 12px;
  padding-bottom: 16px;
}

/*FIXME*/
.workspace-osd {
  /*color: red;*/
  text-shadow: black 5px 5px 5px;
  font-weight: bold;
  font-size: 48pt;
}

.notification-applet-padding {
  padding: .5em 1em;
}

.notification-applet-container {
  max-height: 100px;
}

.tile-preview, .tile-preview.snap,
.tile-hud, .tile-hud.snap {
  background-color: rgba(251, 132, 65, 0.3);
  border: 1px solid #fb8441;
}

.xkcd-box {
  padding: 6px;
  border: 0px;
  background-color: rgba(0, 0, 0, 0);
  border-radius: 0px;
}
