/* Modal Dialogs */

.headline { @include font(title); }
.lightbox { background-color: black; }
.flashspot { background-color: white; }

.modal-dialog {
  border-radius: 2px;
  color: $fg_color;
  background-color: $base_color;
  border: none;
  box-shadow: $shadow_4;
  .modal-dialog-content-box {
    padding: 24px;
  }
  .run-dialog-entry { width: 20em; margin-bottom: 6px; }
  .run-dialog-error-box {
    padding-top: 16px;
    spacing: 6px;
  }
  .run-dialog-button-box { padding-top: 1em; }
  .run-dialog-label {
    font-size: 1em;
    font-weight: normal;
    color: $button_fg_color;
    padding-bottom: .4em;
  }

}

  .mount-dialog-subject,
  .end-session-dialog-subject { //this should be a generic header class
    @include font(title);
  }

/* Message Dialog */
  .message-dialog-main-layout {
    padding: 12px 20px 0;
    spacing: 12px;
  }

  .message-dialog-content {
    max-width: 28em;
    spacing: 20px;
  }

  .message-dialog-icon {
    min-width: 48px;
    icon-size: 48px;
  }

  .message-dialog-title {
    font-weight: bold;
  }

  .message-dialog-subtitle {
    color: $secondary_fg_color;
    font-weight: bold;
  }

/* End Session Dialog */
.end-session-dialog {
  spacing: 42px;
  border: none;
}

  .end-session-dialog-list {
      padding-top: 20px;
  }

  .end-session-dialog-layout {
    padding-left: 17px;
    &:rtl { padding-right: 17px; }
  }

  .end-session-dialog-description {
    width: 28em;
    padding-bottom: 10px;
    &:rtl {
      text-align: right;
    }
  }

  .end-session-dialog-warning {
    width: 28em;
    color: $warning_color;
    padding-top: 6px;
    &:rtl {
      text-align: right;
    }
  }

  .end-session-dialog-logout-icon {
    //border: 2px solid #8b8b8b;
    border-radius: 5px;
    width: 48px;
    height: 48px;
    background-size: contain;
  }

  .end-session-dialog-shutdown-icon {
    color: $hint_fg_color;
    width: 48px;
    height: 48px;
  }

  .end-session-dialog-inhibitor-layout {
    spacing: 16px;
    max-height: 200px;
    padding-right: 65px;
    padding-left: 65px;
  }

  .end-session-dialog-session-list,
  .end-session-dialog-app-list {
    spacing: 1em;
  }

  .end-session-dialog-list-header {
    font-weight: bold;
    &:rtl { text-align: right; }
  }

  .end-session-dialog-app-list-item,
  .end-session-dialog-session-list-item {
    spacing: 1em;
  }

  .end-session-dialog-app-list-item-name,
  .end-session-dialog-session-list-item-name {
    font-weight: bold;
  }

  .end-session-dialog-app-list-item-description {
    color: $hint_fg_color;
    font-size: 1em;
  }

/* ShellMountOperation Dialogs */
.shell-mount-operation-icon { icon-size: 48px; }

  .mount-dialog {
    spacing: 24px;

    .message-dialog-title {
      padding-top: 10px;
      padding-left: 17px;
      padding-bottom: 6px;
      max-width: 34em;
    }

    .message-dialog-title:rtl {
      padding-left: 0px;
      padding-right: 17px;
    }

    .message-dialog-body {
      padding-left: 17px;
      width: 28em;
    }

    .message-dialog-body:rtl {
      padding-left: 0px;
      padding-right: 17px;
    }
  }

  .mount-dialog-app-list {
    max-height: 200px;
    padding-top: 24px;
    padding-left: 49px;
    padding-right: 32px;
  }

  .mount-dialog-app-list:rtl {
    padding-right: 49px;
    padding-left: 32px;
  }

  .mount-dialog-app-list-item {
    color: $fg_color;
    &:hover { color: $fg_color; }
    &:ltr { padding-right: 1em; }
    &:rtl { padding-left: 1em; }
  }

  .mount-dialog-app-list-item-icon {
    &:ltr { padding-right: 17px; }
    &:rtl { padding-left: 17px; }
  }

  .mount-dialog-app-list-item-name {
    font-size: 1em;
  }


/* Password or Authentication Dialog */

.prompt-dialog {
  //this is the width of the entire modal popup
  width: 34em;
  border: none;

  .message-dialog-main-layout { spacing: 24px; padding: 10px; }
  .message-dialog-content { spacing: 16px; }
  .message-dialog-title { @include font(title); color: $fg_color; }
}

  .prompt-dialog-description:rtl {
    text-align: right;
  }

  .prompt-dialog-password-box {
    spacing: 1em;
    padding-bottom: 1em;
  }

  .prompt-dialog-error-label {
    font-size: 1em;
    color: $error_color;
    padding-bottom: 8px;
  }

  .prompt-dialog-info-label {
    font-size: 1em;
    padding-bottom: 8px;
  }

  .hidden {
    color: rgba(0,0,0,0);
  }

  .prompt-dialog-null-label {
    font-size: 1em;
    padding-bottom: 8px;
  }


/* Polkit Dialog */

.polkit-dialog-user-layout {
  padding-left: 10px;
  spacing: 10px;
  &:rtl {
    padding-left: 0px;
    padding-right: 10px;
  }
}

  .polkit-dialog-user-root-label {
    color: $warning_color;
  }

  .polkit-dialog-user-icon {
    border-radius: 5px;
    background-size: contain;
    width: 48px;
    height: 48px;
  }

/* Audio selection dialog */
.audio-device-selection-dialog {
  spacing: 30px;
}

  .audio-selection-content {
    spacing: 20px;
    padding: 24px;
  }

  .audio-selection-title {
    font-weight: bold;
    text-align: center;
  }

  .audio-selection-box {
    spacing: 20px;
  }

  .audio-selection-device {
    border: 1px solid $border_color;
    border-radius: 2px;
    &:active,&:hover,&:focus { background-color: $primary_color; }
  }

  .audio-selection-device-box {
    padding: 20px;
    spacing: 20px;
  }

  .audio-selection-device-icon {
    icon-size: 64px;
  }

/* Access Dialog */
.access-dialog {
  spacing: 30px;
}

/* Geolocation Dialog */
.geolocation-dialog {
  spacing: 30px;
}

/* Extension Dialog */
.extension-dialog {
  .message-dialog-main-layout { spacing: 24px; padding: 10px; }
  .message-dialog-title { color: $secondary_fg_color; }
}

/* Inhibit-Shortcuts Dialog */
.inhibit-shortcuts-dialog {
  spacing: 30px;
}

/* Network Agent Dialog */

.network-dialog-secret-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.keyring-dialog-control-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

/* NETWORK DIALOGS */

.nm-dialog {
  max-height: 34em;
  min-height: 31em;
  min-width: 32em;
}

.nm-dialog-content {
  spacing: 20px;
  padding: 24px;
}
.nm-dialog-header-hbox { spacing: 10px; }
.nm-dialog-airplane-box { spacing: 12px; }

.nm-dialog-airplane-headline {
  font-weight: bold;
  text-align: center;
}

.nm-dialog-airplane-text { color: $fg_color; }
.nm-dialog-header-icon { icon-size: 32px; }
.nm-dialog-scroll-view { border: none; }
.nm-dialog-header { @include font(title); }

.nm-dialog-item {
  font-size: 1em;
  border-bottom: none;
  border-radius: 2px;
  padding: 12px;
  spacing: 20px;
  &:hover, &:focus { background-color: $divider_color; }
  &:active { background-color: $track_color; }
}

.nm-dialog-item:selected {
  background-color: $primary_color;
  color: $inverse_fg_color;
}

.nm-dialog-icons { spacing: .5em; }
.nm-dialog-icon { icon-size: 16px; }
.no-networks-label { color: $hint_fg_color; }
.no-networks-box { spacing: 12px; }

