/* OVERVIEW */

#overview {
  spacing: 24px; //
  StScrollBar { @extend %overview_scrollbar; }
}

.overview-controls {
  padding-bottom: 32px;
}

  .window-picker { //container around window thumbnails
    -horizontal-spacing: 16px;
    -vertical-spacing: 16px;
    padding: 0 16px 16px;

    &.external-monitor { padding: 16px; }
  }

  .window-clone-border {
    border: 4px solid $inverse_track_color;
    border-radius: 2px;
    // For window decorations with round corners we can't match
    // the exact shape when the window is scaled. So apply a shadow
    // to fix that case
    box-shadow: inset 0 0 0 1px $inverse_track_color;
  }
  .window-caption {
    spacing: 25px;
    color: $inverse_fg_color;
    background-color: $inverse_bg_color;
    border-radius: 2px;
    padding: 4px 8px;
  }

  //search entry
  .search-entry {
    width: 320px - 8px * 2;
    padding: 0 8px;
    border-radius: 0;
    color: $inverse_hint_fg_color;
    selection-background-color: $inverse_track_color;
    selected-color: $inverse_fg_color;
    @include entry(normal,$fc:$inverse_track_color);
    &:focus {
      @include entry(focus,$fc:$accent_color);
      padding: 0 8px;
      border-width: 0;
      color: $inverse_fg_color;
    }

    .search-entry-icon {
      icon-size: 16px;
      padding: 0 0;
      color: $inverse_hint_fg_color;
      transition: $longer_transition;
    }

    &:hover, &:focus {
      .search-entry-icon { color: $inverse_fg_color; }
    }
  }

  //search results

  #searchResultsBin {
    max-width: 1000px;
  }

  #searchResultsContent {
    padding-left: 20px;
    padding-right: 20px;
    spacing: 16px;
  }

  .search-section { spacing: 16px; } // This should be equal to #searchResultsContent spacing
  .search-section-content { spacing: 32px; } // This is the space between the provider icon and the results container
  .search-statustext { // "no results"
    @extend %status_text;
  }
  .list-search-results { spacing: 3px; }

  .search-section-separator { height: 1px; background-color: $inverse_divider_color; }

  .list-search-result-content { spacing: 30px; }
  .list-search-result-title { @include font(subheading); color: $inverse_fg_color; spacing: 12px; }
  .list-search-result-description { color: $inverse_secondary_fg_color; }
  .list-search-provider-details { width: 150px; color: $inverse_secondary_fg_color; margin-top: 0.24em; }
  .list-search-provider-content { spacing: 20px; }
  .search-provider-icon { padding: 15px; }


  /* DASHBOARD */

  #dash {
    font-size: 1em;
    color: $inverse_fg_color;
    background-color: rgba($panel_bg_color, 0.5);
    padding: 3px 0;
    border: none;
    border-left: 0px;
    border-radius: 0px $material_radius $material_radius 0px;

    &:rtl {
      border-radius: $material_radius 0 0 $material_radius;
    }

    .placeholder {
      background-image: url("assets/dash-placeholder.svg");
      background-size: contain;
      height: 24px;
    }

    .empty-dash-drop-target {
      width: 24px;
      height: 24px;
    }

  }

  .dash-item-container > StWidget {
    padding: 3px 6px;
  }

  .dash-label { //osd tooltip
    // min-height: 32px - 6px * 2;
    border-radius: 2px;
    padding: 7px 8px;
    color: $fg_color;
    background-color: $base_color;
    box-shadow: $shadow_2;
    text-align: center;
    -x-offset: 8px;
  }

  /* App Vault/Grid */
  .icon-grid {
    spacing: 30px;
    -shell-grid-horizontal-item-size: 136px;
    -shell-grid-vertical-item-size: 136px;

    .overview-icon { icon-size: 96px; }
  }
  //.app-display { spacing: 20px; }

  .system-action-icon {
    box-shadow: 0 4px 4px rgba(0, 0, 0, 0.2);
    background-color: $grey_900;
    color: $white;
    border-radius: 99px;
    icon-size: 48px;
  }

  .app-view-controls { //favorties | all toggle container
    width: 320px;
    padding-bottom: 32px;
  }
  .app-view-control { //favorties | all toggle button
    padding: 0 16px;
    font-weight: bold;
    color: $inverse_secondary_fg_color;
    &:hover {
      color: $inverse_fg_color;
      background-color: $inverse_divider_color !important;
    }
    &:active {
      color: $inverse_fg_color;
      background-color: $inverse_track_color !important;
    }
    &:checked {
      color: $inverse_fg_color;
      background-color: rgba($bg_color, 0.01) !important;
      box-shadow: inset 0 2px 0 $accent_color;
    }
    &:first-child {
      border-right-width: 0;
      border-radius: 2px;
      &:checked { border-radius: 0; }
    }
    &:last-child {
      border-radius: 2px;
      &:checked { border-radius: 0; }
    }
  }

  //Icon tile
  .search-provider-icon,
  .list-search-result {
    @extend %icon_tile;
    &:focus, &:selected, &:hover {
      background-color: rgba($inverse_fg_color, 0.2);
      transition-duration: 0ms;
    }
    &:active, &:checked {
      background-color: rgba($inverse_fg_color, 0.2);
      transition-duration: $longer_duration;
    }
  }
  .app-well-app,
  .app-well-app.app-folder,
  .show-apps,
  .grid-search-result {
    & .overview-icon {
      @extend %icon_tile;
    }
    &:hover .overview-icon,
    &:focus .overview-icon,
    &:selected .overview-icon {
      background-color: rgba($inverse_fg_color, 0.2);
      transition-duration: 0ms;
      border-image: none;
      background-image: none;
    }
    &:active .overview-icon,
    &:checked .overview-icon {
      background-color: rgba($inverse_fg_color, 0.2);
      box-shadow: $shadow_0;
      transition-duration: $longer_duration;
    }

  }

  .app-well-app-running-dot { //running apps indicator
    width: 32px; height: 2px;
    background-color: $accent_color;
    margin-bottom: 0;
  }

  %icon_tile {
    color: $inverse_fg_color;
    background-color: transparent;
    border-radius: 2px;
    padding: 6px;
    border: none;
    transition-duration: $longer_duration;
    text-align: center;
  }

  .app-well-app.app-folder > .overview-icon {
    background-color: rgba($inverse_fg_color, 0.2);
  }

  .show-apps .show-apps-icon {
    color: $inverse_secondary_fg_color;
  }

  .show-apps:hover .show-apps-icon,
  .show-apps:active .show-apps-icon,
  .show-apps:checked .show-apps-icon,
  .show-apps:focus .show-apps-icon {
    color: $inverse_fg_color;
    transition-duration: $longer_duration;
  }


  // Collections
  .app-folder-popup { //expanded collection
    -arrow-border-radius: 2px;
    -arrow-background-color: rgba($inverse_fg_color, 0.2);
    -arrow-base: 24px;
    -arrow-rise: 12px;
  }
  .app-folder-popup-bin { padding: 5px; }
  .app-folder-icon {
    padding: 5px;
    spacing-rows: 5px;
    spacing-columns: 5px;
  }

  .page-indicator {
    padding: 15px 20px;

    .page-indicator-icon {
      width: 12px;
      height: 12px;
      border-radius: 12px;
      background-image: none;
      background-color: $inverse_disabled_secondary_fg_color;
    }
    &:hover .page-indicator-icon {
      background-image: none;
      background-color: $inverse_disabled_fg_color;
    }
    &:active .page-indicator-icon {
      background-image: none;
      background-color: $inverse_secondary_fg_color;
    }
    &:checked .page-indicator-icon {
      background-image: none;
      background-color: $inverse_fg_color;
      transition-duration: 0ms;
    }
    &:checked:active { background-image: none; }
  }

  .no-frequent-applications-label { @extend %status_text; }

  .app-well-app > .overview-icon.overview-icon-with-label,
  .grid-search-result .overview-icon.overview-icon-with-label {
    padding: 10px 8px 5px 8px;
    spacing: 4px;
  }

  // Workspace pager
  .workspace-thumbnails { //container ala dash
    @extend %overview-panel;
    background-color: transparent !important;
    visible-width: 32px; //amount visible before hover
    spacing: 12px;
    padding: 12px;
    border-radius: 2px 0 0 2px;
    //border-width: 0; //fixme: can't have non unoform borders :(
    &:rtl { border-radius: 0 2px 2px 0;}
  }
  .workspace-thumbnail-indicator {
    border: 0 solid $accent_color;
    border-left-width: 2px;
    padding: 6px;
    border-radius: 0;
  }

  //Some hacks I don't even
  .search-display > StBoxLayout,
  .all-apps,
  .frequent-apps > StBoxLayout {
    // horizontal padding to make sure scrollbars or dash don't overlap content
    padding: 0px 88px 10px 88px;
  }

%overview-panel {
  color: $inverse_fg_color;
  background-color: transparent;
  border: none;
}

%status_text {
  @include font(display-2);
  color: $inverse_hint_fg_color;
}
