// based css:
// https://bazaar.launchpad.net/~lightdm-gtk-greeter-team/lightdm-gtk-greeter/trunk/view/head:/data/sample-lightdm-gtk-greeter.css

/************************
 * LightDM GTK+ Greeter *
 ************************/
// the panel widget at the top
#panel_window {
  background-color: $alt_panel_bg_color;
  color: $inverse_fg_color;
  // font-weight: bold;

  // the menubars/menus of the panel, i.e. indicators
  menubar,
  separator { background-color: transparent; }

  separator {
    padding: 0 4px;

    &:first-child { padding: 0 8px; }
  }

  menubar > menuitem {
    color: $inverse_secondary_fg_color;

    &:hover { color: $inverse_fg_color; }

    &:disabled label { color: $inverse_disabled_secondary_fg_color; }
  }
}

// the login window
#login_window,
#shutdown_dialog,
#restart_dialog {
  margin: 8px;
  border-radius: 2px;
  box-shadow: $shadow_2, inset 0 1px $highlight_color;
  background-color: $lighter_bg_color;
}

// the top half of the login-window, in GtkDialog terms, the content
#content_frame {
  padding-bottom: 20px;
  border-bottom: 1px solid $border_color;
}

#login_window {
  // the user-combobox
  #user_combobox button { @extend %combo_flat; }

  // the entries, one for the username, one for the password
  entry { @extend %entry_flat; }
}

// the buttons, alternatively this could also be done with a simple ".lightdm-gtk-greeter button"
#login_window button,
#shutdown_dialog button,
#restart_dialog button {
}

.lightdm-gtk-greeter button { @extend %simple_flat_button; }

// the user's avatar box
#user_image {
}

// the border around the user's avatar box
#user_image_border {
}

// the lower half of the login-window, in GtkDialog terms the buttonbox or action area
#buttonbox_frame {
  padding-top: 24px;

  button { margin: -16px; }
}

// the shutdown button
#shutdown_button {
}

// the restart button
#restart_button {
}

// the warning, in case a wrong password is entered or something else goes wrong according to PAM
#greeter_infobar {
  margin-top: -1px;
  // font-weight: bold;
}
