/* Slider */

.slider {
  height: 20px;
  color: $primary_color;
  -slider-height: 2px;
  -slider-background-color: $track_color; //background of the trough
  -slider-border-color: transparent; //trough border color
  -slider-active-background-color: $primary_color; //active trough fill
  -slider-active-border-color: transparent; //active trough border
  -slider-border-width: 0;
  -slider-handle-radius: 7px;
}
