// IBus Candidate Pocilloup

.candidate-popup-content {
  padding: 8px;
  spacing: 0;
}

.candidate-index {
  padding: 0 4px 0 0;
  color: $hint_fg_color;
  .candidate-box:selected & { color: $inverse_hint_fg_color; }
}

.candidate-box {
  transition-duration: 0ms; 
  min-height: $menuitem_size;
  padding: 0 8px;
  border-radius: 2px;
  &:hover { background-color: $divider_color; color: $fg_color; }
  &:active { background-color: $track_color; color: $fg_color; }
  &:selected { background-color: $primary_color; color: $inverse_fg_color; }
}

.candidate-page-button-box {
  height: $menuitem_size;
  .vertical & { padding-top: 0; }
  .horizontal & { padding-left: 0; }
}

.candidate-page-button {
  min-width: $menuitem_size;
  min-height: $menuitem_size;
  padding: 0;
}

.candidate-page-button-previous { border-radius: 2px; border-right-width: 0; }
.candidate-page-button-next { border-radius: 2px;  }
.candidate-page-button-icon { icon-size: em(16px); }
