/* Scrollbars */
StScrollView {
  &.vfade { -st-vfade-offset: 32px; }
  &.hfade { -st-hfade-offset: 32px; }
}

StScrollBar {
  padding: 0;

  StScrollView & {
    min-width: 16px;
    min-height: 16px;
  }

  StBin#trough {
    margin: 4px;
    border-radius: 100px;
    background-color: $divider_color;
  }

  StButton#vhandle, StButton#hhandle {
    border-radius: 100px;
    background-color: $hint_fg_color;
    //border: 4px solid transparent; //would be nice to margin or at least to transparent
    margin: 4px;
    &:hover { background-color: $secondary_fg_color; }
    &:active { background-color: $fg_color; }
  }
}

%overview_scrollbar {
  StBin#trough {
    background-color: $inverse_divider_color;
  }

  StButton#vhandle, StButton#hhandle {
    background-color: $inverse_hint_fg_color;
    &:hover { background-color: $inverse_secondary_fg_color; }
    &:active { background-color: $inverse_fg_color; }
  }
}
