/*********
 * Emoji *
 *********/
popover.emoji-picker {
  padding: 0;

  scrolledwindow { border-bottom: 1px solid $border_color; }
}

// mimic tab style
button.emoji-section {
  margin-top: -1px;
  padding: 0 $small_padding;
  min-width: $button_size;
  min-height: $button_size + $standard_padding;
  border-radius: 0;
  outline-offset: -6px;
  box-shadow: none;

  &:hover { box-shadow: inset 0 2px $track_color; }

  &:active {
    box-shadow: inset 0 2px $primary_color;
    background-image: radial-gradient(circle farthest-corner at center,
                                      rgba($primary_color, 0.7) 10%,
                                      transparent 0%);
  }

  &:checked {
    box-shadow: inset 0 2px $primary_color;
    background-color: transparent;
  }

  &:first-child { margin-left: $tiny_padding; }

  &:last-child { margin-right: $tiny_padding; }
}

.emoji {
  min-width: 3em;
  min-height: 3em;
  padding: 0;
  // font-size: large;

  widget {
    transition: $shorter_transition;

    &:hover { font-size: larger; }
  }
}
