/************
 * Popovers *
 ************/
popover.background {
  transition: $shadow_transition;
  padding: $mini_padding;
  box-shadow: $shadow_2; // this should really have a highlight
  background-color: $lighter_bg_color;

  &:backdrop { box-shadow: $shadow_1; }

  &, .csd & {
    border-style: solid;
    border-width: $border_size;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.2) rgba(0, 0, 0, 0.3);
    border-radius: $pocillo_radius;
  }

  > stack { margin: -4px; } // remove extra padding from menu style popovers

  > toolbar { margin: -2px; }

  > list,
  > .view,
  > toolbar {
    border-style: none;
    box-shadow: none;
    background-color: transparent;
  }

  &.touch-selection,
  &.magnifier,
  &.osd { @extend %osd; }

  &.menu button,
  button.model {
    @extend %simple_flat_button;

    min-height: $large_size;
    padding: 0 $small_padding;
    border-radius: $other_radius;
    outline-offset: 4px;

    &:checked { @extend %selected_items; }
  }

  separator { margin: $tiny_padding - 2px 0; }

  list separator { margin: 0; }
}
