// LOGIN DIALOG

.login-dialog-banner-view {
  padding-top: 24px;
  max-width: 27em;
}

.login-dialog {
  //reset
  border: none;
  background-color: transparent;

  StEntry {
    color: $inverse_fg_color;
    selection-background-color: $inverse_track_color;
    selected-color: $inverse_fg_color;
    @include entry(normal, $fc:$inverse_track_color);
    &:focus { @include entry(focus, $fc:$accent_color); }
    &:insensitive {
      @include entry(insensitive, $fc:$inverse_divider_color);
      color: $inverse_disabled_fg_color;
    }
  }

  .modal-dialog-button-box { spacing: 3px; }
  .modal-dialog-button {
    padding: 0 16px;
    @include button(flat-normal, $tc: $inverse_fg_color);
    &:hover,&:focus { @include button(flat-hover, $tc: $inverse_fg_color); }
    &:active { @include button(flat-active, $tc: $inverse_fg_color); }
    &:insensitive { @include button(flat-insensitive, $tc: $inverse_fg_color); }

    &:default {
      @include button(normal, $c: $suggested_color, $tc: $inverse_fg_color);
      &:hover,&:focus { @include button(hover, $c: $suggested_color, $tc: $inverse_fg_color); }
      &:active { @include button(active, $c: $suggested_color, $tc: $inverse_fg_color); }
      &:insensitive { @include button(insensitive, $c: $inverse_divider_color, $tc: $inverse_disabled_fg_color); }
    }
  }
}

.login-dialog-logo-bin { padding: 24px 0px; }
.login-dialog-banner { color: $inverse_secondary_fg_color; }
.login-dialog-button-box { spacing: 5px; }
.login-dialog-message-warning { color: $warning_color; }
.login-dialog-message-hint { padding-top: 0; padding-bottom: 20px; }
.login-dialog-user-selection-box { padding: 100px 0px; }
.login-dialog-not-listed-label {
  padding-left: 2px;
  .login-dialog-not-listed-button:focus &,
  .login-dialog-not-listed-button:hover & {
    color: $inverse_fg_color;
  }
}
.login-dialog-not-listed-label {
  font-size: 1em;
  font-weight: bold;
  color: $inverse_secondary_fg_color;
  padding-top: 1em;
  &:hover { color: $inverse_fg_color; }
  &:focus { background-color: $inverse_divider_color; }
}

.login-dialog-user-list-view { -st-vfade-offset: 1em; }
.login-dialog-user-list {
  spacing: 12px;
  padding: .2em;
  width: 27em;
  &:expanded .login-dialog-user-list-item:selected { background-color: $inverse_divider_color; color: $inverse_fg_color; }
  &:expanded .login-dialog-user-list-item:hover { background-color: $inverse_divider_color; color: $inverse_fg_color; }
  &:expanded .login-dialog-user-list-item:active { background-color: $inverse_track_color; color: $inverse_fg_color; }
  &:expanded .login-dialog-user-list-item:logged-in { border-right: 2px solid $inverse_fg_color; }
}
.login-dialog-user-list-item {
  border-radius: 2px;
  padding: 4px 4px 0;
  color: $inverse_secondary_fg_color;
  &:ltr { padding-right: 1em; }
  &:rtl { padding-left: 1em; }
  &:hover { background-color: $inverse_divider_color; color: $inverse_fg_color; }
  &:active { background-color: $inverse_track_color; color: $inverse_fg_color; }
  .login-dialog-timed-login-indicator {
    height: 2px;
    margin: 2px 0 0 0;
    background-color: $inverse_fg_color;
  }
  &:focus .login-dialog-timed-login-indicator { background-color: $inverse_fg_color; }
}

.login-dialog-username,
.user-widget-label {
  color: $inverse_fg_color;
  @include font(title);
  text-align: left;
  padding-left: 15px;
}
  .user-widget-label {
    &:ltr { padding-left: 18px; }
    &:rtl { padding-right: 18px; }
  }

.login-dialog-prompt-layout {
    padding-top: 24px;
    padding-bottom: 12px;
    spacing: 8px;
    width: 27em;
}

.login-dialog-prompt-label {
    color: $inverse_hint_fg_color;
    font-size: 1em;
    padding-top: 1em;
}

.login-dialog-session-list-button StIcon {
    icon-size: 1.25em;
}

.login-dialog-session-list-button {
    color: $inverse_secondary_fg_color;
    &:hover,&:focus { color: $inverse_fg_color; }
    &:active { color: $inverse_fg_color; }
}
