/* Pocilloovers/Menus */

.popup-menu {
  min-width: 200px;

  .popup-menu-arrow { } //defined globally in the TOP BAR
  .popup-sub-menu {
    background-color: $alt_base_color;
    box-shadow: $shadow_0;
  }

  .popup-menu-content { padding: 8px 0; }
  .popup-menu-item {
    // min-height: $menuitem_size - 4px * 2;
    spacing: 8px;
    transition-duration: $shorter_duration;

    &:ltr { padding: 0.4em 24px 0.4em 0; }
    &:rtl { padding: 0.4em 0 0.4em 24px; }
    &:checked {
      background-color: $accent_color;
      color: $inverse_fg_color;
      box-shadow: $shadow_0;
      font-weight: normal;
      &.selected {
        background-color: mix($inverse_fg_color, $accent_color, percentage($lower_opacity / 2));
        color: $inverse_fg_color;
      }
      &:active {
        background-color: mix($inverse_fg_color, $accent_color, percentage($lower_opacity));
        color: $inverse_fg_color !important;
      }
      &:insensitive { color: $inverse_disabled_fg_color; }
    }
    &.selected {
      background-color: $divider_color;
      color: $fg_color;
      transition-duration: 0ms;
    }
    &:active {
      background-color: $track_color;
      color: $fg_color;
      transition-duration: $longer_duration;
    }
    &.selected:active { color: $fg_color; }
    &:insensitive { color: $disabled_fg_color; }
  }

  .popup-inactive-menu-item { //all icons and other graphical elements
    color: $fg_color;

    &:insensitive { color: $hint_fg_color; }
  }
  //.popup-status-menu-item { font-weight: normal;  color: pink; } //dunno what that is
  &.panel-menu {
    -boxpointer-gap: 4px;
    margin-bottom: 1.75em;
  }
}



  .popup-menu-ornament {
    text-align: right;
    width: 16px;
    height: 16px;
  }
  .popup-menu-boxpointer,
  .candidate-popup-boxpointer {
    -arrow-border-radius: 0;
    -arrow-background-color: transparent;
    -arrow-border-width: 0;
    -arrow-border-color: transparent;
    -arrow-base: 0;
    -arrow-rise: 0;
    -arrow-box-shadow: none; //dreaming. bug #689995
    margin: 5px 8px 8px;
    background-color: $base_color;
    border-radius: 2px;
    box-shadow: $shadow_2;
  }

  .popup-separator-menu-item {
    //-margin-horizontal: 24px;
    height: 1px; //not really the whole box
    margin: 8px 64px - 24px;
    background-color: transparent;
    border-color: $border_color;
    border-bottom-width: 1px;
    border-bottom-style: solid;
  }


// Background menu
.background-menu { -boxpointer-gap: 4px; -arrow-rise: 0; }

/* fallback menu
- odd thing for styling App menu when apparently not running under shell. Light Adwaita styled
  app menu inside the main app window itself rather than the top bar
*/
