// apps rely on some named colors to be exported
/* GTK NAMED COLORS
   ----------------
   use responsibly! */

// Sass thinks we're using the colors in the variables as strings and may shoot
// warning, it's innocuous and can be defeated by using "" + $var
/*
widget text/foreground color */
@define-color theme_fg_color #{"" + $fg_color};

/*
text color for entries, views and content in general */
@define-color theme_text_color #{"" + $fg_color};

/*
widget base background color */
@define-color theme_bg_color #{"" + $bg_color};
@define-color bg_color #{"" + $bg_color};

/*
text widgets and the like base background color */
@define-color theme_base_color #{"" + $base_color};

/*
base background color of selections */
@define-color theme_selected_bg_color #{"" + $primary_color};

/*
text/foreground color of selections */
@define-color theme_selected_fg_color #{"" + $inverse_fg_color};

/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #{"" + $bg_color};

/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #{"" + $disabled_fg_color};

/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #{"" + $alt_base_color};

/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #{"" + $fg_color};

/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color #{"" + $fg_color};

/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #{"" + $bg_color};

/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #{"" + $base_color};

/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #{"" + $primary_color};

/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #{"" + $inverse_fg_color};

/*
insensitive color on backdrop windows */
@define-color unfocused_insensitive_color #{"" + $disabled_fg_color};

/*
widgets main borders color */
@define-color borders #{"" + $border_color};

/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #{"" + $border_color};

/*
these are pretty self explicative */
@define-color warning_color #{"" + $warning_color};
@define-color error_color #{"" + $error_color};
@define-color success_color #{"" + $success_color};
@define-color destructive_color #{"" + $destructive_color};
@define-color suggested_color #{"" + $suggested_color};

/*
this is really an API */
@define-color content_view_bg #{"" + $base_color};
@define-color text_view_bg #{"" + $base_color};
@define-color placeholder_text_color #{"" + $placeholder_text_color};

$spice_slide_background: lighten($brown_800, 5%);
$spice_selected_slide_background: lighten($brown_800, 7%);

/*
These are for Spice-up Presentation maker*/
@define-color SpicePrimaryBackground #{"" + $brown_800};
@define-color SpiceSlideBackground #{"" + $spice_slide_background};
@define-color SpiceSlideBackgroundSelected #{"" + lighten($brown_800, 7%)};
@define-color colorPrimary #{"" + $primary_color};
