/********
 * Nemo *
 ********/
.nemo-window {
  .primary-toolbar {
    border-bottom: 1px solid $border_color;

    background-color: transparent;

    // FIXME: workaround for wrong size allocation of Nemo
    entry {
      min-height: 0;
      margin: 0;
    }

    // instead of .path-bar button
    button.text-button {
      padding-left: 8px;
      padding-right: 8px;
    }

    // instead of .path-bar button.slider-button
    button:not(.text-button):not(.image-button) {
      padding-left: 4px;
      padding-right: 4px;
    }
  }

  .nemo-places-sidebar {
    &.frame { border-width: 0; }

    .places-treeview {
      @extend %row_activatable;

      -NemoPlacesTreeView-disk-full-bg-color: $panel_bg_color;
      -NemoPlacesTreeView-disk-full-fg-color: $warning_color;
    }
  }

  scrolledwindow.frame {
    border-style: none;

    .view:not(:selected) { 
      background-color: transparent; 
      padding-top: 4px;
      padding-bottom: 4px;
    }
  }

  scrolledwindow widget.entry {
    border: 1px solid $border_color;
  }

  infobar { margin-top: -6px; }

  .nemo-inactive-pane .view:not(:selected) { background-color: $alt_base_color; }

  .toolbar button { @extend %flat_button; }

  .view .entry {
    border: 1px solid green;
  }
}

/* virtualbox autorun button */
.nemo-window-pane buttonbox {
  padding-top: 6px;
}
