
/* Import theme */

@import "Qogir/theme.css"; /**/

/*
 * Here you can enable other theme features not included by default.
 * To enable a specific feature, uncomment its @import line by removing "/*" at
 * the beginning of the line. To disable it, put the "/*" back.
 */

/* Hide the tab bar when only one tab is open (GNOMISH)
 * You should move the new tab button somewhere else for this to work, because by
 * default it is on the tab bar too. */
/*@import "Qogir/hide-single-tab.css"; /**/

/* Limit the URL bar's autocompletion popup's width to the URL bar's width (GNOMISH) 
 * This feature is included by default for Firefox 70+. */
/*@import "Qogir/matching-autocomplete-width.css"; /**/

/* Use circle title buttons old style */
/*@import "Qogir/circle-title-buttons.css"; /**/

/* Use normal width tabs */
/*@import "Qogir/normal-width-tabs.css"; /**/

/* Active tab high contrast */
/*@import "Qogir/active-tab-contrast.css"; /**/

/* Use system theme icons instead of Adwaita icons included by theme */
/*@import "Qogir/system-icons.css"; /**/

/* Allow drag window from headerbar buttons (GNOMISH) [BUGGED] 
 * It can activate button action, with unpleasant behavior. */
/*@import "Qogir/drag-window-headerbar-buttons.css"; /**/

/* Make all tab icons look kinda like symbolic icons */
/*@import "Qogir/symbolic-tab-icons.css"; /**/

/* Import a custom stylesheet
 * Everything you add in your customChrome.css file (it doesn't exist by
 * default) will be included here and preserved between updates, so you can move
 * your configuration to that file if you don't like setting it up after every
 * update. You can also apply your own custom styles in that file. */
@import "customChrome.css"; /**/
