/* Buttons */
.button {
  min-height: $medium_size;
  padding: 0 16px;
  border-width: 0;
  border-radius: 2px;
  @include font(button);
  @include button(flat-normal);
  &:hover { @include button(flat-hover); }
  &:active { @include button(flat-active); }
  &:insensitive { @include button(flat-insensitive); }
  &:focus { @include button(flat-focus); }

}

.modal-dialog-linked-button {
  min-height: 40px;
  padding: 0 16px;
  border-top: 1px solid $border_color !important;
  border-right-width: 0;
  @include font(button);
  @include button(flat-normal);
  &:hover { @include button(flat-hover); }
  &:active { @include button(flat-active); }
  &:insensitive { @include button(flat-insensitive); }
  &:focus { @include button(flat-focus); }

  &:first-child {
    border-radius: 0px 0px 0px 2px;
  }
  &:last-child {
    border-right-width: 0px;
    border-radius: 0px 0px 2px 0px;
  }
  &:first-child:last-child {
    border-right-width: 0px;
    border-radius: 0px 0px 2px 2px;
  }
}
