$variant: 'light';
$titlebar: 'light';
$compact: 'false';

@import 'sass/variables';
@import 'sass/colors';
@import 'sass/drawing';
@import 'sass/common';
@import 'sass/apps';
@import 'sass/colors-public';
