/* Entries */
StEntry {
  min-height: $medium_size;
  padding: 0 8px;
  border-radius: 0;
  border-width: 0;
  color: $fg_color;
  selection-background-color: $primary_color;
  selected-color: $inverse_fg_color;
  @include font(subheading);
  @include entry(normal);
  //&:hover { @include entry(hover);}
  &:focus { @include entry(focus);}
  &:insensitive { @include entry(insensitive);}
  StIcon.capslock-warning {
    icon-size: 16px;
    warning-color: $warning_color;
    padding: 0 0;
  }
}
