$variant: 'light';
$trans: 'true';
$titlebar: 'dark';
$theme: 'manjaro';
$titlebutton: '';

@import "../../_sass/colors"; //use gtk colors
@import "../../_sass/variables";
@import "../../_sass/cinnamon/drawing";
@import "../../_sass/cinnamon/common";
