$asset_suffix: if($variant == 'dark', '-dark', '');
$extra_background_clip: if($variant == 'light', padding-box, border-box);

$panel_corner_radius: 4px;

// font families
$font-family: Fira Sans, Cantarell, Sans-Serif;
$large-font-family: Fira Sans, "M+ 1c", Cantarell, Sans-Serif;

// font sizes
$root-font-size: if($compact == 'false', 14px, 13px);
$subheading-size: if($compact == 'false', 16px, 15px);

// opacities
$higher_opacity: 0.9;
$middle_opacity: 0.6;
$lower_opacity: 0.3;

$secondary_opacity: 0.75;
$hint_opacity: 0.6;
$disabled_opacity: 0.5;

// sizes
$small_size: if($compact == 'false', 24px, 20px);
$medium_size: if($compact == 'false', 36px, 32px);
$large_size: if($compact == 'false', 48px, 44px);
$panel_item_size: if($compact == 'false', 16px, 12px);

$container_padding: 6px;

$bar_size: 4px;
$menuitem_size: if($compact == 'false', 32px, 24px);

// radiuses
$material_radius: 4px;
$circular_radius: 9999px;

// durations
$shorter_duration: 0.2s / 2;
$longer_duration: 0.3s / 2;
$ripple_duration: 0.5s / 2;

// timing functions
$standard_curve: cubic-bezier(0.4, 0.0, 0.2, 1);
$deceleration_curve: cubic-bezier(0.0, 0.0, 0.2, 1);
$acceleration_curve: cubic-bezier(0.4, 0.0, 1, 1);
$sharp_curve: cubic-bezier(0.4, 0.0, 0.6, 1);

// transition shorthands
$shorter_transition: all $shorter_duration $deceleration_curve;
$longer_transition: all $longer_duration $deceleration_curve;
$shadow_transition: box-shadow $shorter_duration $deceleration_curve;

// shadows
// based shadow values:
// https://material-design.storage.googleapis.com/images/layout-principles-dimensionality-shadows-08_large_mdpi.png

$shadow_0: 0 0 transparent;
$shadow_1: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
$shadow_2: 0 3px 3px rgba(0, 0, 0, 0.16 * 1.5), 0 3px 3px rgba(0, 0, 0, 0.23 * 1.5);
$shadow_3: 0 10px 10px rgba(0, 0, 0, 0.19 * 1.5), 0 6px 3px rgba(0, 0, 0, 0.23 * 1.5);
$shadow_4: 0 10px 14px 5px rgba(0, 0, 0, 0.25 * 2), 0 10px 5px 5px rgba(0, 0, 0, 0.22 * 2);
$shadow_5: 0 19px 19px rgba(0, 0, 0, 0.30 * 2), 0 15px 6px rgba(0, 0, 0, 0.22 * 2);
