/*********
 * Paned *
 *********/
paned {
  > separator {
    min-width: $separator_size;
    min-height: $separator_size;
    -gtk-icon-source: none; // defeats the ugly default handle decoration
    border-style: none; // just to be sure
    background-color: transparent;
    // workaround, using background istead of a border since the border will get rendered twice (?)
    background-image: image($border_color);
    background-size: $border_size $border_size;
    background-clip: content-box; // avoids borders image being rendered twice (?)

    &.wide {
      min-width: $mini_size;
      min-height: $mini_size;
      background-color: $bg_color;
      background-image: image($border_color), image($border_color);
      background-size: $border_size $border_size, $border_size $border_size;
    }
  }

  &.horizontal > separator {
    background-repeat: repeat-y;

    &:dir(ltr) {
      margin: 0 -$small_padding 0 0;
      padding: 0 $small_padding 0 0;
      background-position: left;
    }

    &:dir(rtl) {
      margin: 0 0 0 -$small_padding;
      padding: 0 0 0 $small_padding;
      background-position: right;
    }

    &.wide {
      margin: 0;
      padding: 0;
      background-repeat: repeat-y, repeat-y;
      background-position: left, right;
    }
  }

  &.vertical > separator {
    margin: 0 0 -$small_padding 0;
    padding: 0 0 $small_padding 0;
    background-repeat: repeat-x;
    background-position: top;

    &.wide {
      margin: 0;
      padding: 0;
      background-repeat: repeat-x, repeat-x;
      background-position: bottom, top;
    }
  }
}
