/* Switches */
.toggle-switch {
  width: 40px;
  height: 20px;
  background-size: contain;
}

  @each $v in us, intl {
    .toggle-switch-#{$v} {
      background-image: url("assets/toggle-off.svg");
      &:checked { background-image: url("assets/toggle-on.svg"); }
    }
  }
