/***********
 * Dialogs *
 ***********/
messagedialog { // Message Dialog styling
  &.background { background-color: $lighter_bg_color; }

  .titlebar {
    min-height: $titlebar_size;
    border-style: none;
    box-shadow: inset 0 1px $highlight_color;
    background-color: $lighter_bg_color;
    color: $fg_color;

    &:backdrop { background-color: $lighter_bg_color; }
  }

  &.csd { // rounded bottom border styling for csd version
    &.background {
      // bigger radius for better antialiasing
      border-bottom-left-radius: $pocillo_radius;
      border-bottom-right-radius: $pocillo_radius;
    }

    .dialog-action-area button {
      color: $fg_color;
      padding: $small_padding $large_padding;
      border-top: 1px solid $border_color;
      border-radius: 0;

      @extend %simple_flat_button;

      &:first-child { border-bottom-left-radius: $other_radius; }

      &:last-child { border-bottom-right-radius: $other_radius; }

      &:focus {
        background-color: $modal_button_color;
        color: rgba($fg_color, 0.9);
	    }
    }
  }

}

filechooser {
  .dialog-action-box { border-top: 1px solid $border_color; }

  #pathbarbox {
    border-bottom: 1px solid $border_color;
    background-color: $bg_color;
  }
}

filechooserbutton:drop(active) {
  box-shadow: none;
}

