// based css:
// https://bazaar.launchpad.net/~ubuntu-art-pkg/ubuntu-themes/trunk/view/head:/Ambiance/gtk-3.20/apps/unity.css

/*********
 * Unity *
 *********/
// Decorations
UnityDecoration {
  -UnityDecoration-extents: 28px 0 0 0;
  -UnityDecoration-input-extents: 8px;

  -UnityDecoration-shadow-offset-x: 0;
  -UnityDecoration-shadow-offset-y: 3px;
  -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.48);
  -UnityDecoration-active-shadow-radius: 18px;
  -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.32);
  -UnityDecoration-inactive-shadow-radius: 6px;

  -UnityDecoration-glow-size: 8px;
  -UnityDecoration-glow-color: $primary_color;

  -UnityDecoration-title-indent: 4px;
  -UnityDecoration-title-fade: 32px;
  -UnityDecoration-title-alignment: 0.0;

  .top {
    padding: 0 2px;
    border-style: none;
    border-radius: 2px 2px 0 0;
    // box-shadow: inset 0 1px $titlebar_highlight_color;
    box-shadow: inset 0 1px $unity_highlight_color;
    background-color: $alt_titlebar_bg_color;
    color: $titlebar_fg_color;

    &:backdrop { color: $titlebar_secondary_fg_color; }
  }

  .left,
  .right {}

  .bottom {}

  .menuitem {
    color: $titlebar_secondary_fg_color;

    &:hover {
      box-shadow: inset 0 -2px $titlebar_indicator_color;
      background-color: transparent;
      color: $titlebar_fg_color;
    }
  }
}

.background:not(.csd) headerbar:not(.titlebar) {
  border-radius: 0;
  box-shadow: $shadow_1;

  &.inline-toolbar { border-style: none; }
}

sheet-style-dialog.unity-force-quit {
  // background-color: $bg_color;
}

// Panel Style
UnityPanelWidget,
.unity-panel {
  background-color: $unity_panel_bg_color;
  color: $titlebar_fg_color;

  &:backdrop { color: $titlebar_secondary_fg_color; }
}

.unity-panel.menubar,
.unity-panel .menubar {
}

.unity-panel.menuitem,
.unity-panel .menuitem {
  color: $titlebar_secondary_fg_color;
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
  box-shadow: inset 0 -2px $titlebar_indicator_color;
  background-color: transparent;
  color: $titlebar_fg_color;
}

.menu IdoPlaybackMenuItem.menuitem:active {
  -gtk-icon-source: -gtk-icontheme('process-working-symbolic');
  animation: spin 1s linear infinite;
  color: $primary_color;
}
