@import 'apps/third-party';
@import 'apps/unity';
@import 'apps/mate';
@import 'apps/budgie';
@import 'apps/gnome';
@import 'apps/lightdm';
@import 'apps/elementary';
@import 'apps/slick-greeter';
@import 'apps/nemo';
