//Keyboard
/* On-screen Keyboard */

#keyboard {
    background-color: $alt_bg_color;
}

.keyboard-layout {
  spacing: 10px;
  padding: 10px;
}

.keyboard-row { spacing: 15px; }

.keyboard-key {
  min-height: $medium_size * 2;
  min-width: $medium_size * 2;
  font-size: 2em;
  font-weight: 500;
  border-radius: 2px;
  border: none;
  color: inherit;
  @include button(normal);
  &:focus { @include button(focus); }
  &:hover,&:checked { @include button(hover); }
  &:active { @include button(active);}
  &:grayed { //FIXME
    background-color: $alt_bg_color;
    color: $inverse_fg_color;
    border-color: $alt_bg_color;
  }
}

.keyboard-subkeys { //long press on a key popup
  color: inherit;
  padding: 5px;
  -arrow-border-radius: 0;
  -arrow-background-color: transparent;
  -arrow-border-width: 0;
  -arrow-border-color: transparent;
  -arrow-base: 0;
  -arrow-rise: 0;
  -boxpointer-gap: 5px;
  background-color: $base_color;
  border-radius: 2px;
  box-shadow: $shadow_2;
}
