/* Dash to Dock */

#dashtodockContainer #dash {
  background-color: rgba($panel_bg_color, 0.85);
}

#dashtodockContainer:overview #dash {
  background-color: rgba($panel_bg_color, 0.85);
}

#dashtodockContainer.extended:overview #dash {
  background-color: transparent;
}

#dashtodockContainer.left #dash,
#dashtodockContainer.right #dash {
  padding: 3px 0;
}

#dashtodockContainer.top #dash,
#dashtodockContainer.bottom #dash {
  padding: 0 3px;
}

#dashtodockContainer.extended #dash {
  padding: 0;
  border-radius: 0;
}

#dashtodockContainer.left .dash-item-container > StWidget,
#dashtodockContainer.right .dash-item-container > StWidget,
#dashtodockContainer.extended.left .dash-item-container > StWidget,
#dashtodockContainer.extended.right .dash-item-container > StWidget {
  padding: 3px 6px;
}

#dashtodockContainer.extended.left .dash-item-container:first-child > StWidget,
#dashtodockContainer.extended.right .dash-item-container:first-child > StWidget {
  padding: 6px 6px 3px 6px;
}

#dashtodockContainer.extended.left .dash-item-container:last-child > StWidget,
#dashtodockContainer.extended.right .dash-item-container:last-child > StWidget {
  padding: 3px 6px 6px 6px;
}

#dashtodockContainer.top .dash-item-container > StWidget,
#dashtodockContainer.bottom .dash-item-container > StWidget,
#dashtodockContainer.extended.top .dash-item-container > StWidget,
#dashtodockContainer.extended.bottom .dash-item-container > StWidget {
  padding: 6px 3px;
}

#dashtodockContainer.extended.top .dash-item-container:first-child > StWidget,
#dashtodockContainer.extended.bottom .dash-item-container:first-child > StWidget {
  padding: 6px 3px 6px 6px;
}

#dashtodockContainer.extended.top .dash-item-container:last-child > StWidget,
#dashtodockContainer.extended.bottom .dash-item-container:last-child > StWidget {
  padding: 6px 6px 6px 3px;
}

#dashtodockContainer .app-well-app-running-dot {
  background-color: transparent;
}

#dashtodockContainer .dash-item-container > StWidget {
  background-size: cover;
}

@each $p, $pt in ('.left', 'left'),
                 ('.right', 'right'),
                 ('.top', 'top'),
                 ('.bottom', 'bottom') {
  @each $n, $nb in ('.running1', 'running1'),
                   ('.running2', 'running2'),
                   ('.running3', 'running3'),
                   ('.running4', 'running4') {
    @each $f, $fc in ('', ''),
                     ('.focused', '-focused') {
      #dashtodockContainer#{$p} .dash-item-container > StWidget#{$n}#{$f} {
        background-image: url("assets/dash/#{$pt}-#{$nb}#{$fc}.svg");
      }
    }
  }
}


/* Simple Dock */

#dash:desktop {
  background-color: $bg_color;
}


/* GPaste */

.popup-menu {
  .search-entry {
    color: $fg_color;
    selection-background-color: $primary_color;
    selected-color: $inverse_fg_color;
    @include entry(normal);

    &:focus {
      @include entry(focus);
      color: $fg_color;
    }

    .search-entry-icon { color: $hint_fg_color; }

    &:hover, &:focus {
      .search-entry-icon { color: $fg_color; }
    }
  }
}

/*****************
 * GNOME Classic *
 *****************/

#panel.bottom-panel {
  &, &.solid {
    height: 32px; // = 1.875em
    border-top-width: 1px;
    border-bottom-width: 0;
    border-color: $panel_bg_color;
    background-color: $panel_bg_color;
    background-gradient-drection: vertical;
    background-gradient-start: $panel_bg_color;
    background-gradient-end: $panel_bg_color;
    color: $fg_color;
  }
}

#panel {
  height: 32px; // = 1.875em
  border-top-width: 0;
  border-bottom-width: 1px;
  border-color: $panel_bg_color;
  background-color: $panel_bg_color;
  background-gradient-drection: vertical;
  background-gradient-start: $panel_bg_color;
  background-gradient-end: $panel_bg_color;
  color: $fg_color;

  .panel-button {
    &:active,
    &:focus {
      background-color: $panel_bg_color;
      background-gradient-drection: vertical;
      background-gradient-start: $panel_bg_color;
      background-gradient-end: $panel_bg_color;
    }
  }
}
