//This is the RIGHT PLACE to edit the stylesheet

//let's start by telling people not to edit the generated CSS:
$cakeisalie: "This stylesheet is generated, DO NOT EDIT";
/* #{$cakeisalie} */

/* Copyright 2009, 2015 Red Hat, Inc.
 *
 * Portions adapted from Mx's data/style/default.css
 *   Copyright 2009 Intel Corporation
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */


/* GLOBALS */
* {
  // transition-timing-function: $deceleration_curve;
  transition-duration: $longer_duration;
}

stage {
  font-family: $font-family;
  @include font(body-1);
  color: $fg_color;
}

/* WIDGETS */

@import 'widgets/buttons';
@import 'widgets/checkbox';
@import 'widgets/entries';
@import 'widgets/ibuspopup';
@import 'widgets/lockscreen';
@import 'widgets/loginscreen';
@import 'widgets/lookingglass';
@import 'widgets/menu-popover';
@import 'widgets/misc';
@import 'widgets/modal';
@import 'widgets/osd';
@import 'widgets/overview';
@import 'widgets/scrollbars';
@import 'widgets/slider';
@import 'widgets/switches';
@import 'widgets/topbar';
@import 'widgets/virtkeyboard';
@import 'widgets/notifications';

