@function scale-alpha($c, $a) {
  @return scale-color($c, $alpha: percentage(-1 + $a));
}

@function gtkalpha($c,$a) {
  @return unquote("alpha(#{$c},#{$a})");
}

$asset_suffix: if($variant == 'dark', '-dark', '');
$asset_suffix_dark: if($titlebar == 'dark', '-dark', '');
$asset_suffix_win: if($titlebutton == 'circle', '', '-win');

// sizes
$small_size: 16px;
$medium_size: 28px;
$large_size: 38px;

$cont_padding: 6px;
$menuitem_size: 28px;
$icon_padding: 5px;

// radiuses
$bt_radius: 2px;
$corner_radius: 0;
$material_radius: 2px;
$circular_radius: 9999px;

// durations
$shorter_duration: 180ms;
$longer_duration: 270ms;
$ripple_duration: 450ms;

// timing functions
$standard_curve: cubic-bezier(0.4, 0.0, 0.2, 1);
$deceleration_curve: cubic-bezier(0.0, 0.0, 0.2, 1);
$acceleration_curve: cubic-bezier(0.4, 0.0, 1, 1);
$sharp_curve: cubic-bezier(0.4, 0.0, 0.6, 1);

// transition shorthands
$shorter_transition: all $shorter_duration $deceleration_curve;
$longer_transition: all $longer_duration $deceleration_curve;
$shadow_transition: box-shadow $shorter_duration $deceleration_curve;

$ease-out-quad: cubic-bezier(0.25, 0.46, 0.45, 0.94);
$backdrop_transition: 200ms ease-out;
