//SCREEN SHIELD

.screen-shield-arrows {
    padding-bottom: 3em;
}

.screen-shield-arrows Gjs_Arrow {
    color: white;
    width: 80px;
    height: 48px;
    -arrow-thickness: 12px;
    -arrow-shadow: $shadow_1;
}

.screen-shield-clock {
  color: white;
  text-shadow: $shadow_1;
  font-weight: normal;
  text-align: center;
  padding-bottom: 1.5em;
}

.screen-shield-clock-time {
  @include font(display-4);
  text-shadow: $shadow_1;
}

.screen-shield-clock-date { @include font(display-2); }

.screen-shield-notifications-container {
  spacing: 6px;
  width: 30em;
  background-color: transparent;
  max-height: 500px;
  .summary-notification-stack-scrollview {
    padding-top: 0;
    padding-bottom: 0;
  }

  .notification,
  .screen-shield-notification-source {
    padding: 8px;
    border: none;
    background-color: $alt_bg_color;
    color: $inverse_fg_color;
    border-radius: 2px;
  }
  .notification { margin-right: 16px; } //compensate for space allocated to the scrollbar
}


.screen-shield-notification-label {
  min-height: $small_size - 2px;
  padding: 2px 0px 0px 16px;
  font-weight: bold;
}

.screen-shield-notification-count-text {
  min-height: $small_size - 2px;
  padding: 2px 0px 0px 16px;
  color: $inverse_secondary_fg_color;
}

#panel.lock-screen { background-color: $alt_bg_color; }

.screen-shield-background { //just the shadow, really
  background: black;
  box-shadow: $shadow_5;
}

#lockDialogGroup {
  background: #607D8B url("assets/noise-texture.svg");
  background-size: cover;
}

#screenShieldNotifications {
  StScrollBar { @extend %overview_scrollbar; }
}

