/* Find bar  */

@namespace xul "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

findbar {
	position: relative;
}

findbar label, findbar description {
	color: var(--gnome-toolbar-color) !important;
}

.findbar-container {
	padding: 6px !important;
	display: flex;
	justify-content: flex-start;
	position: relative;
	flex-direction: row;
	width: calc(100% - 42px);
}

hbox[anonid="findbar-textbox-wrapper"] {
	display: flex !important;
}

.findbar-entire-word {
	margin-right: auto !important;
}

.findbar-find-status, .found-matches {	
	margin-right: 6px !important;
	padding: 7px 0;
}

.findbar-closebutton {
	margin: 6px 6px 6px 0 !important;
}
