/* Buttons Issues/Glitches fixes */
@namespace xul "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

/* Overrides: Make the back button the same as other buttons */
:root:not([uidensity=compact]) #back-button {
	border-radius: var(--toolbarbutton-border-radius) !important;
}
:root:not([uidensity=compact]) #back-button > .toolbarbutton-icon {
	background-color: unset !important;
	border: unset !important;
	width: calc(2 * var(--toolbarbutton-inner-padding) + 16px) !important;
	height: calc(2 * var(--toolbarbutton-inner-padding) + 16px) !important;
	padding: var(--toolbarbutton-inner-padding) !important;
	border-radius: var(--toolbarbutton-border-radius);
	box-shadow: none !important;
}
:root:not([uidensity=compact]) #back-button:not([disabled]):not([open]):hover > .toolbarbutton-icon {
	background-color: var(--toolbarbutton-hover-background) !important;
	box-shadow: unset;
	border-color: unset;
}
:root:not([uidensity=compact]) #back-button[open] > .toolbarbutton-icon,
:root:not([uidensity=compact]) #back-button:not([disabled]):hover:active > .toolbarbutton-icon {
	background-color: var(--toolbarbutton-active-background) !important;
	border-color: unset;
}

/* Remove the header bar buttons' hover styles */
#nav-bar {
	--toolbarbutton-active-background: transparent !important;
	--toolbarbutton-hover-background: transparent !important;
}

/* Glitch customizing: Cut / Copy / Paste buttons' icons
 * :not(#hack) is there just to elevate rule priority */
:root[customizing] #nav-bar > hbox toolbaritem toolbarbutton image:not(#hack) {
	opacity: 1 !important;
}
/* Glitch customizing: Reload and Cut / Copy / Paste buttons */
:root:-moz-window-inactive[customizing] #nav-bar #stop-reload-button toolbarbutton,
:root:-moz-window-inactive[customizing] #nav-bar #edit-controls toolbarbutton {
	background-image: var(--gnome-inactive-button-background);
	box-shadow: var(--gnome-inactive-button-box-shadow);
}
/* Glitch customizing: Reload and Cut / Copy / Paste buttons' icons */
:root:-moz-window-inactive[customizing] #nav-bar #stop-reload-button image.toolbarbutton-icon,
:root:-moz-window-inactive[customizing] #nav-bar #edit-controls image.toolbarbutton-icon {
	opacity: .7 !important;
}

/* Glitch: Overflow and Burger buttons
 * :not(#hack) is there just to elevate rule priority */
:root[customizing] #nav-bar > toolbarbutton[disabled]:not(#hack),
:root[customizing] #nav-bar > toolbaritem > toolbarbutton[disabled]:not(#hack) {
	opacity: .5 !important;
}
/* Glitch: Overflow button's icon */
:root[customizing] #nav-bar toolbarbutton:not(#urlbar-zoom-button)[disabled] image {
	fill-opacity: var(--toolbarbutton-icon-fill-opacity) !important;
}

/* Bookmark buttons */
#nav-bar toolbarbutton.bookmark-item {
	width: auto !important;
}
#nav-bar toolbarbutton.bookmark-item .toolbarbutton-icon {
	margin-left: 6px;
}
#nav-bar toolbarbutton.bookmark-item .toolbarbutton-text {
	padding-right: 6px;
}

/* Remove Burger button's left separator */
#PanelUI-button {
	border: 0 !important;
	margin: 0 !important;
	padding-inline-start: 0 !important;
}

/* Space main menu button from other headerbar buttons
#nav-bar #PanelUI-menu-button:not(#hack) {
	margin-left: 10px !important;
}*/

/* Fix library animation */
#library-animatable-box  {
	--library-button-height: 46px !important;
	--library-icon-x: 1716px !important;
	/*--library-icon-x: 1715.9833984375px !important;*/
}
#library-button[animate] > .toolbarbutton-icon {
	fill: transparent !important;
}

/* Fix toolbars close icons */
.close-icon:not(.tab-close-button) image {
	height: 16px !important;
	width: 16px !important;
	margin: 6px !important;
}

/* */
#appMenu-popup .panel-banner-item[notificationid="update-restart"]::after {
	display: none !important;
}

/* Identity site popover buttons */
.identity-popup-preferences-button:not(#hack) {
	list-style-image: url("chrome://browser/skin/settings.svg") !important;
}
#tracking-protection-preferences-button > .toolbarbutton-text {
	padding-inline-end: 0 !important;
}
.protections-popup-footer-button-label {
	margin-inline-start: 3px !important;
}

/* Fix findbar buttons issues */
.findbar-container .findbar-find-previous image,
.findbar-container .findbar-find-next image {
	margin: 6px !important;
	opacity: 1 !important;
}
.findbar-container toolbarbutton:focus {
	outline: 0 !important;
}

/* Sidebar header button reset font size */
#sidebar-header {
	font-size: 1em !important;
}

/* Sidebar header button arrow opacity */
#sidebar-switcher-arrow {
	opacity: 1 !important;
}

/* Sidebar history view */
#viewButton {
	margin: 0 !important;
	margin-inline-start: 6px !important;
}

/* Menulist */
menulist {
	-moz-appearance: none !important;
}
#identity-popup-popup-menulist {
	margin-right: 0 !important;
}

/* Bookmarks editor buttons */
.expander-down image, .expander-up image {
	margin: 6px !important;
}

/* Identity popup tracking protection button */
.tracking-protection-button {
	margin-inline-end: 0 !important;
}

/* Identity popup delete permission button */
.identity-popup-permission-remove-button {
	opacity: 1 !important;
}

/* Identity popup expander button */
#identity-popup-security {
	-moz-box-align: center;
}
#identity-popup-security-expander {
	width: 34px !important;
}
#identity-popup-security-expander .button-icon {
	margin: 0 !important;
}
