/***********
 * Sidebar *
 ***********/
.sidebar {
  border-style: none;
  background-color: $lighter_bg_color;

  @at-root %sidebar_left,
  &:dir(ltr),
  &.left,
  &.left:dir(rtl) {
    border-right: $border_size solid $border_color;
    border-left-style: none;
  }

  @at-root %sidebar_right,
  &:dir(rtl),
  &.right {
    border-left: $border_size solid $border_color;
    border-right-style: none;
  }

  list { background-color: transparent; }

  paned & { &.left, &.right, &.left:dir(rtl), &:dir(rtl), &:dir(ltr), & { border-style: none; }}
}

stacksidebar {
  &.sidebar {
    &:dir(ltr),
    &.left,
    &.left:dir(rtl) { list { @extend %sidebar_left; }}

    &:dir(rtl),
    &.right { list { @extend %sidebar_right; }}
  }

  row {
    padding: $tiny_padding;

    > label {
      padding-left: $tiny_padding;
      padding-right: $tiny_padding;
    }

    &.needs-attention > label { @extend %needs_attention; }
  }
}
