/* NOTIFICATIONS & MESSAGE TRAY */

.url-highlighter { link-color: $link_color; }

// Banners
.notification-banner {
  font-size: 1em;
  width: 34em;
  min-height: $menuitem_size * 2;
  margin: 5px;
  border-radius: 2px;
  color: $fg_color;
  background-color: $bg_color;
  border: none;
  box-shadow: $shadow_2;
  &:hover { background-color: $bg_color; }
  &:focus { background-color: $bg_color; }

  .notification-icon { padding: 5px; }
  .notification-content { padding: 5px; spacing: 5px; }
  .secondary-icon { icon-size: em(16px); }
  .notification-actions {
    background-color: $bg_color;
    padding-top: 0;
    border-top: 1px solid $border_color;
    spacing: 1px;
  }
  .notification-button {
    min-height: 40px;
    padding: 0 16px;
    background-color: $bg_color;
    color: $secondary_fg_color;
    font-weight: 500;
    &:first-child { border-radius: 0 0 0 2px; }
    &:last-child { border-radius: 0 0 2px 0; }
    &:hover, &focus { background-color: $divider_color; color: $fg_color; }
    &:active { background-color: $track_color; color: $fg_color; }
  }
}
.summary-source-counter {
  font-size: 1em;
  font-weight: bold;
  height: 1.6em; width: 1.6em;
  -shell-counter-overlap-x: 3px;
  -shell-counter-overlap-y: 3px;
  background-color: $primary_color;
  color: $inverse_fg_color;
  border: 2px solid $inverse_fg_color;
  box-shadow: 0 2px 2px rgba(0,0,0,0.5);
  border-radius: 0.9em; // should be 0.8 but whatever; wish I could do 50%;
}

.secondary-icon { icon-size: em(16px); }

//chat bubbles
.chat-body { spacing: 5px; }
.chat-response { margin: 5px; }
.chat-log-message { color: $fg_color; }
.chat-new-group { padding-top: 1em; }
.chat-received {
  padding-left: 4px;
  &:rtl { padding-left: 0px; padding-right: 4px; }
}
.chat-sent {
  padding-left: 18pt;
  color: $secondary_fg_color;
  &:rtl { padding-left: 0; padding-right: 18pt; }
}
.chat-meta-message {
  padding-left: 4px;
  @include font(caption);
  color: $hint_fg_color;
  &:rtl { padding-left: 0; padding-right: 4px; }
}

//hotplug
.hotplug-transient-box {
  spacing: 6px;
  padding: 2px 72px 2px 12px;
}
.hotplug-notification-item {
  padding: 2px 10px;
  &:focus { padding: 1px 71px 1px 11px; }
}

.hotplug-notification-item-icon {
  icon-size: 24px;
  padding: 2px 5px;
}

.hotplug-resident-box { spacing: 8px; }

.hotplug-resident-mount {
  spacing: 8px;
  border-radius: 2px;
  &:hover { background-color: $divider_color; }
  &:active { background-color: $track_color; }
}

.hotplug-resident-mount-label {
  color: inherit;
  padding-left: 6px;
}

.hotplug-resident-mount-icon {
  icon-size: 24px;
  padding-left: 6px;
}

.hotplug-resident-eject-icon {
  icon-size: 16px;
}

.hotplug-resident-eject-button {
  padding: 7px;
  border-radius: 2px;
  color: $fg_color;
}
