/* links */
.shell-link {
  border-radius: 2px;
  color: $link_color;
  &:hover {
    color: $link_color;
    background-color: rgba($link_color, $lower_opacity / 2);
  }
  &:active {
    color: $link_color;
    background-color: rgba($link_color, $lower_opacity);
  }
}

//user icons
.framed-user-icon {
  background-size: contain;
  border: none;
  color: $inverse_fg_color;
  border-radius: 2px;
  &:hover {
    border-color: $inverse_fg_color;
    color: $inverse_fg_color;
  }
}

//magnifier

.magnifier-zoom-region {
  border: 2px solid $primary_color;
  &.full-screen { border-width: 0; }
}
