/* Copyright 2009, 2015 Red Hat, Inc.
 *
 * Portions adapted from Mx's data/style/default.css
 *   Copyright 2009 Intel Corporation
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */
stage {
  font-size: 10pt;
  color: #5c616c;
}

.button, .hotplug-notification-item, .notification-banner .notification-button,
.notification-banner:hover .notification-button,
.notification-banner:focus .notification-button {
  min-height: 20px;
  padding: 5px 32px;
  transition-duration: 0;
  border-radius: 2px;
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: white;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.button:focus, .hotplug-notification-item:focus, .notification-banner .notification-button:focus {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: white;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.button:hover, .hotplug-notification-item:hover, .notification-banner .notification-button:hover {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.03);
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.button:hover:focus, .hotplug-notification-item:hover:focus, .notification-banner .notification-button:hover:focus {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.03);
  border: 1px solid #2eb398;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.button:active, .button:active:focus, .hotplug-notification-item:active, .notification-banner .notification-button:active {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #248a76;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.button:insensitive, .hotplug-notification-item:insensitive, .notification-banner .notification-button:insensitive {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: rgba(92, 97, 108, 0.55);
  border: 1px solid rgba(0, 0, 0, 0);
  background-color: rgba(255, 255, 255, 0.55);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

StEntry {
  padding: 7px;
  caret-size: 1px;
  caret-color: #5c616c;
  selection-background-color: #2eb398;
  selected-color: #ffffff;
  transition-duration: 300ms;
  border-radius: 3px;
  color: #5c616c;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 2px 4px rgba(255, 255, 255, 0.05);
}

StEntry:focus, StEntry:hover {
  color: #5c616c;
  background-color: #ffffff;
  border: 1px solid #2eb398;
  box-shadow: inset 0 2px 4px rgba(255, 255, 255, 0.05);
}

StEntry:focus StLabel.hint-text, StEntry:hover StLabel.hint-text {
  color: rgba(255, 255, 255, 0.7);
}

StEntry:insensitive {
  color: rgba(92, 97, 108, 0.55);
  background-color: #fdfdfe;
  border-color: 1px solid rgba(227, 228, 229, 0.5325);
  box-shadow: inset 0 2px 4px rgba(253, 253, 254, 0.05);
}

StEntry StIcon.capslock-warning {
  icon-size: 16px;
  warning-color: #F27835;
  padding: 0 4px;
}

StEntry StIcon.peek-password {
  icon-size: 16px;
  padding: 0 4px;
}

StEntry StLabel.hint-text {
  margin-left: 2px;
  color: rgba(92, 97, 108, 0.7);
}

StScrollView.vfade {
  -st-vfade-offset: 0px;
}

StScrollView.hfade {
  -st-hfade-offset: 0px;
}

StScrollBar {
  padding: 8px;
}

StScrollView StScrollBar {
  min-width: 5px;
  min-height: 5px;
}

StScrollBar StBin#trough {
  background-color: rgba(255, 255, 255, 0.1);
  border-radius: 8px;
}

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle {
  border-radius: 4px;
  background-color: #bbbdc2;
  border: 0px solid;
  margin: 0px;
}

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover {
  background-color: #cbcdd1;
}

StScrollBar StButton#vhandle:active, StScrollBar StButton#hhandle:active {
  background-color: #2eb398;
}

.slider {
  -slider-height: 4px;
  -slider-background-color: rgba(0, 0, 0, 0.15);
  -slider-border-color: transparent;
  -slider-active-background-color: #2eb398;
  -slider-active-border-color: transparent;
  -slider-border-width: 0;
  -slider-handle-radius: 0;
  height: 18px;
  border: 0 solid transparent;
  border-right-width: 1px;
  border-left-width: 5px;
  color: transparent;
  -barlevel-height: 4px;
  -barlevel-background-color: rgba(0, 0, 0, 0.15);
  -barlevel-border-color: transparent;
  -barlevel-active-background-color: #2eb398;
  -barlevel-active-border-color: transparent;
  -barlevel-overdrive-color: #F04A50;
  -barlevel-overdrive-border-color: transparent;
  -barlevel-overdrive-separator-width: 2px;
  -barlevel-border-width: 0;
}

.popup-menu-item.selected .slider {
  -slider-background-color: rgba(0, 0, 0, 0.2);
  -slider-active-background-color: #ffffff;
  -barlevel-background-color: rgba(0, 0, 0, 0.2);
  -barlevel-active-background-color: #ffffff;
}

.check-box StBoxLayout {
  spacing: .8em;
}

.check-box StBin {
  width: 16px;
  height: 16px;
  background-image: url("assets/checkbox/checkbox-unchecked.svg");
}

.check-box:focus StBin {
  background-image: url("assets/checkbox/checkbox-unchecked-focused.svg");
}

.check-box:checked StBin {
  background-image: url("assets/checkbox/checkbox-checked.svg");
}

.check-box:focus:checked StBin {
  background-image: url("assets/checkbox/checkbox-checked-focused.svg");
}

.toggle-switch {
  width: 50px;
  height: 20px;
  background-size: contain;
  background-image: url("assets/switch/switch-off.svg");
}

.toggle-switch:checked {
  background-image: url("assets/switch/switch-on.svg");
}

.popup-menu-item.selected .toggle-switch {
  background-image: url("common-assets/switch/switch-off-selected.svg");
}

.popup-menu-item.selected .toggle-switch:checked {
  background-image: url("common-assets/switch/switch-on-selected.svg");
}

.shell-link {
  color: #248a76;
}

.shell-link:hover {
  color: #2eb398;
}

.nm-dialog, .inhibit-shortcuts-dialog, .extension-dialog, .geolocation-dialog, .access-dialog, .audio-device-selection-dialog, .prompt-dialog, .show-processes-dialog,
.mount-question-dialog, .end-session-dialog {
  color: #5c616c;
  background-color: #fafbfc;
  border: none;
}

.headline {
  font-size: 110%;
}

.lightbox {
  background-color: black;
}

.flashspot {
  background-color: white;
}

.modal-dialog {
  color: #5c616c;
  background-color: rgba(250, 251, 252, 0);
  border-radius: 0;
  border: none;
  border-image: url("assets/misc/modal.svg") 18 18 18 67;
  padding: 0 5px 6px 5px;
  box-shadow: none;
}

.modal-dialog .modal-dialog-content-box {
  padding: 20px 10px 10px 10px;
}

.modal-dialog-linked-button {
  height: 38px;
  padding: 0;
  box-shadow: inset 0 0 black;
  color: #D3DAE3;
  background-color: #282A33;
  border-top-width: 0px;
  border-bottom-width: 0;
}

.modal-dialog-linked-button:hover {
  background-color: #333641;
}

.modal-dialog-linked-button:focus {
  color: #2eb398;
}

.modal-dialog-linked-button:active {
  color: #ffffff;
  background-color: #2eb398;
}

.modal-dialog-linked-button:insensitive {
  color: rgba(211, 218, 227, 0.5);
  background-color: #24252d;
}

.modal-dialog-linked-button:first-child {
  border-radius: 0px 0px 0px 2px;
}

.modal-dialog-linked-button:last-child {
  border-right-width: 0px;
  border-radius: 0px 0px 2px 0px;
}

.modal-dialog-linked-button:first-child:last-child {
  border-right-width: 0px;
  border-radius: 0px 0px 2px 2px;
}

.modal-dialog .run-dialog-entry {
  width: 21em;
  margin-bottom: 6px;
}

.modal-dialog .run-dialog-error-box {
  padding-top: 16px;
  spacing: 6px;
}

.modal-dialog .run-dialog-button-box {
  padding-top: 1em;
}

.modal-dialog .run-dialog-label {
  font-size: 11pt;
  font-weight: normal;
  color: #5c616c;
  padding-bottom: .4em;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject,
.end-session-dialog-subject {
  font-size: 12pt;
  font-weight: bold;
  color: #5c616c;
}

/* Message Dialog */
.message-dialog-main-layout {
  padding: 12px 20px 0;
  spacing: 12px;
}

.message-dialog-content {
  max-width: 28em;
  spacing: 20px;
}

.message-dialog-content .message-dialog-title {
  text-align: center;
  font-size: 18pt;
  font-weight: bold;
}

.message-dialog-content .message-dialog-title.leightweight {
  font-size: 13pt;
  font-weight: 800;
}

.message-dialog-content .message-dialog-description {
  text-align: center;
}

.message-dialog-icon {
  min-width: 48px;
  icon-size: 48px;
}

.message-dialog-subtitle {
  color: #5c616c;
  font-weight: bold;
}

/* Dialog List */
.dialog-list {
  spacing: 18px;
}

.dialog-list .dialog-list-title {
  text-align: center;
  font-weight: bold;
}

.dialog-list .dialog-list-scrollview {
  max-height: 200px;
}

.dialog-list .dialog-list-box {
  spacing: 1em;
}

.dialog-list .dialog-list-box .dialog-list-item {
  spacing: 1em;
}

.dialog-list .dialog-list-box .dialog-list-item .dialog-list-item-title {
  font-weight: bold;
}

.dialog-list .dialog-list-box .dialog-list-item .dialog-list-item-description {
  color: rgba(92, 97, 108, 0.75);
}

/* Run Dialog */
.run-dialog .modal-dialog-content-box {
  margin-top: 24px;
  margin-bottom: 14px;
}

.run-dialog-entry {
  width: 20em;
}

.run-dialog-description {
  text-align: center;
  color: rgba(92, 97, 108, 0.75);
}

.end-session-dialog {
  spacing: 42px;
}

.end-session-dialog-list {
  padding-top: 20px;
}

.end-session-dialog-layout {
  padding-left: 17px;
}

.end-session-dialog-layout:rtl {
  padding-right: 17px;
}

.end-session-dialog-description {
  width: 28em;
  padding-bottom: 10px;
}

.end-session-dialog-description:rtl {
  text-align: right;
}

.end-session-dialog-warning {
  width: 28em;
  color: #F27835;
  padding-top: 6px;
}

.end-session-dialog-warning:rtl {
  text-align: right;
}

.end-session-dialog-logout-icon {
  border: 0px solid transparent;
  border-radius: 2px;
  width: 48px;
  height: 48px;
  background-size: contain;
}

.end-session-dialog-shutdown-icon {
  color: #5c616c;
  width: 48px;
  height: 48px;
}

.end-session-dialog-inhibitor-layout {
  spacing: 16px;
  max-height: 200px;
  padding-right: 10px;
  padding-left: 10px;
}

.end-session-dialog-session-list, .end-session-dialog-app-list {
  spacing: 1em;
}

.end-session-dialog-list-header {
  font-weight: bold;
}

.end-session-dialog-list-header:rtl {
  text-align: right;
}

.end-session-dialog-app-list-item, .end-session-dialog-session-list-item {
  spacing: 1em;
}

.end-session-dialog-app-list-item-name, .end-session-dialog-session-list-item-name {
  font-weight: bold;
}

.end-session-dialog-app-list-item-description {
  color: #686d7a;
  font-size: 9pt;
}

.end-session-dialog .modal-dialog-linked-button:last-child {
  color: white;
  background-color: #F04A50;
}

.end-session-dialog .modal-dialog-linked-button:last-child:hover {
  color: white;
  background-color: #f47479;
}

.end-session-dialog .modal-dialog-linked-button:last-child:active {
  color: white;
  background-color: #ee3239;
}

.shell-mount-operation-icon {
  icon-size: 48px;
}

.show-processes-dialog,
.mount-question-dialog {
  spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-question-dialog-subject {
  max-width: 500px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
  padding-left: 17px;
  width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
  padding-right: 17px;
}

.show-processes-dialog-app-list {
  font-size: 11pt;
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.show-processes-dialog-app-list-item {
  color: #454850;
}

.show-processes-dialog-app-list-item:hover {
  color: #5c616c;
}

.show-processes-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
  font-size: 11pt;
}

.mount-dialog {
  spacing: 24px;
}

.mount-dialog .message-dialog-title {
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
  max-width: 34em;
}

.mount-dialog .message-dialog-title:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-dialog .message-dialog-body {
  padding-left: 17px;
  width: 28em;
}

.mount-dialog .message-dialog-body:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-dialog-app-list {
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.mount-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.mount-dialog-app-list-item {
  color: #737a88;
}

.mount-dialog-app-list-item:hover {
  color: #5c616c;
}

.mount-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.mount-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.mount-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.mount-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.mount-dialog-app-list-item-name {
  font-size: 10pt;
}

.prompt-dialog {
  width: 34em;
}

.prompt-dialog .modal-dialog-content-box {
  margin-bottom: 24px;
}

.prompt-dialog .message-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.prompt-dialog .message-dialog-content {
  spacing: 16px;
}

.prompt-dialog .message-dialog-title {
  color: rgba(92, 97, 108, 0.75);
}

.prompt-dialog-password-grid {
  spacing-rows: 8px;
  spacing-columns: 4px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry {
  width: auto;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:ltr {
  margin-left: 20px;
}

.prompt-dialog-password-grid .prompt-dialog-password-entry:rtl {
  margin-right: 20px;
}

.prompt-dialog-password-layout {
  spacing: 8px;
}

.prompt-dialog-password-entry {
  width: 18em;
}

.prompt-dialog-error-label, .prompt-dialog-info-label, .prompt-dialog-null-label {
  text-align: center;
  margin: 6px;
}

.prompt-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.prompt-dialog-message-layout {
  spacing: 16px;
}

.prompt-dialog-headline {
  font-size: 13pt;
  font-weight: bold;
  color: #5c616c;
}

.prompt-dialog-descritption:rtl {
  text-align: right;
}

.prompt-dialog-password-box {
  spacing: 1em;
  padding-bottom: 1em;
}

.prompt-dialog-error-label {
  font-size: 10pt;
  color: #FC4138;
  padding-bottom: 8px;
}

.prompt-dialog-info-label {
  font-size: 10pt;
  padding-bottom: 8px;
  color: rgba(92, 97, 108, 0.6);
}

.prompt-dialog-null-label {
  font-size: 10pt;
  padding-bottom: 8px;
  color: rgba(92, 97, 108, 0.6);
}

.prompt-dialog-pim-box {
  spacing: 1em;
}

.prompt-dialog-grid {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.prompt-dialog-keyfiles-box {
  spacing: 1em;
}

.prompt-dialog-button.button {
  padding: 8px;
}

.hidden {
  color: rgba(0, 0, 0, 0);
}

.polkit-dialog-user-layout {
  text-align: center;
  spacing: 8px;
  margin-bottom: 6px;
}

.polkit-dialog-user-root-label {
  color: #F27835;
}

.polkit-dialog-user-icon {
  border-radius: 100px;
  background-size: contain;
  margin: 6px;
  width: 48px;
  height: 48px;
}

.audio-device-selection-dialog {
  spacing: 30px;
}

.audio-device-selection-dialog .modal-dialog-content-box {
  margin-bottom: 28px;
}

.audio-device-selection-dialog .audio-selection-box {
  spacing: 20px;
}

.audio-selection-content {
  spacing: 20px;
  padding: 24px;
}

.audio-selection-title {
  font-weight: bold;
  text-align: center;
}

.audio-selection-box {
  spacing: 20px;
}

.audio-selection-device {
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 3px;
}

.audio-selection-device:active, .audio-selection-device:hover, .audio-selection-device:focus {
  background-color: #2eb398;
  border-color: #2eb398;
}

.audio-selection-device-box {
  padding: 20px;
  spacing: 20px;
}

.audio-selection-device-icon {
  icon-size: 64px;
}

.access-dialog {
  spacing: 30px;
}

.access-dialog-main-layout {
  padding: 12px 20px 0;
  spacing: 12px;
}

.access-dialog-content {
  max-width: 28em;
  spacing: 20px;
}

.access-dialog-icon {
  min-width: 48px;
  icon-size: 48px;
}

.access-dialog-title {
  font-weight: bold;
}

.access-dialog-subtitle {
  color: #5c616c;
  font-weight: bold;
}

.geolocation-dialog {
  spacing: 30px;
}

.geolocation-dialog-main-layout {
  spacing: 12px;
}

.geolocation-dialog-content {
  spacing: 20px;
}

.geolocation-dialog-icon {
  icon-size: 48px;
}

.geolocation-dialog-title {
  font-weight: bold;
}

.geolocation-dialog-reason {
  color: #5c616c;
  font-weight: bold;
}

/* Extension Dialog */
.extension-dialog .message-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.extension-dialog .message-dialog-title {
  font-weight: normal;
  color: #5c616c;
}

/* Inhibit-Shortcuts Dialog */
.inhibit-shortcuts-dialog {
  spacing: 30px;
}

.network-dialog-secret-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.keyring-dialog-control-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.popup-menu {
  min-width: 15em;
  color: #5c616c;
  border-image: url("assets/menu/menu.svg") 18 18 18 18;
  box-shadow: none;
}

.popup-menu .popup-sub-menu {
  background: none;
  box-shadow: none;
  border-image: url("assets/menu/submenu.svg") 18 18 2 2;
}

.popup-menu .popup-menu-content {
  padding: 1em 0;
}

.popup-menu .popup-menu-item {
  spacing: 12px;
  padding: 6px 0;
}

.popup-menu .popup-menu-item:ltr {
  padding-right: 2em;
  padding-left: 0;
}

.popup-menu .popup-menu-item:rtl {
  padding-right: 0;
  padding-left: 2em;
}

.popup-menu .popup-menu-item:checked {
  font-weight: normal;
  background: none;
  box-shadow: none;
  border-image: url("assets/menu/submenu-open.svg") 18 18 2 2;
}

.popup-menu .popup-menu-item:active, .popup-menu .popup-menu-item.selected {
  color: #ffffff;
  background-color: transparent;
  border-image: url("common-assets/menu/menu-hover.svg") 18 18 2 2;
}

.popup-menu .popup-menu-item:insensitive {
  color: rgba(92, 97, 108, 0.5);
  background: none;
}

.popup-menu .popup-inactive-menu-item {
  color: #5c616c;
}

.popup-menu .popup-inactive-menu-item:insensitive {
  color: rgba(92, 97, 108, 0.55);
}

.popup-menu.panel-menu {
  -boxpointer-gap: 4px;
  margin-bottom: 1.75em;
}

.popup-menu-ornament {
  text-align: right;
  margin-left: 10px;
  width: 16px;
  height: 0;
}

.popup-menu-boxpointer {
  -arrow-border-radius: 2px;
  -arrow-background-color: rgba(0, 0, 0, 0);
  -arrow-border-width: 1px;
  -arrow-border-color: rgba(0, 0, 0, 0);
  -arrow-base: 48px;
  -arrow-rise: 0;
}

.popup-menu-boxpointer StEntry {
  selection-background-color: #ffffff;
  selected-background-color: #ffffff;
  selected-color: #2eb398;
}

.candidate-popup-boxpointer {
  -arrow-border-radius: 2px;
  -arrow-background-color: #282A33;
  -arrow-border-width: 1px;
  -arrow-border-color: rgba(0, 0, 0, 0.4);
  -arrow-base: 48px;
  -arrow-rise: 0;
}

.popup-separator-menu-item {
  margin: 0 0;
  padding: 0 0;
  background: none;
  border: none;
}

.popup-separator-menu-item .popup-separator-menu-item-separator {
  margin: 0 0;
  padding: 0 0;
  background: none;
}

.popup-sub-menu .popup-separator-menu-item .popup-separator-menu-item-separator {
  margin: 0 0;
  padding: 0 0;
  background: none;
}

.rename-folder-popup .rename-folder-popup-item {
  spacing: 6px;
}

.rename-folder-popup .rename-folder-popup-item:ltr, .rename-folder-popup .rename-folder-popup-item:rtl {
  padding: 0, 12px;
}

.background-menu {
  -boxpointer-gap: 4px;
  -arrow-rise: 0px;
}

.system-switch-user-submenu-icon.user-icon {
  icon-size: 20px;
  padding: 0 2px;
}

.system-switch-user-submenu-icon.default-icon {
  icon-size: 16px;
  padding: 0 4px;
}

.system-switch-user-submenu-icon {
  icon-size: 16px;
  padding: 0 4px;
}

#appMenu {
  spinner-image: url("process-working.svg");
  spacing: 4px;
  padding: 0 8px;
}

#appMenu .label-shadow {
  color: transparent;
}

.app-menu,
.app-well-menu {
  max-width: 27.25em;
}

.aggregate-menu {
  min-width: 21em;
}

.aggregate-menu .popup-menu-icon {
  padding: 0 0;
  margin: 0 0;
  -st-icon-style: symbolic;
}

.aggregate-menu .popup-sub-menu .popup-menu-item > :first-child:ltr {
  /* 12px spacing + 2*4px padding */
  padding-left: 24px;
  margin-left: 1.09em;
}

.aggregate-menu .popup-sub-menu .popup-menu-item > :first-child:rtl {
  /* 12px spacing + 2*4px padding */
  padding-right: 24px;
  margin-right: 1.09em;
}


.system-menu-action {
  padding: 13px;
  color: #5c616c;
  border-radius: 32px;
  /* wish we could do 50% */
  border: 1px solid transparent;
  -st-icon-style: symbolic;
}


.system-menu-action:hover,
.system-menu-action:focus {
  transition-duration: 100ms;
  padding: 13px;
  color: #5c616c;
  background-color: transparent;
  border: 1px solid #2eb398;
}


.system-menu-action:active {
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #2eb398;
}


.system-menu-action > StIcon {
  icon-size: 16px;
}

/* Outline for low res icons */
.lowres-icon {
  icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
}

/* Drapshadow for large icons */
.icon-dropshadow {
  icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.4);
}

.osd-window {
  text-align: center;
  font-weight: bold;
  spacing: 1em;
  padding: 20px;
  margin: 32px;
  min-width: 64px;
  min-height: 64px;
  color: white;
  background: none;
  border: none;
  border-radius: 5px;
  border-image: url("common-assets/misc/osd.svg") 18 18 18 18;
  box-shadow: none;
}

.osd-window .osd-monitor-label {
  font-size: 3em;
}

.osd-window .level {
  height: 4px;
  background-color: rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  color: #2eb398;
  -barlevel-height: 4px;
  -barlevel-background-color: rgba(0, 0, 0, 0.15);
  -barlevel-active-background-color: #2eb398;
  -barlevel-overdrive-color: #F04A50;
  -barlevel-overdrive-separator-width: 2px;
  -barlevel-border-width: 0;
}

.osd-window .level-bar {
  background-color: #2eb398;
  border-radius: 3px;
}

.resize-popup {
  color: white;
  background: none;
  border: none;
  border-radius: 5px;
  border-image: url("common-assets/misc/osd.svg") 18 18 18 18;
  box-shadow: none;
  padding: 12px;
}

.switcher-popup {
  padding: 8px;
  spacing: 16px;
}

.switcher-list {
  background: none;
  border: none;
  border-image: url("common-assets/misc/bg.svg") 18 18 18 18;
  border-radius: 3px;
  padding: 20px;
  box-shadow: none;
}

.switcher-list-item-container {
  spacing: 8px;
}

.switcher-list .item-box {
  padding: 8px;
  border-radius: 2px;
  border: 1px solid transparent;
}

.switcher-list .item-box:outlined {
  padding: 8px;
  border: 1px solid #2eb398;
}

.switcher-list .item-box:selected {
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #2eb398;
}

.switcher-list .thumbnail-box {
  padding: 2px;
  spacing: 4px;
}

.switcher-list .thumbnail {
  width: 256px;
}

.switcher-list .separator {
  width: 1px;
  background: rgba(92, 97, 108, 0.33);
}

.switcher-arrow {
  border-color: rgba(0, 0, 0, 0);
  color: #D3DAE3;
}

.switcher-arrow:highlighted {
  color: white;
}

.input-source-switcher-symbol {
  font-size: 34pt;
  width: 96px;
  height: 96px;
}

.cycler-highlight {
  border: 5px solid #2eb398;
}

.workspace-switcher {
  background: transparent;
  border: 0px;
  border-radius: 0px;
  padding: 0px;
  spacing: 8px;
  background: none;
  box-shadow: none;
}

.workspace-switcher-group {
  padding: 12px;
}

.workspace-switcher-container {
  border-image: url("common-assets/misc/bg.svg") 18 18 18 18;
  border-radius: 3px;
  padding: 20px;
  padding-bottom: 24px;
  background: none;
  box-shadow: none;
}

.ws-switcher-active-up, .ws-switcher-active-down {
  height: 30px;
  background-color: #2eb398;
  background-size: 96px;
  border-radius: 2px;
  border: 1px solid #2eb398;
}

.ws-switcher-active-up {
  background-image: url("common-assets/misc/ws-switch-arrow-up.png");
}

.ws-switcher-active-down {
  background-image: url("common-assets/misc/ws-switch-arrow-down.png");
}

.ws-switcher-box {
  height: 96px;
  background-color: rgba(0, 0, 0, 0.33);
  border-color: rgba(0, 0, 0, 0.33);
  border-radius: 2px;
}

.tile-preview {
  background-color: rgba(46, 179, 152, 0.35);
  border: 1px solid #2eb398;
}

.tile-preview-left.on-primary {
  border-radius: 0px 0 0 0;
}

.tile-preview-right.on-primary {
  border-radius: 0 0px 0 0;
}

.tile-preview-left.tile-preview-right.on-primary {
  border-radius: 0px 0px 0 0;
}

#panel {
  font-weight: bold;
  height: 2.1em;
  min-height: 27px;
  background-color: #21232b;
  border: none;
  font-feature-settings: "tnum";
}

#panel.dynamic-top-bar-white-btn {
  border-image: none;
}

#panel.unlock-screen, #panel.login-screen, #panel.lock-screen {
  background-color: transparent;
  border-image: none;
}

#panel #panelLeft, #panel #panelCenter {
  spacing: 8px;
}

#panel .panel-corner {
  -corner_radius: 0;
  -panel-corner-radius: 0;
  -panel-corner-background-color: rgba(0, 0, 0, 0);
  -panel-corner-border-width: 0;
  -panel-corner-border-color: transparent;
}

#panel .panel-corner:active, #panel .panel-corner:overview, #panel .panel-corner:focus {
  -panel-corner-border-color: transparent;
}

#panel .panel-corner.lock-screen, #panel .panel-corner.login-screen, #panel .panel-cornerunlock-screen {
  -corner_radius: 0;
  -panel-corner-radius: 0;
  -panel-corner-background-color: transparent;
  -panel-corner-border-color: transparent;
}

#panel .panel-button {
  -natural-hpadding: 10px;
  -minimum-hpadding: 6px;
  font-weight: bold;
  color: #D3DAE3;
  transition-duration: 100ms;
  text-shadow: none;
  border: none;
}

#panel .panel-button .app-menu-icon {
  width: 0;
  height: 0;
  margin-left: 0px;
  margin-right: 0px;
}

#panel .panel-button .system-status-icon,
#panel .panel-button .app-menu-icon > StIcon,
#panel .panel-button .popup-menu-arrow {
  icon-shadow: none;
}

#panel .panel-button:hover {
  color: #D3DAE3;
  background-color: rgba(211, 218, 227, 0.05);
}

#panel .panel-button:active, #panel .panel-button:overview, #panel .panel-button:focus, #panel .panel-button:checked {
  color: #D3DAE3;
  background-color: rgba(211, 218, 227, 0.1);
  box-shadow: inset 0 -2px 0 #2eb398;
}

#panel .panel-button:active > .system-status-icon, #panel .panel-button:overview > .system-status-icon, #panel .panel-button:focus > .system-status-icon, #panel .panel-button:checked > .system-status-icon {
  icon-shadow: none;
}

#panel .panel-button.clock-display:active .clock, #panel .panel-button.clock-display:overview .clock, #panel .panel-button.clock-display:focus .clock, #panel .panel-button.clock-display:checked .clock {
  background-color: transparent;
  box-shadow: none;
}

#panel .panel-button .system-status-icon {
  icon-size: 16px;
  padding: 0 4px;
}

.unlock-screen #panel .panel-button, .login-screen #panel .panel-button, .lock-screen #panel .panel-button {
  color: #f2f4f7;
}

.unlock-screen #panel .panel-button:focus, .unlock-screen #panel .panel-button:hover, .unlock-screen #panel .panel-button:active, .login-screen #panel .panel-button:focus, .login-screen #panel .panel-button:hover, .login-screen #panel .panel-button:active, .lock-screen #panel .panel-button:focus, .lock-screen #panel .panel-button:hover, .lock-screen #panel .panel-button:active {
  color: #f2f4f7;
}

#panel #panelActivities.panel-button {
  -natural-hpadding: 12px;
}

#panel .panel-status-indicators-box,
#panel .panel-status-menu-box {
  spacing: 2px;
}

#panel .power-status.panel-status-indicators-box {
  spacing: 0;
}

#panel.solid {
  /* transition from transparent to solid */
  transition-duration: 250ms;
  background-gradient-direction: none;
  text-shadow: none;
}

#panel.solid:overview {
  background-color: transparent;
}

#panel.solid .panel-corner {
  -panel-corner-background-color: #21232b;
}

#panel.solid .panel-button {
  color: #D3DAE3;
  text-shadow: none;
}

#panel.solid .panel-button:hover, #panel.solid .panel-button:active, #panel.solid .panel-button:overview, #panel.solid .panel-button:focus, #panel.solid .panel-button:checked {
  text-shadow: none;
}

#panel.solid .system-status-icon,
#panel.solid .app-menu-icon > StIcon,
#panel.solid .popup-menu-arrow {
  icon-shadow: none;
}

#panel .screencast-indicator {
  color: #FC4138;
}

#panel .remote-access-indicator {
  color: #F27835;
}

#panel .popup-menu-arrow {
  width: 0;
}

#panel #panelActivities.panel-button > * {
  background-image: url("common-assets/misc/activities.svg");
  width: 24px;
  height: 24px;
  background-color: transparent !important;
  background-gradient-direction: none !important;
  border: 0 solid transparent !important;
  text-shadow: 0 0 transparent !important;
  transition-duration: 0ms !important;
  box-shadow: none !important;
  color: transparent;
}

#panel #panelActivities.panel-button:active, #panel #panelActivities.panel-button:overview, #panel #panelActivities.panel-button:focus, #panel #panelActivities.panel-button:checked {
  background-color: transparent;
  box-shadow: none;
  border-bottom-width: 1px;
  border-color: transparent;
}

#panel #panelActivities.panel-button:active > *, #panel #panelActivities.panel-button:overview > *, #panel #panelActivities.panel-button:focus > *, #panel #panelActivities.panel-button:checked > * {
  background-image: url("common-assets/misc/activities-active.svg");
}

#calendarArea {
  padding: 0.75em 1.0em;
}

.calendar {
  margin-bottom: 1em;
  box-shadow: none;
  background: none;
  border: none;
}

.calendar,
.datemenu-today-button,
.datemenu-displays-box,
.message-list-sections {
  margin: 0 0.4em;
}

.datemenu-calendar-column {
  spacing: 0.5em;
  border: none;
}

.datemenu-displays-section {
  padding-bottom: 3em;
}

.datemenu-displays-box {
  spacing: 1em;
}

.datemenu-today-button,
.world-clocks-button,
.weather-button,
.message-list-section-title,
.events-section-title {
  border-radius: 3px;
  padding: .4em;
}

.message-list-section-list:ltr {
  padding-left: .4em;
}

.message-list-section-list:rtl {
  padding-right: .4em;
}

.datemenu-today-button,
.world-clocks-button,
.weather-button,
.message-list-section-title,
.events-section-title {
  padding: 7px 10px 7px 10px;
  border: 1px solid rgba(255, 255, 255, 0);
  background: none;
  color: rgba(92, 97, 108, 0.65);
  text-shadow: none;
}

.datemenu-today-button:hover, .datemenu-today-button:focus,
.world-clocks-button:hover,
.world-clocks-button:focus,
.weather-button:hover,
.weather-button:focus,
.message-list-section-title:hover,
.message-list-section-title:focus,
.events-section-title:hover,
.events-section-title:focus {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.03);
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.datemenu-today-button:active,
.world-clocks-button:active,
.weather-button:active,
.message-list-section-title:active,
.events-section-title:active {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #248a76;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.datemenu-today-button .date-label {
  font-size: 1.5em;
  font-weight: 300;
}

.world-clocks-header,
.weather-header,
.message-list-section-title,
.events-section-title {
  color: rgba(92, 97, 108, 0.75);
  font-weight: bold;
}

.world-clocks-grid,
.weather-grid {
  spacing-rows: 0.4em;
  spacing-columns: 0.8em;
}

.world-clocks-city {
  color: rgba(92, 97, 108, 0.6);
  font-weight: bold;
  font-size: 0.9em;
}

.world-clocks-time {
  color: rgba(92, 97, 108, 0.6);
  font-feature-settings: "tnum";
  font-size: 1.2em;
}

.world-clocks-timezone {
  color: rgba(92, 97, 108, 0.75);
  font-feature-settings: "tnum";
  font-size: 0.9em;
}

.weather-box {
  spacing: 0.4em;
}

.weather-header.location {
  font-weight: normal;
  color: rgba(92, 97, 108, 0.55);
}

.weather-forecast-icon {
  icon-size: 2.18em;
  color: rgba(92, 97, 108, 0.65);
}

.weather-forecast-time {
  color: rgba(92, 97, 108, 0.6);
  font-size: 0.8em;
  font-feature-settings: "tnum";
  font-weight: normal;
  padding-top: 0.2em;
  padding-bottom: 0.4em;
}

.weather-forecast-temp {
  font-weight: bold;
  color: rgba(92, 97, 108, 0.65);
  text-shadow: none;
}

.world-clocks-button:active *,
.weather-button:active * {
  color: #ffffff;
}

.calendar-month-label {
  color: #5c616c;
  font-weight: bold;
  padding: 8px 0;
}

.pager-button {
  color: transparent;
  background-color: transparent;
  width: 32px;
  border-radius: 2px;
}

.pager-button:focus, .pager-button:hover, .pager-button:active {
  background-color: transparent;
}

.calendar-change-month-back {
  background-image: url("assets/misc/calendar-arrow-left.svg");
}

.calendar-change-month-back:focus, .calendar-change-month-back:hover {
  background-image: url("assets/misc/calendar-arrow-left-hover.svg");
}

.calendar-change-month-back:active {
  background-image: url("assets/misc/calendar-arrow-left.svg");
}

.calendar-change-month-back:rtl {
  background-image: url("assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-back:rtl:focus, .calendar-change-month-back:rtl:hover {
  background-image: url("assets/misc/calendar-arrow-right-hover.svg");
}

.calendar-change-month-back:rtl:active {
  background-image: url("assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-forward {
  background-image: url("assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-forward:focus, .calendar-change-month-forward:hover {
  background-image: url("assets/misc/calendar-arrow-right-hover.svg");
}

.calendar-change-month-forward:active {
  background-image: url("assets/misc/calendar-arrow-right.svg");
}

.calendar-change-month-forward:rtl {
  background-image: url("assets/misc/calendar-arrow-left.svg");
}

.calendar-change-month-forward:rtl:focus, .calendar-change-month-forward:rtl:hover {
  background-image: url("assets/misc/calendar-arrow-left-hover.svg");
}

.calendar-change-month-forward:rtl:active {
  background-image: url("assets/misc/calendar-arrow-left.svg");
}

.calendar-day-base {
  font-size: 90%;
  text-align: center;
  width: 2.4em;
  height: 2.4em;
  padding: 0.1em;
  margin: 2px;
  border-radius: 100px;
  font-feature-settings: "tnum";
  color: rgba(92, 97, 108, 0.75);
  background-color: transparent;
}

.calendar-day-base:hover, .calendar-day-base:focus {
  background-color: #eaeef2;
}

.calendar-day-base:active, .calendar-day-base:checked, .calendar-day-base:selected {
  color: #5c616c;
  background-color: dif(true, #dae2e9, white);
  border: none;
}

.calendar-day-base.calendar-day-heading {
  color: rgba(92, 97, 108, 0.75);
  margin-top: 1em;
  font-size: 80%;
}

.calendar-day {
  border-width: 0;
  color: rgba(92, 97, 108, 0.8);
  background-color: transparent;
}

.calendar-day:active, .calendar-day:checked, .calendar-day:selected {
  color: #5c616c;
  background-color: dif(true, #dae2e9, white);
  border: none;
}

.calendar-day-top {
  border-top-width: 0;
}

.calendar-day-left {
  border-left-width: 0;
}

.calendar-nonwork-day {
  color: #5c616c;
  font-weight: bold;
}

.calendar-today,
.calendar-today:active,
.calendar-today:selected,
.calendar-today:focus,
.calendar-today:hover {
  font-weight: bold;
  color: #ffffff;
  background-color: #2eb398;
  border-width: 0;
}

.calendar-day-with-events {
  font-weight: bold;
  background-image: url("common-assets/misc/calendar-today.svg");
}

.calendar-today.calendar-day-with-events {
  color: #ffffff;
}

.calendar-other-month-day {
  color: rgba(92, 97, 108, 0.3);
  opacity: 1;
}

.calendar-week-number {
  font-size: 70%;
  font-weight: bold;
  width: 2.3em;
  height: 1.8em;
  border-radius: 2px;
  padding: 0.5em 0 0;
  margin: 6px;
  background-color: rgba(92, 97, 108, 0.3);
  color: #fafbfc;
}

.message-list {
  width: 31.5em;
  padding: 0 12px;
}

.message-list-sections {
  spacing: 1.5em;
}

.message-list-section, .message-list-section-list {
  spacing: 0.7em;
}

.message-list-section-list-title-box {
  spacing: 0.4em;
}

.message-list-placeholder {
  spacing: 12px;
}

.message-list-placeholder StIcon {
  width: 0;
  height: 0;
}

.message-list-placeholder StLabel {
  color: rgba(92, 97, 108, 0.55);
}

.message-list-clear-button.button {
  margin: 1.5em 1.5em 0;
  padding: 4px 12px;
}

.message-list-clear-button.button:hover, .message-list-clear-button.button:focus {
  background-color: #eaeef2;
}

.message-list-clear-button.button:active {
  background-color: #2eb398;
}

.message-list-controls {
  margin: 8px 16px 0;
  padding: 4px;
  spacing: 16px;
}

.message-list-section-close > StIcon {
  icon-size: 18px;
  border-radius: 0px;
  color: transparent;
  background-color: transparent;
  background-image: url("assets/misc/message-close.svg");
}

.message-list-section-close:hover > StIcon {
  color: transparent;
  background-color: transparent;
  background-image: url("assets/misc/message-close-hover.svg");
}

.message-list-section-close:active > StIcon {
  color: transparent;
  background-color: transparent;
  background-image: url("assets/misc/message-close-active.svg");
}

.message {
  padding: 4px;
  color: #5c616c;
  border-image: url("assets/misc/message.svg") 18 18 18 18;
  background: none;
  box-shadow: none;
  text-shadow: none;
}

.message:hover, .message:focus {
  color: #5c616c;
  border-image: url("assets/misc/message-hover.svg") 18 18 18 18;
}

.message:active {
  color: #ffffff;
  border-image: url("assets/misc/message-active.svg") 18 18 18 18;
}

.message-icon-bin {
  padding: 8px 0 8px 8px;
}

.message-icon-bin:rtl {
  padding: 8px 8px 8px 0;
}

.message-icon-bin > StIcon {
  icon-size: 32px;
  -st-icon-style: symbolic;
  color: inherit;
}

.message-icon-bin > .fallback-app-icon {
  width: 16px;
  height: 16px;
}

.message-secondary-bin, .message-secondary-bin > .event-time {
  color: rgba(92, 97, 108, 0.6);
  font-size: 0.9em;
}

.message-secondary-bin:ltr, .message-secondary-bin > .event-time:ltr {
  padding-left: 8px;
}

.message-secondary-bin:rtl, .message-secondary-bin > .event-time:rtl {
  padding-right: 8px;
}

.message:active .message-secondary-bin, .message:active .message-secondary-bin > .event-time {
  color: rgba(255, 255, 255, 0.6);
}

.message-secondary-bin > StIcon {
  icon-size: 16px;
}

.message-title {
  color: #5c616c;
  text-shadow: none;
  font-weight: bold;
  font-size: 1em;
  padding: 2px 0 2px 0;
}

.message-content {
  color: rgba(92, 97, 108, 0.75);
  padding: 8px;
  font-size: 1em;
  /* FIXME: how do you do this in sass? */
}

.message-content * > StIcon {
  icon-size: 16px;
  border-radius: 100px;
  padding: 2px;
  color: rgba(92, 97, 108, 0.75);
}

.message-content *:hover > StIcon,
.message-content *:focus > StIcon {
  color: #5c616c;
  background-color: #eaeef2;
}

.message-content *:active > StIcon {
  color: #5c616c;
  background-color: dif(true, #dae2e9, white);
}

.message .message-close-button {
  color: rgba(92, 97, 108, 0.75);
  padding: 2px;
  height: 16px;
  width: 16px;
  border-radius: 100px;
}

.message .message-close-button:hover, .message .message-close-button:active {
  color: #5c616c;
}

.message .message-close-button:hover, .message .message-close-button:focus {
  background-color: #eaeef2;
}

.message .message-close-button:active {
  background-color: dif(true, #dae2e9, white);
}

.message .message-body {
  color: rgba(92, 97, 108, 0.6);
}

.url-highlighter {
  link-color: #248a76;
}

.message-media-control {
  margin: 16px 4px;
  padding: 8px;
  border-radius: 100px;
  color: #5c616c;
}

.message-media-control:last-child:ltr {
  margin-right: 16px;
  padding-right: 8px;
}

.message-media-control:last-child:rtl {
  margin-left: 16px;
  padding-left: 8px;
}

.message-media-control:hover {
  color: #5c616c;
  background-color: #eaeef2;
}

.message-media-control:active {
  color: #2eb398;
  background-color: dif(true, #dae2e9, white);
}

.message-media-control:insensitive {
  color: rgba(92, 97, 108, 0.55);
}

.message:active .message-close-button,
.message:active .message-title,
.message:active .message-content,
.message:active .message-body,
.message:active .message-media-control {
  color: #ffffff;
}

.media-message-cover-icon {
  icon-size: 32px !important;
  margin: 8px 0px 8px 4px !important;
}

.media-message-cover-icon:rtl {
  margin: 8px 4px 8px 0px !important;
}

.media-message-cover-icon.fallback {
  color: rgba(92, 97, 108, 0.55);
  background-color: #fafbfc;
  border-radius: 2px;
  icon-size: 16px;
  padding: 8px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.ripple-box {
  width: 52px;
  height: 52px;
  background-image: url("common-assets/misc/corner-ripple-ltr.svg");
  background-size: contain;
}

.ripple-box:rtl {
  background-image: url("common-assets/misc/corner-ripple-rtl.svg");
}

.popup-menu-arrow {
  width: 16px;
  height: 16px;
}

.popup-menu-icon {
  icon-size: 16px;
}

.window-close {
  background-image: url("common-assets/misc/close.svg");
  background-size: 26px;
  height: 26px;
  width: 26px;
  -shell-close-overlap: 10px;
  border-radius: 100px;
  border: 0 none transparent;
  background-color: transparent;
  color: transparent;
  box-shadow: none;
}

.window-close StIcon {
  icon-size: 26px;
}

.window-close:hover {
  background-image: url("common-assets/misc/close-hover.svg");
  background-size: 26px;
  height: 26px;
  width: 26px;
}

.window-close:active {
  background-image: url("common-assets/misc/close-active.svg");
  background-size: 26px;
  height: 26px;
  width: 26px;
}

.pie-timer {
  width: 60px;
  height: 60px;
  -pie-border-width: 3px;
  -pie-border-color: #2eb398;
  -pie-background-color: rgba(191, 238, 229, 0.3);
}

.nm-dialog {
  max-height: 500px;
  min-height: 450px;
  min-width: 470px;
}

.nm-dialog-content {
  spacing: 20px;
  padding: 10px;
}

.nm-dialog-header-hbox {
  spacing: 10px;
}

.nm-dialog-airplane-box {
  spacing: 12px;
}

.nm-dialog-airplane-headline {
  font-size: 1.1em;
  font-weight: bold;
  text-align: center;
}

.nm-dialog-airplane-text {
  color: #5c616c;
}

.nm-dialog-header-icon {
  icon-size: 32px;
}

.nm-dialog-scroll-view {
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px;
  background-color: #ffffff;
}

.nm-dialog-header {
  font-weight: bold;
  font-size: 1.2em;
}

.nm-dialog-item {
  font-size: 1em;
  border-bottom: 0px solid;
  padding: 12px;
  spacing: 0px;
}

.nm-dialog-item:selected {
  background-color: #2eb398;
  color: #ffffff;
}

.nm-dialog-icons {
  spacing: .5em;
}

.nm-dialog-icon {
  icon-size: 16px;
}

.no-networks-label {
  color: rgba(92, 97, 108, 0.55);
}

.no-networks-box {
  spacing: 12px;
}

#overview {
  spacing: 24px;
}

#overview .icon-grid {
  spacing: 30px;
  -shell-grid-horizontal-item-size: 136px;
  -shell-grid-vertical-item-size: 136px;
}

#overview .icon-grid .overview-icon {
  icon-size: 96px;
}

#overview .app-view-controls {
  padding-bottom: 32px;
}

#overview .app-view-control {
  padding: 6px 48px;
  margin: 0;
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #21232a;
  background-color: rgba(40, 42, 51, 0.5);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
  border-color: rgba(0, 0, 0, 0.65);
}

#overview .app-view-control:hover {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #1d1e25;
  background-color: rgba(56, 58, 71, 0.65);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
  border-color: rgba(0, 0, 0, 0.65);
}

#overview .app-view-control:checked {
  color: #ffffff;
  background-color: #2eb398;
}

#overview .app-view-control:first-child:ltr, #overview .app-view-control:last-child:rtl {
  border-radius: 2px 0 0 2px;
  border-right: none;
  margin: 0;
}

#overview .app-view-control:last-child:ltr, #overview .app-view-control:first-child:rtl {
  border-radius: 0 2px 2px 0;
  border-left: none;
  margin: 0;
}

.app-view-control:first-child:ltr, .app-view-control:last-child:rtl {
  border-radius: 2px 0 0 2px;
  border-right-width: 0;
}

.app-view-control:last-child:ltr, .app-view-control:first-child:rtl {
  border-radius: 0 2px 2px 0;
  border-left-width: 1px;
}

.overview-controls {
  padding-bottom: 32px;
}

.window-picker {
  -horizontal-spacing: 32px;
  -vertical-spacing: 32px;
  padding-left: 32px;
  padding-right: 32px;
  padding-bottom: 48px;
}

.window-picker.external-monitor {
  padding: 32px;
}

.window-clone-border {
  border: 3px solid rgba(46, 179, 152, 0.8);
  border-radius: 4px;
  box-shadow: inset 0px 0px 0px 1px rgba(46, 179, 152, 0);
}

.window-caption, .window-caption:hover {
  spacing: 25px;
  color: white;
  background-color: rgba(0, 0, 0, 0.7);
  border-radius: 2px;
  padding: 4px 12px;
  -shell-caption-spacing: 12px;
  border: none;
  font-weight: normal;
  font-size: 10pt;
}

.search-entry, .app-folder-dialog .folder-name-container .folder-name-entry {
  width: 320px;
  padding: 7px 9px;
  border-radius: 100px;
  border: 1px solid rgba(0, 0, 0, 0.25);
  background-color: rgba(255, 255, 255, 0.9);
  color: #5c616c;
  caret-color: #5c616c;
}

.search-entry StLabel.hint-text, .app-folder-dialog .folder-name-container .folder-name-entry StLabel.hint-text {
  margin-left: 2px;
  color: rgba(92, 97, 108, 0.7);
}

.search-entry:focus, .app-folder-dialog .folder-name-container .folder-name-entry:focus {
  padding: 7px 9px;
}

.search-entry:focus StLabel.hint-text, .app-folder-dialog .folder-name-container .folder-name-entry:focus StLabel.hint-text {
  color: rgba(255, 255, 255, 0.7);
}

.search-entry .search-entry-icon, .app-folder-dialog .folder-name-container .folder-name-entry .search-entry-icon {
  icon-size: 16px;
  padding: 0 4px;
  color: #5c616c;
}

.search-entry:hover, .app-folder-dialog .folder-name-container .folder-name-entry:hover, .search-entry:focus, .app-folder-dialog .folder-name-container .folder-name-entry:focus {
  color: #ffffff;
  caret-color: #ffffff;
  background-color: #2eb398;
  selection-background-color: rgba(255, 255, 255, 0.25);
  selected-color: #ffffff;
}

.search-entry:hover .search-entry-icon, .app-folder-dialog .folder-name-container .folder-name-entry:hover .search-entry-icon, .search-entry:focus .search-entry-icon, .app-folder-dialog .folder-name-container .folder-name-entry:focus .search-entry-icon {
  color: #ffffff;
}

.search-entry:insensitive, .app-folder-dialog .folder-name-container .folder-name-entry:insensitive {
  color: rgba(92, 97, 108, 0.55);
  background-color: rgba(255, 255, 255, 0.45);
}

#searchResultsContent {
  max-width: 1000px;
  padding-left: 20px;
  padding-right: 20px;
  spacing: 16px;
}

.search-section {
  spacing: 16px;
}

.search-section-content {
  spacing: 32px;
  background: none;
  box-shadow: none;
  border: none;
}

.list-search-results {
  spacing: 3px;
}

.search-section-separator {
  background-color: rgba(255, 255, 255, 0.12);
  -margin-horizontal: 1.5em;
  height: 1px;
}

.list-search-result-content {
  spacing: 12px;
  padding: 12px;
}

.list-search-result-title {
  font-size: 1.5em;
  color: white;
}

.list-search-result-description {
  color: #cccccc;
}

.list-search-provider-details {
  width: 150px;
  color: #f2f2f2;
  margin-top: 0.24em;
}

.list-search-provider-content {
  spacing: 20px;
}

.search-provider-icon {
  padding: 15px;
}

.search-provider-icon-more {
  width: 16px;
  height: 16px;
  background-image: url("common-assets/misc/more-results.svg");
}

#dash {
  font-size: 1em;
  color: #D3DAE3;
  background-color: #32343D;
  border-color: rgba(0, 0, 0, 0.4);
  padding: 4px 0;
  border-radius: 0 3px 3px 0;
}

#dash:rtl {
  border-radius: 3px 0 0 3px;
}

.right #dash, #dash:rtl {
  padding: 4px 0;
}

.top #dash, .bottom #dash {
  padding: 0;
}

#dash .placeholder {
  background-image: url("common-assets/dash/dash-placeholder.svg");
  background-size: contain;
  height: 24px;
}

#dash .empty-dash-drop-target {
  width: 24px;
  height: 24px;
}

.dash-item-container > StWidget, .dash-item-container > StWidget:rtl, .right .dash-item-container > StWidget {
  padding: 4px 8px;
}

.top .dash-item-container > StWidget, .bottom .dash-item-container > StWidget {
  padding: 6px;
}

.dash-label {
  border-radius: 3px;
  padding: 4px 12px;
  color: white;
  background-color: rgba(40, 42, 51, 0.7);
  text-align: center;
  border: none;
  -x-offset: 3px;
}

.bottom .dash-label, .top .dash-label {
  -y-offset: 3px;
  -x-offset: 0;
}

#dash .app-well-app:hover .overview-icon, .right #dash .app-well-app:hover .overview-icon, .bottom #dash .app-well-app:hover .overview-icon, .top #dash .app-well-app:hover .overview-icon {
  background-color: rgba(46, 179, 152, 0.5);
  border: 1px solid #2eb398;
}

#dash .app-well-app:active .overview-icon, .right #dash .app-well-app:active .overview-icon, .bottom #dash .app-well-app:active .overview-icon, .top #dash .app-well-app:active .overview-icon {
  box-shadow: none;
  background-color: #2eb398;
  border: 1px solid #248a76;
}

#dash .app-well-app:checked .overview-icon, .right #dash .app-well-app:checked .overview-icon, .bottom #dash .app-well-app:checked .overview-icon, .top #dash .app-well-app:checked .overview-icon {
  box-shadow: none;
  background-color: rgba(46, 179, 152, 0.5);
  border: 1px solid rgba(46, 179, 152, 0.5);
}

#dash .app-well-app:checked:hover .overview-icon, .right #dash .app-well-app:checked:hover .overview-icon, .bottom #dash .app-well-app:checked:hover .overview-icon, .top #dash .app-well-app:checked:hover .overview-icon, #dash .app-well-app:active:hover .overview-icon, .right #dash .app-well-app:active:hover .overview-icon, .bottom #dash .app-well-app:active:hover .overview-icon, .top #dash .app-well-app:active:hover .overview-icon {
  background-color: rgba(46, 179, 152, 0.75);
  border: 1px solid #2eb398;
}

#dash .app-well-app-running-dot {
  width: 11px;
  height: 2px;
  margin-bottom: 2px;
  background-color: #2eb398;
}

.show-apps .show-apps-icon {
  color: #ffffff;
}

.show-apps:hover .show-apps-icon, .show-apps:focus .show-apps-icon {
  color: #ffffff;
}

.show-apps .overview-icon {
  background-color: transparent;
  border-radius: 2px;
  color: rgba(82, 93, 118, 0.8);
}

.show-apps:hover .overview-icon {
  background-color: rgba(255, 255, 255, 0.1);
}

.show-apps:active .overview-icon, .show-apps:checked .overview-icon {
  color: #ffffff;
  background-color: #2eb398;
  box-shadow: none;
  transition-duration: 0ms;
}

.search-provider-icon:active, .search-provider-icon:checked,
.list-search-result:active,
.list-search-result:checked {
  background-color: rgba(18, 18, 22, 0.9);
}

.search-provider-icon:focus, .search-provider-icon:selected, .search-provider-icon:hover,
.list-search-result:focus,
.list-search-result:selected,
.list-search-result:hover {
  background-color: rgba(211, 218, 227, 0.3);
  transition-duration: 200ms;
}

.app-well-app:active .overview-icon, .app-well-app:checked .overview-icon,
.app-well-app.app-folder:active .overview-icon,
.app-well-app.app-folder:checked .overview-icon,
.grid-search-result:active .overview-icon,
.grid-search-result:checked .overview-icon {
  background-color: rgba(18, 18, 22, 0.9);
  box-shadow: none;
}

.app-well-app:hover .overview-icon, .app-well-app:focus .overview-icon, .app-well-app:selected .overview-icon,
.app-well-app.app-folder:hover .overview-icon,
.app-well-app.app-folder:focus .overview-icon,
.app-well-app.app-folder:selected .overview-icon,
.grid-search-result:hover .overview-icon,
.grid-search-result:focus .overview-icon,
.grid-search-result:selected .overview-icon {
  background-color: rgba(211, 218, 227, 0.3);
  transition-duration: 0ms;
  border: 1px solid rgba(211, 218, 227, 0.1);
  background-image: none;
}

.search-provider-icon,
.list-search-result, .app-well-app .overview-icon,
.app-well-app.app-folder .overview-icon,
.grid-search-result .overview-icon {
  color: white;
  border-radius: 2px;
  padding: 6px;
  border: 1px solid transparent;
  transition-duration: 0ms;
  text-align: center;
}

.app-well-app.app-folder > .overview-icon {
  background-color: rgba(50, 52, 61, 0.75);
  border: rgba(0, 0, 0, 0.15);
}

.app-well-app.app-folder:hover > .overview-icon {
  background-color: rgba(57, 59, 69, 0.65);
  border: 1px solid rgba(50, 52, 61, 0.95);
}

.app-well-app.app-folder:active > .overview-icon, .app-well-app.app-folder:checked > .overview-icon {
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #33c7a9;
  box-shadow: none;
}

.app-well-app.app-folder:focus > .overview-icon {
  background-color: #2eb398;
}

.app-folder-popup {
  -arrow-border-radius: 2px;
  -arrow-background-color: rgba(32, 33, 39, 0.65);
  -arrow-border-color: rgba(0, 0, 0, 0.15);
  -arrow-border-width: 1px;
  -arrow-base: 5;
  -arrow-rise: 5;
}

.app-folder-popup-bin {
  padding: 5px;
}

.app-folder-icon {
  padding: 5px;
  spacing-rows: 5px;
  spacing-columns: 5px;
}

.page-indicator {
  padding: 15px 20px;
}

.page-indicator .page-indicator-icon {
  width: 18px;
  height: 18px;
  margin: 0;
  padding: 0;
  color: transparent;
  background-color: transparent;
  border: none;
  box-shadow: none;
  background-image: url(common-assets/misc/page-indicator-inactive.svg);
}

.page-indicator:hover .page-indicator-icon {
  background-image: url(common-assets/misc/page-indicator-hover.svg);
}

.page-indicator:active .page-indicator-icon {
  margin: 0;
  padding: 0;
  color: transparent;
  background-color: transparent;
  border: none;
  box-shadow: none;
  background-image: url(common-assets/misc/page-indicator-active.svg);
}

.page-indicator:checked .page-indicator-icon, .page-indicator:checked:active {
  background-image: url(common-assets/misc/page-indicator-checked.svg);
}

.app-well-app > .overview-icon.overview-icon-with-label,
.grid-search-result .overview-icon.overview-icon-with-label {
  padding: 10px 8px 5px 8px;
  spacing: 4px;
}

.app-folder-dialog {
  border-radius: 5px;
  border: none;
  spacing: 12px;
  background-color: rgba(18, 18, 22, 0.9);
}

.app-folder-dialog .folder-name-container {
  padding: 24px 36px 0;
  spacing: 12px;
  /* FIXME: this is to keep the label in sync with the entry */
}

.app-folder-dialog .folder-name-container .folder-name-label, .app-folder-dialog .folder-name-container .folder-name-entry {
  font-size: 18pt;
  font-weight: bold;
}

.app-folder-dialog .folder-name-container .folder-name-label {
  padding: 5px 7px;
  color: #ffffff;
}

.app-folder-dialog .folder-name-container .edit-folder-button {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #21232a;
  background-color: rgba(40, 42, 51, 0.5);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
  padding: 0;
  width: 36px;
  height: 36px;
  border-radius: 5px;
}

.app-folder-dialog .folder-name-container .edit-folder-button > StIcon {
  icon-size: 16px;
}

.app-folder-dialog .folder-name-container .edit-folder-button:hover {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #1d1e25;
  background-color: rgba(56, 58, 71, 0.65);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
}

.app-folder-dialog .folder-name-container .edit-folder-button:active, .app-folder-dialog .folder-name-container .edit-folder-button:checked {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.35);
  background-color: #2eb398;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.app-folder-dialog StButton#vhandle, .app-folder-dialog StButton#vhandle:hover, .app-folder-dialog StButton#vhandle:active {
  background-color: transparent;
}

.app-folder-dialog-container {
  padding: 12px;
  width: 800px;
  height: 600px;
}

.app-folder-icon {
  padding: 6px;
  spacing-rows: 6px;
  spacing-columns: 6px;
}

.workspace-thumbnails, .workspace-thumbnails:rtl,
.workspace-thumbnails-left,
.workspace-thumbnails-left:rtl {
  visible-width: 40px;
  spacing: 11px;
  padding: 12px;
}

.workspace-thumbnails,
.workspace-thumbnails-left:rtl {
  padding-right: 7px;
  border-image: url("common-assets/dash/dash-right.svg") 18 18 18 18;
  background: none;
  box-shadow: none;
}

.workspace-thumbnails:rtl,
.workspace-thumbnails-left {
  padding-left: 7px;
  border-image: url("common-assets/dash/dash-left.svg") 18 18 18 18;
  background: none;
  box-shadow: none;
}

.workspace-thumbnail-indicator {
  border: 4px solid rgba(46, 179, 152, 0.8);
  border-radius: 1px;
  padding: 1px;
}

.search-display > StBoxLayout,
.all-apps,
.frequent-apps > StBoxLayout {
  padding: 0px 88px 10px 88px;
}

.search-statustext, .no-frequent-applications-label {
  font-size: 2em;
  font-weight: bold;
  color: #5c616c;
}

.url-highlighter {
  link-color: #248a76;
}

.notification-banner,
.notification-banner:hover,
.notification-banner:focus {
  font-size: 1em;
  width: 34em;
  margin: 5px;
  padding: 10px;
  color: #5c616c;
  background-color: transparent;
  border: 1px solid transparent;
  border-image: url("assets/menu/menu.svg") 18 18 18 18;
  box-shadow: none;
}

.notification-banner .notification-icon,
.notification-banner:hover .notification-icon,
.notification-banner:focus .notification-icon {
  padding: 5px;
}

.notification-banner .notification-content,
.notification-banner:hover .notification-content,
.notification-banner:focus .notification-content {
  padding: 5px;
  spacing: 5px;
}

.notification-banner .secondary-icon,
.notification-banner:hover .secondary-icon,
.notification-banner:focus .secondary-icon {
  icon-size: 1.09em;
}

.notification-banner .notification-actions,
.notification-banner:hover .notification-actions,
.notification-banner:focus .notification-actions {
  background-color: transparent;
  padding: 6px;
  spacing: 3px;
  border-color: rgba(0, 0, 0, 0.15);
}

.notification-banner .notification-button,
.notification-banner:hover .notification-button,
.notification-banner:focus .notification-button {
  padding: 2px 4px;
}

.notification-banner .notification-button:first-child, .notification-banner .notification-button:last-child,
.notification-banner:hover .notification-button:first-child,
.notification-banner:hover .notification-button:last-child,
.notification-banner:focus .notification-button:first-child,
.notification-banner:focus .notification-button:last-child {
  border-radius: 2px;
}

.summary-source-counter {
  font-size: 10pt;
  font-weight: bold;
  height: 1.6em;
  width: 1.6em;
  -shell-counter-overlap-x: 3px;
  -shell-counter-overlap-y: 3px;
  background-color: #2eb398;
  color: #ffffff;
  border: 2px solid #5c616c;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.5);
  border-radius: 0.9em;
}

.secondary-icon {
  icon-size: 1.09em;
}

.chat-body {
  spacing: 5px;
}

.chat-response {
  margin: 5px;
}

.chat-log-message {
  color: #5c616c;
}

.chat-new-group {
  padding-top: 1em;
}

.chat-received {
  padding-left: 4px;
}

.chat-received:rtl {
  padding-left: 0px;
  padding-right: 4px;
}

.chat-sent {
  padding-left: 18pt;
  color: #2eb398;
}

.chat-sent:rtl {
  padding-left: 0;
  padding-right: 18pt;
}

.chat-meta-message {
  padding-left: 4px;
  font-size: 9pt;
  font-weight: bold;
  color: rgba(92, 97, 108, 0.6);
}

.chat-meta-message:rtl {
  padding-left: 0;
  padding-right: 4px;
}

.subscription-message {
  font-style: italic;
}

.hotplug-transient-box {
  spacing: 6px;
  padding: 2px 72px 2px 12px;
}

.hotplug-notification-item {
  padding: 2px 10px;
}

.hotplug-notification-item:focus {
  padding: 2px 10px;
}

.hotplug-notification-item-icon {
  icon-size: 24px;
  padding: 2px 5px;
}

.hotplug-resident-box {
  spacing: 8px;
}

.hotplug-resident-mount {
  spacing: 8px;
  border-radius: 4px;
}

.hotplug-resident-mount:hover {
  background-color: rgba(250, 251, 252, 0.3);
}

.hotplug-resident-mount-label {
  color: inherit;
  padding-left: 6px;
}

.hotplug-resident-mount-icon {
  icon-size: 24px;
  padding-left: 6px;
}

.hotplug-resident-eject-icon {
  icon-size: 16px;
}

.hotplug-resident-eject-button {
  padding: 7px;
  border-radius: 5px;
  color: pink;
}

.legacy-tray {
  background-color: #21232b;
}

.legacy-tray:ltr {
  border-radius: 0 2px 0 0;
  border-left-width: 0;
}

.legacy-tray:rtl {
  border-radius: 2px 0 0 0;
  border-right-width: 0;
}

.legacy-tray-handle,
.legacy-tray-icon {
  padding: 6px;
}

.legacy-tray-handle StIcon,
.legacy-tray-icon StIcon {
  icon-size: 24px;
}

.legacy-tray-handle:hover, .legacy-tray-handle:focus,
.legacy-tray-icon:hover,
.legacy-tray-icon:focus {
  background-color: rgba(92, 97, 108, 0.1);
}

.legacy-tray-icon-box {
  spacing: 12px;
}

.legacy-tray-icon-box:ltr {
  padding-left: 12px;
}

.legacy-tray-icon-box:rtl {
  padding-right: 12px;
}

.legacy-tray-icon-box StButton {
  width: 24px;
  height: 24px;
}

.masterslider.smaller .masterlabel,
.masterslider.smaller .slider {
  min-width: 155px;
}

.magnifier-zoom-region {
  border: 2px solid #2eb398;
}

.magnifier-zoom-region.full-screen {
  border-width: 0;
}

/* On-screen Keyboard */
.word-suggestions {
  font-size: 14pt;
  spacing: 12px;
  min-height: 20pt;
}

#keyboard {
  background-color: #282A33;
  border-width: 0;
  border-top-width: 1px;
  border-color: rgba(0, 0, 0, 0.2);
}

.keyboard-layout {
  spacing: 10px;
  padding: 10px;
}

.keyboard-row {
  spacing: 15px;
}

.key-container {
  padding: 4px;
  spacing: 4px;
}

.keyboard-key {
  min-height: 2em;
  min-width: 2em;
  font-size: 14pt;
  font-weight: bold;
  border-radius: 3px;
  box-shadow: none;
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #21232a;
  background-color: rgba(40, 42, 51, 0.5);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
}

.keyboard-key:hover {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #1d1e25;
  background-color: rgba(56, 58, 71, 0.65);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
}

.keyboard-key:active, .keyboard-key:checked {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.35);
  background-color: #2eb398;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.keyboard-key:grayed {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: rgba(82, 93, 118, 0.5);
  border: 1px solid rgba(0, 0, 0, 0.15);
  background-color: rgba(62, 66, 80, 0.35);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
}

.keyboard-subkeys {
  color: #D3DAE3;
  padding: 5px;
  -arrow-border-radius: 2px;
  -arrow-background-color: #282A33;
  -arrow-border-width: 1px;
  -arrow-border-color: rgba(0, 0, 0, 0.4);
  -arrow-base: 20px;
  -arrow-rise: 10px;
  -boxpointer-gap: 5px;
}

.emoji-page .keyboard-key {
  background-color: transparent;
  border: none;
}

.emoji-panel .keyboard-key:latched {
  border-color: #33c7a9;
  background-color: #2eb398;
}

.candidate-popup-content {
  padding: 0.5em;
  spacing: 0.3em;
  color: #D3DAE3;
  font-size: 1.15em;
}

.candidate-index {
  padding: 0 0.5em 0 0;
  color: #f2f4f7;
}

.candidate-box {
  padding: 0.3em 0.5em 0.3em 0.5em;
  border-radius: 2px;
  color: #D3DAE3;
}

.candidate-box:selected, .candidate-box:hover {
  background-color: #2eb398;
  color: #ffffff;
}

.candidate-page-button-box {
  height: 2em;
}

.vertical .candidate-page-button-box {
  padding-top: 0.5em;
}

.horizontal .candidate-page-button-box {
  padding-left: 0.5em;
}

.candidate-page-button {
  padding: 4px;
  border: none;
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #21232a;
  background-color: rgba(40, 42, 51, 0.5);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
}

.candidate-page-button:hover {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #D3DAE3;
  border: 1px solid #1d1e25;
  background-color: rgba(56, 58, 71, 0.65);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.05);
}

.candidate-page-button:active, .candidate-page-button:checked {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.35);
  background-color: #2eb398;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.candidate-page-button:insensitive {
  background-color: transparent;
  box-shadow: none;
}

.candidate-page-button-previous {
  border-radius: 2px 0px 0px 2px;
}

.candidate-page-button-next {
  border-radius: 0px 2px 2px 0px;
}

.candidate-page-button-icon {
  icon-size: 1em;
}

.user-icon,
.framed-user-icon {
  background-size: contain;
  border: 0px solid transparent;
  color: #5c616c;
  border-radius: 100px;
}

.user-icon:hover,
.framed-user-icon:hover {
  border-color: transparent;
  color: #aaaeb7;
}

.login-dialog-banner-view {
  padding-top: 24px;
  max-width: 23em;
}

.login-dialog {
  border: none;
  background-color: transparent;
}

.login-dialog .modal-dialog-button-box {
  spacing: 3px;
}

.login-dialog .modal-dialog-button {
  padding: 3px 18px;
}

.login-dialog .modal-dialog-button:default {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: white;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.login-dialog .modal-dialog-button:default:hover, .login-dialog .modal-dialog-button:default:focus {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.03);
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.login-dialog .modal-dialog-button:default:active {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #248a76;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.login-dialog .modal-dialog-button:default:insensitive {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: rgba(92, 97, 108, 0.55);
  border: 1px solid rgba(0, 0, 0, 0);
  background-color: rgba(255, 255, 255, 0.55);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.login-dialog .modal-dialog-button.button.cancel-button {
  padding-left: 0;
  padding-right: 0;
  max-height: 2em;
  height: 2em;
  width: 2em;
}

.login-dialog .modal-dialog-button.button.cancel-button StIcon {
  icon-size: 1.5em;
}

.login-dialog StPasswordEntry {
  padding-top: 0;
  padding-bottom: 0;
  max-height: 2em;
}

.login-dialog-logo-bin {
  padding: 24px 0px;
}

.login-dialog-banner {
  color: #b4c0cf;
}

.login-dialog-button-box {
  spacing: 5px;
}

.login-dialog-message-warning {
  color: #F27835;
}

.login-dialog-message-hint {
  padding-top: 0;
  padding-bottom: 20px;
}

.login-dialog-user-selection-box {
  padding: 100px 0px;
}

.login-dialog-user-selection-box .login-dialog-not-listed-label {
  padding-left: 2px;
}

.login-dialog-not-listed-button:focus .login-dialog-user-selection-box .login-dialog-not-listed-label, .login-dialog-not-listed-button:hover .login-dialog-user-selection-box .login-dialog-not-listed-label {
  color: #D3DAE3;
}

.login-dialog-not-listed-label {
  font-size: 90%;
  font-weight: bold;
  color: #768ba8;
  padding-top: 1em;
}

.login-dialog-user-list-view {
  -st-vfade-offset: 1em;
}

.login-dialog-user-list {
  spacing: 12px;
  padding: .2em;
  width: 23em;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:focus {
  background-color: #2eb398;
  color: #ffffff;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in {
  border-right: 2px solid #2eb398;
}

.login-dialog-user-list-item {
  border-radius: 5px;
  padding: .2em;
  color: #768ba8;
}

.login-dialog-user-list-item:ltr {
  padding-right: 1em;
}

.login-dialog-user-list-item:rtl {
  padding-left: 1em;
}

.login-dialog-user-list-item:hover {
  background-color: #2eb398;
  color: #ffffff;
}

.login-dialog-user-list-item .login-dialog-timed-login-indicator {
  height: 2px;
  margin: 2px 0 0 0;
  background-color: #D3DAE3;
}

.login-dialog-user-list-item:focus .login-dialog-timed-login-indicator {
  background-color: #ffffff;
}

.login-dialog-username,
.user-widget-label {
  color: #D3DAE3;
  font-size: 120%;
  font-weight: bold;
  text-align: left;
}

.user-widget.horizontal .user-widget-label {
  font-weight: bold;
  text-align: left;
  padding-left: 20px;
}

.user-widget.horizontal .user-widget-label:ltr {
  padding-left: 18px;
}

.user-widget.horizontal .user-widget-label:rtl {
  padding-right: 18px;
}

.user-widget.vertical .user-widget-label {
  text-align: center;
  font-weight: normal;
  padding-top: 16px;
}

.login-dialog-prompt-entry {
  height: 1.5em;
}

.login-dialog-prompt-layout {
  padding-top: 24px;
  padding-bottom: 12px;
  spacing: 8px;
  width: 23em;
}

.login-dialog-prompt-label {
  color: #95a6bb;
  font-size: 110%;
  padding-top: 1em;
}

.login-dialog-session-list-button StIcon {
  icon-size: 1.25em;
}

.login-dialog-session-list-button {
  color: #768ba8;
}

.login-dialog-session-list-button:hover, .login-dialog-session-list-button:focus {
  color: #D3DAE3;
}

.login-dialog-session-list-button:active {
  color: #475970;
}

.screen-shield-arrows {
  padding-bottom: 3em;
}

.screen-shield-arrows Gjs_Arrow {
  color: white;
  width: 80px;
  height: 48px;
  -arrow-thickness: 12px;
  -arrow-shadow: 0 1px 1px rgba(0, 0, 0, 0.4);
}

.screen-shield-clock {
  color: white;
  text-shadow: 0px 1px 2px rgba(0, 0, 0, 0.6);
  font-weight: bold;
  text-align: center;
  padding-bottom: 1.5em;
}

.unlock-dialog-clock-time,
.screen-shield-clock-time {
  font-size: 72pt;
  text-shadow: 0px 2px 2px rgba(0, 0, 0, 0.4);
}

.unlock-dialog-clock-date,
.screen-shield-clock-date {
  font-size: 28pt;
}

.screen-shield-notifications-container {
  spacing: 6px;
  width: 30em;
  background-color: transparent;
  max-height: 500px;
}

.screen-shield-notifications-container .summary-notification-stack-scrollview {
  padding-top: 0;
  padding-bottom: 0;
}

.screen-shield-notifications-container .notification,
.screen-shield-notifications-container .screen-shield-notification-source {
  padding: 12px 6px;
  border: 1px solid rgba(211, 218, 227, 0.2);
  background-color: rgba(40, 42, 51, 0.5);
  color: #D3DAE3;
  border-radius: 4px;
}

.screen-shield-notifications-container .notification {
  margin-right: 15px;
}

.screen-shield-notification-label {
  font-weight: bold;
  padding: 0px 0px 0px 12px;
}

.screen-shield-notification-count-text {
  padding: 0px 0px 0px 12px;
}

#panel .lock-screen {
  background-color: rgba(33, 35, 43, 0.5);
}

.screen-shield-background {
  background: black;
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.4);
}

#lockDialogGroup {
  background: url("background.jpeg");
  background-repeat: no-repeat;
  background-size: cover;
}

#screenShieldNotifications StButton#vhandle, #screenShieldNotifications StButton#hhandle {
  background-color: rgba(250, 251, 252, 0.3);
}

#screenShieldNotifications StButton#vhandle:hover, #screenShieldNotifications StButton#vhandle:focus, #screenShieldNotifications StButton#hhandle:hover, #screenShieldNotifications StButton#hhandle:focus {
  background-color: rgba(250, 251, 252, 0.5);
}

#screenShieldNotifications StButton#vhandle:active, #screenShieldNotifications StButton#hhandle:active {
  background-color: rgba(46, 179, 152, 0.5);
}

#LookingGlassDialog {
  spacing: 4px;
  padding: 8px 8px 10px 8px;
  background-color: rgba(0, 0, 0, 0.7);
  border: 1px solid black;
  border-image: url("common-assets/misc/bg.svg") 18 18 18 18;
  border-radius: 2px;
  color: white;
}

#LookingGlassDialog > #Toolbar {
  padding: 3px;
  border: none;
  background-color: transparent;
  border-radius: 0px;
}

#LookingGlassDialog .labels {
  spacing: 4px;
}

#LookingGlassDialog .notebook-tab {
  -natural-hpadding: 12px;
  -minimum-hpadding: 6px;
  font-weight: bold;
  color: #D3DAE3;
  transition-duration: 100ms;
  padding-left: .3em;
  padding-right: .3em;
}

#LookingGlassDialog .notebook-tab:hover {
  color: white;
  text-shadow: black 0px 2px 2px;
}

#LookingGlassDialog .notebook-tab:selected {
  border-bottom-width: 0px;
  color: #2eb398;
  text-shadow: black 0px 2px 2px;
}

#LookingGlassDialog StBoxLayout#EvalBox {
  padding: 4px;
  spacing: 4px;
}

#LookingGlassDialog StBoxLayout#ResultsArea {
  spacing: 4px;
}

.lg-dialog StEntry {
  caret-color: #ffffff;
  selection-background-color: #2eb398;
  selected-color: #ffffff;
  color: #D3DAE3;
  background-color: rgba(89, 94, 114, 0.4);
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
}

.lg-dialog StEntry:focus {
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid rgba(13, 14, 17, 0.4);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.05);
  selection-background-color: #ffffff;
  selected-color: #2eb398;
}

.lg-dialog .shell-link {
  color: #248a76;
}

.lg-dialog .shell-link:hover {
  color: #2eb398;
}

.lg-completions-text {
  font-size: .9em;
  font-style: italic;
}

.lg-obj-inspector-title {
  spacing: 4px;
}

.lg-obj-inspector-button {
  border: 1px solid gray;
  padding: 4px;
  border-radius: 4px;
}

.lg-obj-inspector-button:hover {
  border: 1px solid #ffffff;
}

#lookingGlassExtensions {
  padding: 4px;
}

.lg-extensions-list {
  padding: 4px;
  spacing: 6px;
}

.lg-extension {
  border: 1px solid rgba(98, 103, 125, 0.55);
  border-radius: 2px;
  background-color: #282A33;
  padding: 4px;
}

.lg-extension-name {
  font-weight: bold;
}

.lg-extension-meta {
  spacing: 6px;
}

#LookingGlassPropertyInspector {
  background: rgba(0, 0, 0, 0.7);
  border: 1px solid grey;
  border-radius: 2px;
  padding: 6px;
}

.masterslider.smaller .masterlabel,
.masterslider.smaller .slider {
  min-width: 0.6em;
}

.openweather-button, .openweather-button-action, .openweather-menu-button-container, .openweather-button-box {
  border: 1px solid transparent;
  background: none;
}

.openweather-button:hover, .openweather-button-action:hover, .openweather-menu-button-container:hover, .openweather-button-box:hover {
  border: 1px solid #2eb398;
}

.openweather-provider {
  padding: 0 16px;
  font-weight: 500;
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: white;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.openweather-provider:hover {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.03);
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.openweather-provider:focus {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #5c616c;
  background-color: white;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.openweather-provider:active {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: #ffffff;
  background-color: #2eb398;
  border: 1px solid #248a76;
  box-shadow: inset 0 1px rgba(46, 179, 152, 0.05);
}

.openweather-provider:insensitive {
  text-shadow: 0 1px rgba(255, 255, 255, 0);
  color: rgba(92, 97, 108, 0.55);
  border: 1px solid rgba(0, 0, 0, 0);
  background-color: rgba(255, 255, 255, 0.55);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
}

.openweather-current-icon, .openweather-current-summary, .openweather-current-summarybox {
  background: none;
  color: #5c616c;
  -st-icon-style: symbolic;
}

.openweather-current-databox-values {
  background: none;
  color: rgba(92, 97, 108, 0.6);
}

.openweather-current-databox-captions {
  background: none;
  color: rgba(92, 97, 108, 0.6);
}

.openweather-forecast-icon, .openweather-forecast-summary {
  background: none;
  color: rgba(92, 97, 108, 0.75);
  -st-icon-style: symbolic;
}

.openweather-forecast-day {
  background: none;
  color: #5c616c;
}

.openweather-forecast-temperature {
  background: none;
  color: rgba(92, 97, 108, 0.75);
}

.openweather-sunrise-icon, .openweather-sunset-icon, .openweather-build-icon {
  color: rgba(92, 97, 108, 0.75);
  -st-icon-style: symbolic;
}

#dashtodockContainer {
  background: transparent;
}

#dashtodockContainer #dash, #dashtodockContainer:overview #dash, #dashtodockContainer.extended #dash, #dashtodockContainer.extended:overview #dash {
  padding: 0;
  border-color: rgba(0, 0, 0, 0.4);
  transition-duration: 270ms;
}

#dashtodockContainer.top #dash, #dashtodockContainer.top:overview #dash {
  border-radius: 0 0 3px 3px;
}

#dashtodockContainer.top.extended #dash, #dashtodockContainer.top.extended:overview #dash {
  border-radius: 0;
}

#dashtodockContainer.bottom #dash, #dashtodockContainer.bottom:overview #dash {
  border-radius: 3px 3px 0 0;
}

#dashtodockContainer.bottom.extended #dash, #dashtodockContainer.bottom.extended:overview #dash {
  border-radius: 0;
}

#dashtodockContainer.left #dash, #dashtodockContainer.left:overview #dash {
  border-radius: 0 3px 3px 0;
}

#dashtodockContainer.left.extended #dash, #dashtodockContainer.left.extended:overview #dash {
  border-radius: 0;
}

#dashtodockContainer.right #dash, #dashtodockContainer.right:overview #dash {
  border-radius: 3px 0 0 3px;
}

#dashtodockContainer.right.extended #dash, #dashtodockContainer.right.extended:overview #dash {
  border-radius: 0;
}

#dashtodockContainer #dash {
  background-color: #32343D;
}

#dashtodockContainer.opaque #dash {
  background-color: #32343D;
}

#dashtodockContainer.transparent #dash {
  background-color: rgba(50, 52, 61, 0.75);
}

#dashtodockContainer:overview #dash {
  background-color: #32343D;
}

#dashtodockContainer.opaque:overview #dash, #dashtodockContainer.transparent:overview #dash {
  background-color: #32343D;
}

#dashtodockContainer.extended:overview #dash, #dashtodockContainer.opaque.extended:overview #dash, #dashtodockContainer.transparent.extended:overview #dash {
  background-color: #32343D;
}

#dashtodockContainer .app-well-app .overview-icon,
#dashtodockContainer .show-apps .overview-icon {
  padding: 8px;
  background-size: contain;
}

#dashtodockContainer .dash-item-container {
  background: transparent;
}

#dashtodockContainer .dash-item-container > StWidget {
  background-size: contain;
}

#dashtodockContainer .dash-item-container .app-well-app-running-dot {
  width: 6px;
  height: 2px;
  box-shadow: none;
  margin: 2px;
  border-radius: 0;
  background-color: #2eb398;
}

#dashtodockContainer .dash-item-container > StWidget.focused .app-well-app-running-dot {
  width: 18px;
  height: 2px;
  background-color: #2eb398;
}

#dashtodockContainer .number-overlay,
#dashtodockContainer .notification-badge {
  min-width: 1.4em;
  min-height: 1.4em;
  margin: 0;
  padding: 0;
  border-radius: 3px;
  font-weight: 700;
  text-align: center;
}

#dashtodockContainer .number-overlay {
  background-color: #282A33;
  color: #D3DAE3;
}

#dashtodockContainer .notification-badge {
  background-color: #282A33;
  color: #D3DAE3;
}

#dashtodockContainer.top .dash-item-container > .app-well-app.focused .overview-icon,
#dashtodockContainer.extended.top .dash-item-container > .app-well-app.focused .overview-icon {
  background-color: rgba(46, 179, 152, 0.35);
  border: 1px solid rgba(46, 179, 152, 0.5);
}

#dashtodockContainer.top .dash-item-container > .app-well-app.focused:hover .overview-icon,
#dashtodockContainer.extended.top .dash-item-container > .app-well-app.focused:hover .overview-icon {
  background-color: rgba(46, 179, 152, 0.5);
  border: 1px solid #2eb398;
}

#dashtodockContainer.bottom .dash-item-container > .app-well-app.focused .overview-icon,
#dashtodockContainer.extended.bottom .dash-item-container > .app-well-app.focused .overview-icon {
  background-color: rgba(46, 179, 152, 0.35);
  border: 1px solid rgba(46, 179, 152, 0.5);
}

#dashtodockContainer.bottom .dash-item-container > .app-well-app.focused:hover .overview-icon,
#dashtodockContainer.extended.bottom .dash-item-container > .app-well-app.focused:hover .overview-icon {
  background-color: rgba(46, 179, 152, 0.5);
  border: 1px solid #2eb398;
}

#dashtodockContainer.left .dash-item-container > .app-well-app.focused .overview-icon,
#dashtodockContainer.extended.left .dash-item-container > .app-well-app.focused .overview-icon {
  background-color: rgba(46, 179, 152, 0.35);
  border: 1px solid rgba(46, 179, 152, 0.5);
}

#dashtodockContainer.left .dash-item-container > .app-well-app.focused:hover .overview-icon,
#dashtodockContainer.extended.left .dash-item-container > .app-well-app.focused:hover .overview-icon {
  background-color: rgba(46, 179, 152, 0.5);
  border: 1px solid #2eb398;
}

#dashtodockContainer.right .dash-item-container > .app-well-app.focused .overview-icon,
#dashtodockContainer.extended.right .dash-item-container > .app-well-app.focused .overview-icon {
  background-color: rgba(46, 179, 152, 0.35);
  border: 1px solid rgba(46, 179, 152, 0.5);
}

#dashtodockContainer.right .dash-item-container > .app-well-app.focused:hover .overview-icon,
#dashtodockContainer.extended.right .dash-item-container > .app-well-app.focused:hover .overview-icon {
  background-color: rgba(46, 179, 152, 0.5);
  border: 1px solid #2eb398;
}

.popup-menu.app-well-menu .popup-menu-item.dashtodock-app-well-preview-menu-item {
  padding-left: 1em;
  padding-right: 1em;
}

#panel.dashtopanelMainPanel.dashtopanelTop {
  background-gradient-start: #21232b;
  background-gradient-end: #D3DAE3;
}

#panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:hover,
#panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:hover,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:hover,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-button:hover {
  box-shadow: inset 0 2px rgba(46, 179, 152, 0.5);
}

#panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:active, #panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:focus, #panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:checked, #panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:overview,
#panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:active,
#panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:focus,
#panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:checked,
#panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:overview,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:active,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:focus,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:checked,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:overview,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-button:active,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-button:focus,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-button:checked,
#panel.dashtopanelMainPanel.dashtopanelTop .panel-button:overview {
  box-shadow: inset 0 2px #2eb398;
}

#panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:checked .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelTop .show-apps:focus .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelTop .show-apps:hover .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelTop .show-apps:active .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelTop .show-apps:checked .overview-icon {
  border-radius: 0;
  background-color: rgba(211, 218, 227, 0.1);
  box-shadow: 0 0 0 transparent;
}

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview {
  padding: 0;
}

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:focus .dtp-container, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:hover .dtp-container {
  background-color: rgba(211, 218, 227, 0.1);
}

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:active .dtp-container {
  background-color: rgba(211, 218, 227, 0.15);
}

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app .app-well-app-running-dot {
  background-color: #33c7a9;
}

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app.focused .app-well-app-running-dot {
  background-color: #33c7a9;
}

#panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:focus, #panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:hover {
  background-color: rgba(211, 218, 227, 0.1);
  box-shadow: 0 0 0 transparent;
}

#panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:active {
  background-color: rgba(211, 218, 227, 0.15);
  box-shadow: inset 0 2px #2eb398;
}

#panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:checked {
  background-color: rgba(211, 218, 227, 0.15);
  box-shadow: inset 0 2px #2eb398;
}

#panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:checked:hover {
  background-color: rgba(211, 218, 227, 0.2);
}

#panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop StButton.show-apps:checked .overview-icon {
  background-color: transparent;
}

#panel.dashtopanelMainPanel.dashtopanelBottom {
  background-gradient-start: #21232b;
  background-gradient-end: #D3DAE3;
}

#panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:hover,
#panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:hover,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:hover,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:hover {
  box-shadow: inset 0 -2px rgba(46, 179, 152, 0.5);
}

#panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:active, #panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:focus, #panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:checked, #panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:overview,
#panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:active,
#panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:focus,
#panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:checked,
#panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:overview,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:active,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:focus,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:checked,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:overview,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:active,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:focus,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:checked,
#panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:overview {
  box-shadow: inset 0 -2px #2eb398;
}

#panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:checked .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:focus .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:hover .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:active .overview-icon,
#panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:checked .overview-icon {
  border-radius: 0;
  background-color: rgba(211, 218, 227, 0.1);
  box-shadow: 0 0 0 transparent;
}

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview {
  padding: 0;
}

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:focus .dtp-container, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:hover .dtp-container {
  background-color: rgba(211, 218, 227, 0.1);
}

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:active .dtp-container {
  background-color: rgba(211, 218, 227, 0.15);
}

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app .app-well-app-running-dot {
  background-color: #33c7a9;
}

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app.focused .app-well-app-running-dot {
  background-color: #33c7a9;
}

#panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:focus, #panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:hover {
  background-color: rgba(211, 218, 227, 0.1);
  box-shadow: 0 0 0 transparent;
}

#panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:active {
  background-color: rgba(211, 218, 227, 0.15);
  box-shadow: inset 0 -2px #2eb398;
}

#panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:checked {
  background-color: rgba(211, 218, 227, 0.15);
  box-shadow: inset 0 -2px #2eb398;
}

#panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:checked:hover {
  background-color: rgba(211, 218, 227, 0.2);
}

#panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom StButton.show-apps:checked .overview-icon {
  background-color: transparent;
}
