@keyframes header_ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, #ffffff 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, #ffffff 100%, transparent 0%);
  }
}

@keyframes ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 100%, transparent 0%);
  }
}

* {
  background-clip: padding-box;
  -GtkToolButton-icon-spacing: 4;
  -GtkTextView-error-underline-color: #FC4138;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkToolItemGroup-expander-size: 11;
  -GtkWidget-text-handle-width: 20;
  -GtkWidget-text-handle-height: 20;
  -GtkDialog-button-spacing: 4;
  -GtkDialog-action-area-border: 0;
  outline-color: alpha(currentColor,0.3);
  outline-style: dashed;
  outline-offset: -3px;
  outline-width: 1px;
  -gtk-outline-radius: 2px;
}

.background {
  color: #5c616c;
  background-color: #fafbfc;
}

*:disabled {
  -gtk-icon-effect: dim;
}

.gtkstyle-fallback {
  background-color: #fafbfc;
  color: #5c616c;
}

.gtkstyle-fallback:hover {
  background-color: white;
  color: #5c616c;
}

.gtkstyle-fallback:active {
  background-color: #dae2e9;
  color: #5c616c;
}

.gtkstyle-fallback:disabled {
  background-color: white;
  color: rgba(92, 97, 108, 0.55);
}

.gtkstyle-fallback:selected {
  background-color: #5294e2;
  color: #ffffff;
}

button.gtkstyle-fallback:active, button.gtkstyle-fallback:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.view,
window.thunar notebook scrolledwindow.frame.standard-view .view,
iconview,
textview text {
  color: #5c616c;
  background-color: #ffffff;
}

textview border {
  background-color: #fdfdfe;
}

iconview:hover, iconview:active, iconview:selected {
  border-radius: 2px;
}

rubberband, XfdesktopIconView.view .rubberband, .content-view rubberband, treeview.view rubberband, flowbox rubberband,
.rubberband {
  border: 1px solid #68a2e6;
  background-color: rgba(104, 162, 230, 0.2);
}

flowbox flowboxchild {
  padding: 3px;
  border-radius: 2px;
}

flowbox flowboxchild:selected {
  outline-offset: -2px;
}

flowbox.search-bar {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

label.separator {
  color: #5c616c;
}

label selection {
  color: #ffffff;
  background-color: #5294e2;
}

label:disabled {
  color: rgba(92, 97, 108, 0.55);
}

label:disabled selection {
  color: #a9caf1;
}

.dim-label, .slate-notification .notification-body,
.budgie-notification .notification-body,
.budgie-switcher .notification-body, popover label.separator,
popover.background label.separator, headerbar .subtitle, label.separator {
  opacity: 0.55;
}

assistant .sidebar {
  background-color: #ffffff;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

assistant.csd .sidebar {
  border-top-style: none;
}

assistant .sidebar label {
  padding: 6px 12px;
}

assistant .sidebar label.highlight {
  background-color: #5294e2;
  color: #ffffff;
}

textview {
  background-color: #ffffff;
}

.osd .scale-popup, popover.osd, popover.magnifier, .csd popover.osd, .csd popover.magnifier,
popover.background.osd,
popover.background.magnifier, .csd popover.background.osd, .csd popover.background.magnifier, .osd {
  color: #D3DAE3;
  border: none;
  background-color: #282A33;
  background-clip: padding-box;
  box-shadow: none;
}

@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

entry {
  min-height: 22px;
  border: 1px solid;
  padding: 2px 8px;
  caret-color: currentColor;
  border-radius: 3px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

entry.search {
  border-radius: 50px;
}

entry image {
  color: #7d8189;
}

entry image.left {
  padding-left: 0;
  padding-right: 5px;
}

entry image.right {
  padding-right: 0;
  padding-left: 5px;
}

entry.flat, entry.flat:focus {
  min-height: 0;
  padding: 2px;
  background-image: none;
  border-color: transparent;
  border-radius: 0;
}

entry:focus {
  background-clip: border-box;
  color: #5c616c;
  border-color: #5294e2;
  background-color: #ffffff;
}

entry:disabled {
  color: rgba(92, 97, 108, 0.55);
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

entry.warning {
  color: white;
  border-color: #F27835;
  background-color: #f7ae86;
}

entry.warning image {
  color: white;
}

entry.warning:focus {
  color: white;
  background-color: #F27835;
  box-shadow: none;
}

entry.warning selection, entry.warning selection:focus {
  background-color: white;
  color: #F27835;
}

entry.error {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

entry.error image {
  color: white;
}

entry.error:focus {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

entry.error selection, entry.error selection:focus {
  background-color: white;
  color: #FC4138;
}

entry.search-missing {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

entry.search-missing image {
  color: white;
}

entry.search-missing:focus {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

entry.search-missing selection, entry.search-missing selection:focus {
  background-color: white;
  color: #FC4138;
}

entry:drop(active):focus, entry:drop(active) {
  border-color: #F08437;
  box-shadow: none;
}

.osd entry {
  color: #D3DAE3;
  border-color: rgba(13, 14, 17, 0.4);
  background-color: rgba(89, 94, 114, 0.4);
}

.osd entry image, .osd entry image:hover {
  color: inherit;
}

.osd entry:focus {
  color: #ffffff;
  border-color: rgba(13, 14, 17, 0.4);
  background-color: #5294e2;
}

.osd entry:disabled {
  color: rgba(211, 218, 227, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

.osd entry selection:focus, .osd entry selection {
  color: #5294e2;
  background-color: #ffffff;
}

entry progress {
  margin: 0 -6px;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #5294e2;
  border-style: solid;
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #ffffff;
}

treeview entry.flat:focus, treeview entry:focus {
  border-color: #5294e2;
}

@keyframes needs_attention {
  from {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#5294e2), to(transparent));
  }
  to {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#5294e2), to(transparent));
  }
}

button {
  min-height: 22px;
  min-width: 20px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border: 1px solid;
  border-radius: 3px;
  padding: 2px 6px;
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

button separator {
  margin: 4px 1px;
}

.budgie-panel button.flat.launcher, .budgie-panel #tasklist-button:not(.flat), button.budgie-menu-launcher, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button, button.sidebar-button, button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  transition: none;
}

.budgie-panel button.flat.launcher:hover, .budgie-panel #tasklist-button:hover:not(.flat), button.budgie-menu-launcher:hover, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:hover, button.sidebar-button:hover, button.flat:hover {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 250ms;
}

.budgie-panel #tasklist-button:hover:active:not(.flat), button.budgie-menu-launcher:hover:active, PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:hover:active, button.sidebar-button:hover:active, button.flat:hover:active {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
  -gtk-icon-effect: highlight;
}

button:active, button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  background-clip: border-box;
  transition-duration: 50ms;
}

button:active:not(:disabled) label:disabled, button:checked:not(:disabled) label:disabled {
  color: inherit;
  opacity: 0.6;
}

button:active {
  color: #5c616c;
}

button:active:hover, button:checked {
  color: #ffffff;
}

button.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

button:disabled label, button:disabled {
  color: rgba(92, 97, 108, 0.55);
}

button:disabled:active, button:disabled:checked {
  border-color: rgba(82, 148, 226, 0.75);
  background-color: rgba(82, 148, 226, 0.75);
  opacity: 0.6;
}

button:disabled:active label, button:disabled:active, button:disabled:checked label, button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

button.image-button {
  min-width: 24px;
  padding-left: 5px;
  padding-right: 5px;
}

button.text-button {
  padding-left: 12px;
  padding-right: 12px;
}

button.text-button.image-button {
  padding-left: 5px;
  padding-right: 5px;
}

button.text-button.image-button label:first-child {
  padding-left: 8px;
  padding-right: 2px;
}

button.text-button.image-button label:last-child {
  padding-right: 8px;
  padding-left: 2px;
}

button.text-button.image-button label:only-child {
  padding-left: 8px;
  padding-right: 8px;
}

button.text-button.image-button.popup {
  padding-right: 8px;
  padding-left: 8px;
}

button:drop(active) {
  color: #F08437;
  border-color: #F08437;
  box-shadow: none;
}

button.osd {
  color: #D3DAE3;
  background-color: #282A33;
  border-color: #16171c;
}

button.osd.image-button {
  padding: 0;
  min-height: 36px;
  min-width: 36px;
}

button.osd:hover {
  color: #5294e2;
}

button.osd:active, button.osd:checked {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
}

button.osd:disabled {
  color: #5b5f68;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

.osd button {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.4);
}

.osd button:hover {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

.osd button:active, .osd button:checked {
  background-clip: padding-box;
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
}

.osd button:disabled {
  color: #5b5f68;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

.osd button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

.osd button.flat:hover {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

.osd button.flat:disabled {
  color: #5b5f68;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
  background-image: none;
}

.osd button.flat:active, .osd button.flat:checked {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
}

.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child), .osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active) + button:not(:checked):not(:active) {
  box-shadow: none;
}

button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #5294e2;
  border-color: #3c86de;
}

button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #5294e2;
}

button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #68a2e6;
  border-color: #5294e2;
}

button.suggested-action:active, button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #7eafe9;
  border-color: #68a2e6;
}

button.suggested-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(92, 97, 108, 0.55);
}

button.suggested-action:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

button.suggested-action:disabled label, button.suggested-action:disabled {
  color: rgba(92, 97, 108, 0.55);
}

button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #F04A50;
  border-color: #ee3239;
}

button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #F04A50;
}

button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #f26267;
  border-color: #f04a50;
}

button.destructive-action:active, button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #f4797e;
  border-color: #f26267;
}

button.destructive-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(92, 97, 108, 0.55);
}

button.destructive-action:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

button.destructive-action:disabled label, button.destructive-action:disabled {
  color: rgba(92, 97, 108, 0.55);
}

.stack-switcher > button {
  outline-offset: -3px;
}

.stack-switcher > button > label {
  padding-left: 6px;
  padding-right: 6px;
}

.stack-switcher > button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 3px;
  padding-bottom: 3px;
}

.stack-switcher > button.text-button {
  padding-left: 10px;
  padding-right: 10px;
}

.stack-switcher > button.image-button {
  padding-left: 2px;
  padding-right: 2px;
}

.stack-switcher > button.needs-attention:active > label, .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label, .stack-switcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

button stacksidebar row.needs-attention > label, stacksidebar button row.needs-attention > label, .stack-switcher > button.needs-attention > label, .stack-switcher > button.needs-attention > image {
  animation: needs_attention 150ms ease-in;
  background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#5294e2), to(transparent));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 4px;
}

button stacksidebar row.needs-attention > label:dir(rtl), stacksidebar button row.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px, left 4px;
}

button.font separator, button.file separator {
  background-color: transparent;
}

.inline-toolbar button:hover, .inline-toolbar button:backdrop:hover {
  background-color: rgba(92, 97, 108, 0.03);
}

.inline-toolbar button:active, .inline-toolbar button:checked, .inline-toolbar button:backdrop:active, .inline-toolbar button:backdrop:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.slate-notification-window button.image-button,
.budgie-notification-window button.image-button,
.budgie-switcher-window button.image-button,
.budgie-osd-window button.image-button, .raven .expander-button, .raven button.image-button, popover.background > scrolledwindow > viewport.frame > list > row.activatable button.page-row-close-button, button.nautilus-circular-button.image-button,
button.circular-button, .app-notification button.flat, button.close, button.circular {
  min-height: 24px;
  min-width: 24px;
  padding: 2px;
  border-radius: 100px;
  -gtk-outline-radius: 100px;
}

.slate-notification-window button.image-button label,
.budgie-notification-window button.image-button label,
.budgie-switcher-window button.image-button label,
.budgie-osd-window button.image-button label, .raven .expander-button label, .raven button.image-button label, popover.background > scrolledwindow > viewport.frame > list > row.activatable button.page-row-close-button label, button.nautilus-circular-button.image-button label,
button.circular-button label, .app-notification button.flat label, button.close label, button.circular label {
  padding: 0;
}

.inline-toolbar toolbutton > button {
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

.inline-toolbar toolbutton > button:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.inline-toolbar toolbutton > button:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

.inline-toolbar toolbutton > button:disabled label, .inline-toolbar toolbutton > button:disabled {
  color: rgba(92, 97, 108, 0.55);
}

.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked {
  border-color: rgba(82, 148, 226, 0.75);
  background-color: rgba(82, 148, 226, 0.75);
  opacity: 0.6;
}

.inline-toolbar toolbutton > button:disabled:active label, .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked label, .inline-toolbar toolbutton > button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

toolbar.inline-toolbar toolbutton:first-child > button.flat, .inline-toolbar toolbutton:first-child > button.flat {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
  border-left-style: solid;
  border-right-style: none;
}

toolbar.inline-toolbar toolbutton:last-child > button.flat, .inline-toolbar toolbutton:last-child > button.flat {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
  border-left-style: none;
}

toolbar.inline-toolbar toolbutton:only-child > button.flat, .inline-toolbar toolbutton:only-child > button.flat {
  border-radius: 3px;
  border-style: solid;
}

toolbar.inline-toolbar toolbutton:hover, .inline-toolbar toolbutton:hover {
  background-color: rgba(92, 97, 108, 0.03);
}

toolbar.inline-toolbar toolbutton:active, .inline-toolbar toolbutton:active, toolbar.inline-toolbar toolbutton:checked, .inline-toolbar toolbutton:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry.warning,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus:last-child {
  border-left-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + entry {
  border-left-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button + button {
  border-left-style: none;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) {
  box-shadow: none;
}

.linked.path-bar:not(.vertical) > button, .linked.stack-switcher:not(.vertical) > button {
  border-left-style: none;
  border-right-style: none;
}

.linked.path-bar:not(.vertical) > button:first-child, .linked.stack-switcher:not(.vertical) > button:first-child {
  border-left-style: solid;
}

.linked.path-bar:not(.vertical) > button:last-child, .linked.stack-switcher:not(.vertical) > button:last-child {
  border-right-style: solid;
}

.linked.path-bar:not(.vertical) > button + button, .linked.stack-switcher:not(.vertical) > button + button {
  border-left-style: none;
  border-right-style: none;
}

.linked.path-bar:not(.vertical) > button + button:last-child, .linked.stack-switcher:not(.vertical) > button + button:last-child {
  border-right-style: solid;
}

.linked.path-bar:not(.vertical) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, .linked.stack-switcher:not(.vertical) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
  box-shadow: none;
}

.linked.path-bar:not(.vertical) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, .linked.stack-switcher:not(.vertical) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
  box-shadow: none;
}

.osd .linked:not(.vertical) > entry + entry {
  border-left-color: rgba(13, 14, 17, 0);
}

.osd .linked:not(.vertical) > entry.error + entry,
.osd .linked:not(.vertical) > entry + entry.error {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.warning + entry,
.osd .linked:not(.vertical) > entry + entry.warning {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.error + entry.warning,
.osd .linked:not(.vertical) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.osd .linked:not(.vertical) > entry + entry:focus:not(:last-child),
.osd .linked:not(.vertical) > entry + entry:focus:last-child {
  border-left-color: #5294e2;
}

.osd .linked:not(.vertical) > entry:focus:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:focus:not(:only-child) + button,
.osd .linked:not(.vertical) > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #5294e2;
}

.osd .linked:not(.vertical) > entry + entry:drop(active):not(:last-child),
.osd .linked:not(.vertical) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + button,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry + entry.warning:focus:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.warning:focus:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.warning:focus:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry + entry.error:focus:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.error:focus:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.error:focus:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > button:active + entry,
.osd .linked:not(.vertical) > button:checked + entry {
  border-left-color: #5294e2;
}

.osd .linked:not(.vertical) > button + button {
  border-left-style: none;
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(98, 103, 125, 0.55);
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(98, 103, 125, 0.05);
}

.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.osd .linked:not(.vertical) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry.error,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error + entry.warning,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning + entry.error {
  border-left-color: rgba(0, 0, 0, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:focus:last-child {
  border-left-color: #5294e2;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.warning:focus:last-child {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + entry.error:focus:last-child {
  border-left-color: #FC4138;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + entry {
  border-left-color: rgba(0, 0, 0, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + entry {
  border-left-color: rgba(0, 0, 0, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button + button {
  border-left-style: solid;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) {
  box-shadow: inset 1px 0 transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) {
  box-shadow: inset 1px 0 transparent;
  border-left-color: rgba(0, 0, 0, 0.12);
}

.linked.vertical > entry + entry {
  border-top-color: rgba(0, 0, 0, 0);
}

.linked.vertical > entry.error + entry,
.linked.vertical > entry + entry.error {
  border-top-color: #FC4138;
}

.linked.vertical > entry.warning + entry,
.linked.vertical > entry + entry.warning {
  border-top-color: #F27835;
}

.linked.vertical > entry.error + entry.warning,
.linked.vertical > entry.warning + entry.error {
  border-top-color: #f75d37;
}

.linked.vertical > entry + entry:focus:not(:last-child),
.linked.vertical > entry + entry:focus:last-child {
  border-top-color: #5294e2;
}

.linked.vertical > entry:focus:not(:only-child) + entry,
.linked.vertical > entry:focus:not(:only-child) + button,
.linked.vertical > entry:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #5294e2;
}

.linked.vertical > entry + entry:drop(active):not(:last-child),
.linked.vertical > entry + entry:drop(active):last-child {
  border-top-color: #F08437;
}

.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #F08437;
}

.linked.vertical > entry + entry.warning:focus:not(:last-child),
.linked.vertical > entry + entry.warning:focus:last-child {
  border-top-color: #F27835;
}

.linked.vertical > entry.warning:focus:not(:only-child) + entry,
.linked.vertical > entry.warning:focus:not(:only-child) + button,
.linked.vertical > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #F27835;
}

.linked.vertical > entry + entry.error:focus:not(:last-child),
.linked.vertical > entry + entry.error:focus:last-child {
  border-top-color: #FC4138;
}

.linked.vertical > entry.error:focus:not(:only-child) + entry,
.linked.vertical > entry.error:focus:not(:only-child) + button,
.linked.vertical > entry.error:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #FC4138;
}

.linked.vertical > button:active + entry,
.linked.vertical > button:checked + entry {
  border-top-color: #5294e2;
}

.linked.vertical > button + button {
  border-top-style: none;
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.15);
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0);
}

.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked.vertical {
  box-shadow: none;
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):last-child:disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):last-child:hover {
  box-shadow: none;
}

.linked:not(.vertical) > combobox > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox > box > button.combo:dir(rtl), .budgie-settings-window buttonbox.inline-toolbar button, spinbutton:not(.vertical) button, spinbutton:not(.vertical) entry, .linked:not(.vertical) > entry, .linked:not(.vertical) > entry:focus, .linked:not(.vertical) > button, .linked:not(.vertical) > button:hover, .linked:not(.vertical) > button:active, .linked:not(.vertical) > button:checked {
  border-radius: 0;
  border-right-style: none;
}

.inline-toolbar button, .inline-toolbar button:backdrop, toolbar.inline-toolbar toolbutton > button.flat, .inline-toolbar toolbutton > button.flat {
  border-radius: 0;
  border-right-style: none;
  border-left-style: none;
}

.budgie-settings-window buttonbox.inline-toolbar button:first-child, spinbutton:not(.vertical) button:first-child, spinbutton:not(.vertical) entry:first-child, .linked:not(.vertical) > entry:first-child, .linked:not(.vertical) > button:first-child {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

.budgie-settings-window buttonbox.inline-toolbar button:last-child, spinbutton:not(.vertical) button:last-child, spinbutton:not(.vertical) entry:last-child, .linked:not(.vertical) > entry:last-child, .linked:not(.vertical) > button:last-child {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

.budgie-settings-window buttonbox.inline-toolbar button:only-child, spinbutton:not(.vertical) button:only-child, spinbutton:not(.vertical) entry:only-child, .linked:not(.vertical) > entry:only-child, .linked:not(.vertical) > button:only-child {
  border-radius: 3px;
  border-style: solid;
}

.inline-toolbar button:first-child, .inline-toolbar button:first-child:backdrop {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
  border-left-style: solid;
  border-right-style: none;
}

.inline-toolbar button:last-child, .inline-toolbar button:last-child:backdrop {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
  border-left-style: none;
}

.inline-toolbar button:only-child, .inline-toolbar button:only-child:backdrop {
  border-radius: 3px;
  border-style: solid;
}

.linked.vertical > combobox > box > button.combo, spinbutton.vertical button, spinbutton.vertical entry, .linked.vertical > entry, .linked.vertical > entry:focus, .linked.vertical > button, .linked.vertical > button:hover, .linked.vertical > button:active, .linked.vertical > button:checked {
  border-radius: 0;
  border-bottom-style: none;
}

spinbutton.vertical button:first-child, spinbutton.vertical entry:first-child, .linked.vertical > entry:first-child, .linked.vertical > button:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

spinbutton.vertical button:last-child, spinbutton.vertical entry:last-child, .linked.vertical > entry:last-child, .linked.vertical > button:last-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-style: solid;
}

spinbutton.vertical button:only-child, spinbutton.vertical entry:only-child, .linked.vertical > entry:only-child, .linked.vertical > button:only-child {
  border-radius: 3px;
  border-style: solid;
}

.nemo-window .floating-bar button, calendar.button, .app-notification button.flat:disabled, .app-notification button.flat, notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:active:hover, notebook > header > tabs > tab button.flat:hover, button:link:hover, button:link:active, button:link:checked, button:visited:hover, button:visited:active, button:visited:checked, button:link, button:visited, menuitem.button.flat,
modelbutton.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

menuitem.button.flat,
modelbutton.flat {
  transition: none;
  min-height: 24px;
  padding-left: 8px;
  padding-right: 8px;
  outline-offset: -3px;
  border-radius: 2px;
  border: 1px solid transparent;
}

menuitem.button.flat:hover,
modelbutton.flat:hover {
  background-color: #f2f3f5;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

menuitem.button.flat:active, menuitem.button.flat:selected,
modelbutton.flat:active,
modelbutton.flat:selected {
  border: 1px solid #2679db;
}

menuitem.button.flat:checked,
modelbutton.flat:checked {
  color: #5c616c;
}

menuitem.button.flat:disabled,
modelbutton.flat:disabled {
  color: rgba(92, 97, 108, 0.55);
}

menuitem.button.flat check:last-child,
menuitem.button.flat radio:last-child,
modelbutton.flat check:last-child,
modelbutton.flat radio:last-child {
  margin-left: 8px;
}

menuitem.button.flat check:first-child,
menuitem.button.flat radio:first-child,
modelbutton.flat check:first-child,
modelbutton.flat radio:first-child {
  margin-right: 8px;
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

*:link, button:link, button:visited {
  color: #2679db;
}

*:link:visited, button:visited {
  color: #50555e;
}

*:selected *:link:visited, *:selected button:visited {
  color: #bad4f3;
}

*:link:hover, button:hover:link, button:hover:visited {
  color: #5294e2;
}

*:selected *:link:hover, *:selected button:hover:link, *:selected button:hover:visited {
  color: #eef4fc;
}

*:link:active, button:active:link, button:active:visited {
  color: #2679db;
}

*:selected *:link:active, *:selected button:active:link, *:selected button:active:visited {
  color: #dceaf9;
}

.selection-mode hdyleaflet headerbar .subtitle:link, infobar.info *:link, infobar.question *:link, infobar.warning *:link, infobar.error *:link, headerbar.selection-mode .subtitle:link, *:link:selected, *:selected *:link, button:selected:link, button:selected:visited, *:selected button:link, *:selected button:visited {
  color: #dceaf9;
}

button:link > label, button:visited > label {
  text-decoration-line: underline;
}

spinbutton:drop(active) {
  box-shadow: none;
}

spinbutton button:active {
  color: #ffffff;
}

spinbutton:disabled {
  color: rgba(92, 97, 108, 0.55);
}

.linked.vertical > spinbutton:not(.vertical):not(:last-child) button, .linked.vertical > spinbutton:not(.vertical):not(:last-child) entry {
  border-bottom: none;
}

.linked.vertical > spinbutton:not(.vertical):not(:last-child) entry:focus {
  box-shadow: inset 0 -1px #5294e2;
}

.linked.vertical > spinbutton:not(.vertical):not(:last-child):not(:first-child) button, .linked.vertical > spinbutton:not(.vertical):not(:last-child):not(:first-child) entry {
  border-radius: 0;
}

spinbutton:not(.vertical) entry {
  min-width: 28px;
}

spinbutton:not(.vertical):dir(ltr) entry, spinbutton:not(.vertical):dir(rtl) button.up {
  border-radius: 3px 0 0 3px;
}

spinbutton:not(.vertical) > button + button {
  border-left-style: none;
}

spinbutton:not(.vertical) > button:hover:not(:active),
spinbutton:not(.vertical) > button:hover + button {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.15);
}

spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.05);
}

spinbutton:not(.vertical) > button:first-child:hover:not(:active),
spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
spinbutton:not(.vertical) > entry + button:not(:active):hover {
  box-shadow: none;
}

spinbutton:not(.vertical) > entry:focus + button {
  border-left-color: #5294e2;
}

spinbutton:not(.vertical) > entry:drop(active) + button {
  border-left-color: #F08437;
}

.osd spinbutton:not(.vertical) > button:hover:not(:active),
.osd spinbutton:not(.vertical) > button:hover + button {
  border-left-color: rgba(98, 103, 125, 0.55);
}

.osd spinbutton:not(.vertical) > button:first-child:hover:not(:active),
.osd spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
.osd spinbutton:not(.vertical) > entry + button:not(:active):hover {
  box-shadow: none;
}

.osd spinbutton:not(.vertical) > entry:focus + button {
  border-left-color: #5294e2;
}

spinbutton.vertical button, spinbutton.vertical entry {
  padding-left: 4px;
  padding-right: 4px;
  min-width: 0;
}

spinbutton.vertical button.up {
  border-radius: 3px 3px 0 0;
}

spinbutton.vertical > entry:focus + button {
  border-top-color: #5294e2;
}

spinbutton.vertical > entry:drop(active) + button {
  border-top-color: #F08437;
}

combobox button.combo {
  min-width: 0;
  padding-left: 8px;
  padding-right: 8px;
}

combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

combobox:drop(active) button.combo {
  color: #F08437;
  border-color: #F08437;
  box-shadow: none;
}

combobox decoration,
combobox button.combo:checked {
  transition: none;
}

.linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}

.linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid;
}

.linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

.linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

.linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-bottom-style: solid;
}

.linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid;
}

toolbar, .inline-toolbar {
  -GtkWidget-window-dragging: true;
  padding: 4px;
  background-color: #fafbfc;
}

toolbar separator, .inline-toolbar separator {
  background: none;
}

toolbar.horizontal separator, .horizontal.inline-toolbar separator {
  margin: 0 6px;
}

toolbar.vertical separator, .vertical.inline-toolbar separator {
  margin: 6px 0;
}

.osd toolbar, .osd .inline-toolbar {
  background-color: transparent;
}

toolbar.osd, .osd.inline-toolbar {
  padding: 7px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  background-color: #282A33;
}

toolbar.osd.left, .osd.left.inline-toolbar, toolbar.osd.right, .osd.right.inline-toolbar, toolbar.osd.top, .osd.top.inline-toolbar, toolbar.osd.bottom, .osd.bottom.inline-toolbar {
  border-radius: 0;
}

toolbar.osd.top, .osd.top.inline-toolbar {
  border-width: 0 0 1px 0;
}

toolbar.osd.bottom, .osd.bottom.inline-toolbar {
  border-width: 1px 0 0 0;
}

toolbar.osd.left, .osd.left.inline-toolbar {
  border-width: 0 1px 0 0;
}

toolbar.osd.right, .osd.right.inline-toolbar {
  border-width: 0 0 0 1px;
}

toolbar:not(.inline-toolbar) switch, .inline-toolbar:not(.inline-toolbar) switch,
toolbar:not(.inline-toolbar) scale,
.inline-toolbar:not(.inline-toolbar) scale,
toolbar:not(.inline-toolbar) entry,
.inline-toolbar:not(.inline-toolbar) entry,
toolbar:not(.inline-toolbar) spinbutton,
.inline-toolbar:not(.inline-toolbar) spinbutton,
toolbar:not(.inline-toolbar) button,
.inline-toolbar:not(.inline-toolbar) button {
  margin-right: 1px;
  margin-bottom: 1px;
}

toolbar:not(.inline-toolbar) .linked > button, .inline-toolbar:not(.inline-toolbar) .linked > button,
toolbar:not(.inline-toolbar) .linked > entry,
.inline-toolbar:not(.inline-toolbar) .linked > entry {
  margin-right: 0;
}

.primary-toolbar:not(.libreoffice-toolbar) {
  color: #5c616c;
  background-color: transparent;
  box-shadow: none;
  border-width: 0 0 1px 0;
  border-style: solid;
  border-image: linear-gradient(to bottom, #cad5df, #cad5df) 1 0 1 0;
}

.inline-toolbar {
  background-color: #f0f3f6;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.15);
  border-width: 0 1px 1px;
  padding: 3px;
  border-radius: 0 0 3px 3px;
}

searchbar {
  padding: 0;
  margin: 0;
  border: none;
}

searchbar > revealer > box {
  padding: 6px;
  margin: -6px;
  border-style: solid;
  border-color: #cad5df;
  background-color: #fafbfc;
  border-width: 0 0 1px;
}

actionbar {
  padding: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  background-color: #f0f3f6;
}

headerbar {
  padding: 0 10px;
  color: rgba(82, 93, 118, 0.8);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
  min-height: 38px;
}

headerbar:backdrop {
  transition: 200ms ease-out;
  color: rgba(82, 93, 118, 0.5);
  background-color: white;
}

headerbar .title {
  padding-left: 12px;
  padding-right: 12px;
}

headerbar .subtitle {
  font-size: 80%;
  padding-left: 12px;
  padding-right: 12px;
  margin-top: -3px;
}

headerbar.selection-mode {
  color: #ffffff;
  background-color: #5294e2;
  border-color: #4189df;
  box-shadow: none;
}

headerbar.selection-mode:backdrop {
  background-color: #5294e2;
  color: rgba(255, 255, 255, 0.6);
}

headerbar.selection-mode .selection-menu {
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

headerbar.selection-mode .selection-menu GtkArrow {
  -GtkArrow-arrow-scaling: 1;
}

headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.maximized headerbar.selection-mode {
  background-color: #5294e2;
}

.tiled headerbar, .tiled headerbar:backdrop, .maximized headerbar, .maximized headerbar:backdrop {
  border-radius: 0;
}

.maximized headerbar {
  background-color: white;
  border-color: #e6e6e6;
}

.maximized headerbar:backdrop {
  background-color: white;
}

headerbar.default-decoration:not(.csd) > button.titlebutton {
  min-height: 23px;
  min-width: 23px;
  padding: 2px;
}

headerbar.default-decoration:not(.csd) {
  min-height: 30px;
  padding: 0 8px;
  background-color: #ffffff;
}

headerbar.default-decoration:not(.csd) > button.titlebutton {
  border: none;
}

headerbar.default-decoration, .csd headerbar.default-decoration, headerbar.default-decoration:backdrop, .csd headerbar.default-decoration:backdrop {
  background-color: #ffffff;
  border-bottom-width: 0;
  box-shadow: none;
}

.tiled headerbar.default-decoration, .maximized headerbar.default-decoration, .fullscreen headerbar.default-decoration, .tiled .csd headerbar.default-decoration, .maximized .csd headerbar.default-decoration, .fullscreen .csd headerbar.default-decoration, .tiled headerbar.default-decoration:backdrop, .maximized headerbar.default-decoration:backdrop, .fullscreen headerbar.default-decoration:backdrop, .tiled .csd headerbar.default-decoration:backdrop, .maximized .csd headerbar.default-decoration:backdrop, .fullscreen .csd headerbar.default-decoration:backdrop {
  box-shadow: none;
}

.titlebar {
  border-radius: 0 0 0 0;
}

headerbar entry, headerbar button, headerbar separator:not(.sidebar) {
  margin-top: 5px;
  margin-bottom: 5px;
}

window > .titlebar:not(headerbar), window > .titlebar:not(headerbar):backdrop, window.csd > .titlebar:not(headerbar), window.csd > .titlebar:not(headerbar):backdrop {
  padding: 0;
  background: none;
  border: none;
  box-shadow: none;
}

.titlebar:not(headerbar) > separator {
  background-image: image(#ffffff);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

.titlebar:not(headerbar) > separator:backdrop {
  background-image: image(#ffffff);
}

.primary-toolbar:not(.libreoffice-toolbar) separator, headerbar separator.titlebutton, headerbar separator {
  min-width: 0;
  min-height: 0;
  background: none;
  border-width: 0;
  border-image: none;
}

window.thunar toolbar#location-toolbar entry, window.thunar #location-toolbar.inline-toolbar entry, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry, .nemo-window .primary-toolbar entry, headerbar entry {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f7f7f7;
}

window.thunar toolbar#location-toolbar entry image, window.thunar #location-toolbar.inline-toolbar entry image, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry image, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry image, .nemo-window .primary-toolbar entry image, headerbar entry image, headerbar entry image:hover {
  color: inherit;
}

window.thunar toolbar#location-toolbar entry:backdrop, window.thunar #location-toolbar.inline-toolbar entry:backdrop, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry:backdrop, .nemo-window .primary-toolbar entry:backdrop, headerbar entry:backdrop {
  opacity: 0.85;
}

window.thunar toolbar#location-toolbar entry:focus, window.thunar #location-toolbar.inline-toolbar entry:focus, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry:focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry:focus, .nemo-window .primary-toolbar entry:focus, headerbar entry:focus {
  color: rgba(132, 144, 170, 0.8);
  border-color: #5294e2;
  background-color: #fcfcfc;
  background-clip: border-box;
}

window.thunar toolbar#location-toolbar entry:focus image, window.thunar #location-toolbar.inline-toolbar entry:focus image, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry:focus image, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry:focus image, .nemo-window .primary-toolbar entry:focus image, headerbar entry:focus image {
  color: #5294e2;
}

window.thunar toolbar#location-toolbar entry:disabled, window.thunar #location-toolbar.inline-toolbar entry:disabled, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry:disabled, .nemo-window .primary-toolbar entry:disabled, headerbar entry:disabled {
  color: rgba(82, 93, 118, 0.35);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: rgba(247, 247, 247, 0.85);
}

window.thunar toolbar#location-toolbar entry selection:focus, window.thunar #location-toolbar.inline-toolbar entry selection:focus, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry selection:focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry selection:focus, .nemo-window .primary-toolbar entry selection:focus, headerbar entry selection:focus {
  background-color: #5294e2;
  color: #ffffff;
}

window.thunar toolbar#location-toolbar entry progress, window.thunar #location-toolbar.inline-toolbar entry progress, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry progress, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry progress, .nemo-window .primary-toolbar entry progress, headerbar entry progress {
  border-color: #5294e2;
  background-image: none;
  background-color: transparent;
}

window.thunar toolbar#location-toolbar entry.warning, window.thunar #location-toolbar.inline-toolbar entry.warning, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry.warning, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry.warning, .nemo-window .primary-toolbar entry.warning, headerbar entry.warning {
  color: white;
  border-color: #F27835;
  background-color: #f7ae86;
}

window.thunar toolbar#location-toolbar entry.warning:focus, window.thunar #location-toolbar.inline-toolbar entry.warning:focus, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry.warning:focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry.warning:focus, .nemo-window .primary-toolbar entry.warning:focus, headerbar entry.warning:focus {
  color: white;
  background-color: #F27835;
}

window.thunar toolbar#location-toolbar entry.warning selection, window.thunar #location-toolbar.inline-toolbar entry.warning selection, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry.warning selection, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry.warning selection, .nemo-window .primary-toolbar entry.warning selection, headerbar entry.warning selection {
  background-color: white;
  color: #F27835;
}

window.thunar toolbar#location-toolbar entry.error, window.thunar #location-toolbar.inline-toolbar entry.error, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry.error, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry.error, .nemo-window .primary-toolbar entry.error, headerbar entry.error {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

window.thunar toolbar#location-toolbar entry.error:focus, window.thunar #location-toolbar.inline-toolbar entry.error:focus, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry.error:focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry.error:focus, .nemo-window .primary-toolbar entry.error:focus, headerbar entry.error:focus {
  color: white;
  background-color: #FC4138;
}

window.thunar toolbar#location-toolbar entry.error selection, window.thunar #location-toolbar.inline-toolbar entry.error selection, .caja-navigation-window toolbar#Toolbar.primary-toolbar entry.error selection, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar entry.error selection, .nemo-window .primary-toolbar entry.error selection, headerbar entry.error selection {
  background-color: white;
  color: #FC4138;
}

window.thunar toolbar#location-toolbar button, window.thunar #location-toolbar.inline-toolbar button, .caja-navigation-window toolbar#Toolbar.primary-toolbar button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button, .nemo-window .primary-toolbar button, headerbar button {
  color: rgba(82, 93, 118, 0.8);
  outline-offset: -3px;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

window.thunar toolbar#location-toolbar button:backdrop, window.thunar #location-toolbar.inline-toolbar button:backdrop, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:backdrop, .nemo-window .primary-toolbar button:backdrop, headerbar button:backdrop {
  opacity: 0.7;
}

window.thunar toolbar#location-toolbar button:hover, window.thunar #location-toolbar.inline-toolbar button:hover, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:hover, .nemo-window .primary-toolbar button:hover, headerbar button:hover {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
}

window.thunar toolbar#location-toolbar button:active, window.thunar #location-toolbar.inline-toolbar button:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:active, .nemo-window .primary-toolbar button:active, headerbar button:active, window.thunar toolbar#location-toolbar button:checked, window.thunar #location-toolbar.inline-toolbar button:checked, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:checked, .nemo-window .primary-toolbar button:checked, headerbar button:checked {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  background-clip: border-box;
}

window.thunar toolbar#location-toolbar button:disabled, window.thunar #location-toolbar.inline-toolbar button:disabled, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled, .nemo-window .primary-toolbar button:disabled, headerbar button:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

window.thunar toolbar#location-toolbar button:disabled label, window.thunar #location-toolbar.inline-toolbar button:disabled label, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled label, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled label, .nemo-window .primary-toolbar button:disabled label, headerbar button:disabled label, window.thunar toolbar#location-toolbar button:disabled, window.thunar #location-toolbar.inline-toolbar button:disabled, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled, .nemo-window .primary-toolbar button:disabled, headerbar button:disabled {
  color: rgba(82, 93, 118, 0.3);
}

window.thunar toolbar#location-toolbar button:disabled:active, window.thunar #location-toolbar.inline-toolbar button:disabled:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled:active, .nemo-window .primary-toolbar button:disabled:active, headerbar button:disabled:active, window.thunar toolbar#location-toolbar button:disabled:checked, window.thunar #location-toolbar.inline-toolbar button:disabled:checked, .caja-navigation-window toolbar#Toolbar.primary-toolbar button:disabled:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button:disabled:checked, .nemo-window .primary-toolbar button:disabled:checked, headerbar button:disabled:checked {
  color: rgba(255, 255, 255, 0.5);
  border-color: rgba(82, 148, 226, 0.65);
  background-color: rgba(82, 148, 226, 0.65);
}

window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button,
.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.image-button.text-button, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button {
  background: none;
  border: none;
  border-radius: 0;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 0%, transparent 0%) 0 0 0/0 0 0;
}

window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:hover, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:hover, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:hover,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:hover, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:hover, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:hover, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:hover {
  color: rgba(61, 69, 88, 0.8);
  background-color: transparent;
  box-shadow: inset 0 -2px rgba(82, 148, 226, 0.5);
}

window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:checked, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:checked, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:checked,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:checked, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:checked, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:checked, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:checked, window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:active, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:active, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:active,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:active, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:active, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:active {
  color: rgba(82, 93, 118, 0.8);
  background-color: transparent;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 100%, transparent 0%) 0 0 2/0 0 2px;
}

window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:disabled, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:disabled, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:disabled,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:disabled, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:disabled, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:disabled, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:disabled {
  color: rgba(82, 93, 118, 0.4);
  background-color: transparent;
}

window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:checked:disabled, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:checked:disabled, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button:checked:disabled,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button:checked:disabled, .nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:checked:disabled, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:checked:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:checked:disabled, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button:checked:disabled {
  color: rgba(82, 93, 118, 0.4);
  background-color: transparent;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(82, 148, 226, 0.4) 100%, transparent 0%) 0 0 2/0 0 2px;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.flat.popup.toggle.sources-button:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.flat.popup.toggle.sources-button:hover, .nemo-window .primary-toolbar button.flat.popup.toggle.sources-button:hover, headerbar button.flat.popup.toggle.sources-button:hover {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button, .nemo-window .selection-mode.primary-toolbar button, headerbar.selection-mode button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:hover, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:hover, .nemo-window .selection-mode.primary-toolbar button:hover, headerbar.selection-mode button:hover {
  background-color: alpha(#ffffff,0.3);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:active, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:active, .nemo-window .selection-mode.primary-toolbar button:active, headerbar.selection-mode button:active, .caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:checked, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:checked, .nemo-window .selection-mode.primary-toolbar button:checked, headerbar.selection-mode button:checked {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.35);
  border-color: rgba(255, 255, 255, 0.65);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:disabled, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:disabled, .nemo-window .selection-mode.primary-toolbar button:disabled, headerbar.selection-mode button:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.4);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:disabled, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:disabled, .nemo-window .selection-mode.primary-toolbar button:disabled, headerbar.selection-mode button:disabled, .caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:disabled label, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:disabled label, .nemo-window .selection-mode.primary-toolbar button:disabled label, headerbar.selection-mode button:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:disabled:active, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:disabled:active, .nemo-window .selection-mode.primary-toolbar button:disabled:active, headerbar.selection-mode button:disabled:active, .caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:disabled:checked, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:disabled:checked, .nemo-window .selection-mode.primary-toolbar button:disabled:checked, headerbar.selection-mode button:disabled:checked {
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.4);
}

.caja-navigation-window toolbar#Toolbar.selection-mode.primary-toolbar button:backdrop, .caja-navigation-window #Toolbar.selection-mode.primary-toolbar.inline-toolbar button:backdrop, .nemo-window .selection-mode.primary-toolbar button:backdrop, headerbar.selection-mode button:backdrop {
  opacity: 0.7;
  background: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) button:not(:only-child), .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) button:not(:only-child), .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) button:not(:only-child), headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) button:not(:only-child) {
  margin-left: 1px;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button, headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar):not(.stack-switcher) > button {
  border-radius: 3px;
  border-style: solid;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child), .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child), .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child), headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
.caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover),
.caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover),
.nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:backdrop, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:backdrop, headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:backdrop {
  box-shadow: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar) > entry, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry, headerbar .linked:not(.vertical):not(.path-bar) > entry {
  margin-left: 1px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked:not(.vertical):not(.path-bar) > entry:focus, .nemo-window .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:focus, headerbar .linked:not(.vertical):not(.path-bar) > entry:focus {
  border-color: #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button, .nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button, headerbar .linked.path-bar:not(.vertical):not(.stack-switcher) > button {
  margin: 0;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button {
  background-color: white;
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover {
  background-color: #f7f7f7;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:active, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:active, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:checked, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:checked, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled {
  color: rgba(82, 93, 118, 0.4);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled label, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled label, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled label, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:disabled label {
  color: rgba(82, 93, 118, 0.4);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button {
  border-left-style: none;
  border-right-style: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:first-child, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:first-child, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:first-child, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:first-child {
  border-left-style: solid;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:last-child, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:last-child, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:last-child, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:last-child {
  border-right-style: solid;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button {
  border-left-style: none;
  border-right-style: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button:last-child, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button:last-child, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button:last-child, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button + button:last-child {
  border-right-style: solid;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
  box-shadow: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, .nemo-window .primary-toolbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, headerbar .linked.stack-switcher:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
  box-shadow: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action, .nemo-window .primary-toolbar button.suggested-action, headerbar button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #5294e2;
  border-color: #3c86de;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action.flat, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action.flat, .nemo-window .primary-toolbar button.suggested-action.flat, headerbar button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:hover, .nemo-window .primary-toolbar button.suggested-action:hover, headerbar button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #68a2e6;
  border-color: #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:active, .nemo-window .primary-toolbar button.suggested-action:active, headerbar button.suggested-action:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:checked, .nemo-window .primary-toolbar button.suggested-action:checked, headerbar button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #7eafe9;
  border-color: #68a2e6;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:disabled, .nemo-window .primary-toolbar button.suggested-action:disabled, headerbar button.suggested-action:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:disabled label, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:disabled label, .nemo-window .primary-toolbar button.suggested-action:disabled label, headerbar button.suggested-action:disabled label, .caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:disabled, .nemo-window .primary-toolbar button.suggested-action:disabled, headerbar button.suggested-action:disabled {
  color: rgba(82, 93, 118, 0.3);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.suggested-action:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.suggested-action:backdrop, .nemo-window .primary-toolbar button.suggested-action:backdrop, headerbar button.suggested-action:backdrop {
  opacity: 0.8;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action, .nemo-window .primary-toolbar button.destructive-action, headerbar button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #F04A50;
  border-color: #ee3239;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action.flat, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action.flat, .nemo-window .primary-toolbar button.destructive-action.flat, headerbar button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #F04A50;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:hover, .nemo-window .primary-toolbar button.destructive-action:hover, headerbar button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #f26267;
  border-color: #f04a50;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:active, .nemo-window .primary-toolbar button.destructive-action:active, headerbar button.destructive-action:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:checked, .nemo-window .primary-toolbar button.destructive-action:checked, headerbar button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #f4797e;
  border-color: #f26267;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:disabled, .nemo-window .primary-toolbar button.destructive-action:disabled, headerbar button.destructive-action:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:disabled label, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:disabled label, .nemo-window .primary-toolbar button.destructive-action:disabled label, headerbar button.destructive-action:disabled label, .caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:disabled, .nemo-window .primary-toolbar button.destructive-action:disabled, headerbar button.destructive-action:disabled {
  color: rgba(82, 93, 118, 0.3);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar button.destructive-action:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar button.destructive-action:backdrop, .nemo-window .primary-toolbar button.destructive-action:backdrop, headerbar button.destructive-action:backdrop {
  opacity: 0.8;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar spinbutton:not(.vertical):focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar spinbutton:not(.vertical):focus, .nemo-window .primary-toolbar spinbutton:not(.vertical):focus, headerbar spinbutton:not(.vertical):focus {
  color: #ffffff;
  caret-color: #ffffff;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar spinbutton:not(.vertical) button, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar spinbutton:not(.vertical) button, .nemo-window .primary-toolbar spinbutton:not(.vertical) button, headerbar spinbutton:not(.vertical) button {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar spinbutton:not(.vertical) button:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar spinbutton:not(.vertical) button:hover, .nemo-window .primary-toolbar spinbutton:not(.vertical) button:hover, headerbar spinbutton:not(.vertical) button:hover {
  background-color: rgba(255, 255, 255, 0.9);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar spinbutton:not(.vertical) button:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar spinbutton:not(.vertical) button:active, .nemo-window .primary-toolbar spinbutton:not(.vertical) button:active, headerbar spinbutton:not(.vertical) button:active, .caja-navigation-window toolbar#Toolbar.primary-toolbar spinbutton:not(.vertical) button:checked, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar spinbutton:not(.vertical) button:checked, .nemo-window .primary-toolbar spinbutton:not(.vertical) button:checked, headerbar spinbutton:not(.vertical) button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar spinbutton:not(.vertical) button:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar spinbutton:not(.vertical) button:disabled, .nemo-window .primary-toolbar spinbutton:not(.vertical) button:disabled, headerbar spinbutton:not(.vertical) button:disabled {
  color: rgba(82, 93, 118, 0.2);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox:disabled, .nemo-window .primary-toolbar combobox:disabled, headerbar combobox:disabled {
  color: rgba(82, 93, 118, 0.2);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > button.combo, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > button.combo, .nemo-window .primary-toolbar combobox > .linked > button.combo, headerbar combobox > .linked > button.combo {
  color: rgba(82, 93, 118, 0.8);
  outline-offset: -3px;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > button.combo:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > button.combo:hover, .nemo-window .primary-toolbar combobox > .linked > button.combo:hover, headerbar combobox > .linked > button.combo:hover {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
  box-shadow: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > button.combo:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > button.combo:disabled, .nemo-window .primary-toolbar combobox > .linked > button.combo:disabled, headerbar combobox > .linked > button.combo:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > button.combo:disabled label, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > button.combo:disabled label, .nemo-window .primary-toolbar combobox > .linked > button.combo:disabled label, headerbar combobox > .linked > button.combo:disabled label, .caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > button.combo:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > button.combo:disabled, .nemo-window .primary-toolbar combobox > .linked > button.combo:disabled, headerbar combobox > .linked > button.combo:disabled {
  color: rgba(82, 93, 118, 0.3);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > entry.combo:dir(ltr), .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > entry.combo:dir(ltr), .nemo-window .primary-toolbar combobox > .linked > entry.combo:dir(ltr), headerbar combobox > .linked > entry.combo:dir(ltr) {
  border-right-style: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > entry.combo:dir(ltr):focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > entry.combo:dir(ltr):focus, .nemo-window .primary-toolbar combobox > .linked > entry.combo:dir(ltr):focus, headerbar combobox > .linked > entry.combo:dir(ltr):focus {
  box-shadow: 1px 0 #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > entry.combo:dir(rtl), .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > entry.combo:dir(rtl), .nemo-window .primary-toolbar combobox > .linked > entry.combo:dir(rtl), headerbar combobox > .linked > entry.combo:dir(rtl) {
  border-left-style: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar combobox > .linked > entry.combo:dir(rtl):focus, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar combobox > .linked > entry.combo:dir(rtl):focus, .nemo-window .primary-toolbar combobox > .linked > entry.combo:dir(rtl):focus, headerbar combobox > .linked > entry.combo:dir(rtl):focus {
  box-shadow: -1px 0 #5294e2;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar switch:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar switch:backdrop, .nemo-window .primary-toolbar switch:backdrop, headerbar switch:backdrop {
  opacity: 0.75;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar progressbar trough, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar progressbar trough, .nemo-window .primary-toolbar progressbar trough, headerbar progressbar trough {
  background-color: #e6e6e6;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar progressbar:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar progressbar:backdrop, .nemo-window .primary-toolbar progressbar:backdrop, headerbar progressbar:backdrop {
  opacity: 0.75;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale:backdrop, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale:backdrop, .nemo-window .primary-toolbar scale:backdrop, headerbar scale:backdrop {
  opacity: 0.75;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale slider, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale slider, .nemo-window .primary-toolbar scale slider, headerbar scale slider {
  background-color: white;
  border-color: rgba(82, 93, 118, 0.5);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale slider:hover, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale slider:hover, .nemo-window .primary-toolbar scale slider:hover, headerbar scale slider:hover {
  background-color: white;
  border-color: rgba(82, 93, 118, 0.5);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale slider:active, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale slider:active, .nemo-window .primary-toolbar scale slider:active, headerbar scale slider:active {
  background-color: #5294e2;
  border-color: #2679db;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale slider:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale slider:disabled, .nemo-window .primary-toolbar scale slider:disabled, headerbar scale slider:disabled {
  background-color: white;
  border-color: rgba(82, 93, 118, 0.5);
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale trough, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale trough, .nemo-window .primary-toolbar scale trough, headerbar scale trough {
  background-color: #e6e6e6;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar scale trough:disabled, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar scale trough:disabled, .nemo-window .primary-toolbar scale trough:disabled, headerbar scale trough:disabled {
  background-color: rgba(230, 230, 230, 0.95);
}

.path-bar button:hover {
  background-color: rgba(92, 97, 108, 0.06);
}

.path-bar button:checked, .path-bar button:active {
  background-color: #5294e2;
  border-color: #5294e2;
}

.path-bar button:checked:hover, .path-bar button:active:hover {
  background-color: #68a2e6;
  border-color: #68a2e6;
}

.path-bar button.text-button, .path-bar button.image-button, .path-bar button {
  padding-left: 6px;
  padding-right: 6px;
}

.path-bar button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child {
  padding-right: 10px;
}

.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child {
  padding-left: 10px;
}

.path-bar button.slider-button, .path-bar button:not(.image-button):not(.text-button) {
  padding-left: 1px;
  padding-right: 1px;
}

.path-bar button image {
  padding-left: 4px;
  padding-right: 4px;
}

treeview.view {
  border-left-color: rgba(92, 97, 108, 0.15);
  border-top-color: rgba(0, 0, 0, 0.1);
}

* {
  -GtkTreeView-horizontal-separator: 4;
  -GtkTreeView-grid-line-width: 1;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
}

treeview.view acceleditor > label {
  background-color: #5294e2;
}

treeview.view:selected, treeview.view:selected:focus {
  border-radius: 0;
  border-left-color: #a9caf1;
  border-top-color: rgba(92, 97, 108, 0.1);
}

treeview.view:disabled {
  color: rgba(92, 97, 108, 0.55);
}

treeview.view:disabled:selected {
  color: #97bfee;
}

treeview.view.separator {
  min-height: 2px;
  color: rgba(0, 0, 0, 0.1);
}

treeview.view:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #577ba7;
}

treeview.view.after:drop(active) {
  border-top-style: none;
}

treeview.view.before:drop(active) {
  border-bottom-style: none;
}

treeview.view.expander {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  color: #aeb0b6;
}

treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

treeview.view.expander:hover {
  color: #5c616c;
}

treeview.view.expander:selected {
  color: #cbdff6;
}

treeview.view.expander:selected:hover {
  color: #ffffff;
}

treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

treeview.view.progressbar, treeview.view.progressbar:focus {
  color: #ffffff;
  border-radius: 3px;
  background-color: #5294e2;
}

treeview.view.progressbar:selected, treeview.view.progressbar:selected:focus, treeview.view.progressbar:focus:selected, treeview.view.progressbar:focus:selected:focus {
  color: #5294e2;
  box-shadow: none;
  background-color: #ffffff;
}

treeview.view.trough {
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  border-width: 0;
}

treeview.view.trough:selected, treeview.view.trough:selected:focus {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  border-width: 0;
}

treeview.view header button {
  min-height: 0;
  min-width: 0;
  padding: 3px 6px;
  font-weight: bold;
  color: #7d8189;
  background-color: #ffffff;
  background-image: none;
  border-style: none solid none none;
  border-radius: 0;
  border-image: linear-gradient(to bottom, #ffffff 20%, rgba(0, 0, 0, 0.11) 20%, rgba(0, 0, 0, 0.11) 80%, #ffffff 80%) 0 1 0 0/0 1px 0 0 stretch;
}

treeview.view header button:hover {
  color: #5294e2;
}

treeview.view header button:active {
  color: #5c616c;
}

treeview.view header button:active, treeview.view header button:hover {
  background-color: #ffffff;
}

treeview.view header button:active:hover {
  color: #5c616c;
}

treeview.view header button:disabled {
  border-color: #fafbfc;
  background-image: none;
}

treeview.view header button:last-child {
  border-right-style: none;
  border-image: none;
}

treeview.view button.dnd, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd:active,
treeview.view header.button.dnd,
treeview.view header.button.dnd:selected,
treeview.view header.button.dnd:hover,
treeview.view header.button.dnd:active {
  padding: 0 6px;
  transition: none;
  color: #ffffff;
  background-color: #5294e2;
  border-radius: 0;
  border-style: none;
}

menubar,
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 0 0 0 0;
  background-color: white;
  color: rgba(82, 93, 118, 0.8);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

menubar:backdrop,
.menubar:backdrop {
  color: rgba(82, 93, 118, 0.5);
}

menubar > menuitem,
.menubar > menuitem {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
  padding: 4px 8px;
  border: 1px solid transparent;
  border-radius: 0;
}

menubar > menuitem:hover,
.menubar > menuitem:hover {
  background-color: #5294e2;
  box-shadow: none;
  border-color: #2679db;
  color: #ffffff;
}

menubar > menuitem:disabled,
.menubar > menuitem:disabled {
  color: rgba(82, 93, 118, 0.45);
}

menubar > menuitem label:disabled,
.menubar > menuitem label:disabled {
  color: rgba(82, 93, 118, 0.45);
}

menu,
.menu,
.context-menu,
popover.touch-selection,
.csd popover.touch-selection,
popover.background.touch-selection,
.csd popover.background.touch-selection {
  padding: 4px 0;
  border-radius: 0;
  transition: none;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.csd menu, .csd .menu, .csd .context-menu, .csd popover.touch-selection,
.csd popover.background.touch-selection {
  border: none;
}

menu separator, .csd menu separator,
.menu separator, .csd .menu separator,
.context-menu separator,
popover.touch-selection separator,
.csd popover.touch-selection separator,
popover.background.touch-selection separator, .csd .context-menu separator {
  margin: 4px 0;
  background-color: #ffffff;
}

menu menuitem,
.menu menuitem,
.context-menu menuitem,
popover.touch-selection menuitem,
.csd popover.touch-selection menuitem,
popover.background.touch-selection menuitem {
  min-height: 16px;
  min-width: 38px;
  padding: 4px 8px;
  text-shadow: none;
  transition: background-color 20ms ease-out;
}

menu menuitem:hover,
.menu menuitem:hover,
.context-menu menuitem:hover,
popover.touch-selection menuitem:hover {
  transition: none;
  color: #ffffff;
  background-color: #5294e2;
}

menu menuitem:disabled,
.menu menuitem:disabled,
.context-menu menuitem:disabled,
popover.touch-selection menuitem:disabled {
  color: rgba(92, 97, 108, 0.55);
}

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr),
.menu menuitem label:dir(rtl),
.menu menuitem label:dir(ltr),
.context-menu menuitem label:dir(rtl),
popover.touch-selection menuitem label:dir(rtl),
.context-menu menuitem label:dir(ltr),
popover.touch-selection menuitem label:dir(ltr) {
  color: inherit;
}

menu menuitem arrow,
.menu menuitem arrow,
.context-menu menuitem arrow,
popover.touch-selection menuitem arrow,
.csd popover.touch-selection menuitem arrow,
popover.background.touch-selection menuitem arrow {
  min-height: 16px;
  min-width: 16px;
}

menu menuitem arrow:dir(ltr),
.menu menuitem arrow:dir(ltr),
.context-menu menuitem arrow:dir(ltr),
popover.touch-selection menuitem arrow:dir(ltr) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  margin-left: 8px;
}

menu menuitem arrow:dir(rtl),
.menu menuitem arrow:dir(rtl),
.context-menu menuitem arrow:dir(rtl),
popover.touch-selection menuitem arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
  margin-right: 8px;
}

menuitem accelerator {
  color: alpha(currentColor,0.55);
}

menuitem check, menuitem radio {
  min-height: 16px;
  min-width: 16px;
}

menuitem check:dir(ltr), menuitem radio:dir(ltr) {
  margin-right: 6px;
  margin-left: 2px;
}

menuitem check:dir(rtl), menuitem radio:dir(rtl) {
  margin-left: 6px;
  margin-right: 2px;
}

menu > arrow,
.menu > arrow,
.context-menu > arrow,
popover.touch-selection > arrow,
.csd popover.touch-selection > arrow,
popover.background.touch-selection > arrow {
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  background-color: #ffffff;
  border-radius: 0;
  transition: none;
}

menu > arrow.top,
.menu > arrow.top,
.context-menu > arrow.top,
popover.touch-selection > arrow.top,
.csd popover.touch-selection > arrow.top {
  margin-top: -4px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menu > arrow.bottom,
.menu > arrow.bottom,
.context-menu > arrow.bottom,
popover.touch-selection > arrow.bottom,
.csd popover.touch-selection > arrow.bottom {
  margin-top: 8px;
  margin-bottom: -12px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menu > arrow:hover,
.menu > arrow:hover,
.context-menu > arrow:hover,
popover.touch-selection > arrow:hover,
.csd popover.touch-selection > arrow:hover {
  background-color: #efeff0;
}

menu > arrow:disabled,
.menu > arrow:disabled,
.context-menu > arrow:disabled,
popover.touch-selection > arrow:disabled,
.csd popover.touch-selection > arrow:disabled {
  color: transparent;
  background-color: transparent;
  border-color: transparent;
}

popover,
popover.background {
  padding: 2px;
  background-clip: border-box;
  background-color: #ffffff;
}

popover, .csd popover, popover.menu,
popover.background, .csd popover.background,
popover.background.menu {
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: 0 2px 8px 0 rgba(0, 0, 0, 0.1);
}

popover separator,
popover.background separator {
  background-color: #ffffff;
}

popover label.separator,
popover.background label.separator {
  color: #5c616c;
}

popover > list,
popover > .view,
popover > toolbar,
popover > .inline-toolbar,
popover.background > list,
popover.background > .view,
popover.background > toolbar,
popover.background > .inline-toolbar {
  border-style: none;
  background-color: transparent;
}

popover button:not(.suggested-action):not(.destructive-action):hover,
popover.background button:not(.suggested-action):not(.destructive-action):hover {
  background-color: rgba(0, 0, 0, 0.05);
  color: #5c616c;
}

popover button:not(.suggested-action):not(.destructive-action):checked, popover button:not(.suggested-action):not(.destructive-action):active,
popover.background button:not(.suggested-action):not(.destructive-action):checked,
popover.background button:not(.suggested-action):not(.destructive-action):active {
  background-color: #5294e2;
  color: #ffffff;
}

cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none;
}

cursor-handle.top {
  -gtk-icon-source: -gtk-icontheme("selection-start-symbolic");
}

cursor-handle.bottom {
  -gtk-icon-source: -gtk-icontheme("selection-end-symbolic");
}

notebook {
  padding: 0;
}

notebook.frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > stack:not(:only-child) {
  background-color: #ffffff;
}

notebook > header {
  padding: 0;
  background-color: #fafbfc;
}

notebook > header.top {
  padding-bottom: 0;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.top > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-bottom: none;
}

notebook > header.top > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.top > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.top > tabs > tab:hover {
  box-shadow: inset 0 -1px alpha(#5294e2,0.6), 0 1px alpha(#5294e2,0.6);
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -1px #5294e2, 0 1px #5294e2;
}

notebook > header.bottom {
  padding-top: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.bottom > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-top: none;
}

notebook > header.bottom > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.bottom > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.bottom > tabs > tab:hover {
  box-shadow: inset 0 1px alpha(#5294e2,0.6), 0 -1px alpha(#5294e2,0.6);
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 1px #5294e2, 0 -1px #5294e2;
}

notebook > header.right {
  padding-left: 0;
  border-left: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.right > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-left: none;
}

notebook > header.right > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.right > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.right > tabs > tab:hover {
  box-shadow: inset 1px 0 alpha(#5294e2,0.6), -1px 0 alpha(#5294e2,0.6);
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 1px 0 #5294e2, -1px 0 #5294e2;
}

notebook > header.left {
  padding-right: 0;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

notebook > header.left > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-right: none;
}

notebook > header.left > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.left > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.left > tabs > tab:hover {
  box-shadow: inset -1px 0 alpha(#5294e2,0.6), 1px 0 alpha(#5294e2,0.6);
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -1px 0 #5294e2, 1px 0 #5294e2;
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.top > tabs > arrow.up:last-child, notebook > header.bottom > tabs > arrow.up:last-child {
  margin-left: 2px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.down:first-child, notebook > header.bottom > tabs > arrow.down:first-child {
  margin-right: 2px;
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header.left > tabs > arrow.up:last-child, notebook > header.right > tabs > arrow.up:last-child {
  margin-top: 2px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.down:first-child, notebook > header.right > tabs > arrow.down:first-child {
  margin-bottom: 2px;
}

notebook > header > tabs > arrow {
  color: rgba(92, 97, 108, 0.55);
}

notebook > header > tabs > arrow:hover {
  color: rgba(92, 97, 108, 0.75);
}

notebook > header > tabs > arrow:active {
  color: #5c616c;
}

notebook > header > tabs > arrow:disabled {
  color: rgba(92, 97, 108, 0.3);
}

notebook > header > tabs > tab {
  color: rgba(92, 97, 108, 0.55);
  background-color: rgba(250, 251, 252, 0);
}

notebook > header > tabs > tab:hover:not(:checked) {
  color: rgba(92, 97, 108, 0.75);
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab:checked {
  color: #5c616c;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab button.flat {
  border-radius: 100%;
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  margin: 4px 0;
  color: #93979e;
}

notebook > header > tabs > tab button.flat:hover {
  color: #ff4d4d;
  background-color: #eaeef2;
}

notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:active:hover {
  color: #5294e2;
  background-color: #e1e7ed;
}

scrollbar {
  background-color: rgba(0, 0, 0, 0.05);
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

* {
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
}

scrollbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar.left {
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.15);
}

scrollbar button {
  border: none;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-right-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-left-symbolic");
}

scrollbar slider {
  min-width: 6px;
  min-height: 6px;
  margin: -1px;
  border: 4px solid transparent;
  border-radius: 8px;
  background-clip: padding-box;
  background-color: #bbbdc2;
}

scrollbar slider:hover {
  background-color: #cbcdd1;
}

scrollbar slider:hover:active {
  background-color: #5294e2;
}

scrollbar slider:disabled {
  background-color: transparent;
}

scrollbar.fine-tune slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar.fine-tune.horizontal slider {
  border-width: 5px 4px;
}

scrollbar.fine-tune.vertical slider {
  border-width: 4px 5px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  opacity: 0.4;
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  margin: 0;
  min-width: 4px;
  min-height: 4px;
  background-color: #8b8f97;
  border: 1px solid rgba(255, 255, 255, 0.6);
}

scrollbar.overlay-indicator.horizontal:not(.dragging):not(.hovering) slider {
  margin: 0 2px;
  min-width: 38px;
}

scrollbar.overlay-indicator.vertical:not(.dragging):not(.hovering) slider {
  margin: 2px 0;
  min-height: 38px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  opacity: 0.99;
}

scrollbar.horizontal slider {
  min-width: 38px;
}

scrollbar.vertical slider {
  min-height: 38px;
}

switch {
  font-size: 0;
  min-width: 50px;
  min-height: 20px;
  background-size: 50px 20px;
  background-repeat: no-repeat;
  background-position: center center;
  transition: all 350ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

switch slider {
  min-width: 0;
  min-height: 0;
}

switch, switch slider {
  outline-color: transparent;
  color: transparent;
  border: none;
  box-shadow: none;
}

switch {
  background-image: -gtk-scaled(url("assets/switch.png"), url("assets/switch@2.png"));
}

menuitem:hover switch,
row:selected switch,
infobar switch {
  background-image: -gtk-scaled(url("assets/switch-selected.png"), url("assets/switch-selected@2.png"));
}

switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active.png"), url("assets/switch-active@2.png"));
}

menuitem:hover switch:checked,
row:selected switch:checked,
infobar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-selected.png"), url("assets/switch-active-selected@2.png"));
}

switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive.png"), url("assets/switch-insensitive@2.png"));
}

menuitem:hover switch:disabled,
row:selected switch:disabled,
infobar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-selected.png"), url("assets/switch-insensitive-selected@2.png"));
}

switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive.png"), url("assets/switch-active-insensitive@2.png"));
}

menuitem:hover switch:checked:disabled,
row:selected switch:checked:disabled,
infobar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-selected.png"), url("assets/switch-active-insensitive-selected@2.png"));
}

.check,
check,
.view check:hover,
treeview.check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked.png"), url("assets/checkbox-unchecked@2.png"));
}

.view check:hover {
  background-color: transparent;
}

.osd check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.png"), url("assets/checkbox-unchecked-dark@2.png"));
}

menuitem check:hover,
.view check:selected,
treeview.check:selected,
row:selected check,
infobar check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-selected.png"), url("assets/checkbox-unchecked-selected@2.png"));
}

.check:disabled,
check:disabled,
.view check:disabled:hover,
treeview.check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive.png"), url("assets/checkbox-unchecked-insensitive@2.png"));
}

.view check:disabled:hover {
  background-color: transparent;
}

.osd check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.png"), url("assets/checkbox-unchecked-insensitive-dark@2.png"));
}

menuitem check:disabled:hover,
.view check:disabled:selected,
treeview.check:disabled:selected,
row:selected check:disabled,
infobar check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-selected.png"), url("assets/checkbox-unchecked-insensitive-selected@2.png"));
}

.check:indeterminate,
check:indeterminate,
.view check:indeterminate:hover,
treeview.check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed.png"), url("assets/checkbox-mixed@2.png"));
}

.view check:indeterminate:hover {
  background-color: transparent;
}

.osd check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.png"), url("assets/checkbox-mixed-dark@2.png"));
}

menuitem check:indeterminate:hover,
.view check:indeterminate:selected,
treeview.check:indeterminate:selected,
row:selected check:indeterminate,
infobar check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-selected.png"), url("assets/checkbox-mixed-selected@2.png"));
}

.check:indeterminate:disabled,
check:indeterminate:disabled,
.view check:indeterminate:disabled:hover,
treeview.check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive.png"), url("assets/checkbox-mixed-insensitive@2.png"));
}

.view check:indeterminate:disabled:hover {
  background-color: transparent;
}

.osd check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.png"), url("assets/checkbox-mixed-insensitive-dark@2.png"));
}

menuitem check:indeterminate:disabled:hover,
.view check:indeterminate:disabled:selected,
treeview.check:indeterminate:disabled:selected,
row:selected check:indeterminate:disabled,
infobar check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-selected.png"), url("assets/checkbox-mixed-insensitive-selected@2.png"));
}

.check:checked,
check:checked,
.view check:checked:hover,
treeview.check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked.png"), url("assets/checkbox-checked@2.png"));
}

.view check:checked:hover {
  background-color: transparent;
}

.osd check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.png"), url("assets/checkbox-checked-dark@2.png"));
}

menuitem check:checked:hover,
.view check:checked:selected,
treeview.check:checked:selected,
row:selected check:checked,
infobar check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selected.png"), url("assets/checkbox-checked-selected@2.png"));
}

.check:checked:disabled,
check:checked:disabled,
.view check:checked:disabled:hover,
treeview.check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive.png"), url("assets/checkbox-checked-insensitive@2.png"));
}

.view check:checked:disabled:hover {
  background-color: transparent;
}

.osd check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.png"), url("assets/checkbox-checked-insensitive-dark@2.png"));
}

menuitem check:checked:disabled:hover,
.view check:checked:disabled:selected,
treeview.check:checked:disabled:selected,
row:selected check:checked:disabled,
infobar check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-selected.png"), url("assets/checkbox-checked-insensitive-selected@2.png"));
}

.radio,
radio,
.view radio:hover,
treeview.radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked.png"), url("assets/radio-unchecked@2.png"));
}

.view radio:hover {
  background-color: transparent;
}

.osd radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-dark.png"), url("assets/radio-unchecked-dark@2.png"));
}

menuitem radio:hover,
.view radio:selected,
treeview.radio:selected,
row:selected radio,
infobar radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-selected.png"), url("assets/radio-unchecked-selected@2.png"));
}

.radio:disabled,
radio:disabled,
.view radio:disabled:hover,
treeview.radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive.png"), url("assets/radio-unchecked-insensitive@2.png"));
}

.view radio:disabled:hover {
  background-color: transparent;
}

.osd radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-dark.png"), url("assets/radio-unchecked-insensitive-dark@2.png"));
}

menuitem radio:disabled:hover,
.view radio:disabled:selected,
treeview.radio:disabled:selected,
row:selected radio:disabled,
infobar radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-selected.png"), url("assets/radio-unchecked-insensitive-selected@2.png"));
}

.radio:indeterminate,
radio:indeterminate,
.view radio:indeterminate:hover,
treeview.radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed.png"), url("assets/radio-mixed@2.png"));
}

.view radio:indeterminate:hover {
  background-color: transparent;
}

.osd radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.png"), url("assets/radio-mixed-dark@2.png"));
}

menuitem radio:indeterminate:hover,
.view radio:indeterminate:selected,
treeview.radio:indeterminate:selected,
row:selected radio:indeterminate,
infobar radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-selected.png"), url("assets/radio-mixed-selected@2.png"));
}

.radio:indeterminate:disabled,
radio:indeterminate:disabled,
.view radio:indeterminate:disabled:hover,
treeview.radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive.png"), url("assets/radio-mixed-insensitive@2.png"));
}

.view radio:indeterminate:disabled:hover {
  background-color: transparent;
}

.osd radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.png"), url("assets/radio-mixed-insensitive-dark@2.png"));
}

menuitem radio:indeterminate:disabled:hover,
.view radio:indeterminate:disabled:selected,
treeview.radio:indeterminate:disabled:selected,
row:selected radio:indeterminate:disabled,
infobar radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-selected.png"), url("assets/radio-mixed-insensitive-selected@2.png"));
}

.radio:checked,
radio:checked,
.view radio:checked:hover,
treeview.radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked.png"), url("assets/radio-checked@2.png"));
}

.view radio:checked:hover {
  background-color: transparent;
}

.osd radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-dark.png"), url("assets/radio-checked-dark@2.png"));
}

menuitem radio:checked:hover,
.view radio:checked:selected,
treeview.radio:checked:selected,
row:selected radio:checked,
infobar radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-selected.png"), url("assets/radio-checked-selected@2.png"));
}

.radio:checked:disabled,
radio:checked:disabled,
.view radio:checked:disabled:hover,
treeview.radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive.png"), url("assets/radio-checked-insensitive@2.png"));
}

.view radio:checked:disabled:hover {
  background-color: transparent;
}

.osd radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-dark.png"), url("assets/radio-checked-insensitive-dark@2.png"));
}

menuitem radio:checked:disabled:hover,
.view radio:checked:disabled:selected,
treeview.radio:checked:disabled:selected,
row:selected radio:checked:disabled,
infobar radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-selected.png"), url("assets/radio-checked-insensitive-selected@2.png"));
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  min-height: 40px;
  min-width: 40px;
  margin: 0;
  padding: 0;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png"));
  background-color: transparent;
}

.view.content-view.check:checked:not(list),
.content-view .tile check:checked:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png"));
  background-color: transparent;
}

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0;
}

checkbutton.text-button:hover, radiobutton.text-button:hover {
  color: #393c43;
}

checkbutton.text-button:disabled, radiobutton.text-button:disabled {
  color: rgba(92, 97, 108, 0.55);
}

checkbutton label:not(:only-child):first-child, radiobutton label:not(:only-child):first-child {
  margin-left: 4px;
}

checkbutton label:not(:only-child):last-child, radiobutton label:not(:only-child):last-child {
  margin-right: 4px;
}

check,
radio {
  min-width: 16px;
  min-height: 16px;
  margin: 0 2px;
}

check:only-child, menu menuitem check,
radio:only-child, menu menuitem radio {
  margin: 0;
}

scale {
  min-height: 15px;
  min-width: 15px;
  padding: 3px;
}

scale.horizontal trough {
  padding: 0 4px;
}

scale.horizontal highlight, scale.horizontal fill {
  margin: 0 -4px;
}

scale.vertical trough {
  padding: 4px 0;
}

scale.vertical highlight, scale.vertical fill {
  margin: -4px 0;
}

scale slider {
  min-height: 15px;
  min-width: 15px;
  margin: -6px;
}

scale.fine-tune slider {
  margin: -4px;
}

scale.fine-tune fill,
scale.fine-tune highlight,
scale.fine-tune trough {
  border-radius: 5px;
  -gtk-outline-radius: 7px;
}

scale trough {
  outline-offset: 2px;
  -gtk-outline-radius: 4.5px;
  border-radius: 2.5px;
  background-color: rgba(0, 0, 0, 0.15);
}

scale trough:disabled {
  background-color: rgba(0, 0, 0, 0.045);
}

.osd scale trough {
  background-color: #383a47;
}

.osd scale trough highlight {
  background-color: #5294e2;
}

row:selected scale trough, infobar scale trough {
  background-color: rgba(0, 0, 0, 0.2);
}

row:selected scale trough highlight, infobar scale trough highlight {
  background-color: #ffffff;
}

row:selected scale trough highlight:disabled, infobar scale trough highlight:disabled {
  background-color: #b1cff2;
}

row:selected scale trough:disabled, infobar scale trough:disabled {
  background-color: rgba(0, 0, 0, 0.1);
}

scale highlight {
  border-radius: 2.5px;
  background-color: #5294e2;
}

scale highlight:disabled {
  background-color: rgba(82, 148, 226, 0.55);
}

scale fill {
  border-radius: 2.5px;
  background-color: rgba(82, 148, 226, 0.5);
}

scale fill:disabled {
  background-color: transparent;
}

scale slider {
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 100%;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background, border;
}

scale slider:hover {
  background-clip: border-box;
  background-color: #5f9ce4;
  border-color: #2679db;
}

scale slider:active {
  background-clip: border-box;
  background-color: #458ce0;
  border-color: #2679db;
}

scale slider:disabled {
  background-color: #e6e6e6;
  border-color: rgba(0, 0, 0, 0.15);
}

row:selected scale slider, infobar scale slider {
  background-clip: border-box;
  background-color: #ffffff;
  border-color: #ffffff;
}

row:selected scale slider:hover, infobar scale slider:hover {
  background-color: #e5effb;
  border-color: #e5effb;
}

row:selected scale slider:active, infobar scale slider:active {
  background-color: #a9caf1;
  border-color: #a9caf1;
}

row:selected scale slider:disabled, infobar scale slider:disabled {
  background-color: #b1cff2;
  border-color: #b1cff2;
}

.osd scale slider {
  background-clip: border-box;
  background-color: #5294e2;
  border-color: #5294e2;
}

.osd scale slider:hover {
  background-color: #7eafe9;
  border-color: #7eafe9;
}

.osd scale slider:active {
  background-color: #68a2e6;
  border-color: #68a2e6;
}

scale value {
  color: alpha(currentColor,0.4);
}

scale marks {
  color: alpha(currentColor,0.4);
}

scale marks.top {
  margin-bottom: 1px;
  margin-top: -4px;
}

scale marks.bottom {
  margin-top: 1px;
  margin-bottom: -4px;
}

scale marks.top {
  margin-right: 1px;
  margin-left: -4px;
}

scale marks.bottom {
  margin-left: 1px;
  margin-right: -4px;
}

scale.fine-tune marks.top {
  margin-bottom: 0px;
  margin-top: -2px;
}

scale.fine-tune marks.bottom {
  margin-top: 0px;
  margin-bottom: -2px;
}

scale.fine-tune marks.top {
  margin-right: 0px;
  margin-left: -2px;
}

scale.fine-tune marks.bottom {
  margin-left: 0px;
  margin-right: -2px;
}

scale.horizontal indicator {
  min-height: 3px;
  min-width: 1px;
}

scale.horizontal.fine-tune indicator {
  min-height: 2px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 3px;
}

scale.vertical.fine-tune indicator {
  min-width: 2px;
}

progressbar {
  padding: 0;
  font-size: smaller;
  color: rgba(92, 97, 108, 0.7);
}

progressbar.osd {
  min-width: 3px;
  min-height: 3px;
  background-color: transparent;
}

progressbar.osd trough {
  border-style: none;
  background-color: transparent;
  box-shadow: none;
}

progressbar progress {
  background-color: #5294e2;
  border: none;
  border-radius: 3px;
  box-shadow: none;
}

row:selected progressbar progress, infobar progressbar progress {
  background-color: #ffffff;
}

progressbar trough {
  border: none;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.15);
}

row:selected progressbar trough, infobar progressbar trough {
  background-color: rgba(0, 0, 0, 0.2);
}

levelbar block {
  min-width: 32px;
  min-height: 1px;
}

levelbar.vertical block {
  min-width: 1px;
  min-height: 32px;
}

levelbar trough {
  border: none;
  padding: 3px;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.15);
}

levelbar.horizontal.discrete block {
  margin: 0 1px;
}

levelbar.vertical.discrete block {
  margin: 1px 0;
}

levelbar block:not(.empty) {
  border: 1px solid #5294e2;
  background-color: #5294e2;
  border-radius: 2px;
}

levelbar block.low {
  border-color: #F27835;
  background-color: #F27835;
}

levelbar block.high {
  border-color: #5294e2;
  background-color: #5294e2;
}

levelbar block.full {
  border-color: #73d216;
  background-color: #73d216;
}

levelbar block.empty {
  background-color: rgba(92, 97, 108, 0.2);
  border-color: rgba(92, 97, 108, 0.2);
}

printdialog paper {
  border: 1px solid rgba(0, 0, 0, 0.15);
  background: #ffffff;
  padding: 0;
}

printdialog .dialog-action-box {
  margin: 12px;
}

frame > border,
.frame {
  margin: 0;
  padding: 0;
  border-radius: 0;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

frame.flat > border,
frame > border.flat,
.frame.flat {
  border-style: none;
}

scrolledwindow viewport.frame {
  border-style: none;
}

scrolledwindow overshoot.top {
  background-image: -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(82, 148, 226, 0.2)), to(rgba(82, 148, 226, 0)));
  background-size: 100% 60%;
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.bottom {
  background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(82, 148, 226, 0.2)), to(rgba(82, 148, 226, 0)));
  background-size: 100% 60%;
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.left {
  background-image: -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(82, 148, 226, 0.2)), to(rgba(82, 148, 226, 0)));
  background-size: 60% 100%;
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.right {
  background-image: -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(82, 148, 226, 0.2)), to(rgba(82, 148, 226, 0)));
  background-size: 60% 100%;
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.top {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-top: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center top;
  border: none;
}

scrolledwindow undershoot.bottom {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-bottom: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center bottom;
  border: none;
}

scrolledwindow undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center;
  border: none;
}

scrolledwindow undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center;
  border: none;
}

scrolledwindow junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.15) 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: rgba(0, 0, 0, 0.05);
}

scrolledwindow junction:dir(rtl) {
  border-image-slice: 0 1 0 0;
}

separator {
  background-color: rgba(0, 0, 0, 0.15);
  min-width: 1px;
  min-height: 1px;
}

list {
  background-color: #ffffff;
  border-color: rgba(0, 0, 0, 0.15);
}

list row {
  padding: 2px;
}

window.thunar .sidebar treeview.has-open-popup.view, .budgie-menu button.has-open-popup, .nemo-window .nemo-places-sidebar .has-open-popup.places-treeview, .has-open-popup.view,
window.thunar notebook scrolledwindow.frame.standard-view .has-open-popup.view,
textview text.has-open-popup,
iconview.has-open-popup, window.thunar .sidebar treeview.view:hover, .budgie-menu button:hover, .nemo-window .nemo-places-sidebar .places-treeview:hover, .view:hover,
window.thunar notebook scrolledwindow.frame.standard-view .view:hover,
textview text:hover,
iconview:hover, row.activatable.has-open-popup, row.activatable:hover {
  transition: none;
  animation: none;
  background-color: rgba(0, 0, 0, 0.05);
}

window.thunar .sidebar treeview.view:active, .budgie-menu button:active, .nemo-window .nemo-places-sidebar .places-treeview:active, .view:active,
window.thunar notebook scrolledwindow.frame.standard-view .view:active,
textview text:active,
iconview:active, window.thunar .sidebar treeview.view:checked, .budgie-menu button:checked, .nemo-window .nemo-places-sidebar .places-treeview:checked, .view:checked,
window.thunar notebook scrolledwindow.frame.standard-view .view:checked,
textview text:checked,
iconview:checked, row.activatable:active, row.activatable:checked {
  transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

window.thunar .sidebar treeview.view:disabled, .budgie-menu button:disabled, .nemo-window .nemo-places-sidebar .places-treeview:disabled, .view:disabled,
window.thunar notebook scrolledwindow.frame.standard-view .view:disabled,
textview text:disabled,
iconview:disabled, row.activatable:disabled {
  color: rgba(92, 97, 108, 0.55);
}

window.thunar .sidebar treeview.view:disabled image, .budgie-menu button:disabled image, .nemo-window .nemo-places-sidebar .places-treeview:disabled image, .view:disabled image,
window.thunar notebook scrolledwindow.frame.standard-view .view:disabled image,
textview text:disabled image,
iconview:disabled image, row.activatable:disabled image {
  color: inherit;
}

.app-notification {
  padding: 10px;
  color: #D3DAE3;
  background-color: alpha(#282A33,0.9);
  background-clip: border-box;
  border-radius: 0 0 2px 2px;
  border-width: 0 1px 1px 1px;
  border-style: solid;
  border-color: rgba(98, 103, 125, 0.55);
}

.app-notification border {
  border: none;
}

.app-notification button {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.4);
}

.app-notification button.flat {
  border-color: rgba(82, 148, 226, 0);
}

.app-notification button:hover {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

.app-notification button:active, .app-notification button:checked {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
  background-clip: padding-box;
}

.app-notification button:disabled {
  color: #5b5f68;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

expander arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander arrow:hover {
  color: #aaaeb7;
}

expander arrow:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

calendar {
  color: #5c616c;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
  padding: 2px 7px;
}

calendar:selected {
  border-radius: 6px;
}

calendar.header {
  color: #5c616c;
  border: none;
}

calendar.button {
  color: rgba(92, 97, 108, 0.45);
}

calendar.button:hover {
  color: #5c616c;
}

calendar.button:disabled {
  color: rgba(92, 97, 108, 0.55);
}

calendar:indeterminate {
  color: alpha(currentColor,0.55);
}

calendar.highlight {
  color: #5c616c;
}

messagedialog .linked:not(.vertical) > button,
messagedialog .linked:not(.vertical) > button:hover,
messagedialog .linked:not(.vertical) > button:active,
messagedialog .linked:not(.vertical) > button:checked,
messagedialog .linked:not(.vertical) > button:disabled {
  border-radius: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  border-right: none;
  border-bottom: none;
}

messagedialog .linked:not(.vertical) > button:last-child {
  border-bottom-right-radius: 2px;
  border-top-right-radius: 0;
  border-right: none;
  border-bottom: none;
}

messagedialog .linked:not(.vertical) > button:first-child {
  border-bottom-left-radius: 2px;
  border-top-left-radius: 0;
  border-left: none;
  border-bottom: none;
}

messagedialog .linked:not(.vertical) > button:only-child {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-left: none;
  border-right: none;
  border-bottom: none;
}

messagedialog.background {
  background-color: #ffffff;
  color: rgba(82, 93, 118, 0.8);
}

messagedialog .titlebar {
  min-height: 20px;
  background-color: #ffffff;
  border-bottom: none;
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.13);
}

messagedialog .titlebar:backdrop {
  background-color: #ffffff;
}

messagedialog .dialog-action-area button {
  padding: 6px 10px 8px 10px;
  border-radius: 0;
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
  color: rgba(82, 93, 118, 0.8);
}

messagedialog .dialog-action-area button:active, messagedialog .dialog-action-area button:checked {
  transition: background-color 0.00001s 0.2s;
  animation: ripple_effect 0.2s cubic-bezier(0, 0, 0.2, 1);
}

messagedialog .dialog-action-area button:not(.suggested-action):not(.destructive-action):hover {
  background-color: rgba(82, 93, 118, 0.06);
}

messagedialog .dialog-action-area button:not(.suggested-action):not(.destructive-action):active, messagedialog .dialog-action-area button:not(.suggested-action):not(.destructive-action):checked {
  background-color: rgba(82, 93, 118, 0.1);
  color: rgba(82, 93, 118, 0.8);
}

messagedialog.csd.background {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border: none;
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  background-color: #fafbfc;
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

messagedialog.background:not(.csd) .dialog-vbox .dialog-action-box button {
  border-radius: 0;
}

.sidebar {
  border-style: none;
  background-color: #fafbfc;
}

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left {
  border-right: 1px solid #cad5df;
  border-left-style: none;
}

stacksidebar.sidebar:dir(rtl) list, stacksidebar.sidebar.right list, .sidebar:dir(rtl), .sidebar.right {
  border-left: 1px solid #cad5df;
  border-right-style: none;
}

.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

stacksidebar row {
  padding: 4px 4px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

stacksidebar row.needs-attention > label {
  background-size: 6px 6px, 0 0;
}

placessidebar > viewport.frame {
  border-style: none;
}

placessidebar row {
  min-height: 28px;
  padding: 2px;
  outline-offset: -3px;
}

placessidebar row > revealer {
  padding: 0 10px;
}

placessidebar row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

button.sidebar-button {
  min-width: 22px;
  min-height: 22px;
  margin-top: 2px;
  margin-bottom: 2px;
  padding: 0;
  border-radius: 100%;
  -gtk-outline-radius: 100%;
}

button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

placessidebar row.sidebar-placeholder-row {
  padding: 0 8px;
  min-height: 2px;
  background-image: linear-gradient(to bottom, #F08437, #F08437);
  background-clip: content-box;
}

placessidebar row.sidebar-new-bookmark-row {
  color: #5294e2;
}

placessidebar row:drop(active):not(:disabled) {
  box-shadow: inset 0 1px #F08437, inset 0 -1px #F08437;
}

placessidebar row:drop(active):not(:disabled), placessidebar row:drop(active):not(:disabled) label, placessidebar row:drop(active):not(:disabled) image {
  color: #F08437;
}

placessidebar row:drop(active):not(:disabled):selected {
  background-color: #F08437;
}

placessidebar row:drop(active):not(:disabled):selected, placessidebar row:drop(active):not(:disabled):selected label, placessidebar row:drop(active):not(:disabled):selected image {
  color: #ffffff;
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: linear-gradient(to bottom, #cad5df, #cad5df);
  background-size: 1px 1px;
}

paned > separator:selected {
  background-image: linear-gradient(to bottom, #5294e2, #5294e2);
}

paned > separator.wide {
  min-width: 5px;
  min-height: 5px;
  background-color: #fafbfc;
  background-image: linear-gradient(to bottom, #cad5df, #cad5df), linear-gradient(to bottom, #cad5df, #cad5df);
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

infobar {
  border-style: none;
  margin: 0;
  padding: 0;
}

infobar.info {
  background-color: #73d216;
}

infobar.question {
  background-color: #5294e2;
}

infobar.warning {
  background-color: #F27835;
}

infobar.error {
  background-color: #FC4138;
}

infobar.info, infobar.question, infobar.warning, infobar.error {
  color: #ffffff;
  caret-color: currentColor;
}

infobar.info selection, infobar.question selection, infobar.warning selection, infobar.error selection {
  color: #5294e2;
  background-color: #ffffff;
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button, .nemo-window .floating-bar button, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button, .nautilus-window .floating-bar button, row:selected button, infobar.info button, infobar.question button, infobar.warning button, infobar.error button {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.5);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button.flat, .nemo-window .floating-bar button.flat, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.flat.page-row-close-button, .nautilus-window .floating-bar button.flat, row:selected button.flat, infobar.info button.flat, infobar.question button.flat, infobar.warning button.flat, infobar.error button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button.flat:disabled, .nemo-window .floating-bar button.flat:disabled, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.flat.page-row-close-button:disabled, .nautilus-window .floating-bar button.flat:disabled, row:selected button.flat:disabled, infobar.info button.flat:disabled, infobar.question button.flat:disabled, infobar.warning button.flat:disabled, infobar.error button.flat:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button.flat:disabled label, .nemo-window .floating-bar button.flat:disabled label, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.flat.page-row-close-button:disabled label, .nautilus-window .floating-bar button.flat:disabled label, row:selected button.flat:disabled label, infobar.info button.flat:disabled label, infobar.question button.flat:disabled label, infobar.warning button.flat:disabled label, infobar.error button.flat:disabled label {
  color: rgba(255, 255, 255, 0.4);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:hover, .nemo-window .floating-bar button:hover, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:hover, .nautilus-window .floating-bar button:hover, row:selected button:hover, infobar.info button:hover, infobar.question button:hover, infobar.warning button:hover, infobar.error button:hover {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.65);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:active, .nemo-window .floating-bar button:active, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:active, .nautilus-window .floating-bar button:active, row:selected button:active, infobar.info button:active, infobar.question button:active, infobar.warning button:active, infobar.error button:active, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:checked, .nemo-window .floating-bar button:checked, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:checked, .nautilus-window .floating-bar button:checked, row:selected button:checked, infobar.info button:checked, infobar.question button:checked, infobar.warning button:checked, infobar.error button:checked {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.35);
  border-color: rgba(255, 255, 255, 0.65);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:disabled, .nemo-window .floating-bar button:disabled, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:disabled, .nautilus-window .floating-bar button:disabled, row:selected button:disabled, infobar.info button:disabled, infobar.question button:disabled, infobar.warning button:disabled, infobar.error button:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.4);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:disabled, .nemo-window .floating-bar button:disabled, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:disabled, .nautilus-window .floating-bar button:disabled, row:selected button:disabled, infobar.info button:disabled, infobar.question button:disabled, infobar.warning button:disabled, infobar.error button:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:disabled label, .nemo-window .floating-bar button:disabled label, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:disabled label, .nautilus-window .floating-bar button:disabled label, row:selected button:disabled label, infobar.info button:disabled label, infobar.question button:disabled label, infobar.warning button:disabled label, infobar.error button:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:disabled:active, .nemo-window .floating-bar button:disabled:active, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:disabled:active, .nautilus-window .floating-bar button:disabled:active, row:selected button:disabled:active, infobar.info button:disabled:active, infobar.question button:disabled:active, infobar.warning button:disabled:active, infobar.error button:disabled:active, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected button:disabled:checked, .nemo-window .floating-bar button:disabled:checked, popover.background > scrolledwindow > viewport.frame > list > row.activatable:selected button.page-row-close-button:disabled:checked, .nautilus-window .floating-bar button:disabled:checked, row:selected button:disabled:checked, infobar.info button:disabled:checked, infobar.question button:disabled:checked, infobar.warning button:disabled:checked, infobar.error button:disabled:checked {
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.4);
}

tooltip {
  border-radius: 2px;
  box-shadow: none;
}

tooltip.background {
  background-color: #3e4250;
  background-clip: padding-box;
}

tooltip.background label {
  padding: 4px;
}

tooltip decoration {
  background-color: transparent;
}

tooltip * {
  background-color: transparent;
  color: #D3DAE3;
}

colorswatch, colorswatch:drop(active) {
  border-style: none;
}

colorswatch.top {
  border-top-left-radius: 2.5px;
  border-top-right-radius: 2.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

colorswatch.bottom {
  border-bottom-left-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 2.5px;
  border-bottom-left-radius: 2.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.dark overlay {
  color: rgba(255, 255, 255, 0.7);
}

colorswatch.dark overlay:hover {
  border-color: rgba(0, 0, 0, 0.5);
}

colorswatch.light overlay {
  color: rgba(0, 0, 0, 0.7);
}

colorswatch.light overlay:hover {
  border-color: rgba(0, 0, 0, 0.3);
}

colorswatch overlay {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

colorswatch overlay:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  border-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

colorswatch#add-color-button {
  border-style: solid;
  border-width: 1px;
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

colorswatch#add-color-button:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

colorswatch#add-color-button overlay {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button.color {
  padding: 0;
}

button.color colorswatch:first-child:last-child, button.color colorswatch:first-child:last-child overlay {
  margin: 4px;
  border-radius: 0;
}

colorchooser .popover.osd {
  border-radius: 3px;
}

.content-view {
  background-color: #ffffff;
}

.content-view:hover {
  -gtk-icon-effect: highlight;
}

.scale-popup button:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

.context-menu, popover.touch-selection, .csd popover.touch-selection,
popover.background.touch-selection, .csd popover.background.touch-selection {
  font: initial;
}

.monospace {
  font-family: Monospace;
}

.keycap {
  min-width: 16px;
  min-height: 20px;
  padding: 3px 6px 4px 6px;
  color: #5c616c;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2.5px;
  box-shadow: inset 0px -2px 0px rgba(0, 0, 0, 0.05);
}

stackswitcher button.text-button {
  min-width: 80px;
}

stackswitcher button.circular {
  min-width: 0;
}

*:drop(active):focus,
*:drop(active) {
  box-shadow: inset 0 0 0 1px #F08437;
}

decoration {
  border-radius: 0;
  border: none;
  transition: 200ms ease-out;
  box-shadow: 0 3px 5px 0 rgba(0, 0, 0, 0.15), 0 8px 8px 0 rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.12);
  margin: 4px;
}

decoration:backdrop {
  box-shadow: 0 3px 5px 0 transparent, 0 8px 8px 0 transparent, 0 3px 3px 0 rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.12);
}

.maximized decoration, .fullscreen decoration, .tiled decoration {
  border-radius: 0;
  box-shadow: 0 3px 3px 0 rgba(0, 0, 0, 0.1);
}

.ssd decoration {
  border-radius: 0;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.15);
}

.popup decoration {
  border-radius: 0;
  box-shadow: none;
}

.csd.popup decoration {
  border-radius: 0;
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.12), 0 0 0 1px rgba(0, 0, 0, 0.15);
}

tooltip.csd decoration {
  border-radius: 2px;
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

messagedialog.csd decoration {
  border-radius: 3px;
}

.solid-csd decoration {
  border: 2px solid #32343D;
  border-radius: 0;
  margin: 0;
  background-color: #ffffff;
  box-shadow: none;
}

headerbar button.titlebutton, .titlebar button.titlebutton {
  margin: 0;
  padding: 0;
  min-width: 28px;
  min-height: 28px;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  background-color: rgba(255, 255, 255, 0);
}

headerbar button.titlebutton:hover, .titlebar button.titlebutton:hover {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
}

headerbar button.titlebutton:active, .titlebar button.titlebutton:active, headerbar button.titlebutton:checked, .titlebar button.titlebutton:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

headerbar button.titlebutton.close, .titlebar button.titlebutton.close, headerbar button.titlebutton.maximize, .titlebar button.titlebutton.maximize, headerbar button.titlebutton.minimize, .titlebar button.titlebutton.minimize, headerbar button.titlebutton.restore, .titlebar button.titlebutton.restore {
  padding: 0;
  min-width: 27px;
  min-height: 27px;
  color: transparent;
  background-color: transparent;
  background-position: center;
  background-repeat: no-repeat;
  border-width: 0;
  border-radius: 0;
}

headerbar button.titlebutton.close:backdrop, .titlebar button.titlebutton.close:backdrop, headerbar button.titlebutton.maximize:backdrop, .titlebar button.titlebutton.maximize:backdrop, headerbar button.titlebutton.minimize:backdrop, .titlebar button.titlebutton.minimize:backdrop, headerbar button.titlebutton.restore:backdrop, .titlebar button.titlebutton.restore:backdrop {
  opacity: 1;
}

headerbar button.titlebutton.close, .titlebar button.titlebutton.close {
  background-image: -gtk-scaled(url("assets/titlebutton-close.png"), url("assets/titlebutton-close@2.png"));
}

headerbar button.titlebutton.close:backdrop, .titlebar button.titlebutton.close:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-close-backdrop.png"), url("assets/titlebutton-close-backdrop@2.png"));
}

headerbar button.titlebutton.close:hover, .titlebar button.titlebutton.close:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-close-hover.png"), url("assets/titlebutton-close-hover@2.png"));
}

headerbar button.titlebutton.close:active, .titlebar button.titlebutton.close:active {
  background-image: -gtk-scaled(url("assets/titlebutton-close-active.png"), url("assets/titlebutton-close-active@2.png"));
}

headerbar button.titlebutton.maximize, .titlebar button.titlebutton.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize.png"), url("assets/titlebutton-maximize@2.png"));
}

headerbar button.titlebutton.maximize:backdrop, .titlebar button.titlebutton.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-backdrop.png"), url("assets/titlebutton-maximize-backdrop@2.png"));
}

headerbar button.titlebutton.maximize:hover, .titlebar button.titlebutton.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-hover.png"), url("assets/titlebutton-maximize-hover@2.png"));
}

headerbar button.titlebutton.maximize:active, .titlebar button.titlebutton.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-active.png"), url("assets/titlebutton-maximize-active@2.png"));
}

headerbar button.titlebutton.minimize, .titlebar button.titlebutton.minimize {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize.png"), url("assets/titlebutton-minimize@2.png"));
}

headerbar button.titlebutton.minimize:backdrop, .titlebar button.titlebutton.minimize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-backdrop.png"), url("assets/titlebutton-minimize-backdrop@2.png"));
}

headerbar button.titlebutton.minimize:hover, .titlebar button.titlebutton.minimize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-hover.png"), url("assets/titlebutton-minimize-hover@2.png"));
}

headerbar button.titlebutton.minimize:active, .titlebar button.titlebutton.minimize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-active.png"), url("assets/titlebutton-minimize-active@2.png"));
}

headerbar button.titlebutton.restore, .titlebar button.titlebutton.restore {
  background-image: -gtk-scaled(url("assets/titlebutton-restore.png"), url("assets/titlebutton-restore@2.png"));
}

headerbar button.titlebutton.restore:backdrop, .titlebar button.titlebutton.restore:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-backdrop.png"), url("assets/titlebutton-restore-backdrop@2.png"));
}

headerbar button.titlebutton.restore:hover, .titlebar button.titlebutton.restore:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-hover.png"), url("assets/titlebutton-restore-hover@2.png"));
}

headerbar button.titlebutton.restore:active, .titlebar button.titlebutton.restore:active {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-active.png"), url("assets/titlebutton-restore-active@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize, .fullscreen .titlebar button.titlebutton.maximize, .maximized headerbar button.titlebutton.maximize, .maximized .titlebar button.titlebutton.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-restore.png"), url("assets/titlebutton-restore@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize:backdrop, .fullscreen .titlebar button.titlebutton.maximize:backdrop, .maximized headerbar button.titlebutton.maximize:backdrop, .maximized .titlebar button.titlebutton.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-backdrop.png"), url("assets/titlebutton-restore-backdrop@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize:hover, .fullscreen .titlebar button.titlebutton.maximize:hover, .maximized headerbar button.titlebutton.maximize:hover, .maximized .titlebar button.titlebutton.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-hover.png"), url("assets/titlebutton-restore-hover@2.png"));
}

.fullscreen headerbar button.titlebutton.maximize:active, .fullscreen .titlebar button.titlebutton.maximize:active, .maximized headerbar button.titlebutton.maximize:active, .maximized .titlebar button.titlebutton.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-active.png"), url("assets/titlebutton-restore-active@2.png"));
}

.nemo-window .sidebar .view.cell:selected, .nemo-window .sidebar row.cell:selected, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row:selected, .polari-room-list .sidebar .activatable:selected, .polari-room-list .sidebar .inactive:selected, .polari-room-list .sidebar .room-list-header:selected, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar:selected, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar:selected, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view:selected, list.gedit-document-panel row.activatable:selected, treeview.view.sidebar.source-list:selected, .budgie-menu button:active, .budgie-menu button:checked, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active arrow, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked arrow, .budgie-popover row.activatable:selected, .atril-window scrolledwindow.frame > .view:selected, .atril-window scrolledwindow.frame > .view:active,
.xreader-window scrolledwindow.frame > .view:selected,
.xreader-window scrolledwindow.frame > .view:active, .caja-desktop > widget.entry:selected, .caja-desktop > widget.entry:focus:selected, #MozillaGtkWidget.background > widget > scrolledwindow > textview text:selected, #MozillaGtkWidget.background > widget > scrolledwindow > textview text:selected:focus,
#MozillaGtkWidget.background > widget > scrolledwindow > textview text selection, .nemo-window .nemo-window-pane widget.entry:selected:focus, .nemo-window .nemo-window-pane widget.entry:selected, .view:selected, .view:selected:focus,
window.thunar notebook scrolledwindow.frame.standard-view .view:selected,
textview text:selected,
textview text:selected:focus, textview text selection:focus, textview text selection,
iconview:selected,
iconview:selected:focus, flowbox flowboxchild:selected, entry selection:focus, entry selection, menuitem.button.flat:active, menuitem.button.flat:active arrow, menuitem.button.flat:selected, menuitem.button.flat:selected arrow,
modelbutton.flat:active,
modelbutton.flat:active arrow,
modelbutton.flat:selected,
modelbutton.flat:selected arrow, treeview.view:selected, treeview.view:selected:focus, row:selected, window.thunar .sidebar treeview.view:selected, .budgie-menu button:selected, .nemo-window .nemo-places-sidebar .places-treeview:selected, .budgie-menu button.has-open-popup:selected, .budgie-menu button:selected:hover, row.activatable:selected, row.activatable.has-open-popup:selected, row.activatable:selected:hover, calendar:selected {
  background-color: #5294e2;
}

row:selected label, label:selected, .nemo-window .sidebar .view.cell:selected, .nemo-window .sidebar row.cell:selected, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row:selected, .polari-room-list .sidebar .activatable:selected, .polari-room-list .sidebar .inactive:selected, .polari-room-list .sidebar .room-list-header:selected, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar:selected, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar:selected, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view:selected, list.gedit-document-panel row.activatable:selected, treeview.view.sidebar.source-list:selected, .budgie-menu button:active, .budgie-menu button:checked, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active arrow, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked arrow, .budgie-popover row.activatable:selected, .atril-window scrolledwindow.frame > .view:selected, .atril-window scrolledwindow.frame > .view:active,
.xreader-window scrolledwindow.frame > .view:selected,
.xreader-window scrolledwindow.frame > .view:active, .caja-desktop > widget.entry:selected, .caja-desktop > widget.entry:focus:selected, #MozillaGtkWidget.background > widget > scrolledwindow > textview text:selected, #MozillaGtkWidget.background > widget > scrolledwindow > textview text:selected:focus,
#MozillaGtkWidget.background > widget > scrolledwindow > textview text selection, .nemo-window .nemo-window-pane widget.entry:selected:focus, .nemo-window .nemo-window-pane widget.entry:selected, .view:selected, .view:selected:focus,
window.thunar notebook scrolledwindow.frame.standard-view .view:selected,
textview text:selected,
textview text:selected:focus, textview text selection:focus, textview text selection,
iconview:selected,
iconview:selected:focus, flowbox flowboxchild:selected, entry selection:focus, entry selection, menuitem.button.flat:active, menuitem.button.flat:active arrow, menuitem.button.flat:selected, menuitem.button.flat:selected arrow,
modelbutton.flat:active,
modelbutton.flat:active arrow,
modelbutton.flat:selected,
modelbutton.flat:selected arrow, treeview.view:selected, treeview.view:selected:focus, row:selected, window.thunar .sidebar treeview.view:selected, .budgie-menu button:selected, .nemo-window .nemo-places-sidebar .places-treeview:selected, .budgie-menu button.has-open-popup:selected, .budgie-menu button:selected:hover, row.activatable:selected, row.activatable.has-open-popup:selected, row.activatable:selected:hover, calendar:selected {
  color: #ffffff;
}

row:selected label:disabled, label:disabled:selected, .nemo-window .sidebar .view.cell:disabled:selected, .nemo-window .sidebar row.cell:disabled:selected, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row:disabled:selected, .polari-room-list .sidebar .activatable:disabled:selected, .polari-room-list .sidebar .inactive:disabled:selected, .polari-room-list .sidebar .room-list-header:disabled:selected, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:disabled:selected, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar:disabled:selected, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar:disabled:selected, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view:disabled:selected, list.gedit-document-panel row.activatable:disabled:selected, treeview.view.sidebar.source-list:disabled:selected, .budgie-menu button:disabled:active, .budgie-menu button:disabled:checked, .budgie-popover:not(.budgie-menu) button.flat:disabled:not(.image-button):active, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active arrow:disabled, .budgie-popover:not(.budgie-menu) button.flat:disabled:not(.image-button):checked, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked arrow:disabled, .budgie-popover row.activatable:disabled:selected, .atril-window scrolledwindow.frame > .view:disabled:selected, .atril-window scrolledwindow.frame > .view:disabled:active,
.xreader-window scrolledwindow.frame > .view:disabled:selected,
.xreader-window scrolledwindow.frame > .view:disabled:active, .caja-desktop > widget.entry:disabled:selected, #MozillaGtkWidget.background > widget > scrolledwindow > textview text:disabled:selected,
#MozillaGtkWidget.background > widget > scrolledwindow > textview text selection:disabled, .nemo-window .nemo-window-pane widget.entry:disabled:selected, .view:disabled:selected,
window.thunar notebook scrolledwindow.frame.standard-view .view:disabled:selected,
textview text:disabled:selected,
textview text:disabled:selected:focus, textview text selection:disabled,
iconview:disabled:selected,
iconview:disabled:selected:focus, flowbox flowboxchild:disabled:selected, entry selection:disabled, menuitem.button.flat:disabled:active, menuitem.button.flat:active arrow:disabled, menuitem.button.flat:disabled:selected, menuitem.button.flat:selected arrow:disabled,
modelbutton.flat:disabled:active,
modelbutton.flat:active arrow:disabled,
modelbutton.flat:disabled:selected,
modelbutton.flat:selected arrow:disabled, row:disabled:selected, window.thunar .sidebar treeview.view:disabled:selected, .budgie-menu button:disabled:selected, .nemo-window .nemo-places-sidebar .places-treeview:disabled:selected, calendar:disabled:selected {
  color: #a9caf1;
}

popover.emoji-picker {
  padding: 0;
}

popover.emoji-picker entry {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
  box-shadow: none;
  border-width: 0 0 1px 0;
  padding: 4px 12px;
  background: none;
}

popover.emoji-picker scrolledwindow {
  background-color: #ffffff;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

button.emoji-section {
  margin-top: -1px;
  padding: 4px 12px;
  border-radius: 0;
  outline-offset: -4px;
  box-shadow: none;
  border: none;
}

button.emoji-section:first-child {
  border-radius: 0 0 0 2px;
}

button.emoji-section:last-child {
  border-radius: 0 0 2px 0;
}

.emoji {
  min-width: 16px;
  min-height: 16px;
  padding: 2px 6px;
  margin: 2px;
}

.emoji widget {
  transition: all 50ms cubic-bezier(0, 0, 0.2, 1);
}

.emoji widget:hover {
  background-color: #5294e2;
  color: #ffffff;
  border-radius: 3px;
}

terminal-window notebook > header.top button,
.mate-terminal notebook > header.top button {
  padding: 0;
  min-width: 24px;
  min-height: 24px;
}

terminal-window notebook scrollbar,
.mate-terminal notebook scrollbar {
  background: none;
}

window.background > box.vertical > box.horizontal > frame > border {
  border-width: 0 1px 0 0;
}

window.background > box.vertical > box.horizontal > stack > widget > notebook.frame {
  border-width: 0 0 0 1px;
}

.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle,
.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.image-button.text-button.toggle {
  background: none;
  border: none;
  margin-top: 0;
  margin-bottom: 0;
  padding: 0 6px 2px 6px;
  border-radius: 0;
}

.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:hover {
  color: rgba(61, 69, 88, 0.8);
  background: none;
  box-shadow: inset 0 -1px rgba(82, 148, 226, 0.5), 0 1px rgba(82, 148, 226, 0.5);
}

.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:checked, .nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:active {
  color: rgba(82, 93, 118, 0.8);
  background: none;
  box-shadow: inset 0 -1px #5294e2, 0 1px #5294e2;
}

.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:disabled {
  color: rgba(82, 93, 118, 0.4);
}

.nautilus-window headerbar.titlebar .path-bar-box .path-bar button.flat.text-button.toggle:checked:disabled {
  color: rgba(82, 93, 118, 0.4);
  box-shadow: inset 0 -1px rgba(82, 148, 226, 0.4), 0 1px rgba(82, 148, 226, 0.4);
}

.nautilus-window headerbar.titlebar .path-bar-box {
  margin-top: 5px;
  margin-bottom: 5px;
  color: rgba(82, 93, 118, 0.8);
  background-color: transparent;
  border: none;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button,
.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.image-button.text-button {
  padding: 3px 6px;
  margin-top: 0;
  margin-bottom: 0;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button:not(:only-child):last-child,
.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.image-button.text-button:not(:only-child):last-child {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 100%, transparent 0%) 0 0 2/0 0 2px;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button.image-button {
  padding: 3px 12px;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button.image-button image {
  padding-left: 0;
  padding-right: 0;
}

.nautilus-window headerbar.titlebar .path-bar-box .linked.nautilus-path-bar button.text-button label {
  padding-right: 6px;
  padding-left: 6px;
}

.nautilus-window headerbar.titlebar .path-bar-box.width-maximized {
  border: none;
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.12);
  background-color: rgba(82, 93, 118, 0.06);
  border-radius: 3px;
  padding: 0 6px;
}

.nautilus-window headerbar.titlebar .path-bar-box.background.frame {
  border: none;
  background-color: transparent;
}

.nautilus-canvas-item {
  border-radius: 2px;
}

.caja-desktop.caja-canvas-item, .caja-desktop, .nemo-desktop.nemo-canvas-item,
.nautilus-desktop.nautilus-canvas-item {
  color: #ffffff;
  text-shadow: 1px 1px rgba(0, 0, 0, 0.6);
}

.caja-desktop:active, .nemo-desktop.nemo-canvas-item:active,
.nautilus-desktop.nautilus-canvas-item:active {
  color: #5c616c;
}

.caja-desktop:selected, .nemo-desktop.nemo-canvas-item:selected,
.nautilus-desktop.nautilus-canvas-item:selected {
  color: #ffffff;
  text-shadow: none;
}

.nautilus-canvas-item.dim-label, .slate-notification .nautilus-canvas-item.notification-body,
.budgie-notification .nautilus-canvas-item.notification-body,
.budgie-switcher .nautilus-canvas-item.notification-body, label.nautilus-canvas-item.separator, headerbar .nautilus-canvas-item.subtitle,
.nautilus-list-dim-label,
.caja-list-dim-label {
  color: #abaeb4;
}

.nautilus-canvas-item.dim-label:selected, .slate-notification .nautilus-canvas-item.notification-body:selected,
.budgie-notification .nautilus-canvas-item.notification-body:selected,
.budgie-switcher .nautilus-canvas-item.notification-body:selected, label.nautilus-canvas-item.separator:selected, headerbar .nautilus-canvas-item.subtitle:selected, .nautilus-canvas-item.dim-label:selected:focus,
.nautilus-list-dim-label:selected,
.caja-list-dim-label:selected,
.nautilus-list-dim-label:selected:focus {
  color: #dceaf9;
}

window.thunar notebook scrolledwindow.frame.standard-view, .nemo-window .nemo-window-pane notebook scrolledwindow.view,
.nautilus-window,
.nautilus-window notebook,
.nautilus-window notebook > stack {
  background-image: none;
}

.nautilus-window .searchbar-container {
  margin-top: -1px;
}

.nautilus-window actionbar {
  border-color: #cad5df;
}

.nautilus-window > menubar {
  border: none;
  box-shadow: none;
  background: none;
}

.nautilus-window notebook,
.nautilus-window notebook > stack:not(:only-child) searchbar {
  background-color: #ffffff;
}

.disk-space-display {
  border-style: solid;
  border-width: 1px;
}

.disk-space-display.unknown {
  background-color: rgba(92, 97, 108, 0.5);
  border-color: rgba(69, 72, 80, 0.5);
}

.disk-space-display.used {
  background-color: rgba(82, 148, 226, 0.8);
  border-color: rgba(38, 121, 219, 0.8);
}

.disk-space-display.free {
  background-color: #f0f3f6;
  border-color: #d1dae3;
}

@keyframes needs_attention_keyframes {
  0% {
    color: rgba(82, 93, 118, 0.8);
    border-color: rgba(0, 0, 0, 0.12);
    background-color: #f2f2f2;
  }
  100% {
    color: #ffffff;
    border-color: #2679db;
    background-color: #5294e2;
  }
}

.nautilus-operations-button-needs-attention {
  animation: needs_attention_keyframes 2s ease-in-out;
}

.nautilus-operations-button-needs-attention-multiple {
  animation: needs_attention_keyframes 3s ease-in-out;
  animation-iteration-count: 3;
}

.conflict-row.activatable, .conflict-row.activatable:active {
  color: white;
  background-color: #FC4138;
}

.conflict-row.activatable:hover {
  background-color: #fd716a;
}

.conflict-row.activatable:selected {
  color: #ffffff;
  background-color: #5294e2;
}

.nautilus-window .floating-bar {
  padding: 1px;
  background-color: #5294e2;
  color: #ffffff;
  border-radius: 2px 2px 0 0;
}

.nautilus-window .floating-bar.bottom.left {
  border-top-left-radius: 0;
}

.nautilus-window .floating-bar.bottom.right {
  border-top-right-radius: 0;
}

.nautilus-window .floating-bar button {
  border: none;
  border-radius: 100px;
  min-height: 0;
  min-width: 0;
  padding: 0;
  margin-right: 6px;
  -gtk-icon-shadow: none;
}

stack grid.vertical scrolledwindow.frame,
stack grid.vertical scrolledwindow.frame.emptyGrid {
  border: none;
}

eog-thumb-nav scrolledwindow, eog-thumb-nav scrolledwindow.frame,
#eog-thumb-nav scrolledwindow,
#eog-thumb-nav scrolledwindow.frame {
  border-top: none;
}

eog-thumb-nav button,
#eog-thumb-nav button {
  -gtk-outline-radius: 2px;
  border-radius: 2px;
  border-top: none;
}

.documents-scrolledwin.frame {
  border-width: 0;
}

button.documents-load-more {
  border-width: 1px 0 0;
  border-radius: 0;
}

.documents-icon-bg {
  background-color: #5294e2;
  color: #ffffff;
  border-radius: 2px;
}

.documents-collection-icon, .photos-collection-icon {
  background-color: rgba(92, 97, 108, 0.3);
  border-radius: 2px;
}

button.documents-favorite:active,
button.documents-favorite:active:hover {
  color: #a9caf1;
}

.documents-entry-tag, .photos-entry-tag {
  color: #ffffff;
  background: #5294e2;
  border-radius: 2px;
  border-width: 0;
  margin: 2px;
  padding: 4px;
}

.documents-entry-tag:hover, .photos-entry-tag:hover {
  color: #ffffff;
  background: #639fe5;
}

.documents-entry-tag:active, .photos-entry-tag:active {
  color: #ffffff;
  background: #4189df;
}

.documents-entry-tag.button, .button.photos-entry-tag {
  box-shadow: none;
  border: none;
  background-color: transparent;
}

.content-view.document-page {
  border-style: solid;
  border-width: 3px 3px 6px 4px;
  border-image: url("assets/thumbnail-frame.png") 3 3 6 4;
}

.photos-fade-in {
  opacity: 1.0;
  transition: opacity 0.2s ease-out;
}

.photos-fade-out {
  opacity: 0.0;
  transition: opacity 0.2s ease-out;
}

window.background.csd > overlay > grid.horizontal > frame:dir(ltr) > border {
  border-top-width: 0;
  border-left-width: 0;
  border-bottom-width: 0;
}

frame.sidebar.chat-sidebar > border {
  border-right: none;
}

frame.sidebar.chat-sidebar frame.chat-status-area > border {
  border-style: none;
  border-top-style: solid;
}

widget#PROCESSOR list row, widget#MEMORY list row {
  margin: -1px;
  border: 1px solid #cad5df;
}

widget#PROCESSOR list row.max, widget#MEMORY list row.max {
  color: #282A33;
}

widget#PROCESSOR list separator.list, widget#MEMORY list separator.list {
  box-shadow: inset 0 0 0 1px #cad5df;
}

widget#STORAGE list {
  margin: -1px;
}

widget#STORAGE list row.activatable {
  color: rgba(92, 97, 108, 0.75);
}

widget#STORAGE list row.activatable:hover, widget#STORAGE list row.activatable:active {
  color: rgba(92, 97, 108, 0.75);
}

widget#STORAGE list separator.list {
  box-shadow: inset 0 0 0 1px #cad5df;
}

graph-switcher-button.toggle {
  color: rgba(92, 97, 108, 0.75);
  font-weight: 500;
}

graph-switcher-button.toggle:hover {
  color: #5c616c;
  background-image: image(rgba(0, 0, 0, 0.05));
}

rg-graph.big {
  background-position: left top;
  background-origin: border-box;
  background-repeat: repeat;
}

box.speedometer-outter {
  opacity: 0.8;
}

box.speedometer-content-area {
  box-shadow: 0 0 0 4px rgba(82, 148, 226, 0.2);
}

.gb-search-entry-occurrences-tag {
  background: none;
}

window.org-gnome-Builder > menubar {
  border: none;
  box-shadow: none;
  background: none;
}

workbench.csd > stack.titlebar:not(headerbar) {
  padding: 0;
  background: none;
  border: none;
  box-shadow: none;
}

workbench.csd > stack.titlebar:not(headerbar) headerbar, workbench.csd > stack.titlebar:not(headerbar) headerbar:first-child, workbench.csd > stack.titlebar:not(headerbar) headerbar:last-child {
  border-radius: 0 0 0 0;
}

editortweak .linked > entry.search:focus + .gb-linked-scroller {
  border-top-color: #5294e2;
}

layouttab {
  background-color: #ffffff;
}

layout {
  border: 1px solid rgba(0, 0, 0, 0.15);
  -PnlDockBin-handle-size: 1;
}

eggsearchbar box.search-bar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

pillbox {
  color: #ffffff;
  background-color: #5294e2;
  border-radius: 3px;
}

pillbox:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

docktabstrip {
  padding: 0 6px;
  background-color: #fafbfc;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

docktabstrip docktab {
  min-height: 28px;
  border: solid transparent;
  border-width: 0 1px;
}

docktabstrip docktab label {
  opacity: 0.5;
}

docktabstrip docktab:checked label, docktabstrip docktab:hover label {
  opacity: 1;
}

docktabstrip docktab:checked {
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

dockbin {
  border: 1px solid rgba(0, 0, 0, 0.15);
  -PnlDockBin-handle-size: 1;
}

dockpaned {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

dockoverlayedge {
  background-color: #fafbfc;
}

dockoverlayedge docktabstrip {
  padding: 0;
  border: none;
}

dockoverlayedge.left-edge tab:checked, dockoverlayedge.right-edge tab:checked {
  border-width: 1px 0;
}

popover.messagepopover.background {
  padding: 0;
}

popover.messagepopover .popover-content-area {
  margin: 16px;
}

popover.messagepopover .popover-action-area {
  margin: 8px;
}

popover.messagepopover .popover-action-area button:not(:first-child):not(:last-child) {
  margin: 0 4px;
}

popover.popover-selector {
  padding: 0;
}

popover.popover-selector list row {
  padding: 5px 0;
}

popover.popover-selector list row image {
  margin-left: 3px;
  margin-right: 10px;
}

button.dzlmenubuttonitem.check label {
  color: #5c616c;
}

button.dzlmenubuttonitem.check label.dim-label, button.dzlmenubuttonitem.check .slate-notification label.notification-body, .slate-notification button.dzlmenubuttonitem.check label.notification-body,
button.dzlmenubuttonitem.check .budgie-notification label.notification-body,
button.dzlmenubuttonitem.check .budgie-switcher label.notification-body,
.budgie-notification button.dzlmenubuttonitem.check label.notification-body,
.budgie-switcher button.dzlmenubuttonitem.check label.notification-body, button.dzlmenubuttonitem.check label.separator, button.dzlmenubuttonitem.check headerbar label.subtitle, headerbar button.dzlmenubuttonitem.check label.subtitle {
  color: #5c616c;
}

button.dzlmenubuttonitem.check box > image {
  opacity: 0.87;
}

entry.search.preferences-search {
  border: none;
  border-right: 1px solid rgba(0, 0, 0, 0.15);
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
}

preferences stacksidebar.sidebar list {
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
}

preferences stacksidebar.sidebar list separator {
  background-color: transparent;
}

devhelppanel entry:focus,
symboltreepanel entry:focus {
  border-color: rgba(0, 0, 0, 0.15);
}

button.run-arrow-button {
  min-width: 12px;
}

omnibar.linked > entry:not(:only-child) {
  border-style: solid;
  border-radius: 3px;
  margin-left: 1px;
  margin-right: 1px;
}

gstyleslidein #scale_box button.toggle:checked,
gstyleslidein #strings_controls button.toggle:checked,
gstyleslidein #palette_controls button.toggle:checked,
gstyleslidein #components_controls button.toggle:checked {
  color: #5c616c;
}

configurationview entry.flat {
  background: none;
}

configurationview list {
  border-width: 0;
}

preferencesbin spinbutton {
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

preferencesbin spinbutton:focus {
  border-color: #5294e2;
}

preferencesbin spinbutton entry, preferencesbin spinbutton button {
  border: none;
  box-shadow: none;
}

window.background.csd > box.horizontal > stack.background > widget > scrolledwindow.frame {
  border: none;
}

button.round-button {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
}

window.background > box.vertical > searchbar {
  box-shadow: none;
}

window.background > box.vertical > overlay > stack > widget > stack > box.vertical > scrolledwindow > viewport.frame > widget > list {
  background-color: #fafbfc;
}

window.background > box.vertical > overlay > stack > widget > stack > box.vertical > scrolledwindow > viewport.frame > widget > list > separator {
  border-left: 100px solid transparent;
  border-right: 100px solid transparent;
}

window.background > box.vertical > overlay > stack > widget > stack widget > box.vertical.app-list {
  background-image: image(#fafbfc);
}

window.background > box.vertical > overlay > stack > widget > stack widget > box.vertical.app-list > box.vertical > list {
  background-color: #fafbfc;
}

window.background > box.vertical > overlay > stack > widget > stack widget > box.vertical.app-list separator {
  border-left: 100px solid transparent;
  border-right: 100px solid transparent;
}

.category_page_header_filter_box {
  background-image: image(#fafbfc);
  border-image: linear-gradient(to bottom, #cad5df, #cad5df) 0 0 1 0/0 0 1px 0 stretch;
}

.category_page_header_filter_box button {
  color: rgba(92, 97, 108, 0.55);
  background-image: image(#fafbfc);
}

.category_page_header_filter_box button:hover {
  color: rgba(92, 97, 108, 0.75);
}

.category_page_header_filter_box button:checked {
  color: #5c616c;
}

.category_page_header_filter_box button:disabled {
  color: rgba(92, 97, 108, 0.65);
}

.application-details-infobar {
  background-image: image(#ffffff);
  border-image: linear-gradient(to bottom, #cad5df, #cad5df) 1 1 1 1/1px 1px 1px 1px stretch;
}

.maps-popover button.radio.layer-radio-button:checked {
  box-shadow: 0 0 0 2px #5294e2;
}

.tr-workarea undershoot,
.tr-workarea overshoot {
  border-color: transparent;
}

#gf-bubble, #gf-bubble.solid,
#gf-osd-window,
#gf-osd-window.solid,
#gf-input-source-popup,
#gf-input-source-popup.solid,
#gf-candidate-popup,
#gf-candidate-popup.solid {
  color: #e9ecf1;
  background-color: #282A33;
  border: 1px solid #16171c;
  border-radius: 2px;
}

#gf-bubble levelbar block.low, #gf-bubble levelbar block.high, #gf-bubble levelbar block.full,
#gf-osd-window levelbar block.low,
#gf-osd-window levelbar block.high,
#gf-osd-window levelbar block.full,
#gf-input-source-popup levelbar block.low,
#gf-input-source-popup levelbar block.high,
#gf-input-source-popup levelbar block.full,
#gf-candidate-popup levelbar block.low,
#gf-candidate-popup levelbar block.high,
#gf-candidate-popup levelbar block.full {
  background-color: #5294e2;
  border-color: #5294e2;
}

#gf-bubble levelbar block.empty,
#gf-osd-window levelbar block.empty,
#gf-input-source-popup levelbar block.empty,
#gf-candidate-popup levelbar block.empty {
  background-color: #1d1e25;
}

#gf-bubble levelbar trough,
#gf-osd-window levelbar trough,
#gf-input-source-popup levelbar trough,
#gf-candidate-popup levelbar trough {
  background: none;
}

#gf-input-source {
  min-height: 32px;
  min-width: 40px;
}

#gf-input-source:selected {
  color: #ffffff;
  background-color: #5294e2;
  border-radius: 2px;
}

gf-candidate-box label {
  padding: 3px;
}

gf-candidate-box:hover, gf-candidate-box:selected {
  color: #ffffff;
  background-color: #5294e2;
  border-radius: 2px;
}

headerbar > button.flat.popup.title-menu-button.toggle {
  border-radius: 2px;
  -gtk-outline-radius: 2px;
}

headerbar > button.flat.popup.title-menu-button.toggle > grid .title {
  margin: -0.16875rem 0;
  padding: 0.08125rem 0.83125rem 0;
  font-size: 90%;
}

headerbar > button.flat.popup.title-menu-button.toggle > grid .subtitle {
  margin: -0.16875rem 0;
  padding: 0 0.83125rem 0.08125rem;
  font-size: 80%;
}

window.background > box.vertical box.horizontal list.categories {
  background-color: #fafbfc;
  border: none;
  color: #5c616c;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category {
  color: #5c616c;
  background-color: transparent;
  font-weight: 500;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category:hover {
  color: #5c616c;
  background-color: rgba(92, 97, 108, 0.08);
}

window.background > box.vertical box.horizontal list.categories row.activatable.category:selected {
  color: #ffffff;
  background-color: #5294e2;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category:selected label {
  color: #ffffff;
}

window.background > box.vertical box.horizontal list.categories row.activatable.category > label {
  padding-left: 0;
  padding-right: 0;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list > separator {
  background-color: transparent;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list > separator.compressed-rows-group-separator {
  background-image: image(rgba(0, 0, 0, 0.15));
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable {
  color: #5c616c;
  transition-duration: 0.1s;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable:hover, window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable:active {
  color: #5c616c;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable label.compressed-entries-label {
  background-image: image(#5294e2);
  color: #ffffff;
  font-weight: 700;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row {
  background-image: image(#f0f3f6);
  color: #2d3035;
  transition-property: opacity, border-image, background-image, box-shadow;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row:hover {
  background-image: image(#f2f3f5);
  color: #5c616c;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row:active, window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row:active:focus {
  background-image: image(#eaecee);
  color: #5c616c;
  animation: none;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row.popover-activated-row {
  background-image: image(#5294e2);
  color: #ffffff;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header {
  background-image: image(#ffffff);
  color: #5294e2;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header:hover {
  background-image: image(#f6fafe);
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header:active, window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header:active:focus {
  background-image: image(#eef4fc);
  color: #5294e2;
  animation: none;
}

window.background > box.vertical box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.event.activatable.compressed-row-header label.compressed-entries-label {
  background-image: image(#5294e2);
  color: #ffffff;
  transition-duration: 0s;
}

headerbar.titlebar.incognito-mode entry {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f7f7f7;
}

headerbar.titlebar.incognito-mode entry image, headerbar.titlebar.incognito-mode entry image:hover {
  color: inherit;
}

headerbar.titlebar.incognito-mode entry:focus {
  color: rgba(132, 144, 170, 0.8);
  border-color: #5294e2;
  background-color: #fcfcfc;
}

headerbar.titlebar.incognito-mode entry:disabled {
  color: rgba(82, 93, 118, 0.35);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: rgba(247, 247, 247, 0.85);
}

notebook > box > stack > box.vertical > paned.vertical > overlay > .floating-bar {
  color: rgba(92, 97, 108, 0.75);
}

.background headerbar entry.starred, .background headerbar entry.non-starred {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f7f7f7;
}

.background headerbar entry.starred image, .background headerbar entry.starred image:hover, .background headerbar entry.non-starred image, .background headerbar entry.non-starred image:hover {
  color: inherit;
}

.background headerbar entry.starred:focus, .background headerbar entry.non-starred:focus {
  color: rgba(132, 144, 170, 0.8);
  border-color: #5294e2;
  background-color: #fcfcfc;
}

.background headerbar entry.starred:disabled, .background headerbar entry.non-starred:disabled {
  color: rgba(82, 93, 118, 0.35);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: rgba(247, 247, 247, 0.85);
}

.background headerbar entry.starred > image.right {
  color: #ccbb00;
}

.background headerbar entry.starred > image.right:hover, .background headerbar entry.starred > image.right:active, .background headerbar entry.starred > image.right:checked {
  color: #FFEA00;
}

popover.background:not(.emoji-picker) > box.vertical > scrolledwindow > viewport.frame > list.background {
  background-color: transparent;
}

popover.background:not(.emoji-picker) > box.vertical > scrolledwindow > viewport.frame > list.background > row.activatable {
  background-color: #fafbfc;
  color: rgba(92, 97, 108, 0.85);
  border-radius: 2px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  margin: 2px;
}

popover.background:not(.emoji-picker) > box.vertical > scrolledwindow > viewport.frame > list.background > row.activatable:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical {
  margin: 0;
  padding: 0;
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row {
  background-color: rgba(255, 255, 255, 0.35);
  color: rgba(92, 97, 108, 0.85);
  border-bottom: 1px dashed rgba(0, 0, 0, 0.05);
  padding: 6px 0;
  margin: 0;
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row:hover, popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row:active, popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row:checked {
  color: #5c616c;
  background-color: rgba(92, 97, 108, 0.05);
}

popover.background:not(.emoji-picker) > box.vertical > stack > box.vertical scrolledwindow > viewport.frame > list.background > row.activatable.bookmarks-row button.flat {
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  margin: 0 6px;
  border-radius: 100px;
  -gtk-outline-radius: 100px;
}

popover.background > scrolledwindow > viewport.frame > list > row.activatable {
  border-radius: 2px;
}

popover.background > scrolledwindow > viewport.frame > list > row.activatable button.page-row-close-button {
  margin: 3px 6px;
}

flowboxchild.bookmark-tag-widget {
  color: #fafbfc;
  font-weight: 500;
}

flowboxchild.bookmark-tag-widget label {
  margin-bottom: 2px;
}

flowboxchild.bookmark-tag-widget-selected {
  color: #ffffff;
}

window#gnome-system-monitor > menubar {
  border: none;
  box-shadow: none;
  background: none;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.15);
  padding: 4px;
  background-color: #f0f3f6;
}

window.csd > box.vertical > box.vertical > toolbar.horizontal, window.csd > box.vertical > box.vertical > .horizontal.inline-toolbar,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal,
window.solid-csd > box.vertical > box.vertical > .horizontal.inline-toolbar {
  margin-top: -1px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: none;
  background-color: transparent;
}

window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button, window.csd > box.vertical > box.vertical > .horizontal.inline-toolbar > toolitem > .linked > button,
window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button,
window.csd > box.vertical > box.vertical > .horizontal.inline-toolbar > toolitem > box.horizontal > button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button,
window.solid-csd > box.vertical > box.vertical > .horizontal.inline-toolbar > toolitem > .linked > button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button,
window.solid-csd > box.vertical > box.vertical > .horizontal.inline-toolbar > toolitem > box.horizontal > button {
  min-height: 36px;
  min-width: 36px;
  padding: 0;
  margin-top: 8px;
  margin-bottom: 8px;
}

window.csd > box.vertical > box.vertical > frame,
window.solid-csd > box.vertical > box.vertical > frame {
  margin-top: -1px;
  padding: 0;
}

window.csd > box.vertical > box.vertical > frame > border,
window.solid-csd > box.vertical > box.vertical > frame > border {
  border: none;
}

window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button.image-button.raised, window.background > box.vertical > .primary-toolbar.inline-toolbar > toolitem > .linked > button.image-button.raised {
  min-height: 36px;
  min-width: 36px;
  padding: 0;
  margin: 0;
}

window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button.image-button.raised > widget > box > image, window.background > box.vertical > .primary-toolbar.inline-toolbar > toolitem > .linked > button.image-button.raised > widget > box > image {
  padding: 0;
}

window.background > box.vertical > toolbar.primary-toolbar > toolitem button.flat.scale, window.background > box.vertical > .primary-toolbar.inline-toolbar > toolitem button.flat.scale {
  min-height: 20px;
  min-width: 36px;
  padding: 0;
  margin-top: 8px;
  margin-bottom: 8px;
}

window.background > box.vertical > toolbar.primary-toolbar > toolitem > box.horizontal:not(.linked) > button.toggle, window.background > box.vertical > .primary-toolbar.inline-toolbar > toolitem > box.horizontal:not(.linked) > button.toggle,
window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button:not(.toggle):not(.raised):not(.flat),
window.background > box.vertical > .primary-toolbar.inline-toolbar > toolitem > .linked > button:not(.toggle):not(.raised):not(.flat) {
  min-height: 28px;
  min-width: 28px;
  padding: 0;
  margin: 0;
}

dialog.background.csd > box.dialog-vbox > grid.horizontal > scrolledwindow.frame {
  border: none;
}

dialog.background.csd > box.dialog-vbox > grid.horizontal > scrolledwindow.frame > viewport.frame {
  border: none;
}

dialog.background.csd > box.dialog-vbox > grid.horizontal > stack > scrolledwindow.frame {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

dialog.background.csd > box.dialog-vbox > filechooser > actionbar > revealer > box.horizontal > box.horizontal > box.horizontal > combobox > .linked > button.combo {
  margin: 24px 6px 24px 120px;
  background-position: right bottom;
}

dialog.background.csd headerbar.default-decoration {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

window.background.csd > paned.horizontal > scrolledwindow.frame.sidebar {
  border-top: none;
}

stack > overlay > frame > scrolledwindow.frame {
  border-left-width: 0;
  border-right-width: 0;
}

.nemo-window .nemo-places-sidebar.frame {
  border-width: 0;
}

.nemo-window .nemo-places-sidebar .places-treeview {
  -NemoPlacesTreeView-disk-full-bg-color: #cad5df;
  -NemoPlacesTreeView-disk-full-fg-color: #3c86de;
}

.nemo-window notebook {
  background-color: #ffffff;
}

.nemo-window notebook .primary-toolbar {
  background-color: #fafbfc;
}

.nemo-window notebook .primary-toolbar button,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo {
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

.nemo-window notebook .primary-toolbar button:hover,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
  -gtk-icon-effect: highlight;
}

.nemo-window notebook .primary-toolbar button:active, .nemo-window notebook .primary-toolbar button:checked,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:active,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.nemo-window notebook .primary-toolbar button:active:not(:disabled) label:disabled, .nemo-window notebook .primary-toolbar button:checked:not(:disabled) label:disabled,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:active:not(:disabled) label:disabled,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:checked:not(:disabled) label:disabled {
  color: inherit;
  opacity: 0.6;
}

.nemo-window notebook .primary-toolbar button:disabled,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

.nemo-window notebook .primary-toolbar button:disabled label, .nemo-window notebook .primary-toolbar button:disabled,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled label,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled {
  color: rgba(92, 97, 108, 0.55);
}

.nemo-window notebook .primary-toolbar button:disabled:active, .nemo-window notebook .primary-toolbar button:disabled:checked,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled:active,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled:checked {
  border-color: rgba(82, 148, 226, 0.75);
  background-color: rgba(82, 148, 226, 0.75);
  opacity: 0.6;
}

.nemo-window notebook .primary-toolbar button:disabled:active label, .nemo-window notebook .primary-toolbar button:disabled:active, .nemo-window notebook .primary-toolbar button:disabled:checked label, .nemo-window notebook .primary-toolbar button:disabled:checked,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled:active label,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled:active,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled:checked label,
.nemo-window notebook .primary-toolbar combobox > .linked > button.combo:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

.nemo-window notebook .primary-toolbar entry {
  min-height: 24px;
  min-width: 24px;
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

.nemo-window notebook .primary-toolbar entry:focus {
  color: #5c616c;
  border-color: #5294e2;
  background-color: #ffffff;
}

.nemo-window .nemo-window-pane widget.entry {
  border: 1px solid;
  border-radius: 3px;
  color: #5c616c;
  border-color: #5294e2;
  background-color: #ffffff;
}

.nemo-window .primary-toolbar {
  padding-top: 0;
  padding-bottom: 0;
  border: none;
  color: rgba(82, 93, 118, 0.8);
  background-color: white;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

.nemo-window .primary-toolbar button {
  min-height: 20px;
  margin-top: 6px;
  margin-bottom: 6px;
}

.nemo-window .primary-toolbar entry {
  min-height: 22px;
  margin-top: 4px;
  margin-bottom: 4px;
}

.nemo-window .primary-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button,
.nemo-window .primary-toolbar widget.linked.raised:not(.vertical):not(.path-bar) button {
  margin-top: 4px;
  margin-bottom: 4px;
}

.nemo-window .sidebar scrolledwindow.frame {
  border: none;
}

.nemo-window .floating-bar {
  padding: 2px;
  background-color: #5294e2;
  color: #ffffff;
  border-radius: 0;
}

.nemo-window .floating-bar.bottom.left {
  border-top-right-radius: 2px;
}

.nemo-window .floating-bar.bottom.right {
  border-top-left-radius: 2px;
}

.nemo-window .floating-bar button {
  border: none;
  border-radius: 3px;
  min-height: 16px;
  min-width: 16px;
  -gtk-icon-shadow: none;
}

dialog.background > .dialog-vbox > frame.view > stack > box.vertical > separator.horizontal {
  background: none;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > widget > separator {
  color: rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > widget > scrollbar {
  background-clip: border-box;
}

window.background:not(.csd) > widget > scrollbar,
window.background:not(.csd) > widget > frame > border {
  border-color: rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > widget > entry,
window.background:not(.csd) > widget .entry {
  border-radius: 2px;
  color: #5c616c;
  background-image: image(#ffffff);
  border: 1px solid rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > widget > entry:focus,
window.background:not(.csd) > widget .entry:focus {
  border-color: #5294e2;
}

window.background:not(.csd) > widget > spinbutton {
  background-image: image(white);
  border: 1px solid rgba(0, 0, 0, 0.15);
}

window.background:not(.csd) > widget > spinbutton:active {
  background-image: image(#eff2f5);
}

window.background:not(.csd) > widget > spinbutton .entry {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

window.background:not(.csd) > widget > button > button, window.background:not(.csd) > widget > button.combo > button {
  color: #5c616c;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px;
}

window.background:not(.csd) > widget > button > button:active, window.background:not(.csd) > widget > button > button:checked, window.background:not(.csd) > widget > button.combo > button:active, window.background:not(.csd) > widget > button.combo > button:checked {
  border: 1px solid #cfd9e2;
  background-image: image(#eff2f5);
}

window.background:not(.csd) > menu,
window.background:not(.csd) > menu > menu {
  border-radius: 0;
}

window.background:not(.csd) > menu > separator, window.background:not(.csd) > menu .separator,
window.background:not(.csd) > menu > menu > separator,
window.background:not(.csd) > menu > menu .separator {
  color: #ffffff;
}

window.background:not(.csd) > menu > menuitem > label:disabled {
  color: rgba(92, 97, 108, 0.55);
}

window.background:not(.csd) > window > menu menuitem {
  transition: none;
}

#MozillaGtkWidget.background {
  background-color: #fafbfc;
}

#MozillaGtkWidget.background .background,
#MozillaGtkWidget.background frame,
#MozillaGtkWidget.background separator,
#MozillaGtkWidget.background scrolledwindow {
  background-color: #fafbfc;
}

#MozillaGtkWidget.background headerbar.titlebar {
  padding-left: 10px;
  padding-right: 10px;
}

#MozillaGtkWidget.background scrollbar {
  background-color: #ffffff;
}

#MozillaGtkWidget.background scrollbar slider {
  background-color: #b3b6bb;
}

#MozillaGtkWidget.background scrollbar slider:hover {
  background-color: #9b9fa6;
}

#MozillaGtkWidget.background scrollbar slider:hover:active {
  background-color: #848890;
}

#MozillaGtkWidget.background scrollbar slider:disabled {
  background-color: transparent;
}

#MozillaGtkWidget.background *:not(menuitem):hover, #MozillaGtkWidget.background *:not(menuitem):hover button,
#MozillaGtkWidget.background *:focus,
#MozillaGtkWidget.background *:focus button,
#MozillaGtkWidget.background *:active,
#MozillaGtkWidget.background *:active button,
#MozillaGtkWidget.background *:checked,
#MozillaGtkWidget.background *:checked button {
  color: #5c616c;
}

#MozillaGtkWidget.background > window.background > menu,
#MozillaGtkWidget.background > window.background > menu > menu {
  border: none;
  background-color: #ffffff;
}

#MozillaGtkWidget.background > window.background > menu > separator,
#MozillaGtkWidget.background > window.background > menu > menu > separator {
  padding: 0;
  border: none;
  background-color: rgba(0, 0, 0, 0.15);
}

#MozillaGtkWidget.background > widget border {
  border-color: #cad5df;
}

#MozillaGtkWidget.background > widget separator {
  background-color: #cfd9e2;
}

#MozillaGtkWidget.background > widget > scrolledwindow > textview {
  background-color: #ffffff;
}

#MozillaGtkWidget.background > widget > scrolledwindow > textview text {
  background-color: transparent;
  color: #5c616c;
}

window.background.chromium headerbar.titlebar button.titlebutton {
  min-width: 23px;
  min-height: 23px;
  padding: 0 2px;
  color: transparent;
}

window.background.chromium {
  background-color: #fafbfc;
  color: #5c616c;
}

window.background.chromium headerbar.titlebar button.toggle {
  color: rgba(82, 93, 118, 0.8);
  outline-offset: -3px;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

window.background.chromium headerbar.titlebar button.toggle:hover {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
}

window.background.chromium headerbar.titlebar button.toggle:checked, window.background.chromium headerbar.titlebar button.toggle:active {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

window.background.chromium button {
  border-width: 1px;
  border-style: solid;
  border-color: #cad5df;
  background-color: #fafbfc;
  color: #5c616c;
}

window.background.chromium entry.chromium {
  border-image: none;
  border: 1px solid #cad5df;
  background-color: #fafbfc;
  color: #5c616c;
}

window.background.chromium entry.chromium:focus {
  border-color: #5294e2;
}

window.background.chromium > textview.view, window.background.chromium textview {
  background-color: #fafbfc;
  color: #5c616c;
}

window.background.chromium > menubar {
  background-color: #ffffff;
}

window.background.chromium > menu {
  color: #5c616c;
  background-color: #ffffff;
  border: 1px solid #cad5df;
}

window.background.chromium > menu > separator, window.background.chromium > menu .separator {
  background-color: #ffffff;
  color: #ffffff;
  border: none;
}

window.background.chromium > menu > menuitem {
  color: #5c616c;
}

window.background.chromium > menu > menuitem:hover {
  color: #ffffff;
  background-color: #5294e2;
}

window.background.chromium > menu > menuitem:disabled {
  color: rgba(92, 97, 108, 0.45);
}

window.background.chromium > menu > menuitem accelerator {
  color: rgba(92, 97, 108, 0.45);
}

window.background > grid.horizontal > grid.horizontal {
  background-color: #ffffff;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

window.background > grid.horizontal > grid.horizontal > button.flat.small-button {
  color: rgba(82, 93, 118, 0.8);
  border: none;
  border-radius: 50px;
}

window.background > grid.horizontal > grid.horizontal > button.flat.small-button:hover {
  background-color: rgba(82, 93, 118, 0.25);
}

window.background > grid.horizontal > grid.horizontal > button.flat.small-button:active, window.background > grid.horizontal > grid.horizontal > button.flat.small-button:checked {
  background-color: #5294e2;
  color: #ffffff;
}

window.background > grid.horizontal > grid.horizontal > button.flat.small-button:disabled {
  color: rgba(82, 93, 118, 0.6);
}

window.background:not(.solid-csd) > notebook:not(.frame) {
  border: 0 none transparent;
  background-color: #ffffff;
}

window.background:not(.solid-csd) > notebook:not(.frame) > stack {
  border: none;
  box-shadow: none;
}

overlay.window-overlay grid.horizontal stack paned.horizontal stack widget.view.frame,
overlay.window-overlay grid.horizontal stack paned.horizontal stack scrolledwindow.frame {
  border-left: none;
  border-right: none;
}

overlay.window-overlay grid.horizontal stack .sidebar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

widget > box.terminal-titlebar {
  padding: 0 6px;
}

widget > box.terminal-titlebar > button.flat.popup.toggle {
  border: none;
  border-radius: 0;
  padding-top: 0;
  padding-bottom: 0;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 0%, transparent 0%) 0 0 0/0 0 0;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:dir(ltr) {
  padding-right: 6px;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:dir(rtl) {
  padding-left: 6px;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:hover {
  box-shadow: inset 0 -2px #5294e2;
  background: none;
}

widget > box.terminal-titlebar > button.flat.popup.toggle:checked, widget > box.terminal-titlebar > button.flat.popup.toggle:active {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 100%, transparent 0%) 0 0 2/0 0 2px;
  background-color: transparent;
  color: #5c616c;
}

widget > box.terminal-titlebar > button.image-button, widget > box.terminal-titlebar > button.image-button.toggle {
  margin: 2px 0;
  padding: 0;
  min-height: 24px;
  min-width: 24px;
  border-radius: 100px;
  -gtk-outline-radius: 100px;
}

list.tilix-session-sidebar {
  background-image: image(#f6f9fb);
}

list.tilix-session-sidebar button.tilix-sidebar-close-button {
  min-height: 20px;
  min-width: 20px;
  padding: 0;
  border-radius: 100px;
  -gtk-outline-radius: 100px;
  background-color: #F04A50;
}

list.tilix-session-sidebar button.tilix-sidebar-close-button, list.tilix-session-sidebar button.tilix-sidebar-close-button:hover, list.tilix-session-sidebar button.tilix-sidebar-close-button:active, list.tilix-session-sidebar button.tilix-sidebar-close-button:checked {
  color: white;
}

list.tilix-session-sidebar button.tilix-sidebar-close-button:hover {
  background-color: #f4797e;
}

list.tilix-session-sidebar button.tilix-sidebar-close-button:active, list.tilix-session-sidebar button.tilix-sidebar-close-button:checked {
  background-image: image(#ec1b22);
}

window.background.csd > box.vertical > stack > box.horizontal > list {
  border-right: 1px solid #cad5df;
}

window.background.csd > box.vertical > stack > box.horizontal > box.vertical > stack > scrolledwindow.frame {
  border: none;
}

window.background.csd > box.vertical > stack > box.horizontal > revealer > stack > list {
  border-right: 1px solid #cad5df;
}

window.background.csd > box.vertical > stack > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list {
  border-right: 1px solid #cad5df;
}

window.background.csd > box.vertical > stack > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list {
  border-right: 1px solid #cad5df;
}

window#ValaPanel.background {
  background-color: #21232b;
  border: none;
  color: #D3DAE3;
}

window#ValaPanel.background widget.-vala-panel-background > separator {
  background: none;
}

window#ValaPanel.background .unpinned button.flat.-panel-icon-button {
  border-radius: 0;
}

window#ValaPanel.background .unpinned button.flat.-panel-icon-button:hover {
  -gtk-icon-effect: highlight;
}

window#ValaPanel.background .unpinned button.flat.-panel-icon-button:hover, window#ValaPanel.background .unpinned button.flat.-panel-icon-button:active, window#ValaPanel.background .unpinned button.flat.-panel-icon-button:checked {
  box-shadow: inset 0 -2px #5294e2;
  color: #c3cdd9;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running {
  border-radius: 0;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running > image {
  background-position: bottom center;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:hover {
  -gtk-icon-effect: highlight;
}

window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:hover, window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:active, window#ValaPanel.background .pinned button.flat.-panel-icon-button.running:checked {
  box-shadow: inset 0 -2px #5294e2;
  color: #c3cdd9;
}

.mate-panel-menu-bar menubar,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button,
menubar.-vala-panel-background,
menubar.-vala-panel-appmenu-private {
  background: none;
  border: none;
  box-shadow: none;
  color: #D3DAE3;
}

.mate-panel-menu-bar menubar > menuitem,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem,
menubar.-vala-panel-background > menuitem,
menubar.-vala-panel-appmenu-private > menuitem {
  border: none;
  border-radius: 0;
  font-weight: normal;
}

.mate-panel-menu-bar menubar > menuitem:hover,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem:hover,
menubar.-vala-panel-background > menuitem:hover,
menubar.-vala-panel-appmenu-private > menuitem:hover {
  background-color: rgba(255, 255, 255, 0.1);
  color: #ffffff;
  box-shadow: inset 0 -2px #5294e2, 0 1px #5294e2;
}

.mate-panel-menu-bar menubar > menuitem:disabled,
.mate-panel-menu-bar #PanelApplet-window-menu-applet-button > menuitem:disabled,
menubar.-vala-panel-background > menuitem:disabled,
menubar.-vala-panel-appmenu-private > menuitem:disabled {
  color: rgba(211, 218, 227, 0.4);
}

window#meldapp notebook.frame.meld-notebook {
  border: none;
}

window#meldapp notebook.frame.meld-notebook paned.meld-vc-console-pane {
  border: none;
}

/*****************
 * Unity Desktop *
 *****************/
UnityDecoration {
  -UnityDecoration-extents: 28px 1 1 1;
  -UnityDecoration-input-extents: 10px;
  -UnityDecoration-shadow-offset-x: 0px;
  -UnityDecoration-shadow-offset-y: 3px;
  -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.2);
  -UnityDecoration-active-shadow-radius: 12px;
  -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.07);
  -UnityDecoration-inactive-shadow-radius: 7px;
  -UnityDecoration-glow-size: 10px;
  -UnityDecoration-glow-color: #5294e2;
  -UnityDecoration-title-indent: 10px;
  -UnityDecoration-title-fade: 35px;
  -UnityDecoration-title-alignment: 0.0;
}

UnityDecoration .top {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-bottom-width: 0;
  border-radius: 4px 4px 0 0;
  padding: 1px 6px 0 6px;
  background-image: linear-gradient(to bottom, white, white);
  color: rgba(82, 93, 118, 0.8);
  box-shadow: inset 0 1px white;
}

UnityDecoration .top:backdrop {
  border-bottom-width: 0;
  color: rgba(82, 93, 118, 0.5);
}

UnityDecoration .left, UnityDecoration .right, UnityDecoration .bottom,
UnityDecoration .left:backdrop, UnityDecoration .right:backdrop, UnityDecoration .bottom:backdrop {
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.1), rgba(0, 0, 0, 0.1));
}

UnityPanelWidget,
.unity-panel {
  background-image: linear-gradient(to bottom, #1b2224, #1b2224);
  color: white;
  box-shadow: none;
}

UnityPanelWidget:backdrop,
.unity-panel:backdrop {
  color: #d6dde5;
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
  border-radius: 0;
  color: #ffffff;
  background-image: linear-gradient(to bottom, #5294e2, #5294e2);
  border-bottom: none;
}

.lightdm.menu {
  background-image: none;
  background-color: rgba(0, 0, 0, 0.4);
  border-color: rgba(255, 255, 255, 0.8);
  border-radius: 4px;
  padding: 1px;
  color: white;
}

.lightdm-combo .menu {
  background-color: white;
  border-radius: 0px;
  padding: 0px;
  color: white;
}

.lightdm.menu .menuitem *,
.lightdm.menu .menuitem.check:active,
.lightdm.menu .menuitem.radio:active {
  color: white;
}

.lightdm.menubar {
  color: rgba(255, 255, 255, 0.8);
  background-image: none;
  background-color: rgba(0, 0, 0, 0.5);
}

.lightdm.menubar > .menuitem {
  padding: 2px 6px;
}

.lightdm-combo.combobox-entry .button,
.lightdm-combo .cell,
.lightdm-combo .button,
.lightdm-combo .entry,
.lightdm.button,
.lightdm.entry {
  background-image: none;
  background-color: rgba(0, 0, 0, 0.3);
  border-color: rgba(255, 255, 255, 0.4);
  border-radius: 10px;
  padding: 7px;
  color: white;
  text-shadow: none;
}

.lightdm.button,
.lightdm.button:hover,
.lightdm.button:active,
.lightdm.button:active:focus,
.lightdm.entry,
.lightdm.entry:hover,
.lightdm.entry:active,
.lightdm.entry:active:focus {
  background-image: none;
  border-image: none;
}

.lightdm.button:focus,
.lightdm.entry:focus {
  border-color: rgba(255, 255, 255, 0.1);
  border-width: 1px;
  border-style: solid;
  color: white;
}

.lightdm.entry:selected {
  background-color: rgba(255, 255, 255, 0.8);
}

.lightdm.entry:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: dashentry_spinner 1s infinite linear;
}

.lightdm.option-button {
  padding: 2px;
  background: none;
  border: 0;
}

.lightdm.toggle-button {
  background: none;
  border-width: 0;
}

.lightdm.toggle-button.selected {
  background-color: rgba(0, 0, 0, 0.7);
  border-width: 1px;
}

@keyframes dashentry_spinner {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

/****************
 * Mate Desktop *
 ****************/
.atril-window .primary-toolbar toolbar, .atril-window .primary-toolbar .inline-toolbar {
  background: none;
}

MsdOsdWindow.background.osd {
  border-radius: 2px;
  border: 1px solid #16171c;
}

MsdOsdWindow.background.osd .progressbar {
  background-color: #5294e2;
  border: none;
  border-color: red;
  border-radius: 5px;
}

MsdOsdWindow.background.osd .trough {
  background-color: #1d1e25;
  border: none;
  border-radius: 5px;
}

.mate-panel-menu-bar, .mate-panel-menu-bar menubar,
panel-toplevel.background,
panel-toplevel.background menubar {
  background-color: #21232b;
}

.mate-panel-menu-bar button label, .mate-panel-menu-bar button image,
.mate-panel-menu-bar button#tasklist-button label,
.mate-panel-menu-bar button#tasklist-button image,
panel-toplevel.background button label,
panel-toplevel.background button image,
panel-toplevel.background button#tasklist-button label,
panel-toplevel.background button#tasklist-button image {
  color: inherit;
}

.mate-panel-menu-bar .wnck-pager,
panel-toplevel.background .wnck-pager {
  color: #6a6d72;
  background-color: #0b0c0e;
}

.mate-panel-menu-bar .wnck-pager:hover,
panel-toplevel.background .wnck-pager:hover {
  background-color: #2c2f39;
}

.mate-panel-menu-bar .wnck-pager:selected,
panel-toplevel.background .wnck-pager:selected {
  color: #a9caf1;
  background-color: #5294e2;
}

.mate-panel-menu-bar na-tray-applet,
panel-toplevel.background na-tray-applet {
  -NaTrayApplet-icon-padding: 0;
  -NaTrayApplet-icon-size: 16px;
}

PanelToplevel.background {
  color: #D3DAE3;
  background-color: #21232b;
}

#PanelWidget,
#PanelPlug,
#PanelApplet {
  color: #D3DAE3;
  background-color: #21232b;
}

PanelSeparator {
  border-width: 0;
  background: none;
  background-image: none;
  color: white;
}

PanelToplevel.horizontal MatePanelAppletFrameDBus {
  background-image: linear-gradient(to right, transparent 2px, rgba(255, 255, 255, 0.1) 2px, rgba(255, 255, 255, 0.1) 3px, transparent 3px, transparent 4px, rgba(255, 255, 255, 0.1) 4px, rgba(255, 255, 255, 0.1) 5px, transparent 5px, transparent 7px);
  background-repeat: no-repeat;
  background-size: 7px 14px;
}

PanelToplevel.horizontal MatePanelAppletFrameDBus:dir(ltr) {
  background-position: left center;
}

PanelToplevel.horizontal MatePanelAppletFrameDBus:dir(rtl) {
  background-position: right center;
}

PanelToplevel.vertical MatePanelAppletFrameDBus {
  background-image: linear-gradient(to bottom, transparent 2px, rgba(255, 255, 255, 0.1) 2px, rgba(255, 255, 255, 0.1) 3px, transparent 3px, transparent 4px, rgba(255, 255, 255, 0.1) 4px, rgba(255, 255, 255, 0.1) 5px, transparent 5px, transparent 7px);
  background-repeat: no-repeat;
  background-size: 14px 7px;
  background-position: center top;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button {
  min-height: 4px;
  min-width: 4px;
  padding: 0;
  border-radius: 0;
  border-style: solid;
  border-color: rgba(255, 255, 255, 0.1);
  -gtk-outline-radius: 0;
  background-color: transparent;
  color: #D3DAE3;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:hover {
  background-color: transparent;
  color: #ffffff;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:active {
  background-color: transparent;
  color: #ffffff;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:disabled {
  color: rgba(211, 218, 227, 0.45);
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:checked {
  background-color: transparent;
  color: #ffffff;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button > image {
  padding: 0 4px;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:first-child:dir(ltr) {
  border-width: 0 1px 0 0;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:first-child:dir(rtl) {
  border-width: 0 0 0 1px;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:not(:first-child):dir(ltr) {
  border-width: 0 0 0 1px;
}

PanelToplevel.mate-panel-menu-bar > grid.horizontal > button:not(:first-child):dir(rtl) {
  border-width: 0 1px 0 0;
}

.mate-panel-menu-bar #clock-applet-button label {
  padding: 0 6px;
}

.mate-panel-menu-bar.vertical menubar > menuitem,
.mate-panel-menu-bar.vertical #PanelApplet-window-menu-applet-button > menuitem {
  padding: 4px 0;
}

.mate-panel-menu-bar.vertical menubar > menuitem:hover,
.mate-panel-menu-bar.vertical #PanelApplet-window-menu-applet-button > menuitem:hover {
  box-shadow: inset 2px 0 #5294e2;
}

.mate-panel-menu-bar.vertical #tasklist-button:hover,
.mate-panel-menu-bar.vertical #clock-applet-button:hover,
.mate-panel-menu-bar.vertical #showdesktop-button:hover {
  box-shadow: inset 2px 0 rgba(255, 255, 255, 0.1);
}

.mate-panel-menu-bar.vertical #tasklist-button:checked, .mate-panel-menu-bar.vertical #tasklist-button:hover:checked,
.mate-panel-menu-bar.vertical #clock-applet-button:checked,
.mate-panel-menu-bar.vertical #clock-applet-button:hover:checked,
.mate-panel-menu-bar.vertical #showdesktop-button:checked,
.mate-panel-menu-bar.vertical #showdesktop-button:hover:checked {
  box-shadow: inset 2px 0 #5294e2;
}

.mate-panel-menu-bar.vertical #clock-applet-button label {
  padding: 6px 0;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button {
  padding: 0 4px;
  border-radius: 0;
  -gtk-outline-radius: 0;
  background-image: none;
  background-color: transparent;
  color: #D3DAE3;
  font-weight: 700;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button:hover {
  background-image: none;
  color: #ffffff;
  box-shadow: inset 0 -2px rgba(255, 255, 255, 0.1);
}

.mate-panel-menu-bar button.flat.toggle.brisk-button:active {
  animation: none;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button:checked {
  background-image: none;
  color: #ffffff;
  box-shadow: inset 0 -2px #5294e2;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button-vertical {
  padding: 0;
}

.mate-panel-menu-bar button.flat.toggle.brisk-button-vertical:hover {
  box-shadow: inset 2px 0 rgba(255, 255, 255, 0.1);
}

.mate-panel-menu-bar button.flat.toggle.brisk-button-vertical:checked {
  box-shadow: inset 2px 0 #5294e2;
}

.brisk-menu entry {
  margin: 0.25rem;
}

.brisk-menu box.horizontal scrolledwindow:dir(ltr) {
  margin: 0.25rem 0.25rem 0.25rem 0;
}

.brisk-menu box.horizontal scrolledwindow:dir(rtl) {
  margin: 0.25rem 0 0.25rem 0.25rem;
}

.brisk-menu .categories-list:dir(ltr) {
  margin: 0.25rem 0 0.25rem 0.25rem;
}

.brisk-menu .categories-list:dir(rtl) {
  margin: 0.25rem 0.25rem 0.25rem 0;
}

.brisk-menu .categories-list button.flat {
  padding-top: unset;
  padding-bottom: unset;
  border-radius: 2px;
  -gtk-outline-radius: 0;
  font-weight: 500;
  transition-duration: 0.1s;
}

.brisk-menu .categories-list button.flat:checked {
  background-color: #5294e2;
  color: #ffffff;
}

.brisk-menu .categories-list button.flat image {
  padding: 0.5rem 0;
}

.brisk-menu .categories-list button.flat label {
  padding-bottom: 0.04375rem;
}

.brisk-menu box.vertical > box.horizontal > box.vertical > separator.horizontal {
  min-height: 0;
  background-color: transparent;
}

.brisk-menu list.content-view.view {
  background-color: #ffffff;
}

.brisk-menu list.content-view.view row.activatable {
  padding: 0;
  background-image: none;
  transition-duration: 0s;
}

.brisk-menu list.content-view.view row.activatable > button.flat {
  padding-top: unset;
  padding-bottom: unset;
  border-radius: 0;
  -gtk-outline-radius: 0;
  font-weight: 400;
  transition-duration: 0s;
  border: none;
}

.brisk-menu list.content-view.view row.activatable > button.flat:hover {
  background-color: rgba(92, 97, 108, 0.06);
}

.brisk-menu list.content-view.view row.activatable > button.flat:active {
  background-color: rgba(92, 97, 108, 0.1);
  color: #5c616c;
}

.brisk-menu list.content-view.view row.activatable > button.flat > box.horizontal > image {
  padding: 0.33125rem 0;
}

.mate-panel-applet-slider {
  background-color: transparent;
}

.mate-panel-applet-slider frame {
  border-width: 1px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.15);
  border-radius: 2px;
  background-color: #fafbfc;
}

.mate-panel-applet-slider frame *,
.mate-panel-applet-slider frame > border {
  border: unset;
}

.caja-notebook {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.caja-side-pane .frame {
  border-width: 1px 0 0;
}

.caja-notebook .frame {
  border-width: 0 0 1px;
}

.caja-canvas-item {
  border-radius: 2px;
}

.caja-desktop > widget.entry, .caja-desktop > widget.entry:focus {
  transition: none;
}

.caja-navigation-window toolbar#Toolbar.primary-toolbar, .caja-navigation-window #Toolbar.primary-toolbar.inline-toolbar {
  background-color: #ffffff;
  color: rgba(82, 93, 118, 0.8);
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame {
  border: none;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame:dir(ltr) {
  border-left: 1px solid #cad5df;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame:dir(rtl) {
  border-right: 1px solid #cad5df;
}

window#MyControlCenter > frame > box.horizontal > widget > scrolledwindow.frame > widget.view {
  all: unset;
  background-color: #fafbfc;
}

.background:not(.csd) > box.horizontal > notebook.frame {
  border: none;
}

.background:not(.csd) > box.horizontal > notebook.frame > stack {
  border-width: 1px;
  border-style: solid;
  border-color: #fafbfc;
  box-shadow: none;
}

.background:not(.csd) > box.horizontal > notebook.frame > stack:dir(ltr) {
  border-left-color: #cad5df;
}

.background:not(.csd) > box.horizontal > notebook.frame > stack:dir(rtl) {
  border-right-color: #cad5df;
}

.eom-window statusbar {
  margin: 0 -10px;
  padding: 0 0.41875rem;
  background-color: #282A33;
  color: #D3DAE3;
}

.pluma-window statusbar frame > border {
  border: none;
}

.pluma-window notebook > stack scrolledwindow {
  border-width: 0 0 1px 0;
}

#pluma-status-combo-button {
  min-height: 0;
  padding: 0;
  border-top: none;
  border-bottom: none;
  border-radius: 0;
}

.atril-window scrolledwindow.frame,
.xreader-window scrolledwindow.frame {
  border-style: solid none none;
}

.atril-window scrolledwindow.frame > .view,
.xreader-window scrolledwindow.frame > .view {
  transition: none;
}

.atril-window toolbar > toolbutton button.flat.image-button, .atril-window .inline-toolbar > toolbutton button.flat.image-button,
.xreader-window toolbar > toolbutton button.flat.image-button,
.xreader-window .inline-toolbar > toolbutton button.flat.image-button {
  border-radius: 2px;
  -gtk-outline-radius: 2px;
}

.atril-window.fullscreen.background > box.vertical,
.xreader-window.fullscreen.background > box.vertical {
  background-color: black;
  transition-duration: 0s;
}

.atril-window.fullscreen.background > box.vertical > toolbar.horizontal:not(.primary-toolbar), .atril-window.fullscreen.background > box.vertical > .inline-toolbar.horizontal:not(.primary-toolbar),
.xreader-window.fullscreen.background > box.vertical > toolbar.horizontal:not(.primary-toolbar),
.xreader-window.fullscreen.background > box.vertical > .inline-toolbar.horizontal:not(.primary-toolbar) {
  border-bottom-color: #cad5df;
}

.atril-window.fullscreen.background > box.vertical > paned.horizontal,
.xreader-window.fullscreen.background > box.vertical > paned.horizontal {
  background-color: #fafbfc;
}

MsdOsdWindow.background.osd {
  border-radius: 2px;
  border: 1px solid rgba(98, 103, 125, 0.55);
  background-color: #282A33;
  box-shadow: none;
}

MsdOsdWindow.background.osd image {
  color: #D3DAE3;
}

MsdOsdWindow.background.osd .trough {
  border-radius: 0;
  border: none;
  background-color: rgba(211, 218, 227, 0.2);
}

MsdOsdWindow.background.osd .progressbar {
  border-radius: 0;
  border: none;
  background-color: #73d216;
}

.slate-notification {
  border-radius: 2px;
}

.slate-notification-window .drop-shadow {
  margin: 4px 6px 10px;
  border-radius: 2px;
}

.drop-shadow button, .raven .raven-header:not(.top) button, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button), .budgie-settings-window buttonbox.inline-toolbar button {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.drop-shadow button:hover, .raven .raven-header:not(.top) button:hover, .budgie-popover:not(.budgie-menu) button.flat:hover:not(.image-button), .budgie-settings-window buttonbox.inline-toolbar button:hover {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 250ms;
}

.drop-shadow button:checked, .raven .raven-header:not(.top) button:checked, .budgie-popover:not(.budgie-menu) button.flat:checked:not(.image-button), .budgie-settings-window buttonbox.inline-toolbar button:checked, .drop-shadow button:active, .raven .raven-header:not(.top) button:active, .budgie-popover:not(.budgie-menu) button.flat:active:not(.image-button), .budgie-settings-window buttonbox.inline-toolbar button:active {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.budgie-panel #tasklist-button:not(.flat), .budgie-panel button {
  color: #D3DAE3;
  background: none;
}

.budgie-panel #tasklist-button:hover:not(.flat), .budgie-panel button:hover {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.05);
}

.budgie-panel #tasklist-button:disabled:not(.flat), .budgie-panel button:disabled {
  color: rgba(211, 218, 227, 0.5);
  background: none;
}

.budgie-panel #tasklist-button:active:not(.flat), .budgie-panel button:active {
  background-color: rgba(255, 255, 255, 0.15);
  color: #ffffff;
}

.budgie-panel #tasklist-button:checked:not(.flat), .budgie-panel button:checked {
  background-color: rgba(255, 255, 255, 0.08);
  color: #ffffff;
}

.budgie-panel #tasklist-button:checked:disabled:not(.flat), .budgie-panel button:checked:disabled {
  background-color: rgba(255, 255, 255, 0.05);
  color: rgba(255, 255, 255, 0.65);
}

.raven-mpris button.image-button, .budgie-panel #tasklist-button.flat:not(.flat), .budgie-panel button.flat {
  color: #D3DAE3;
  background: none;
}

.raven-mpris button.image-button:hover, .budgie-panel #tasklist-button.flat:hover:not(.flat), .budgie-panel button.flat:hover {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.15);
}

.raven-mpris button.image-button:disabled, .budgie-panel #tasklist-button.flat:disabled:not(.flat), .budgie-panel button.flat:disabled {
  color: rgba(211, 218, 227, 0.5);
  background: none;
}

.raven-mpris button.image-button:active, .budgie-panel #tasklist-button.flat:active:not(.flat), .budgie-panel button.flat:active {
  background-color: rgba(255, 255, 255, 0.3);
  color: #ffffff;
}

.raven-mpris button.image-button:checked, .budgie-panel #tasklist-button.flat:checked:not(.flat), .budgie-panel button.flat:checked {
  background-color: rgba(255, 255, 255, 0.2);
  color: #ffffff;
}

.raven-mpris button.image-button:checked:disabled, .budgie-panel #tasklist-button.flat:checked:disabled:not(.flat), .budgie-panel button.flat:checked:disabled {
  background-color: rgba(255, 255, 255, 0.1);
  color: rgba(255, 255, 255, 0.65);
}

.budgie-container {
  background-color: transparent;
}

.budgie-settings-window buttonbox.inline-toolbar {
  border-style: none none solid;
}

.budgie-popover {
  margin: 0;
  padding: 0;
  border-color: rgba(0, 0, 0, 0.15);
  border-radius: 2px;
  background-color: #ffffff;
  box-shadow: 0 3px 5px rgba(0, 0, 0, 0.12), 0 0 0 1px rgba(0, 0, 0, 0.12);
}

.budgie-popover .container {
  padding: 0;
  border: none;
}

.budgie-popover border {
  border: none;
}

.budgie-popover list {
  background-color: transparent;
}

.budgie-popover row.activatable {
  padding: 0;
  background: none;
}

.budgie-popover treeview.view.sidebar {
  min-height: 36px;
  background: none;
  border-right: none;
  color: #5c616c;
}

.budgie-popover treeview.view.sidebar:hover {
  background-color: rgba(92, 97, 108, 0.05);
}

.budgie-popover treeview.view.sidebar:selected, .budgie-popover treeview.view.sidebar:selected:hover {
  color: #ffffff;
  background-color: #5294e2;
}

.budgie-popover > frame.container > grid.horizontal > grid.horizontal > widget > grid.horizontal > stack {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-popover switch {
  margin-left: 56px;
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button) {
  min-height: 28px;
  padding: 0 8px;
  color: rgba(92, 97, 108, 0.85);
  font-weight: normal;
  border: 1px solid transparent;
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button):hover {
  background-color: #f2f3f5;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button):active, .budgie-popover:not(.budgie-menu) button.flat:not(.image-button):checked {
  border: 1px solid #2679db;
  background-color: #5294e2;
}

.budgie-popover:not(.budgie-menu) button.flat:not(.image-button):disabled {
  color: rgba(92, 97, 108, 0.55);
}

.budgie-popover.budgie-menu .container {
  padding: 0;
}

.budgie-popover.user-menu .container {
  padding: 8px;
}

.budgie-popover.user-menu separator {
  margin: 4px 0;
  background-color: rgba(0, 0, 0, 0.15);
}

.budgie-popover.sound-popover separator {
  margin: 3px 0;
  background-color: rgba(0, 0, 0, 0.15);
}

.budgie-popover.night-light-indicator .container {
  padding: 8px;
}

.budgie-popover.places-menu .container {
  padding: 8px;
}

.budgie-popover.places-menu .places-list:not(.always-expand) {
  margin-top: 4px;
  padding-top: 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-popover.places-menu .alternative-label {
  padding: 3px;
  font-size: 15px;
}

.budgie-popover.workspace-popover .container {
  padding: 2px 8px 8px;
}

.budgie-popover.workspace-popover separator {
  margin: 4px 0;
}

.budgie-popover.workspace-popover flowboxchild {
  padding: 0;
}

window.budgie-popover:not(.csd) > frame.container {
  margin: 0 -1px -1px;
}

.bottom window.budgie-popover:not(.csd) > frame.container {
  padding: 2px 0 2px;
}

window.budgie-popover:not(.csd) > frame.container,
window.budgie-popover:not(.csd) > frame.container > border {
  border-style: none;
}

.workspace-switcher .workspace-layout {
  border: 0 solid rgba(255, 255, 255, 0.12);
}

.top .workspace-switcher .workspace-layout:dir(ltr), .bottom .workspace-switcher .workspace-layout:dir(ltr) {
  border-left-width: 1px;
}

.top .workspace-switcher .workspace-layout:dir(rtl), .bottom .workspace-switcher .workspace-layout:dir(rtl) {
  border-right-width: 1px;
}

.left .workspace-switcher .workspace-layout, .right .workspace-switcher .workspace-layout {
  border-top-width: 1px;
}

.workspace-switcher .workspace-item,
.workspace-switcher .workspace-add-button {
  border: 0 solid rgba(255, 255, 255, 0.12);
}

.top .workspace-switcher .workspace-item:dir(ltr), .bottom .workspace-switcher .workspace-item:dir(ltr), .top .workspace-switcher .workspace-add-button:dir(ltr), .bottom .workspace-switcher .workspace-add-button:dir(ltr) {
  border-right-width: 1px;
}

.top .workspace-switcher .workspace-item:dir(rtl), .bottom .workspace-switcher .workspace-item:dir(rtl), .top .workspace-switcher .workspace-add-button:dir(rtl), .bottom .workspace-switcher .workspace-add-button:dir(rtl) {
  border-left-width: 1px;
}

.left .workspace-switcher .workspace-item, .right .workspace-switcher .workspace-item, .left .workspace-switcher .workspace-add-button, .right .workspace-switcher .workspace-add-button {
  border-bottom-width: 1px;
}

.workspace-switcher .workspace-item {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
}

.workspace-switcher .workspace-item.current-workspace {
  background-color: rgba(255, 255, 255, 0.12);
}

.workspace-switcher .workspace-add-button {
  background-color: transparent;
}

.workspace-switcher .workspace-add-button:hover {
  box-shadow: none;
}

.workspace-switcher .workspace-add-button:active {
  background-image: none;
}

.workspace-switcher .workspace-add-button:active image {
  margin: 1px 0 -1px;
}

.budgie-panel .workspace-switcher .workspace-icon-button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 2px;
}

.budgie-menu.background {
  padding: 0;
  background-color: #ffffff;
}

.budgie-menu scrollbar,
.budgie-menu entry.search {
  background-color: transparent;
}

.budgie-menu entry.search {
  padding: 5px 10px;
  border: none;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
  box-shadow: none;
  font-size: 110%;
}

.budgie-menu .categories:dir(ltr) {
  border-bottom-left-radius: 2px;
}

.budgie-menu .categories:dir(rtl) {
  border-bottom-right-radius: 2px;
}

.budgie-menu button {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 0;
  color: #5c616c;
  font-weight: normal;
  border: none;
}

.budgie-menu button:disabled {
  color: rgba(92, 97, 108, 0.55);
}

.budgie-menu button:active, .budgie-menu button:checked {
  border-color: #2679db;
}

.budgie-menu button:checked:disabled {
  background-color: #5294e2;
}

.budgie-menu row {
  padding: 0;
}

.budgie-menu row:hover {
  box-shadow: none;
}

popover.background.user-menu {
  padding: 8px;
}

popover.background.user-menu .content-box {
  background-color: transparent;
}

popover.background.user-menu separator {
  margin: 4px 0;
  background-color: rgba(0, 0, 0, 0.15);
}

popover.background.user-menu row {
  padding: 0;
  box-shadow: none;
  background-image: none;
}

popover.background.places-menu {
  padding: 8px;
}

popover.background.places-menu .name-button.text-button {
  padding-left: 8px;
  padding-right: 8px;
}

popover.background.places-menu .name-button.text-button image:dir(ltr) {
  margin-right: 3px;
}

popover.background.places-menu .name-button.text-button image:dir(rtl) {
  margin-left: 3px;
}

popover.background.places-menu .places-section-header > image:dir(ltr) {
  margin: 0 -2px 0 5px;
}

popover.background.places-menu .places-section-header > image:dir(rtl) {
  margin: 0 5px 0 -2px;
}

popover.background.places-menu .places-list {
  margin-top: 4px;
  padding-top: 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  background-color: transparent;
}

popover.background.places-menu row {
  padding: 0;
  box-shadow: none;
  background-image: none;
}

.budgie-panel {
  transition: background-color 0.2s cubic-bezier(0, 0, 0.2, 1);
  background-color: #21232b;
  color: #D3DAE3;
  font-weight: 500;
}

.budgie-panel.transparent {
  background-color: rgba(33, 35, 43, 0.85);
}

.bottom .budgie-panel.dock-mode {
  border-radius: 5px 5px 0 0;
}

.budgie-panel button {
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  border-radius: 0;
  border: none;
}

.budgie-panel.horizontal button {
  padding: 0 4px;
}

.budgie-panel.vertical button {
  padding: 4px 0;
}

.budgie-panel separator {
  background-color: rgba(211, 218, 227, 0.12);
}

.budgie-panel menubar {
  border: none;
  box-shadow: none;
}

.budgie-panel menubar > menuitem.budgie-menubar {
  border: none;
}

.budgie-panel menubar > menuitem.budgie-menubar:hover {
  background-color: rgba(211, 218, 227, 0.1);
}

.budgie-panel .alert {
  color: #73d216;
}

.budgie-panel #tasklist-button:not(.flat) {
  padding: 0 4px;
  box-shadow: none;
}

.budgie-panel.vertical #tasklist-button {
  min-height: 32px;
}

.budgie-panel button.flat.launcher {
  padding: 0;
}

.budgie-panel button.flat.launcher:not(:checked) {
  color: #D3DAE3;
}

.budgie-panel button.flat.launcher:not(:checked):hover, .budgie-panel button.flat.launcher:not(:checked):active {
  color: rgba(211, 218, 227, 0.8);
}

.budgie-panel button.flat.launcher:not(:checked):disabled {
  color: rgba(211, 218, 227, 0.5);
}

.top window#ValaPanel.background button.flat.-panel-button, window#ValaPanel.background .top button.flat.-panel-button,
.top window#ValaPanel.background button#tasklist-button.toggle.flat,
window#ValaPanel.background .top button#tasklist-button.toggle.flat,
.top window#ValaPanel.background button.flat.-panel-icon-button,
window#ValaPanel.background .top button.flat.-panel-icon-button, .top .budgie-panel #tasklist-button:not(.flat), .budgie-panel .top #tasklist-button:not(.flat), .top .budgie-panel button.flat.launcher, .budgie-panel .top button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at center calc(1px), #5294e2 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.top window#ValaPanel.background button.flat.-panel-button:checked, window#ValaPanel.background .top button.flat.-panel-button:checked,
.top window#ValaPanel.background button#tasklist-button.toggle.flat:checked,
window#ValaPanel.background .top button#tasklist-button.toggle.flat:checked,
.top window#ValaPanel.background button.flat.-panel-icon-button:checked,
window#ValaPanel.background .top button.flat.-panel-icon-button:checked, .top .budgie-panel #tasklist-button:checked:not(.flat), .budgie-panel .top #tasklist-button:checked:not(.flat), .top .budgie-panel button.flat.launcher:checked, .budgie-panel .top button.flat.launcher:checked {
  border-image: radial-gradient(circle closest-corner at center calc(1px), #5294e2 100%, transparent 0%) 2 0 0 0/2px 0 0 0;
}

.bottom window#ValaPanel.background button.flat.-panel-button, window#ValaPanel.background .bottom button.flat.-panel-button,
.bottom window#ValaPanel.background button#tasklist-button.toggle.flat,
window#ValaPanel.background .bottom button#tasklist-button.toggle.flat,
.bottom window#ValaPanel.background button.flat.-panel-icon-button,
window#ValaPanel.background .bottom button.flat.-panel-icon-button, .bottom .budgie-panel #tasklist-button:not(.flat), .budgie-panel .bottom #tasklist-button:not(.flat), .bottom .budgie-panel button.flat.launcher, .budgie-panel .bottom button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.bottom window#ValaPanel.background button.flat.-panel-button:checked, window#ValaPanel.background .bottom button.flat.-panel-button:checked,
.bottom window#ValaPanel.background button#tasklist-button.toggle.flat:checked,
window#ValaPanel.background .bottom button#tasklist-button.toggle.flat:checked,
.bottom window#ValaPanel.background button.flat.-panel-icon-button:checked,
window#ValaPanel.background .bottom button.flat.-panel-icon-button:checked, .bottom .budgie-panel #tasklist-button:checked:not(.flat), .budgie-panel .bottom #tasklist-button:checked:not(.flat), .bottom .budgie-panel button.flat.launcher:checked, .budgie-panel .bottom button.flat.launcher:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 100%, transparent 0%) 0 0 2 0/0 0 2px 0;
}

.left window#ValaPanel.background button.flat.-panel-button, window#ValaPanel.background .left button.flat.-panel-button,
.left window#ValaPanel.background button#tasklist-button.toggle.flat,
window#ValaPanel.background .left button#tasklist-button.toggle.flat,
.left window#ValaPanel.background button.flat.-panel-icon-button,
window#ValaPanel.background .left button.flat.-panel-icon-button, .left .budgie-panel #tasklist-button:not(.flat), .budgie-panel .left #tasklist-button:not(.flat), .left .budgie-panel button.flat.launcher, .budgie-panel .left button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, #5294e2 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.left window#ValaPanel.background button.flat.-panel-button:checked, window#ValaPanel.background .left button.flat.-panel-button:checked,
.left window#ValaPanel.background button#tasklist-button.toggle.flat:checked,
window#ValaPanel.background .left button#tasklist-button.toggle.flat:checked,
.left window#ValaPanel.background button.flat.-panel-icon-button:checked,
window#ValaPanel.background .left button.flat.-panel-icon-button:checked, .left .budgie-panel #tasklist-button:checked:not(.flat), .budgie-panel .left #tasklist-button:checked:not(.flat), .left .budgie-panel button.flat.launcher:checked, .budgie-panel .left button.flat.launcher:checked {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, #5294e2 100%, transparent 0%) 0 0 0 2/0 0 0 2px;
}

.right window#ValaPanel.background button.flat.-panel-button, window#ValaPanel.background .right button.flat.-panel-button,
.right window#ValaPanel.background button#tasklist-button.toggle.flat,
window#ValaPanel.background .right button#tasklist-button.toggle.flat,
.right window#ValaPanel.background button.flat.-panel-icon-button,
window#ValaPanel.background .right button.flat.-panel-icon-button, .right .budgie-panel #tasklist-button:not(.flat), .budgie-panel .right #tasklist-button:not(.flat), .right .budgie-panel button.flat.launcher, .budgie-panel .right button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, #5294e2 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.right window#ValaPanel.background button.flat.-panel-button:checked, window#ValaPanel.background .right button.flat.-panel-button:checked,
.right window#ValaPanel.background button#tasklist-button.toggle.flat:checked,
window#ValaPanel.background .right button#tasklist-button.toggle.flat:checked,
.right window#ValaPanel.background button.flat.-panel-icon-button:checked,
window#ValaPanel.background .right button.flat.-panel-icon-button:checked, .right .budgie-panel #tasklist-button:checked:not(.flat), .budgie-panel .right #tasklist-button:checked:not(.flat), .right .budgie-panel button.flat.launcher:checked, .budgie-panel .right button.flat.launcher:checked {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, #5294e2 100%, transparent 0%) 0 2 0 0/0 2px 0 0;
}


button.flat.launcher {
  min-width: 16px;
  min-height: 16px;
  padding: 0;
  border-radius: 0;
  border: none;
  background-position: center center;
}


button.flat.launcher > image {
  opacity: 0.87;
}


button.flat.launcher:hover {
  -gtk-icon-effect: highlight;
}


button.flat.launcher:hover > image {
  opacity: 1.0;
}


button.flat.launcher:active > image {
  opacity: 1.0;
}


button.flat.launcher:checked:hover {
  -gtk-icon-effect: highlight;
}


button.flat.launcher:checked > image {
  opacity: 1.0;
}


.unpinned button.flat.launcher:hover,
.pinned button.flat.launcher.running:hover,
.pinned button.launcher.running.sidebar-button:hover {
  -gtk-icon-effect: highlight;
}


.unpinned button.flat.launcher > image,
.pinned button.flat.launcher.running > image,
.pinned button.launcher.running.sidebar-button > image {
  background-repeat: no-repeat;
  opacity: 1.0;
}


.unpinned button.flat.launcher:checked > image,
.pinned button.flat.launcher.running:checked > image,
.pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.top .budgie-panel .unpinned button.flat.launcher > image,
.top .budgie-panel .pinned button.flat.launcher.running > image,
.top .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 4px 4px;
  background-position: top center;
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
}

.top .budgie-panel .unpinned button.flat.launcher:checked > image,
.top .budgie-panel .pinned button.flat.launcher.running:checked > image,
.top .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.bottom .budgie-panel .unpinned button.flat.launcher > image,
.bottom .budgie-panel .pinned button.flat.launcher.running > image,
.bottom .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 4px 4px;
  background-position: bottom center;
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
}

.bottom .budgie-panel .unpinned button.flat.launcher:checked > image,
.bottom .budgie-panel .pinned button.flat.launcher.running:checked > image,
.bottom .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.left .budgie-panel .unpinned button.flat.launcher > image,
.left .budgie-panel .pinned button.flat.launcher.running > image,
.left .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 4px 4px;
  background-position: left center;
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
}

.left .budgie-panel .unpinned button.flat.launcher:checked > image,
.left .budgie-panel .pinned button.flat.launcher.running:checked > image,
.left .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

.right .budgie-panel .unpinned button.flat.launcher > image,
.right .budgie-panel .pinned button.flat.launcher.running > image,
.right .budgie-panel .pinned button.launcher.running.sidebar-button > image {
  background-size: 4px 4px;
  background-position: right center;
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
}

.right .budgie-panel .unpinned button.flat.launcher:checked > image,
.right .budgie-panel .pinned button.flat.launcher.running:checked > image,
.right .budgie-panel .pinned button.launcher.running.sidebar-button:checked > image {
  background-image: none;
}

box:not(.unpinned):not(.pinned) > revealer > button.flat.launcher {
  border-image: none;
}

widget.icon-tasklist > box:drop(active),
box.pinned:drop(active) {
  border: none;
  border-radius: 0;
  background-color: rgba(82, 148, 226, 0.2);
  box-shadow: inset 0 0 0 1px #5294e2;
}

*:drop(active):focus,
*:drop(active) {
  box-shadow: inset 0 0 0 1px #5294e2;
}

frame.raven-frame > border {
  border-style: none;
}

.top .shadow-block {
  padding: 0;
  margin: 0;
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.bottom .shadow-block {
  padding: 0;
  margin: 0;
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.left .shadow-block {
  padding: 0;
  margin: 0;
  background-color: transparent;
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.right .shadow-block {
  padding: 0;
  margin: 0;
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

button.raven-trigger:hover, button.raven-trigger:active, button.raven-trigger:checked {
  color: #D3DAE3;
}

.raven {
  background-color: #fafbfc;
}

.raven > box {
  margin-bottom: -10px;
}

.raven > stack {
  margin-bottom: -10px;
}

.raven stackswitcher {
  padding: 0 8px 12px 8px;
}

.raven button.image-button:active, .raven button.image-button:checked {
  background-clip: border-box;
  border-color: #2679db;
}

.raven .raven-header {
  min-height: 36px;
  padding: 3px;
}

.raven .raven-header:not(.top) {
  margin-top: -6px;
}

.raven .raven-header:not(.top) button {
  min-height: 28px;
  min-width: 28px;
  margin: 0;
  padding: 0;
}

.raven .raven-header:not(.top) button.image-button {
  border-radius: 100px;
  -gtk-outline-radius: 100px;
}

.raven .raven-header:not(.top) button.flat:active, .raven .raven-header:not(.top) button.flat:checked {
  background-clip: border-box;
  border-color: #2679db;
}

.raven .raven-header.top {
  padding: 0 6px;
  background-color: #ffffff;
  color: rgba(82, 93, 118, 0.8);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

.raven .raven-header.top stackswitcher {
  padding: 0;
}

.raven .raven-header.top stackswitcher button {
  margin: -4px 0;
  min-height: 36px;
  min-width: 100px;
  border-radius: 0;
  border: none;
  background-color: transparent;
  color: rgba(82, 93, 118, 0.8);
}

.raven .raven-header.top stackswitcher button:hover {
  color: rgba(61, 69, 88, 0.8);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(82, 148, 226, 0.5) 100%, transparent 0%) 0 0 2/0 0 2px;
}

.raven .raven-header.top stackswitcher button:active, .raven .raven-header.top stackswitcher button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #5294e2 100%, transparent 0%) 0 0 2/0 0 2px;
}

.raven .raven-header.top stackswitcher button:disabled {
  color: rgba(82, 93, 118, 0.5);
}

.raven .raven-header.top stackswitcher button:disabled label {
  color: rgba(82, 93, 118, 0.5);
}

.raven .raven-header.top button.image-button:dir(ltr) {
  margin-right: 2px;
}

.raven .raven-header.top button.image-button:dir(rtl) {
  margin-left: 2px;
}

.raven .raven-header.top > image {
  margin: 0 8px;
}

.raven .raven-header.top > label {
  margin: 0 -8px;
  font-weight: bold;
}

.raven .raven-header.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.raven viewport.frame .raven-header {
  margin-top: -8px;
}

.raven .raven-background {
  border-style: solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

.raven .raven-background.middle {
  border-bottom-style: none;
}

.raven .raven-background.frame {
  border-style: solid none;
}

.raven .raven-background > overlay > widget > image {
  color: alpha(currentColor,0.12);
}

.raven .raven-background grid > label:first-child {
  min-height: 26px;
}

.raven .raven-background spinbutton:not(.vertical), .raven .raven-background spinbutton:not(.vertical):focus {
  min-height: 0;
  padding: 2px;
  background-image: none;
  border-color: transparent;
  border-radius: 0;
}

.raven scrolledwindow.raven-background {
  border-bottom-style: none;
}

.raven .raven-header.top + .raven-background {
  border-style: none;
  background-color: #5294e2;
  color: #ffffff;
}

.raven .raven-header.top + .raven-background stackswitcher button {
  margin: -4px 0;
}

.raven .powerstrip button.image-button {
  min-height: 28px;
  min-width: 28px;
  margin: 0 4px;
  padding: 6px;
}

.raven .option-subtitle {
  font-size: smaller;
}

calendar.raven-calendar {
  margin: 2px 0;
  padding: 2px;
  border-style: none;
  background-color: transparent;
}

calendar.raven-calendar:selected {
  border-radius: 3px;
  background-color: #5294e2;
}

box.audio-widget scale.horizontal.marks-after,
window.sound-popover.background scale.horizontal.marks-after {
  padding-top: 0;
  padding-bottom: 0;
}

box.audio-widget scale.horizontal.marks-after mark label,
window.sound-popover.background scale.horizontal.marks-after mark label {
  font-size: 0;
}

.raven-mpris {
  background-color: rgba(0, 0, 0, 0.5);
  color: #ffffff;
}

.raven-mpris label {
  min-height: 24px;
}

.raven-mpris button.image-button {
  padding: 6px;
  border: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame {
  padding: 0;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame list {
  background-color: transparent;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable {
  margin-left: -8px;
  margin-right: -2px;
  background-color: transparent;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable > grid > *,
box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable > box.vertical * {
  color: #5c616c;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable image {
  padding-left: 8px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button {
  min-height: 32px;
  min-width: 32px;
  margin: 8px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button image {
  padding: 0;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:hover {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:active, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  border-color: #2679db;
  background-clip: border-box;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:active image, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable button.image-button:checked image {
  color: white;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list {
  border-radius: 2px;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable:last-child {
  border-bottom: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable:selected {
  background-color: rgba(92, 97, 108, 0.06);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable label {
  padding: 0 16px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable button.image-button {
  min-height: 24px;
  min-width: 24px;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable list > row.activatable button.image-button image {
  padding: 0;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected {
  background-color: rgba(82, 148, 226, 0.75);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected > grid > *,
box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected > box.vertical * {
  color: #ffffff;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button {
  border: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button:hover {
  background-color: rgba(255, 255, 255, 0.25);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button:active, box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected button.image-button:checked {
  background-color: rgba(255, 255, 255, 0.35);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list {
  border: 1px solid rgba(255, 255, 255, 0.12);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list > row.activatable {
  border-bottom: 1px solid rgba(255, 255, 255, 0.12);
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list > row.activatable:last-child {
  border-bottom: none;
}

box.vertical > stack > box.vertical > .raven-background > viewport.frame > list > row.activatable:selected list > row.activatable:selected {
  background-color: rgba(82, 148, 226, 0.65);
}

.devices-list.sound-devices > row.activatable > box.horizontal label {
  padding-left: 8px;
}

.slate-notification-window,
.budgie-notification-window,
.budgie-switcher-window,
.budgie-osd-window {
  background-color: transparent;
  background-image: none;
  border-radius: 2px;
}

.slate-notification-window button,
.budgie-notification-window button,
.budgie-switcher-window button,
.budgie-osd-window button {
  color: rgba(82, 93, 118, 0.8);
  outline-offset: -3px;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

.slate-notification-window button:hover,
.budgie-notification-window button:hover,
.budgie-switcher-window button:hover,
.budgie-osd-window button:hover {
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f2f2f2;
}

.slate-notification-window button:active, .slate-notification-window button:checked,
.budgie-notification-window button:active,
.budgie-switcher-window button:active,
.budgie-osd-window button:active,
.budgie-notification-window button:checked,
.budgie-switcher-window button:checked,
.budgie-osd-window button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.slate-notification-window button:disabled,
.budgie-notification-window button:disabled,
.budgie-switcher-window button:disabled,
.budgie-osd-window button:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0);
}

.slate-notification-window button:disabled label, .slate-notification-window button:disabled,
.budgie-notification-window button:disabled label,
.budgie-switcher-window button:disabled label,
.budgie-osd-window button:disabled label,
.budgie-notification-window button:disabled,
.budgie-switcher-window button:disabled,
.budgie-osd-window button:disabled {
  color: rgba(82, 93, 118, 0.3);
}

.slate-notification .notification-title,
.budgie-notification .notification-title,
.budgie-switcher .notification-title {
  font-size: 120%;
}

.budgie-osd .budgie-osd-text {
  font-size: 120%;
}

.drop-shadow {
  margin: 5px 9px;
  padding: 8px;
  border-radius: 2px;
  box-shadow: 0 5px 5px 0 transparent, 0 8px 15px 0 transparent, 0 3px 3px 0 rgba(0, 0, 0, 0.27);
  background-color: #ffffff;
  color: rgba(82, 93, 118, 0.8);
}

.drop-shadow .linked > button {
  border-radius: 2px;
}

.budgie-run-dialog, .budgie-session-dialog,
.budgie-polkit-dialog {
  border-radius: 2px;
  background-color: #fafbfc;
}

.background.budgie-run-dialog, .background.budgie-session-dialog,
.background.budgie-polkit-dialog {
  border-radius: 2px;
}

.budgie-run-dialog decoration, .budgie-session-dialog decoration,
.budgie-polkit-dialog decoration {
  border-radius: 2px;
}

.budgie-session-dialog .linked.horizontal > button,
.budgie-polkit-dialog .linked.horizontal > button {
  padding: 6px 16px;
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 0;
}

.budgie-session-dialog .linked.horizontal > button:active, .budgie-session-dialog .linked.horizontal > button:checked,
.budgie-polkit-dialog .linked.horizontal > button:active,
.budgie-polkit-dialog .linked.horizontal > button:checked {
  transition: background-color 0.00001s 0.3s;
  animation: ripple_effect 0.3s cubic-bezier(0, 0, 0.2, 1);
}

.budgie-session-dialog .linked.horizontal > button:first-child,
.budgie-polkit-dialog .linked.horizontal > button:first-child {
  border-bottom-left-radius: 2px;
}

.budgie-session-dialog .linked.horizontal > button:last-child,
.budgie-polkit-dialog .linked.horizontal > button:last-child {
  border-bottom-right-radius: 2px;
}

.budgie-session-dialog .linked.horizontal > button:not(.suggested-action):not(.destructive-action):hover,
.budgie-polkit-dialog .linked.horizontal > button:not(.suggested-action):not(.destructive-action):hover {
  background-color: alpha(#5c616c,0.06);
  border-color: rgba(0, 0, 0, 0.15);
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.budgie-session-dialog .linked.horizontal > button:not(.suggested-action):not(.destructive-action):active, .budgie-session-dialog .linked.horizontal > button:not(.suggested-action):not(.destructive-action):checked,
.budgie-polkit-dialog .linked.horizontal > button:not(.suggested-action):not(.destructive-action):active,
.budgie-polkit-dialog .linked.horizontal > button:not(.suggested-action):not(.destructive-action):checked {
  color: #5c616c;
  background-color: alpha(#5c616c,0.1);
  border-color: rgba(0, 0, 0, 0.15);
}

.budgie-polkit-dialog .message {
  color: alpha(currentColor,0.6);
}

.budgie-polkit-dialog .failure {
  color: #F04A50;
}

.budgie-run-dialog {
  background-color: #ffffff;
}

.budgie-run-dialog entry.search {
  font-size: 120%;
  padding: 6px 12px;
  border-radius: 0;
  background-color: transparent;
  border: none;
}

.budgie-run-dialog entry.search:focus {
  border: none;
}

.budgie-run-dialog list .dim-label, .budgie-run-dialog list label.separator, .budgie-run-dialog list headerbar .subtitle, headerbar .budgie-run-dialog list .subtitle, .budgie-run-dialog list .slate-notification .notification-body, .slate-notification .budgie-run-dialog list .notification-body,
.budgie-run-dialog list .budgie-notification .notification-body,
.budgie-notification .budgie-run-dialog list .notification-body,
.budgie-run-dialog list .budgie-switcher .notification-body,
.budgie-switcher .budgie-run-dialog list .notification-body {
  opacity: 1;
}

.budgie-run-dialog scrolledwindow {
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

.budgie-panel box.titlebar {
  min-width: 20px;
  min-height: 20px;
  border-radius: 0;
  background: unset;
  box-shadow: none;
  border: none;
}

.budgie-panel box.titlebar > widget > label {
  color: #D3DAE3;
}

.budgie-panel box.titlebar > button.image-button.titlebutton {
  min-width: 20px;
  min-height: 20px;
  padding: 0;
  margin: 0;
  background: none;
  box-shadow: none;
  color: #D3DAE3;
}

.budgie-panel box.titlebar > button.image-button.titlebutton image {
  border-radius: 100px;
  background-size: 20px 20px;
  background-position: center center;
  background-repeat: no-repeat;
  transition-duration: 0;
}

.budgie-panel box.titlebar > button.image-button.titlebutton:hover, .budgie-panel box.titlebar > button.image-button.titlebutton:active {
  background: none;
  box-shadow: none;
  color: #ffffff;
  animation: none;
}

.budgie-panel box.titlebar > button.image-button.titlebutton.close:hover image {
  background-image: image(#F04A50);
}

.budgie-panel box.titlebar > button.image-button.titlebutton.close:active image {
  background-image: image(#ec1b22);
}

.budgie-panel box.titlebar > button.image-button.titlebutton:not(.close):hover image {
  background-image: image(rgba(255, 255, 255, 0.2));
}

.budgie-panel box.titlebar > button.image-button.titlebutton:not(.close):active image {
  background-image: image(rgba(255, 255, 255, 0.35));
}

.budgie-panel box.titlebar > button.image-button.titlebutton:disabled image {
  opacity: 0;
}

.budgie-panel box.titlebar.horizontal {
  padding: 0 3px;
}

.budgie-panel box.titlebar.horizontal > widget > label:dir(ltr) {
  padding-right: 3px;
}

.budgie-panel box.titlebar.horizontal > widget > label:dir(rtl) {
  padding-left: 3px;
}

.budgie-panel box.titlebar.horizontal > button.image-button.titlebutton {
  padding: 0 3px;
}

.xfce4-panel button, .xfce4-panel button.flat, .mate-panel-menu-bar button,
.mate-panel-menu-bar button#tasklist-button,
panel-toplevel.background button,
panel-toplevel.background button#tasklist-button {
  color: #D3DAE3;
  border-radius: 0;
  border: none;
  background-color: transparent;
}

.xfce4-panel button:hover:not(:active):not(:checked), .mate-panel-menu-bar button:hover:not(:active):not(:checked),
.mate-panel-menu-bar button#tasklist-button:hover:not(:active):not(:checked),
panel-toplevel.background button:hover:not(:active):not(:checked),
panel-toplevel.background button#tasklist-button:hover:not(:active):not(:checked) {
  color: #ffffff;
  box-shadow: inset 0 -2px rgba(82, 148, 226, 0.5);
}

.xfce4-panel button:checked, .mate-panel-menu-bar button:checked,
.mate-panel-menu-bar button#tasklist-button:checked,
panel-toplevel.background button:checked,
panel-toplevel.background button#tasklist-button:checked {
  color: #ffffff;
  box-shadow: inset 0 -2px #5294e2;
}

.xfce4-panel button:checked label, .mate-panel-menu-bar button:checked label,
.mate-panel-menu-bar button#tasklist-button:checked label,
panel-toplevel.background button:checked label,
panel-toplevel.background button#tasklist-button:checked label, .xfce4-panel button:checked image, .mate-panel-menu-bar button:checked image,
.mate-panel-menu-bar button#tasklist-button:checked image,
panel-toplevel.background button:checked image,
panel-toplevel.background button#tasklist-button:checked image {
  color: inherit;
}

.xfce4-panel button:active, .mate-panel-menu-bar button:active,
.mate-panel-menu-bar button#tasklist-button:active,
panel-toplevel.background button:active,
panel-toplevel.background button#tasklist-button:active {
  background-color: rgba(255, 255, 255, 0.12);
  color: #ffffff;
  box-shadow: inset 0 -2px #5294e2;
}

.xfce4-panel.panel {
  background-color: #21232b;
  text-shadow: none;
  -gtk-icon-shadow: none;
  border: none;
}

.XfceHeading {
  border: 0 none transparent;
  background-color: #fafbfc;
  color: #5c616c;
}

.xfce4-panel {
  background-color: #21232b;
  color: #D3DAE3;
  font-weight: 700;
  text-shadow: none;
  -gtk-icon-shadow: none;
}

.xfce4-panel,
.xfce4-panel frame > border {
  border: none;
}

#XfcePanelWindow.xfce4-panel {
  border: none;
}

#XfcePanelWindow.xfce4-panel, #XfcePanelWindow.xfce4-panel.marching-ants {
  transition: none;
}

.xfce4-panel button {
  font-weight: 700;
}

.xfce4-panel button#launcher-arrow:hover, .xfce4-panel button#launcher-arrow + button.toggle:hover {
  box-shadow: none;
}

.xfce4-panel button#launcher-arrow + button.toggle:checked {
  color: #5294e2;
  box-shadow: none;
}

.xfce4-panel button#xfce4-notification-plugin {
  padding: 0 1px;
}

.xfce4-panel menu {
  font-weight: 400;
  text-shadow: none;
  -gtk-icon-effect: none;
}

.xfce4-panel widget.tasklist > button.toggle {
  font-weight: 400;
}

XfdesktopIconView.view {
  border-radius: 2px;
  background: transparent;
  color: #ffffff;
  text-shadow: 0 0 1px rgba(0, 0, 0, 0.26), 0 1px 2px rgba(0, 0, 0, 0.32), 0 2px 3px rgba(0, 0, 0, 0.12);
}

XfdesktopIconView.view:active, XfdesktopIconView.view:checked {
  background-color: #5294e2;
  color: #ffffff;
  text-shadow: none;
}

window#whiskermenu-window {
  background-color: #ffffff;
}

window#whiskermenu-window > frame > border {
  border-radius: 0;
}

window#whiskermenu-window scrolledwindow > viewport button.radio:hover {
  background-color: rgba(0, 0, 0, 0.12);
}

window#whiskermenu-window scrolledwindow > viewport button.radio:checked, window#whiskermenu-window scrolledwindow > viewport button.radio:active {
  background-color: #5294e2;
  color: #ffffff;
}

window#whiskermenu-window scrolledwindow treeview.view:selected:hover {
  background-color: rgba(0, 0, 0, 0.1);
  color: #5c616c;
}

window.thunar .sidebar {
  border-top: none;
}

window.thunar .sidebar treeview.view {
  background-color: #fafbfc;
  color: rgba(92, 97, 108, 0.75);
}

window.thunar .sidebar treeview.view:not(:selected):hover {
  color: #5c616c;
  background-color: #eaecee;
}

window.thunar notebook scrolledwindow.frame.standard-view {
  border-top-width: 0;
  border-right-width: 0;
  background-color: #ffffff;
}

window.thunar notebook scrolledwindow.frame.standard-view .view {
  background-color: transparent;
}

window.thunar notebook scrolledwindow.frame.standard-view widget.view {
  border-radius: 2px;
}

window.thunar notebook header.top tab.reorderable-page > box > label {
  min-height: 0;
}

window.thunar toolbar#location-toolbar, window.thunar #location-toolbar.inline-toolbar {
  background-color: #ffffff;
  color: rgba(82, 93, 118, 0.8);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

window.thunar toolbar#location-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button, window.thunar #location-toolbar.inline-toolbar .linked.path-bar:not(.vertical):not(.stack-switcher) button {
  margin: 0;
  padding: 4px;
}

.menubar.panel .panel, .menubar.panel .panel.color-light, .menubar.panel .panel.color-dark {
  background-color: #21232b;
  background-image: image(#21232b);
  transition: all 100ms ease-in-out;
  color: #D3DAE3;
}

.menubar.panel .panel.maximized {
  background-color: #0b0c0e;
}

.menubar.panel .panel.translucent {
  background-color: rgba(33, 35, 43, 0.95);
}

.menubar.panel .panel menubar {
  background: none;
  box-shadow: none;
  border: none;
}

.menubar.panel-shadow {
  background-image: none;
  background-color: transparent;
}

.menubar.panel popover {
  padding: 2px 4px;
  font-weight: normal;
  border: 1px solid rgba(0, 0, 0, 0.35);
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.12), 0 3px 6px rgba(0, 0, 0, 0.08);
}

.menubar.panel popover button {
  font-weight: normal;
  border-color: transparent;
  background-color: transparent;
}

.menubar.panel popover button:hover {
  border-color: rgba(0, 0, 0, 0.15);
}

.menubar.panel popover button:active, .menubar.panel popover button:checked {
  border-color: #2679db;
}

.menubar.panel popover button:active label, .menubar.panel popover button:checked label {
  color: white;
}

.menubar.panel popover .linked > button {
  border-color: rgba(0, 0, 0, 0.15);
}

.menubar.panel popover list {
  background-color: transparent;
}

.menubar.panel popover separator.horizontal {
  margin: 0 -4px;
}

.menubar.panel popover separator.vertical {
  background-image: image(rgba(0, 0, 0, 0.15));
  margin: 0 2px;
}

.menubar.panel popover .sidebar {
  border-style: none;
  background: none;
}

.menubar.panel popover .sidebar .view {
  background: none;
  border-radius: 2px;
  border: 1px solid transparent;
  color: #5c616c;
  transition: all 180ms cubic-bezier(0, 0, 0.2, 1);
}

.menubar.panel popover .sidebar .view:hover {
  background-color: #f2f3f5;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.menubar.panel popover .sidebar .view:selected, .menubar.panel popover .sidebar .view:active, .menubar.panel popover .sidebar .view:checked, .menubar.panel popover .sidebar .view:active:backdrop, .menubar.panel popover .sidebar .view:checked:backdrop, .menubar.panel popover .sidebar .view:selected:backdrop {
  color: #ffffff;
  background-color: #5294e2;
  border: 1px solid #2679db;
}

button.flat.toggle.switcher {
  -gtk-outline-radius: 100px;
}

button.flat.toggle.switcher:hover image, button.flat.toggle.switcher:active image, button.flat.toggle.switcher:checked image, button.flat.toggle.switcher:selected image {
  color: #5294e2;
}

.circular label:disabled {
  color: rgba(92, 97, 108, 0.55);
}

.circular.accent {
  color: #ffffff;
  background-color: #5294e2;
}

.panel-app-button > GtkWidget > GtkWidget:first-child {
  padding: 0 2px 0 4px;
}

.panel .menu .spinner,
.menu .spinner {
  opacity: 1;
}

.composited-indicator {
  background-color: transparent;
  color: #D3DAE3;
  padding: 0 6px;
}

.composited-indicator > revealer label,
.composited-indicator > revealer image,
.composited-indicator > revealer spinner {
  color: #D3DAE3;
  font-weight: normal;
  text-shadow: none;
  transition: all 200ms ease-in-out;
}

.composited-indicator > revealer image,
.composited-indicator > revealer spinner {
  padding: 3px 0;
}

.composited-indicator > revealer label {
  padding: 3px 6px;
}

.composited-indicator .keyboard {
  background-color: #fff;
  border-radius: 2px;
  box-shadow: none;
  color: #333;
  font-weight: 600;
  padding: 0 3px;
  text-shadow: none;
}

.composited-indicator > GtkWidget > GtkWidget:first-child {
  padding: 0 2px;
}

.composited-indicator .menuitem:active, .composited-indicator .menuitem:hover {
  border-style: none;
}

.composited-indicator > .popup > .menu {
  padding-top: 8px;
  padding-bottom: 8px;
}

BirdieWidgetsTweetList * {
  background-image: none;
  background-color: transparent;
}

MarlinViewWindow *:selected, MarlinViewWindow *:selected:focus {
  color: #ffffff;
  background-color: #5294e2;
  outline-color: transparent;
}

MarlinViewWindow GtkIconView.view:selected, MarlinViewWindow GtkIconView.view:selected:focus, MarlinViewWindow GtkIconView.view:selected:hover, MarlinViewWindow GtkIconView.view:selected:focus:hover {
  background-color: transparent;
}

MarlinViewWindow FMListView, MarlinViewWindow FMColumnView {
  outline-color: transparent;
}

.marlin-pathbar.pathbar {
  border-radius: 3px;
  padding-left: 4px;
  padding-right: 4px;
  color: rgba(82, 93, 118, 0.8);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #f7f7f7;
}

.marlin-pathbar.pathbar image, .marlin-pathbar.pathbar image:hover {
  color: inherit;
}

.marlin-pathbar.pathbar:focus {
  color: rgba(132, 144, 170, 0.8);
  border-color: #5294e2;
  background-color: #fcfcfc;
}

.marlin-pathbar.pathbar:disabled {
  color: rgba(82, 93, 118, 0.35);
  border-color: rgba(0, 0, 0, 0.12);
  background-color: rgba(247, 247, 247, 0.85);
}

.marlin-pathbar.pathbar:active, .marlin-pathbar.pathbar:checked {
  color: #5294e2;
}

treeview.view.sidebar {
  color: #646972;
  background-color: #f6f9fb;
}

treeview.view.sidebar.source-list {
  padding-top: 3px;
  padding-bottom: 3px;
}

treeview.view.sidebar.source-list.has-open-popup, treeview.view.sidebar.source-list:hover {
  color: #646972;
  background-color: #e7ebed;
}

treeview.view.sidebar.source-list:disabled {
  color: rgba(100, 105, 114, 0.35);
}

treeview.view.sidebar.source-list.has-open-popup:selected, treeview.view.sidebar.source-list:selected:hover {
  color: #ffffff;
  background-color: #4a85cb;
}

treeview.view.sidebar.source-list.trough {
  color: #5c616c;
  background-color: rgba(0, 0, 0, 0.15);
  border-radius: 3px;
  border-width: 0;
}

treeview.view.sidebar.source-list.trough:selected, treeview.view.sidebar.source-list.trough:selected:focus {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  border-width: 0;
}

.dynamic-notebook notebook iconview.view.cell:selected {
  background-color: rgba(0, 0, 0, 0.1);
}

.dynamic-notebook notebook .overlay-bar {
  box-shadow: none;
  text-shadow: none;
}

headerbar.titlebar > box.horizontal > entry.pathbar {
  margin-top: 0;
  margin-bottom: 0;
  padding: 2px 12px;
  caret-color: currentColor;
}

headerbar.titlebar button.flat.image-button.toggle {
  margin-top: 4px;
  margin-bottom: 4px;
}

headerbar.titlebar > grid.linked.horizontal.format-bar {
  background-image: image(#ffffff);
  border-bottom: 1px solid transparent;
  border-radius: 0;
}

headerbar.titlebar > grid.linked.horizontal.format-bar:backdrop {
  transition: 200ms ease-out;
  background-image: image(white);
}

popover radiobutton.color-button.color-light, popover radiobutton.color-button.color-dark, popover radiobutton.color-button.color-white {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.gala-notification {
  border: 1px solid rgba(0, 0, 0, 0.35);
  border-radius: 3px;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
  background-image: linear-gradient(to bottom, white, white);
  background-color: transparent;
}

.gala-notification .title, .gala-notification .label {
  color: #5c616c;
}

actionbar.inline-toolbar {
  border: none;
  border-top: 1px solid rgba(0, 0, 0, 0.15);
}

actionbar.inline-toolbar button {
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

actionbar.inline-toolbar button:first-child {
  border-right-style: solid;
}

actionbar.inline-toolbar button:last-child {
  border-left-style: solid;
}

scale.warmth trough {
  background-image: linear-gradient(to right, #5294e2, #F04A50);
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.25);
}

.terminal-window headerbar.titlebar.default-decoration {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
}

.terminal-window .search-bar {
  background-color: #fafbfc;
  border-bottom: 1px solid #cad5df;
}

.terminal-window .dynamic-notebook notebook > header {
  border-color: #cad5df;
}

/***********
 * LightDM *
 ***********/
#panel_window {
  background-color: #21232b;
  color: #D3DAE3;
  font-weight: bold;
  box-shadow: inset 0 -1px #111317;
}

#panel_window menubar {
  padding-left: 5px;
}

#panel_window menubar, #panel_window menubar > menuitem {
  background-color: transparent;
  color: #D3DAE3;
  font-weight: bold;
}

#panel_window menubar menuitem:disabled {
  color: rgba(211, 218, 227, 0.5);
}

#panel_window menubar menuitem:disabled label {
  color: inherit;
}

#panel_window menubar menu > menuitem {
  font-weight: normal;
}

#login_window,
#shutdown_dialog,
#restart_dialog {
  font-weight: normal;
  border-style: none;
  background-color: transparent;
  color: #5c616c;
}

#content_frame {
  padding-bottom: 14px;
  background-color: #fafbfc;
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 1px 1px 0 1px;
}

#content_frame button {
  color: #5c616c;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

#content_frame button:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

#content_frame button:active, #content_frame button:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

#content_frame button:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

#content_frame button:disabled label, #content_frame button:disabled {
  color: rgba(92, 97, 108, 0.55);
}

#buttonbox_frame {
  padding-top: 20px;
  padding-bottom: 0px;
  border-style: none;
  background-color: #282A33;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 0 1px 1px 1px;
  box-shadow: inset 0 1px #d3e1eb;
}

#buttonbox_frame button {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.4);
}

#buttonbox_frame button:hover {
  color: #D3DAE3;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(105, 110, 134, 0.5);
}

#buttonbox_frame button:active, #buttonbox_frame button:checked {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
}

#buttonbox_frame button:disabled {
  color: #5b5f68;
  border-color: rgba(98, 103, 125, 0.55);
  background-color: rgba(89, 94, 114, 0.25);
}

#login_window #user_combobox {
  color: #5c616c;
  font-size: 13px;
}

#login_window #user_combobox menu {
  font-weight: normal;
}

#user_image {
  padding: 3px;
  border-radius: 2px;
}

#shutdown_button.button {
  background-clip: border-box;
  color: green;
  background-color: #F04A50;
  border-color: #ee3239;
}

#shutdown_button.button:hover {
  background-clip: border-box;
  color: green;
  background-color: #f4797e;
  border-color: #f26267;
}

#shutdown_button.button:active, #shutdown_button.button:checked {
  background-clip: border-box;
  color: green;
  background-color: #ec1b22;
  border-color: #db1219;
}

#restart_button.button {
  background-clip: border-box;
  color: green;
  background-color: #5294e2;
  border-color: #3c86de;
}

#restart_button.button:hover {
  background-clip: border-box;
  color: green;
  background-color: #7eafe9;
  border-color: #68a2e6;
}

#restart_button.button:active, #restart_button.button:checked {
  background-clip: border-box;
  color: green;
  background-color: #2679db;
  border-color: #216dc6;
}

#greeter_infobar {
  border-bottom-width: 0;
  font-weight: bold;
}

.overlay-bar {
  background-color: #5294e2;
  border-color: #5294e2;
  border-radius: 2px;
  padding: 3px 6px;
  margin: 3px;
}

.overlay-bar label {
  color: #ffffff;
}

GraniteWidgetsThinPaned {
  background-color: transparent;
  background-image: none;
  margin: 0;
  border-left: 1px solid rgba(0, 0, 0, 0.15);
  border-right: 1px solid rgba(0, 0, 0, 0.15);
}

GraniteWidgetsPopOver .frame,
GraniteWidgetsStaticNotebook .frame {
  border: none;
}

.help_button {
  border-radius: 100px;
  padding: 3px 9px;
}

toolbar.secondary-toolbar, .secondary-toolbar.inline-toolbar {
  padding: 3px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

toolbar.secondary-toolbar button, .secondary-toolbar.inline-toolbar button {
  padding: 0 3px 0 3px;
}

toolbar.bottom-toolbar, .bottom-toolbar.inline-toolbar {
  padding: 5px;
  border-width: 1px 0 0 0;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: #fafbfc;
}

toolbar.bottom-toolbar button, .bottom-toolbar.inline-toolbar button {
  padding: 2px 3px 2px 3px;
}

.source-list {
  -GtkTreeView-horizontal-separator: 1px;
  -GtkTreeView-vertical-separator: 6px;
}

.source-list,
.source-list.view {
  background-color: #fafbfc;
  color: #5c616c;
  -gtk-icon-style: regular;
}

.source-list.category-expander {
  color: transparent;
}

.source-list.view:hover {
  background-color: white;
}

.source-list.view:selected,
.source-list.view:hover:selected,
.source-list.view:selected:focus,
.source-list.category-expander:hover {
  color: #ffffff;
  background-color: #5294e2;
}

.source-list scrollbar,
.source-list junction {
  border-image: none;
  border-color: transparent;
  background-color: #fafbfc;
  background-image: none;
}

.source-list.badge,
.source-list.badge:hover,
.source-list.badge:selected,
.source-list.badge:selected:focus,
.source-list.badge:hover:selected {
  background-image: none;
  background-color: #5294e2;
  color: #ffffff;
  border-radius: 10px;
  padding: 0 6px;
  margin: 0 3px;
  border-width: 0;
}

.source-list.badge:selected,
.source-list.badge:selected:focus,
.source-list.badge:hover:selected {
  background-color: #ffffff;
  color: #5294e2;
}

.source-list.category-expander {
  color: #5c616c;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  -GtkTreeView-expander-size: 16;
}

.source-list.category-expander,
.source-list.category-expander:backdrop {
  color: transparent;
  border: none;
}

.source-list.category-expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

GraniteWidgetsWelcome {
  background-color: #ffffff;
}

GraniteWidgetsWelcome label {
  color: #abaeb4;
  font-size: 11px;
  text-shadow: none;
}

GraniteWidgetsWelcome .h1,
GraniteWidgetsWelcome .h3 {
  color: rgba(92, 97, 108, 0.8);
}

.help_button {
  border-radius: 0;
}

GraniteWidgetsPopOver {
  -GraniteWidgetsPopOver-arrow-width: 21;
  -GraniteWidgetsPopOver-arrow-height: 10;
  -GraniteWidgetsPopOver-border-radius: 2px;
  -GraniteWidgetsPopOver-border-width: 1;
  -GraniteWidgetsPopOver-shadow-size: 12;
  border: 1px solid rgba(0, 0, 0, 0.3);
  margin: 0;
}

.popover_bg {
  background-image: linear-gradient(to bottom, #ffffff, #ffffff);
  border: 1px solid rgba(0, 0, 0, 0.3);
}

GraniteWidgetsPopOver .sidebar.view,
GraniteWidgetsPopOver * {
  background-color: transparent;
}

GraniteWidgetsXsEntry entry {
  padding: 4px;
}

.h1 {
  font-size: 24px;
}

.h2 {
  font-size: 18px;
}

.h3 {
  font-size: 11px;
}

.h4,
.category-label {
  color: #8b8f97;
  font-weight: 600;
}

.h4 {
  padding-bottom: 6px;
  padding-top: 6px;
}

GtkListBox .h4 {
  padding-left: 6px;
}

hdyleaflet > stack > frame > grid.vertical > actionbar, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list, hdyleaflet > stack > frame > grid.vertical, .polari-room-list .sidebar, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list, .sidebar.vertical > paned.geary-sidebar-pane-separator statusbar, .sidebar.vertical > paned.geary-sidebar-pane-separator, .sidebar.vertical > paned.sidebar-pane-separator statusbar, .sidebar.vertical > paned.sidebar-pane-separator, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view, .tweak-categories,
.tweak-category:not(:selected):not(:hover), textview.view.sourceview.gedit-view window#gtk-tooltip, .gedit-map-frame, .gedit-side-panel-paned, .gedit-document-panel-dragged-row, list.gedit-document-panel {
  color: rgba(246, 246, 251, 0.8);
  background-color: #32343D;
}

hdyleaflet > stack > frame > grid.vertical > actionbar:disabled, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list:disabled, hdyleaflet > stack > frame > grid.vertical:disabled, .polari-room-list .sidebar:disabled, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list:disabled, .sidebar.vertical > paned.geary-sidebar-pane-separator statusbar:disabled, .sidebar.vertical > paned.geary-sidebar-pane-separator:disabled, .sidebar.vertical > paned.sidebar-pane-separator statusbar:disabled, .sidebar.vertical > paned.sidebar-pane-separator:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view:disabled, .tweak-categories:disabled,
.tweak-category:disabled:not(:selected):not(:hover), textview.view.sourceview.gedit-view window#gtk-tooltip:disabled, .gedit-map-frame:disabled, .gedit-side-panel-paned:disabled, .gedit-document-panel-dragged-row:disabled, list.gedit-document-panel:disabled, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list label:disabled, hdyleaflet > stack > frame > grid.vertical label:disabled, .polari-room-list .sidebar label:disabled, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal label:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list label:disabled, .sidebar.vertical > paned.geary-sidebar-pane-separator label:disabled, .sidebar.vertical > paned.sidebar-pane-separator label:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list label:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view label:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view label:disabled, .tweak-categories label:disabled,
.tweak-category:not(:selected):not(:hover) label:disabled, textview.view.sourceview.gedit-view window#gtk-tooltip label:disabled, .gedit-map-frame label:disabled, .gedit-side-panel-paned label:disabled, .gedit-document-panel-dragged-row label:disabled, list.gedit-document-panel label:disabled {
  color: rgba(246, 246, 251, 0.35);
}

hdyleaflet > stack > frame > grid.vertical > actionbar button, .polari-entry-area button, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button {
  color: rgba(246, 246, 251, 0.8);
  background-color: rgba(246, 246, 251, 0.15);
  border: none;
}

hdyleaflet > stack > frame > grid.vertical > actionbar button:hover, .polari-entry-area button:hover, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button:hover, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button:hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.25);
}

hdyleaflet > stack > frame > grid.vertical > actionbar button:active, .polari-entry-area button:active, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button:active, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button:active, hdyleaflet > stack > frame > grid.vertical > actionbar button:checked, .polari-entry-area button:checked, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button:checked, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button:checked {
  color: #ffffff;
  background-color: #5294e2;
}

hdyleaflet > stack > frame > grid.vertical > actionbar button:disabled, .polari-entry-area button:disabled, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button:disabled, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button:disabled {
  color: rgba(246, 246, 251, 0.35);
  background-color: rgba(246, 246, 251, 0.08);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable button, hdyleaflet > stack > frame > grid.vertical > actionbar button.flat, .polari-entry-area button.flat, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button.flat, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button.flat {
  border: none;
  background: none;
  box-shadow: none;
  color: rgba(246, 246, 251, 0.8);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable button:hover, hdyleaflet > stack > frame > grid.vertical > actionbar button.flat:hover, .polari-entry-area button.flat:hover, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button.flat:hover, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button.flat:hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.15);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable button:active, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable button:checked, hdyleaflet > stack > frame > grid.vertical > actionbar button.flat:active, .polari-entry-area button.flat:active, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button.flat:active, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button.flat:active, hdyleaflet > stack > frame > grid.vertical > actionbar button.flat:checked, .polari-entry-area button.flat:checked, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button.flat:checked, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button.flat:checked {
  color: #ffffff;
  background-color: #5294e2;
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable button:disabled, hdyleaflet > stack > frame > grid.vertical > actionbar button.flat:disabled, .polari-entry-area button.flat:disabled, window.background.csd > box.horizontal > box.vertical > box.linked.horizontal button.flat:disabled, .gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal button.flat:disabled {
  color: rgba(246, 246, 251, 0.35);
}

hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row, .polari-room-list .sidebar .activatable, .polari-room-list .sidebar .inactive, .polari-room-list .sidebar .room-list-header, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view, .gedit-side-panel-paned treeview.view, list.gedit-document-panel row.activatable {
  color: rgba(246, 246, 251, 0.8);
  background-color: #32343D;
}

hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row:hover, .polari-room-list .sidebar .activatable:hover, .polari-room-list .sidebar .inactive:hover, .polari-room-list .sidebar .room-list-header:hover, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:hover, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar:hover, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar:hover, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view:hover, .gedit-side-panel-paned treeview.view:hover, list.gedit-document-panel row.activatable:hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.1);
}

hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row:disabled, .polari-room-list .sidebar .activatable:disabled, .polari-room-list .sidebar .inactive:disabled, .polari-room-list .sidebar .room-list-header:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:disabled, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar:disabled, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar:disabled, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view:disabled, .gedit-side-panel-paned treeview.view:disabled, list.gedit-document-panel row.activatable:disabled, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row label:disabled, .polari-room-list .sidebar .activatable label:disabled, .polari-room-list .sidebar .inactive label:disabled, .polari-room-list .sidebar .room-list-header label:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable label:disabled, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar label:disabled, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar label:disabled, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view label:disabled, .gedit-side-panel-paned treeview.view label:disabled, list.gedit-document-panel row.activatable label:disabled {
  color: rgba(246, 246, 251, 0.35);
}

hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row.has-open-popup:selected, .polari-room-list .sidebar .activatable.has-open-popup:selected, .polari-room-list .sidebar .inactive.has-open-popup:selected, .polari-room-list .sidebar .room-list-header.has-open-popup:selected, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable.has-open-popup:selected, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar.has-open-popup:selected, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar.has-open-popup:selected, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view.has-open-popup:selected, .gedit-side-panel-paned treeview.view.has-open-popup:selected, list.gedit-document-panel row.activatable.has-open-popup:selected, hdyleaflet > stack > frame > grid.vertical > scrolledwindow > viewport.frame > list.contacts-contact-list row.activatable.contact-data-row:selected:hover, .polari-room-list .sidebar .activatable:selected:hover, .polari-room-list .sidebar .inactive:selected:hover, .polari-room-list .sidebar .room-list-header:selected:hover, window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row.activatable:selected:hover, .sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar:selected:hover, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar:selected:hover, textview.view.sourceview.gedit-view window#gtk-tooltip treeview.view:selected:hover, .gedit-side-panel-paned treeview.view:selected:hover, list.gedit-document-panel row.activatable:selected:hover {
  background-color: #4a85cb;
}

.polari-entry-area, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar, window.geary-main-window > box.vertical > paned > box.vertical > searchbar,
window.background.csd > hdyleaflet > box.vertical > searchbar, window.background.csd > box.horizontal > box.vertical > searchbar {
  background-image: image(#32343D);
  box-shadow: none;
  border: none;
}

.polari-entry-area > revealer > box, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar > revealer > box, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar > revealer > box, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar > revealer > box, window.geary-main-window > box.vertical > paned > box.vertical > searchbar > revealer > box,
window.background.csd > hdyleaflet > box.vertical > searchbar > revealer > box, window.background.csd > box.horizontal > box.vertical > searchbar > revealer > box {
  background: none;
  border: none;
}

.polari-entry-area entry, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar entry, window.geary-main-window > box.vertical > paned > box.vertical > searchbar entry,
window.background.csd > hdyleaflet > box.vertical > searchbar entry, window.background.csd > box.horizontal > box.vertical > searchbar entry {
  color: rgba(246, 246, 251, 0.8);
  background-color: rgba(246, 246, 251, 0.1);
}

.polari-entry-area entry image, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry image, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry image, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar entry image, window.geary-main-window > box.vertical > paned > box.vertical > searchbar entry image,
window.background.csd > hdyleaflet > box.vertical > searchbar entry image, window.background.csd > box.horizontal > box.vertical > searchbar entry image {
  color: rgba(246, 246, 251, 0.8);
}

.polari-entry-area entry:focus, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry:focus, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry:focus, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar entry:focus, window.geary-main-window > box.vertical > paned > box.vertical > searchbar entry:focus,
window.background.csd > hdyleaflet > box.vertical > searchbar entry:focus, window.background.csd > box.horizontal > box.vertical > searchbar entry:focus {
  background-color: rgba(246, 246, 251, 0.12);
}

.polari-entry-area entry:disabled, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry:disabled, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry:disabled, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar entry:disabled, window.geary-main-window > box.vertical > paned > box.vertical > searchbar entry:disabled,
window.background.csd > hdyleaflet > box.vertical > searchbar entry:disabled, window.background.csd > box.horizontal > box.vertical > searchbar entry:disabled, .polari-entry-area entry label:disabled, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry label:disabled, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry label:disabled, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar entry label:disabled, window.geary-main-window > box.vertical > paned > box.vertical > searchbar entry label:disabled,
window.background.csd > hdyleaflet > box.vertical > searchbar entry label:disabled, window.background.csd > box.horizontal > box.vertical > searchbar entry label:disabled, .polari-entry-area entry image:disabled, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry image:disabled, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > searchbar entry image:disabled, window#GearyMainWindow > box.vertical > paned > box.vertical > searchbar entry image:disabled, window.geary-main-window > box.vertical > paned > box.vertical > searchbar entry image:disabled,
window.background.csd > hdyleaflet > box.vertical > searchbar entry image:disabled, window.background.csd > box.horizontal > box.vertical > searchbar entry image:disabled {
  color: rgba(246, 246, 251, 0.35);
}

.selection-mode hdyleaflet headerbar button.titlebutton.close, .geary-titlebar-left button.titlebutton.close, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.close,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.close, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.close, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.close, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.close {
  background-image: -gtk-scaled(url("assets/titlebutton-close-dark.png"), url("assets/titlebutton-close-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.close:backdrop, .geary-titlebar-left button.titlebutton.close:backdrop, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close:backdrop, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close:backdrop, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.close:backdrop,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.close:backdrop, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.close:backdrop, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.close:backdrop, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.close:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-close-backdrop-dark.png"), url("assets/titlebutton-close-backdrop-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.close:hover, .geary-titlebar-left button.titlebutton.close:hover, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close:hover, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close:hover, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.close:hover,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.close:hover, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.close:hover, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.close:hover, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.close:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-close-hover-dark.png"), url("assets/titlebutton-close-hover-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.close:active, .geary-titlebar-left button.titlebutton.close:active, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close:active, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.close:active, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.close:active,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.close:active, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.close:active, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.close:active, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.close:active {
  background-image: -gtk-scaled(url("assets/titlebutton-close-active-dark.png"), url("assets/titlebutton-close-active-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.maximize, .geary-titlebar-left button.titlebutton.maximize, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.maximize,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.maximize, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.maximize, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.maximize, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-dark.png"), url("assets/titlebutton-maximize-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.maximize:backdrop, .geary-titlebar-left button.titlebutton.maximize:backdrop, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize:backdrop, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize:backdrop, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.maximize:backdrop,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.maximize:backdrop, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.maximize:backdrop, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.maximize:backdrop, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-backdrop-dark.png"), url("assets/titlebutton-maximize-backdrop-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.maximize:hover, .geary-titlebar-left button.titlebutton.maximize:hover, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize:hover, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize:hover, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.maximize:hover,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.maximize:hover, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.maximize:hover, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.maximize:hover, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-hover-dark.png"), url("assets/titlebutton-maximize-hover-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.maximize:active, .geary-titlebar-left button.titlebutton.maximize:active, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize:active, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.maximize:active, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.maximize:active,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.maximize:active, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.maximize:active, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.maximize:active, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-maximize-active-dark.png"), url("assets/titlebutton-maximize-active-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.minimize, .geary-titlebar-left button.titlebutton.minimize, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.minimize,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.minimize, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.minimize, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.minimize, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.minimize {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-dark.png"), url("assets/titlebutton-minimize-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.minimize:backdrop, .geary-titlebar-left button.titlebutton.minimize:backdrop, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize:backdrop, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize:backdrop, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.minimize:backdrop,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.minimize:backdrop, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.minimize:backdrop, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.minimize:backdrop, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.minimize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-backdrop-dark.png"), url("assets/titlebutton-minimize-backdrop-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.minimize:hover, .geary-titlebar-left button.titlebutton.minimize:hover, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize:hover, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize:hover, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.minimize:hover,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.minimize:hover, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.minimize:hover, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.minimize:hover, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.minimize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-hover-dark.png"), url("assets/titlebutton-minimize-hover-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.minimize:active, .geary-titlebar-left button.titlebutton.minimize:active, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize:active, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.minimize:active, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.minimize:active,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.minimize:active, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.minimize:active, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.minimize:active, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.minimize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-minimize-active-dark.png"), url("assets/titlebutton-minimize-active-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.restore, .geary-titlebar-left button.titlebutton.restore, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.restore,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.restore, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.restore, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.restore, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.restore {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-dark.png"), url("assets/titlebutton-restore-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.restore:backdrop, .geary-titlebar-left button.titlebutton.restore:backdrop, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore:backdrop, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore:backdrop, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.restore:backdrop,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.restore:backdrop, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.restore:backdrop, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.restore:backdrop, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.restore:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-backdrop-dark.png"), url("assets/titlebutton-restore-backdrop-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.restore:hover, .geary-titlebar-left button.titlebutton.restore:hover, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore:hover, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore:hover, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.restore:hover,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.restore:hover, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.restore:hover, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.restore:hover, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.restore:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-hover-dark.png"), url("assets/titlebutton-restore-hover-dark@2.png"));
}

.selection-mode hdyleaflet headerbar button.titlebutton.restore:active, .geary-titlebar-left button.titlebutton.restore:active, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore:active, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.restore:active, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.restore:active,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.restore:active, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.restore:active, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.restore:active, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.restore:active {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-active-dark.png"), url("assets/titlebutton-restore-active-dark@2.png"));
}

.fullscreen .selection-mode hdyleaflet headerbar button.titlebutton.maximize, .maximized .selection-mode hdyleaflet headerbar button.titlebutton.maximize, window#GearyMainWindow.fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize,
window#GearyMainWindow.maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize, window.background.csd.fullscreen > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize,
window.background.csd.fullscreen > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, window.background.csd.maximized > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize,
window.background.csd.maximized > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, window.background.csd.fullscreen > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, window.background.csd.maximized > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, window.fullscreen.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize,
window.maximized.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, .fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize, .fullscreen window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize, .fullscreen window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize, .fullscreen window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize,
.fullscreen window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, .fullscreen window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, .fullscreen .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize, .fullscreen window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, window.org-gnome-gedit .fullscreen .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, .maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize, .maximized window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize, .maximized window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize, .maximized window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize,
.maximized window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, .maximized window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, .maximized .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize, .maximized window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize, window.org-gnome-gedit .maximized .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-dark.png"), url("assets/titlebutton-restore-dark@2.png"));
}

.fullscreen .selection-mode hdyleaflet headerbar button.titlebutton.maximize:backdrop, .maximized .selection-mode hdyleaflet headerbar button.titlebutton.maximize:backdrop, window#GearyMainWindow.fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:backdrop,
window#GearyMainWindow.maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:backdrop, window.background.csd.fullscreen > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop,
window.background.csd.fullscreen > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, window.background.csd.maximized > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop,
window.background.csd.maximized > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, window.background.csd.fullscreen > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, window.background.csd.maximized > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, window.fullscreen.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop,
window.maximized.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop,
.fullscreen window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize:backdrop, .fullscreen window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, window.org-gnome-gedit .fullscreen .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop,
.maximized window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize:backdrop, .maximized window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop, window.org-gnome-gedit .maximized .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:backdrop {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-backdrop-dark.png"), url("assets/titlebutton-restore-backdrop-dark@2.png"));
}

.fullscreen .selection-mode hdyleaflet headerbar button.titlebutton.maximize:hover, .maximized .selection-mode hdyleaflet headerbar button.titlebutton.maximize:hover, window#GearyMainWindow.fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:hover,
window#GearyMainWindow.maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:hover, window.background.csd.fullscreen > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover,
window.background.csd.fullscreen > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, window.background.csd.maximized > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover,
window.background.csd.maximized > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, window.background.csd.fullscreen > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, window.background.csd.maximized > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, window.fullscreen.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover,
window.maximized.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover,
.fullscreen window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize:hover, .fullscreen window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, window.org-gnome-gedit .fullscreen .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, .maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:hover, .maximized window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:hover, .maximized window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:hover, .maximized window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover,
.maximized window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, .maximized window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, .maximized .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize:hover, .maximized window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover, window.org-gnome-gedit .maximized .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:hover {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-hover-dark.png"), url("assets/titlebutton-restore-hover-dark@2.png"));
}

.fullscreen .selection-mode hdyleaflet headerbar button.titlebutton.maximize:active, .maximized .selection-mode hdyleaflet headerbar button.titlebutton.maximize:active, window#GearyMainWindow.fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:active,
window#GearyMainWindow.maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:active, window.background.csd.fullscreen > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active,
window.background.csd.fullscreen > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, window.background.csd.maximized > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active,
window.background.csd.maximized > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, window.background.csd.fullscreen > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, window.background.csd.maximized > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, window.fullscreen.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active,
window.maximized.org-gnome-gedit > .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, .fullscreen .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:active, .fullscreen window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:active, .fullscreen window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:active, .fullscreen window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active,
.fullscreen window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, .fullscreen window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, .fullscreen .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize:active, .fullscreen window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, window.org-gnome-gedit .fullscreen .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, .maximized .geary-titlebar-left > box.left.horizontal button.titlebutton.maximize:active, .maximized window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:active, .maximized window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical > box.left.horizontal button.titlebutton.maximize:active, .maximized window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active,
.maximized window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, .maximized window.background.csd > box.titlebar.horizontal > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, .maximized .titlebar > headerbar.titlebar.tweak-titlebar-left > box.left.horizontal button.titlebutton.maximize:active, .maximized window.org-gnome-gedit .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active, window.org-gnome-gedit .maximized .titlebar > headerbar:first-child > box.left.horizontal button.titlebutton.maximize:active {
  background-image: -gtk-scaled(url("assets/titlebutton-restore-active-dark.png"), url("assets/titlebutton-restore-active-dark@2.png"));
}

.geary-titlebar-left, .geary-titlebar-left.geary-titlebar, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child, window.background.csd > box.titlebar.horizontal > headerbar:first-child, .titlebar > headerbar.titlebar.tweak-titlebar-left, window.org-gnome-gedit .titlebar > headerbar:first-child {
  color: rgba(246, 246, 251, 0.8);
  background-color: #32343D;
  background-image: image(#32343D);
  border: none;
  box-shadow: none;
}

.geary-titlebar-left button:not(.titlebutton), window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton), window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton), window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button:not(.titlebutton),
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button:not(.titlebutton), window.background.csd > box.titlebar.horizontal > headerbar:first-child button:not(.titlebutton), .titlebar > headerbar.titlebar.tweak-titlebar-left button:not(.titlebutton), window.org-gnome-gedit .titlebar > headerbar:first-child button:not(.titlebutton) {
  color: rgba(246, 246, 251, 0.8);
  border: none;
}

.geary-titlebar-left button:not(.titlebutton):hover, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton):hover, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton):hover, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button:not(.titlebutton):hover,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button:not(.titlebutton):hover, window.background.csd > box.titlebar.horizontal > headerbar:first-child button:not(.titlebutton):hover, .titlebar > headerbar.titlebar.tweak-titlebar-left button:not(.titlebutton):hover, window.org-gnome-gedit .titlebar > headerbar:first-child button:not(.titlebutton):hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.25);
}

.geary-titlebar-left button:not(.titlebutton):active, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton):active, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton):active, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button:not(.titlebutton):active,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button:not(.titlebutton):active, window.background.csd > box.titlebar.horizontal > headerbar:first-child button:not(.titlebutton):active, .titlebar > headerbar.titlebar.tweak-titlebar-left button:not(.titlebutton):active, window.org-gnome-gedit .titlebar > headerbar:first-child button:not(.titlebutton):active, .geary-titlebar-left button:not(.titlebutton):checked, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton):checked, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button:not(.titlebutton):checked, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button:not(.titlebutton):checked,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button:not(.titlebutton):checked, window.background.csd > box.titlebar.horizontal > headerbar:first-child button:not(.titlebutton):checked, .titlebar > headerbar.titlebar.tweak-titlebar-left button:not(.titlebutton):checked, window.org-gnome-gedit .titlebar > headerbar:first-child button:not(.titlebutton):checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.geary-titlebar-left button.titlebutton.appmenu, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.appmenu,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.appmenu, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.appmenu, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.appmenu, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.appmenu {
  border: none;
  min-height: 30px;
  min-width: 30px;
  border-radius: 1000px;
  color: transparent;
  background-color: transparent;
  background-image: -gtk-scaled(url("assets/logo.svg"), url("assets/logo@2.svg"));
  background-repeat: no-repeat;
  background-position: center;
}

.geary-titlebar-left button.titlebutton.appmenu image, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu image, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu image, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.appmenu image,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.appmenu image, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.appmenu image, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.appmenu image, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.appmenu image {
  opacity: 0;
}

.geary-titlebar-left button.titlebutton.appmenu:hover, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu:hover, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu:hover, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.appmenu:hover,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.appmenu:hover, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.appmenu:hover, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.appmenu:hover, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.appmenu:hover {
  background-color: rgba(246, 246, 251, 0.15);
}

.geary-titlebar-left button.titlebutton.appmenu:checked, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu:checked, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu:checked, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.appmenu:checked,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.appmenu:checked, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.appmenu:checked, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.appmenu:checked, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.appmenu:checked, .geary-titlebar-left button.titlebutton.appmenu:active, window#GearyMainWindow > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu:active, window.geary-main-window > overlay > box.vertical > paned.horizontal > box.sidebar.vertical button.titlebutton.appmenu:active, window.background.csd > headerbar.titlebar > box.horizontal > headerbar:first-child button.titlebutton.appmenu:active,
window.background.csd > headerbar.titlebar > hdyleaflet > headerbar:first-child button.titlebutton.appmenu:active, window.background.csd > box.titlebar.horizontal > headerbar:first-child button.titlebutton.appmenu:active, .titlebar > headerbar.titlebar.tweak-titlebar-left button.titlebutton.appmenu:active, window.org-gnome-gedit .titlebar > headerbar:first-child button.titlebutton.appmenu:active {
  background-color: rgba(246, 246, 251, 0.25);
}

.nemo-window .sidebar scrollbar, .nautilus-window placessidebar.sidebar scrollbar {
  border-color: rgba(0, 0, 0, 0.15);
}

.nemo-window .sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider, .nautilus-window placessidebar.sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  background-color: #8a8f98;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.nemo-window .sidebar scrollbar slider, .nautilus-window placessidebar.sidebar scrollbar slider {
  background-color: rgba(138, 143, 152, 0.7);
}

.nemo-window .sidebar scrollbar slider:hover, .nautilus-window placessidebar.sidebar scrollbar slider:hover {
  background-color: #989ca4;
}

.nemo-window .sidebar scrollbar slider:hover:active, .nautilus-window placessidebar.sidebar scrollbar slider:hover:active {
  background-color: #5294e2;
}

.nemo-window .sidebar scrollbar slider:disabled, .nautilus-window placessidebar.sidebar scrollbar slider:disabled {
  background-color: transparent;
}

.nemo-window .sidebar scrollbar trough, .nautilus-window placessidebar.sidebar scrollbar trough {
  background-color: #e4edf3;
}

.nautilus-window headerbar {
  background-image: -gtk-scaled(url("assets/logo.svg"), url("assets/logo@2.svg")), image(#32343D);
  background-repeat: no-repeat;
  background-size: 38px auto;
  background-position: left center;
}

filechooser paned > separator {
  background-image: image(#cad5df);
}

.nautilus-window paned > separator {
  background-image: linear-gradient(to bottom, #d3e1eb, #d3e1eb);
}

.nautilus-window headerbar {
  padding-left: 48px;
}

.nautilus-window headerbar, .nautilus-window headerbar:backdrop {
  box-shadow: inset 0 -1px rgba(50, 52, 61, 0.15), inset 38px 0 0 0 transparent;
}

.nautilus-window placessidebar.sidebar {
  box-shadow: inset 38px 0 0 0 #32343D;
  background-color: #f6f9fb;
}

.nautilus-window placessidebar.sidebar row.sidebar-row {
  transition: none;
  color: #646972;
}

.nautilus-window placessidebar.sidebar row.sidebar-row .sidebar-icon {
  color: rgba(246, 246, 251, 0.85);
}

.nautilus-window placessidebar.sidebar row.sidebar-row image.sidebar-icon {
  padding-right: 2px;
}

.nautilus-window placessidebar.sidebar row.sidebar-row label.sidebar-label {
  padding-right: 2px;
  padding-left: 20px;
}

.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup, .nautilus-window placessidebar.sidebar row.sidebar-row:hover {
  background-color: rgba(100, 105, 114, 0.05);
  box-shadow: inset -2px 0 #7eafe9, inset 38px 0 0 0 #32343D;
}

.nautilus-window placessidebar.sidebar row.sidebar-row:disabled, .nautilus-window placessidebar.sidebar row.sidebar-row:disabled label, .nautilus-window placessidebar.sidebar row.sidebar-row:disabled image {
  color: rgba(100, 105, 114, 0.4);
}

.nautilus-window placessidebar.sidebar row.sidebar-row:active {
  transition: box-shadow 0.2s;
}

.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup:selected, .nautilus-window placessidebar.sidebar row.sidebar-row:selected, .nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover, .nautilus-window placessidebar.sidebar row.sidebar-row:active:hover {
  box-shadow: inset 38px 0 0 0 #5294e2;
  background-color: rgba(82, 148, 226, 0);
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
  background-repeat: no-repeat;
  background-position: 42px center;
}

.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup:selected .sidebar-label, .nautilus-window placessidebar.sidebar row.sidebar-row:selected .sidebar-label, .nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover .sidebar-label, .nautilus-window placessidebar.sidebar row.sidebar-row:active:hover .sidebar-label {
  color: #4c5057;
}

.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover, .nautilus-window placessidebar.sidebar row.sidebar-row:active:hover {
  background-color: rgba(100, 105, 114, 0.05);
  box-shadow: inset -2px 0 #7eafe9, inset 38px 0 0 0 #5294e2;
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
  background-repeat: no-repeat;
  background-position: 42px center;
}

.nautilus-window placessidebar.sidebar row.sidebar-row button.sidebar-button {
  color: #646972;
}

.nautilus-window placessidebar.sidebar row.sidebar-row button.sidebar-button:hover {
  color: #393c43;
  border-color: rgba(0, 0, 0, 0.15);
  background-color: white;
}

.nautilus-window placessidebar.sidebar row.sidebar-row button.sidebar-button:active {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
}

.nautilus-window placessidebar.sidebar row.sidebar-row button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

.nautilus-window placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row {
  color: #5294e2;
}

.nautilus-window placessidebar.sidebar row.sidebar-row:backdrop {
  opacity: 0.75;
}

.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled), .nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) label, .nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) .sidebar-icon {
  color: #F08437;
}

.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected {
  background-color: #F08437;
}

.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected, .nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected label, .nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected .sidebar-icon {
  color: #ffffff;
}

.nautilus-window placessidebar.sidebar separator {
  background-color: transparent;
}

.nemo-window .sidebar {
  color: #646972;
  background-color: #f6f9fb;
}

.nemo-window .sidebar .view, .nemo-window .sidebar row {
  background-color: transparent;
  color: #646972;
}

.nemo-window .sidebar .view.cell.has-open-popup:selected, .nemo-window .sidebar .view.cell:selected:hover, .nemo-window .sidebar row.cell.has-open-popup:selected, .nemo-window .sidebar row.cell:selected:hover {
  color: #ffffff;
  background-color: #4a85cb;
}

.nemo-window .sidebar .view.has-open-popup, .nemo-window .sidebar .view:hover, .nemo-window .sidebar row.has-open-popup, .nemo-window .sidebar row:hover {
  color: #646972;
  background-color: #e7ebed;
}

.nemo-window .sidebar .view.expander, .nemo-window .sidebar row.expander {
  color: #adb1b7;
}

.nemo-window .sidebar .view.expander:hover, .nemo-window .sidebar row.expander:hover {
  color: #646972;
}

.nemo-window .sidebar separator {
  background-color: transparent;
}

window.org-gnome-gedit > paned > separator, window.org-gnome-gedit > paned > separator:backdrop,
window.org-gnome-gedit > overlay > box.vertical > paned > separator,
window.org-gnome-gedit > overlay > box.vertical > paned > separator:backdrop {
  background-image: image(#32343D);
}

.open-document-selector-treeview.view {
  padding: 3px 6px 3px 6px;
  border-color: rgba(0, 0, 0, 0.15);
}

.open-document-selector-treeview.view:hover {
  background-color: #f4f4f5;
}

.open-document-selector-treeview.view:hover:selected {
  color: #ffffff;
  background-color: #5294e2;
}

.open-document-selector-name-label {
  color: #5c616c;
}

.open-document-selector-path-label {
  color: #aeb0b6;
  font-size: smaller;
}

.open-document-selector-path-label:selected {
  color: rgba(255, 255, 255, 0.9);
}

list.gedit-document-panel row.activatable {
  padding: 4px 0;
}

list.gedit-document-panel row button {
  min-width: 22px;
  min-height: 22px;
  padding: 0;
  margin: 0 6px;
  border-radius: 100px;
  -gtk-outline-radius: 100px;
  border: none;
  background: none;
}

list.gedit-document-panel row button:hover {
  color: #ffffff;
  background-color: rgba(246, 246, 251, 0.15);
}

list.gedit-document-panel row button:active, list.gedit-document-panel row button:checked {
  color: #ffffff;
  background-color: rgba(246, 246, 251, 0.25);
}

list.gedit-document-panel row button image {
  color: inherit;
}

list.gedit-document-panel row:hover:not(:selected) button:active, list.gedit-document-panel row:hover:not(:selected) button:checked {
  color: #ffffff;
  background-color: rgba(246, 246, 251, 0.25);
}

.gedit-document-panel-dragged-row {
  border: none;
}

.gedit-side-panel-paned statusbar {
  border-top: 1px solid #cad5df;
  background-color: #fafbfc;
}

.gedit-search-slider {
  background-color: white;
  padding: 6px;
  border-color: rgba(0, 0, 0, 0.15);
  border-radius: 0 0 2px 2px;
  border-width: 0 1px 1px 1px;
  border-style: solid;
}

.gedit-search-entry-occurrences-tag {
  color: rgba(92, 97, 108, 0.6);
  border: none;
  margin: 2px;
  padding: 2px;
}

.gedit-map-frame border {
  border-color: rgba(0, 0, 0, 0.3);
  border-width: 0;
}

.gedit-map-frame border:dir(ltr) {
  border-left-width: 1px;
}

.gedit-map-frame border:dir(rtl) {
  border-right-width: 1px;
}

.gedit-bottom-panel-paned {
  background-color: #ffffff;
}

.gedit-side-panel-paned > separator {
  background-image: linear-gradient(to bottom, #d3e1eb, #d3e1eb);
}

.gedit-bottom-panel-paned > separator {
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15));
}

row#Focus,
row#ClickMethod,
row#StaticWorkspaceTweak,
row#dynamic-workspaces,
row#PrimaryWorkspaceTweak,
row#workspaces-only-on-primary {
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.15);
}

row#Focus row:not(:last-child),
row#ClickMethod row:not(:last-child),
row#StaticWorkspaceTweak row:not(:last-child),
row#dynamic-workspaces row:not(:last-child),
row#PrimaryWorkspaceTweak row:not(:last-child),
row#workspaces-only-on-primary row:not(:last-child) {
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
}

row#Focus.tweak > list,
row#ClickMethod.tweak > list,
row#StaticWorkspaceTweak.tweak > list,
row#dynamic-workspaces.tweak > list,
row#PrimaryWorkspaceTweak.tweak > list,
row#workspaces-only-on-primary.tweak > list {
  margin-top: -3px;
}

row#Focus,
row#ClickMethod,
row#PrimaryWorkspaceTweak,
row#workspaces-only-on-primary {
  margin-top: 4px;
}

row#AutostartTitle.tweak {
  padding: 3px;
  background-color: #ffffff;
}

list#AutostartListBoxTweakGroup.tweak-group-startup {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

.tweak-categories separator,
.tweak-category:not(:selected):not(:hover) separator {
  background: none;
}

.tweak-category:not(:selected):hover {
  color: #F6F6FB;
  background-image: image(rgba(246, 246, 251, 0.06));
}

window.background.csd > box.horizontal:not(.titlebar) > separator.vertical, window.background.csd > box.horizontal:not(.titlebar) > separator.vertical:backdrop {
  background-image: image(#fafbfc);
  background-color: transparent;
}

window.background.csd > headerbar.titlebar > box.horizontal > separator.sidebar,
window.background.csd > headerbar.titlebar > hdyleaflet > separator.sidebar {
  border-right-style: none;
  background: none;
  min-width: 0;
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list separator,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list separator {
  background: none;
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:hover):not(:selected),
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:hover):not(:selected) {
  background-image: image(#32343D);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:selected):hover,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:selected):hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.06);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search {
  color: rgba(246, 246, 251, 0.8);
  background-color: rgba(246, 246, 251, 0.1);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search image,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search image {
  color: rgba(246, 246, 251, 0.8);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search:focus,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search:focus {
  background-color: rgba(246, 246, 251, 0.12);
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search label:disabled, window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search image:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search label:disabled,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack entry.search image:disabled {
  color: rgba(246, 246, 251, 0.35);
}

window.background.csd > box.horizontal > separator.sidebar,
window.background.csd > hdyleaflet > separator.sidebar {
  border-right-style: none;
  background: none;
  min-width: 0;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > border, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > border {
  border-width: 0;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-conversation-frame > border, .sidebar.vertical > paned.sidebar-pane-separator .conversation-frame > border {
  border: none;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-conversation-frame treeview.view, .sidebar.vertical > paned.sidebar-pane-separator .conversation-frame treeview.view {
  color: rgba(246, 246, 251, 0.8);
  background-color: #2b2d35;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-conversation-frame treeview.view:selected, .sidebar.vertical > paned.sidebar-pane-separator .conversation-frame treeview.view:selected {
  background-color: rgba(82, 148, 226, 0.25);
  color: #ffffff;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-conversation-frame treeview.view:selected:dir(ltr), .sidebar.vertical > paned.sidebar-pane-separator .conversation-frame treeview.view:selected:dir(ltr) {
  box-shadow: inset 2px 0 #5294e2;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-conversation-frame treeview.view:selected:dir(rtl), .sidebar.vertical > paned.sidebar-pane-separator .conversation-frame treeview.view:selected:dir(rtl) {
  box-shadow: inset -2px 0 #5294e2;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow:dir(ltr), .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow:dir(ltr) {
  border: none;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow:dir(rtl), .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow:dir(rtl) {
  border: none;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator .geary-folder-frame > scrolledwindow treeview.view.sidebar.cell, .sidebar.vertical > paned.sidebar-pane-separator .folder-frame > scrolledwindow treeview.view.sidebar.cell {
  padding-top: 0.25rem;
  padding-bottom: 0.25rem;
}

window#GearyMainWindow .titlebar, window.geary-main-window .titlebar {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.15);
  background-color: #ffffff;
}

window#GearyMainWindow .titlebar:backdrop, window.geary-main-window .titlebar:backdrop {
  background-color: white;
}

window#GearyMainWindow .titlebar headerbar.geary-titlebar > separator, window.geary-main-window .titlebar headerbar.geary-titlebar > separator {
  margin: 0 -10px 0 0;
}

window#GearyMainWindow > box.vertical > paned > separator, window.geary-main-window > box.vertical > paned > separator {
  background-image: none;
}

.geary-titlebar-left separator {
  margin: 0 -10px 0 0;
  border-right: none;
  background: none;
}

.sidebar.vertical > paned.sidebar-pane-separator separator {
  background: none;
}

.sidebar.vertical > paned.geary-sidebar-pane-separator separator {
  background: none;
}

stack#conversation_viewer scrolledwindow.geary-conversation-scroller > viewport.frame {
  border: none;
}

.geary-accounts-editor-pane > scrolledwindow.frame {
  border: none;
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row > box.vertical > separator.horizontal {
  background: none;
  min-height: 0;
}

window.background.csd > box.horizontal > box.vertical > scrolledwindow > viewport.frame > list row > box.vertical > label:disabled {
  color: #F6F6FB;
}

window.background.csd > box.horizontal > box.vertical > separator.horizontal {
  background: none;
  min-height: 0;
}

window.background.csd > box.horizontal > box.vertical > box.linked.horizontal {
  margin: -6px;
  padding: 6px;
}

.polari-room-list .sidebar {
  margin-top: -1px;
  border-color: #fafbfc;
}

overlay > infobar.info.top {
  margin-bottom: 0;
}

hdyleaflet > stack > frame > grid.vertical > entry.search {
  color: rgba(246, 246, 251, 0.8);
  background-color: rgba(246, 246, 251, 0.1);
}

hdyleaflet > stack > frame > grid.vertical > entry.search image {
  color: rgba(246, 246, 251, 0.8);
}

hdyleaflet > stack > frame > grid.vertical > entry.search:focus {
  background-color: rgba(246, 246, 251, 0.12);
}

hdyleaflet > stack > frame > grid.vertical > entry.search:disabled label, hdyleaflet > stack > frame > grid.vertical > entry.search:disabled image {
  color: rgba(246, 246, 251, 0.35);
}

hdyleaflet > separator.sidebar {
  border-right-style: none;
  background: none;
  min-width: 0;
}

.selection-mode hdyleaflet headerbar {
  color: #ffffff;
  background-color: #5294e2;
  border-color: #4189df;
  box-shadow: none;
}

.selection-mode hdyleaflet headerbar:backdrop {
  background-color: #5294e2;
  color: rgba(255, 255, 255, 0.6);
}

.selection-mode hdyleaflet headerbar .selection-menu {
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

.selection-mode hdyleaflet headerbar .selection-menu GtkArrow {
  -GtkArrow-arrow-scaling: 1;
}

.selection-mode hdyleaflet headerbar .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.maximized .selection-mode hdyleaflet headerbar {
  background-color: #5294e2;
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton), .selection-mode hdyleaflet headerbar button.flat:not(.titlebutton) {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton):hover {
  background-color: alpha(#ffffff,0.3);
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton):active, .selection-mode hdyleaflet headerbar button:not(.titlebutton):checked {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.35);
  border-color: rgba(255, 255, 255, 0.65);
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton):disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.4);
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton):disabled, .selection-mode hdyleaflet headerbar button:not(.titlebutton):disabled label {
  color: rgba(255, 255, 255, 0.5);
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton):disabled:active, .selection-mode hdyleaflet headerbar button:not(.titlebutton):disabled:checked {
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.4);
}

.selection-mode hdyleaflet headerbar button:not(.titlebutton):backdrop {
  opacity: 0.7;
  background: none;
}

.selection-mode hdyleaflet headerbar button.titlebutton.close, .selection-mode hdyleaflet headerbar button.titlebutton.maximize, .selection-mode hdyleaflet headerbar button.titlebutton.minimize {
  color: transparent;
  background-color: transparent;
}

@define-color theme_fg_color #5c616c;
@define-color theme_text_color currentColor;
@define-color theme_bg_color #fafbfc;
@define-color theme_base_color #ffffff;
@define-color theme_selected_bg_color #5294e2;
@define-color theme_selected_fg_color #ffffff;
@define-color fg_color #5c616c;
@define-color text_color currentColor;
@define-color bg_color #fafbfc;
@define-color base_color #ffffff;
@define-color selected_bg_color #5294e2;
@define-color selected_fg_color #ffffff;
@define-color insensitive_bg_color white;
@define-color insensitive_fg_color rgba(92, 97, 108, 0.55);
@define-color insensitive_base_color #ffffff;
@define-color theme_unfocused_fg_color #5c616c;
@define-color theme_unfocused_text_color currentColor;
@define-color theme_unfocused_bg_color #fafbfc;
@define-color theme_unfocused_base_color #ffffff;
@define-color theme_unfocused_selected_bg_color #5294e2;
@define-color theme_unfocused_selected_fg_color #ffffff;
@define-color unfocused_insensitive_color rgba(92, 97, 108, 0.55);
@define-color borders rgba(0, 0, 0, 0.15);
@define-color unfocused_borders rgba(0, 0, 0, 0.15);
@define-color warning_color #F27835;
@define-color error_color #FC4138;
@define-color success_color #73d216;
@define-color placeholder_text_color #A8A8A8;
@define-color link_color #2679db;
@define-color content_view_bg #ffffff;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #ffffff;
@define-color wm_title alpha(#525d76, 0.8);
@define-color wm_unfocused_title alpha(#525d76, 0.5);
@define-color wm_bg white;
@define-color wm_bg_unfocused white;
@define-color wm_highlight white;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border #a6a6a6;
@define-color wm_button_close_bg #f46067;
@define-color wm_button_close_hover_bg #f68086;
@define-color wm_button_close_active_bg #f13039;
@define-color wm_icon_close_bg #F8F8F9;
@define-color wm_button_hover_bg #fdfdfd;
@define-color wm_button_active_bg #5294e2;
@define-color wm_button_hover_border #D1D3DA;
@define-color wm_icon_bg #90949E;
@define-color wm_icon_unfocused_bg #B6B8C0;
@define-color wm_icon_hover_bg #7A7F8B;
@define-color wm_icon_active_bg #ffffff;
@define-color budgie_tasklist_indicator_color #5294e2;
@define-color budgie_tasklist_indicator_color_active #5294e2;
@define-color budgie_tasklist_indicator_color_active_window #3b608e;
@define-color budgie_tasklist_indicator_color_attention #F27835;
@define-color STRAWBERRY_100 #FF9262;
@define-color STRAWBERRY_300 #FF793E;
@define-color STRAWBERRY_500 #F15D22;
@define-color STRAWBERRY_700 #CF3B00;
@define-color STRAWBERRY_900 #AC1800;
@define-color ORANGE_100 #FFDB91;
@define-color ORANGE_300 #FFCA40;
@define-color ORANGE_500 #FAA41A;
@define-color ORANGE_700 #DE8800;
@define-color ORANGE_900 #C26C00;
@define-color BANANA_100 #FFFFA8;
@define-color BANANA_300 #FFFA7D;
@define-color BANANA_500 #FFCE51;
@define-color BANANA_700 #D1A023;
@define-color BANANA_900 #A27100;
@define-color LIME_100 #A2F3BE;
@define-color LIME_300 #8ADBA6;
@define-color LIME_500 #73C48F;
@define-color LIME_700 #479863;
@define-color LIME_900 #1C6D38;
@define-color BLUEBERRY_100 #94A6FF;
@define-color BLUEBERRY_300 #6A7CE0;
@define-color BLUEBERRY_500 #3F51B5;
@define-color BLUEBERRY_700 #213397;
@define-color BLUEBERRY_900 #031579;
@define-color GRAPE_100 #D25DE6;
@define-color GRAPE_300 #B84ACB;
@define-color GRAPE_500 #9C27B0;
@define-color GRAPE_700 #830E97;
@define-color GRAPE_900 #6A007E;
@define-color COCOA_100 #9F9792;
@define-color COCOA_300 #7B736E;
@define-color COCOA_500 #574F4A;
@define-color COCOA_700 #463E39;
@define-color COCOA_900 #342C27;
@define-color SILVER_100 #EEE;
@define-color SILVER_300 #CCC;
@define-color SILVER_500 #AAA;
@define-color SILVER_700 #888;
@define-color SILVER_900 #666;
@define-color SLATE_100 #888;
@define-color SLATE_300 #666;
@define-color SLATE_500 #444;
@define-color SLATE_700 #222;
@define-color SLATE_900 #111;
@define-color BLACK_100 #474341;
@define-color BLACK_300 #403C3A;
@define-color BLACK_500 #393634;
@define-color BLACK_700 #33302F;
@define-color BLACK_900 #2B2928;
